diff -r 60363ba041e2 modules/country/CHANGELOG
--- a/modules/country/CHANGELOG	Wed Jun 26 22:06:39 2019 +0200
+++ b/modules/country/CHANGELOG	Wed Jul 24 18:28:49 2019 +0200
@@ -1,3 +1,5 @@
+* Replace XML data by import script
+
 Version 5.2.0 - 2019-05-06
 * Bug fixes (see mercurial logs for details)
 * Remove starting wildcard when searching on codes and numbers
diff -r 60363ba041e2 modules/country/country.py
--- a/modules/country/country.py	Wed Jun 26 22:06:39 2019 +0200
+++ b/modules/country/country.py	Wed Jul 24 18:28:49 2019 +0200
@@ -1,7 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, DeactivableMixin, fields
+from trytond.pool import Pool
 from trytond.pyson import Eval
+from trytond.transaction import Transaction
 from trytond.tools import lstrip_wildcard
 
 __all__ = ['Country', 'Subdivision', 'Zip']
@@ -28,6 +30,11 @@
 
     @classmethod
     def __register__(cls, module_name):
+        pool = Pool()
+        Data = pool.get('ir.model.data')
+        data = Data.__table__()
+        cursor = Transaction().connection.cursor()
+
         super(Country, cls).__register__(module_name)
 
         table = cls.__table_handler__(module_name)
@@ -39,6 +46,10 @@
         # Migration from 3.8: remove required on code
         table.not_null_action('code', 'remove')
 
+        # Migration from 5.2: remove country data
+        cursor.execute(*data.delete(where=(data.module == 'country')
+                & (data.model == cls.__name__)))
+
     @classmethod
     def search_rec_name(cls, name, clause):
         code_value = clause[2]
@@ -202,6 +213,19 @@
         cls._order.insert(0, ('code', 'ASC'))
 
     @classmethod
+    def __register__(cls, module_name):
+        pool = Pool()
+        Data = pool.get('ir.model.data')
+        data = Data.__table__()
+        cursor = Transaction().connection.cursor()
+
+        super().__register__(module_name)
+
+        # Migration from 5.2: remove country data
+        cursor.execute(*data.delete(where=(data.module == 'country')
+                & (data.model == cls.__name__)))
+
+    @classmethod
     def search_rec_name(cls, name, clause):
         return ['OR',
             ('name',) + tuple(clause[1:]),
diff -r 60363ba041e2 modules/country/data.xml
--- a/modules/country/data.xml	Wed Jun 26 22:06:39 2019 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,36907 +0,0 @@
-<?xml version="1.0"?>
-<tryton>
-    <data skiptest="1" grouped="1">
-
-        <record model="country.country" id="aw">
-            <field name="name">Aruba</field>
-            <field name="code">AW</field>
-            <field name="code3">ABW</field>
-            <field name="code_numeric">533</field>
-        </record>
-
-        <record model="country.country" id="af">
-            <field name="name">Afghanistan</field>
-            <field name="code">AF</field>
-            <field name="code3">AFG</field>
-            <field name="code_numeric">004</field>
-        </record>
-
-        <record model="country.country" id="ao">
-            <field name="name">Angola</field>
-            <field name="code">AO</field>
-            <field name="code3">AGO</field>
-            <field name="code_numeric">024</field>
-        </record>
-
-        <record model="country.country" id="ai">
-            <field name="name">Anguilla</field>
-            <field name="code">AI</field>
-            <field name="code3">AIA</field>
-            <field name="code_numeric">660</field>
-        </record>
-
-        <record model="country.country" id="ax">
-            <field name="name">Åland Islands</field>
-            <field name="code">AX</field>
-            <field name="code3">ALA</field>
-            <field name="code_numeric">248</field>
-        </record>
-
-        <record model="country.country" id="al">
-            <field name="name">Albania</field>
-            <field name="code">AL</field>
-            <field name="code3">ALB</field>
-            <field name="code_numeric">008</field>
-        </record>
-
-        <record model="country.country" id="ad">
-            <field name="name">Andorra</field>
-            <field name="code">AD</field>
-            <field name="code3">AND</field>
-            <field name="code_numeric">020</field>
-        </record>
-
-        <record model="country.country" id="ae">
-            <field name="name">United Arab Emirates</field>
-            <field name="code">AE</field>
-            <field name="code3">ARE</field>
-            <field name="code_numeric">784</field>
-        </record>
-
-        <record model="country.country" id="ar">
-            <field name="name">Argentina</field>
-            <field name="code">AR</field>
-            <field name="code3">ARG</field>
-            <field name="code_numeric">032</field>
-        </record>
-
-        <record model="country.country" id="am">
-            <field name="name">Armenia</field>
-            <field name="code">AM</field>
-            <field name="code3">ARM</field>
-            <field name="code_numeric">051</field>
-        </record>
-
-        <record model="country.country" id="as">
-            <field name="name">American Samoa</field>
-            <field name="code">AS</field>
-            <field name="code3">ASM</field>
-            <field name="code_numeric">016</field>
-        </record>
-
-        <record model="country.country" id="aq">
-            <field name="name">Antarctica</field>
-            <field name="code">AQ</field>
-            <field name="code3">ATA</field>
-            <field name="code_numeric">010</field>
-        </record>
-
-        <record model="country.country" id="tf">
-            <field name="name">French Southern Territories</field>
-            <field name="code">TF</field>
-            <field name="code3">ATF</field>
-            <field name="code_numeric">260</field>
-        </record>
-
-        <record model="country.country" id="ag">
-            <field name="name">Antigua and Barbuda</field>
-            <field name="code">AG</field>
-            <field name="code3">ATG</field>
-            <field name="code_numeric">028</field>
-        </record>
-
-        <record model="country.country" id="au">
-            <field name="name">Australia</field>
-            <field name="code">AU</field>
-            <field name="code3">AUS</field>
-            <field name="code_numeric">036</field>
-        </record>
-
-        <record model="country.country" id="at">
-            <field name="name">Austria</field>
-            <field name="code">AT</field>
-            <field name="code3">AUT</field>
-            <field name="code_numeric">040</field>
-        </record>
-
-        <record model="country.country" id="az">
-            <field name="name">Azerbaijan</field>
-            <field name="code">AZ</field>
-            <field name="code3">AZE</field>
-            <field name="code_numeric">031</field>
-        </record>
-
-        <record model="country.country" id="bi">
-            <field name="name">Burundi</field>
-            <field name="code">BI</field>
-            <field name="code3">BDI</field>
-            <field name="code_numeric">108</field>
-        </record>
-
-        <record model="country.country" id="be">
-            <field name="name">Belgium</field>
-            <field name="code">BE</field>
-            <field name="code3">BEL</field>
-            <field name="code_numeric">056</field>
-        </record>
-
-        <record model="country.country" id="bj">
-            <field name="name">Benin</field>
-            <field name="code">BJ</field>
-            <field name="code3">BEN</field>
-            <field name="code_numeric">204</field>
-        </record>
-
-        <record model="country.country" id="bq">
-            <field name="name">Bonaire, Sint Eustatius and Saba</field>
-            <field name="code">BQ</field>
-            <field name="code3">BES</field>
-            <field name="code_numeric">535</field>
-        </record>
-
-        <record model="country.country" id="bf">
-            <field name="name">Burkina Faso</field>
-            <field name="code">BF</field>
-            <field name="code3">BFA</field>
-            <field name="code_numeric">854</field>
-        </record>
-
-        <record model="country.country" id="bd">
-            <field name="name">Bangladesh</field>
-            <field name="code">BD</field>
-            <field name="code3">BGD</field>
-            <field name="code_numeric">050</field>
-        </record>
-
-        <record model="country.country" id="bg">
-            <field name="name">Bulgaria</field>
-            <field name="code">BG</field>
-            <field name="code3">BGR</field>
-            <field name="code_numeric">100</field>
-        </record>
-
-        <record model="country.country" id="bh">
-            <field name="name">Bahrain</field>
-            <field name="code">BH</field>
-            <field name="code3">BHR</field>
-            <field name="code_numeric">048</field>
-        </record>
-
-        <record model="country.country" id="bs">
-            <field name="name">Bahamas</field>
-            <field name="code">BS</field>
-            <field name="code3">BHS</field>
-            <field name="code_numeric">044</field>
-        </record>
-
-        <record model="country.country" id="ba">
-            <field name="name">Bosnia and Herzegovina</field>
-            <field name="code">BA</field>
-            <field name="code3">BIH</field>
-            <field name="code_numeric">070</field>
-        </record>
-
-        <record model="country.country" id="bl">
-            <field name="name">Saint Barthélemy</field>
-            <field name="code">BL</field>
-            <field name="code3">BLM</field>
-            <field name="code_numeric">652</field>
-        </record>
-
-        <record model="country.country" id="by">
-            <field name="name">Belarus</field>
-            <field name="code">BY</field>
-            <field name="code3">BLR</field>
-            <field name="code_numeric">112</field>
-        </record>
-
-        <record model="country.country" id="bz">
-            <field name="name">Belize</field>
-            <field name="code">BZ</field>
-            <field name="code3">BLZ</field>
-            <field name="code_numeric">084</field>
-        </record>
-
-        <record model="country.country" id="bm">
-            <field name="name">Bermuda</field>
-            <field name="code">BM</field>
-            <field name="code3">BMU</field>
-            <field name="code_numeric">060</field>
-        </record>
-
-        <record model="country.country" id="bo">
-            <field name="name">Bolivia, Plurinational State of</field>
-            <field name="code">BO</field>
-            <field name="code3">BOL</field>
-            <field name="code_numeric">068</field>
-        </record>
-
-        <record model="country.country" id="br">
-            <field name="name">Brazil</field>
-            <field name="code">BR</field>
-            <field name="code3">BRA</field>
-            <field name="code_numeric">076</field>
-        </record>
-
-        <record model="country.country" id="bb">
-            <field name="name">Barbados</field>
-            <field name="code">BB</field>
-            <field name="code3">BRB</field>
-            <field name="code_numeric">052</field>
-        </record>
-
-        <record model="country.country" id="bn">
-            <field name="name">Brunei Darussalam</field>
-            <field name="code">BN</field>
-            <field name="code3">BRN</field>
-            <field name="code_numeric">096</field>
-        </record>
-
-        <record model="country.country" id="bt">
-            <field name="name">Bhutan</field>
-            <field name="code">BT</field>
-            <field name="code3">BTN</field>
-            <field name="code_numeric">064</field>
-        </record>
-
-        <record model="country.country" id="bv">
-            <field name="name">Bouvet Island</field>
-            <field name="code">BV</field>
-            <field name="code3">BVT</field>
-            <field name="code_numeric">074</field>
-        </record>
-
-        <record model="country.country" id="bw">
-            <field name="name">Botswana</field>
-            <field name="code">BW</field>
-            <field name="code3">BWA</field>
-            <field name="code_numeric">072</field>
-        </record>
-
-        <record model="country.country" id="cf">
-            <field name="name">Central African Republic</field>
-            <field name="code">CF</field>
-            <field name="code3">CAF</field>
-            <field name="code_numeric">140</field>
-        </record>
-
-        <record model="country.country" id="ca">
-            <field name="name">Canada</field>
-            <field name="code">CA</field>
-            <field name="code3">CAN</field>
-            <field name="code_numeric">124</field>
-        </record>
-
-        <record model="country.country" id="cc">
-            <field name="name">Cocos (Keeling) Islands</field>
-            <field name="code">CC</field>
-            <field name="code3">CCK</field>
-            <field name="code_numeric">166</field>
-        </record>
-
-        <record model="country.country" id="ch">
-            <field name="name">Switzerland</field>
-            <field name="code">CH</field>
-            <field name="code3">CHE</field>
-            <field name="code_numeric">756</field>
-        </record>
-
-        <record model="country.country" id="cl">
-            <field name="name">Chile</field>
-            <field name="code">CL</field>
-            <field name="code3">CHL</field>
-            <field name="code_numeric">152</field>
-        </record>
-
-        <record model="country.country" id="cn">
-            <field name="name">China</field>
-            <field name="code">CN</field>
-            <field name="code3">CHN</field>
-            <field name="code_numeric">156</field>
-        </record>
-
-        <record model="country.country" id="ci">
-            <field name="name">Côte d'Ivoire</field>
-            <field name="code">CI</field>
-            <field name="code3">CIV</field>
-            <field name="code_numeric">384</field>
-        </record>
-
-        <record model="country.country" id="cm">
-            <field name="name">Cameroon</field>
-            <field name="code">CM</field>
-            <field name="code3">CMR</field>
-            <field name="code_numeric">120</field>
-        </record>
-
-        <record model="country.country" id="cd">
-            <field name="name">Congo, The Democratic Republic of the</field>
-            <field name="code">CD</field>
-            <field name="code3">COD</field>
-            <field name="code_numeric">180</field>
-        </record>
-
-        <record model="country.country" id="cg">
-            <field name="name">Congo</field>
-            <field name="code">CG</field>
-            <field name="code3">COG</field>
-            <field name="code_numeric">178</field>
-        </record>
-
-        <record model="country.country" id="ck">
-            <field name="name">Cook Islands</field>
-            <field name="code">CK</field>
-            <field name="code3">COK</field>
-            <field name="code_numeric">184</field>
-        </record>
-
-        <record model="country.country" id="co">
-            <field name="name">Colombia</field>
-            <field name="code">CO</field>
-            <field name="code3">COL</field>
-            <field name="code_numeric">170</field>
-        </record>
-
-        <record model="country.country" id="km">
-            <field name="name">Comoros</field>
-            <field name="code">KM</field>
-            <field name="code3">COM</field>
-            <field name="code_numeric">174</field>
-        </record>
-
-        <record model="country.country" id="cv">
-            <field name="name">Cabo Verde</field>
-            <field name="code">CV</field>
-            <field name="code3">CPV</field>
-            <field name="code_numeric">132</field>
-        </record>
-
-        <record model="country.country" id="cr">
-            <field name="name">Costa Rica</field>
-            <field name="code">CR</field>
-            <field name="code3">CRI</field>
-            <field name="code_numeric">188</field>
-        </record>
-
-        <record model="country.country" id="cu">
-            <field name="name">Cuba</field>
-            <field name="code">CU</field>
-            <field name="code3">CUB</field>
-            <field name="code_numeric">192</field>
-        </record>
-
-        <record model="country.country" id="cw">
-            <field name="name">Curaçao</field>
-            <field name="code">CW</field>
-            <field name="code3">CUW</field>
-            <field name="code_numeric">531</field>
-        </record>
-
-        <record model="country.country" id="cx">
-            <field name="name">Christmas Island</field>
-            <field name="code">CX</field>
-            <field name="code3">CXR</field>
-            <field name="code_numeric">162</field>
-        </record>
-
-        <record model="country.country" id="ky">
-            <field name="name">Cayman Islands</field>
-            <field name="code">KY</field>
-            <field name="code3">CYM</field>
-            <field name="code_numeric">136</field>
-        </record>
-
-        <record model="country.country" id="cy">
-            <field name="name">Cyprus</field>
-            <field name="code">CY</field>
-            <field name="code3">CYP</field>
-            <field name="code_numeric">196</field>
-        </record>
-
-        <record model="country.country" id="cz">
-            <field name="name">Czechia</field>
-            <field name="code">CZ</field>
-            <field name="code3">CZE</field>
-            <field name="code_numeric">203</field>
-        </record>
-
-        <record model="country.country" id="de">
-            <field name="name">Germany</field>
-            <field name="code">DE</field>
-            <field name="code3">DEU</field>
-            <field name="code_numeric">276</field>
-        </record>
-
-        <record model="country.country" id="dj">
-            <field name="name">Djibouti</field>
-            <field name="code">DJ</field>
-            <field name="code3">DJI</field>
-            <field name="code_numeric">262</field>
-        </record>
-
-        <record model="country.country" id="dm">
-            <field name="name">Dominica</field>
-            <field name="code">DM</field>
-            <field name="code3">DMA</field>
-            <field name="code_numeric">212</field>
-        </record>
-
-        <record model="country.country" id="dk">
-            <field name="name">Denmark</field>
-            <field name="code">DK</field>
-            <field name="code3">DNK</field>
-            <field name="code_numeric">208</field>
-        </record>
-
-        <record model="country.country" id="do">
-            <field name="name">Dominican Republic</field>
-            <field name="code">DO</field>
-            <field name="code3">DOM</field>
-            <field name="code_numeric">214</field>
-        </record>
-
-        <record model="country.country" id="dz">
-            <field name="name">Algeria</field>
-            <field name="code">DZ</field>
-            <field name="code3">DZA</field>
-            <field name="code_numeric">012</field>
-        </record>
-
-        <record model="country.country" id="ec">
-            <field name="name">Ecuador</field>
-            <field name="code">EC</field>
-            <field name="code3">ECU</field>
-            <field name="code_numeric">218</field>
-        </record>
-
-        <record model="country.country" id="eg">
-            <field name="name">Egypt</field>
-            <field name="code">EG</field>
-            <field name="code3">EGY</field>
-            <field name="code_numeric">818</field>
-        </record>
-
-        <record model="country.country" id="er">
-            <field name="name">Eritrea</field>
-            <field name="code">ER</field>
-            <field name="code3">ERI</field>
-            <field name="code_numeric">232</field>
-        </record>
-
-        <record model="country.country" id="eh">
-            <field name="name">Western Sahara</field>
-            <field name="code">EH</field>
-            <field name="code3">ESH</field>
-            <field name="code_numeric">732</field>
-        </record>
-
-        <record model="country.country" id="es">
-            <field name="name">Spain</field>
-            <field name="code">ES</field>
-            <field name="code3">ESP</field>
-            <field name="code_numeric">724</field>
-        </record>
-
-        <record model="country.country" id="ee">
-            <field name="name">Estonia</field>
-            <field name="code">EE</field>
-            <field name="code3">EST</field>
-            <field name="code_numeric">233</field>
-        </record>
-
-        <record model="country.country" id="et">
-            <field name="name">Ethiopia</field>
-            <field name="code">ET</field>
-            <field name="code3">ETH</field>
-            <field name="code_numeric">231</field>
-        </record>
-
-        <record model="country.country" id="fi">
-            <field name="name">Finland</field>
-            <field name="code">FI</field>
-            <field name="code3">FIN</field>
-            <field name="code_numeric">246</field>
-        </record>
-
-        <record model="country.country" id="fj">
-            <field name="name">Fiji</field>
-            <field name="code">FJ</field>
-            <field name="code3">FJI</field>
-            <field name="code_numeric">242</field>
-        </record>
-
-        <record model="country.country" id="fk">
-            <field name="name">Falkland Islands (Malvinas)</field>
-            <field name="code">FK</field>
-            <field name="code3">FLK</field>
-            <field name="code_numeric">238</field>
-        </record>
-
-        <record model="country.country" id="fr">
-            <field name="name">France</field>
-            <field name="code">FR</field>
-            <field name="code3">FRA</field>
-            <field name="code_numeric">250</field>
-        </record>
-
-        <record model="country.country" id="fo">
-            <field name="name">Faroe Islands</field>
-            <field name="code">FO</field>
-            <field name="code3">FRO</field>
-            <field name="code_numeric">234</field>
-        </record>
-
-        <record model="country.country" id="fm">
-            <field name="name">Micronesia, Federated States of</field>
-            <field name="code">FM</field>
-            <field name="code3">FSM</field>
-            <field name="code_numeric">583</field>
-        </record>
-
-        <record model="country.country" id="ga">
-            <field name="name">Gabon</field>
-            <field name="code">GA</field>
-            <field name="code3">GAB</field>
-            <field name="code_numeric">266</field>
-        </record>
-
-        <record model="country.country" id="gb">
-            <field name="name">United Kingdom</field>
-            <field name="code">GB</field>
-            <field name="code3">GBR</field>
-            <field name="code_numeric">826</field>
-        </record>
-
-        <record model="country.country" id="ge">
-            <field name="name">Georgia</field>
-            <field name="code">GE</field>
-            <field name="code3">GEO</field>
-            <field name="code_numeric">268</field>
-        </record>
-
-        <record model="country.country" id="gg">
-            <field name="name">Guernsey</field>
-            <field name="code">GG</field>
-            <field name="code3">GGY</field>
-            <field name="code_numeric">831</field>
-        </record>
-
-        <record model="country.country" id="gh">
-            <field name="name">Ghana</field>
-            <field name="code">GH</field>
-            <field name="code3">GHA</field>
-            <field name="code_numeric">288</field>
-        </record>
-
-        <record model="country.country" id="gi">
-            <field name="name">Gibraltar</field>
-            <field name="code">GI</field>
-            <field name="code3">GIB</field>
-            <field name="code_numeric">292</field>
-        </record>
-
-        <record model="country.country" id="gn">
-            <field name="name">Guinea</field>
-            <field name="code">GN</field>
-            <field name="code3">GIN</field>
-            <field name="code_numeric">324</field>
-        </record>
-
-        <record model="country.country" id="gp">
-            <field name="name">Guadeloupe</field>
-            <field name="code">GP</field>
-            <field name="code3">GLP</field>
-            <field name="code_numeric">312</field>
-        </record>
-
-        <record model="country.country" id="gm">
-            <field name="name">Gambia</field>
-            <field name="code">GM</field>
-            <field name="code3">GMB</field>
-            <field name="code_numeric">270</field>
-        </record>
-
-        <record model="country.country" id="gw">
-            <field name="name">Guinea-Bissau</field>
-            <field name="code">GW</field>
-            <field name="code3">GNB</field>
-            <field name="code_numeric">624</field>
-        </record>
-
-        <record model="country.country" id="gq">
-            <field name="name">Equatorial Guinea</field>
-            <field name="code">GQ</field>
-            <field name="code3">GNQ</field>
-            <field name="code_numeric">226</field>
-        </record>
-
-        <record model="country.country" id="gr">
-            <field name="name">Greece</field>
-            <field name="code">GR</field>
-            <field name="code3">GRC</field>
-            <field name="code_numeric">300</field>
-        </record>
-
-        <record model="country.country" id="gd">
-            <field name="name">Grenada</field>
-            <field name="code">GD</field>
-            <field name="code3">GRD</field>
-            <field name="code_numeric">308</field>
-        </record>
-
-        <record model="country.country" id="gl">
-            <field name="name">Greenland</field>
-            <field name="code">GL</field>
-            <field name="code3">GRL</field>
-            <field name="code_numeric">304</field>
-        </record>
-
-        <record model="country.country" id="gt">
-            <field name="name">Guatemala</field>
-            <field name="code">GT</field>
-            <field name="code3">GTM</field>
-            <field name="code_numeric">320</field>
-        </record>
-
-        <record model="country.country" id="gf">
-            <field name="name">French Guiana</field>
-            <field name="code">GF</field>
-            <field name="code3">GUF</field>
-            <field name="code_numeric">254</field>
-        </record>
-
-        <record model="country.country" id="gu">
-            <field name="name">Guam</field>
-            <field name="code">GU</field>
-            <field name="code3">GUM</field>
-            <field name="code_numeric">316</field>
-        </record>
-
-        <record model="country.country" id="gy">
-            <field name="name">Guyana</field>
-            <field name="code">GY</field>
-            <field name="code3">GUY</field>
-            <field name="code_numeric">328</field>
-        </record>
-
-        <record model="country.country" id="hk">
-            <field name="name">Hong Kong</field>
-            <field name="code">HK</field>
-            <field name="code3">HKG</field>
-            <field name="code_numeric">344</field>
-        </record>
-
-        <record model="country.country" id="hm">
-            <field name="name">Heard Island and McDonald Islands</field>
-            <field name="code">HM</field>
-            <field name="code3">HMD</field>
-            <field name="code_numeric">334</field>
-        </record>
-
-        <record model="country.country" id="hn">
-            <field name="name">Honduras</field>
-            <field name="code">HN</field>
-            <field name="code3">HND</field>
-            <field name="code_numeric">340</field>
-        </record>
-
-        <record model="country.country" id="hr">
-            <field name="name">Croatia</field>
-            <field name="code">HR</field>
-            <field name="code3">HRV</field>
-            <field name="code_numeric">191</field>
-        </record>
-
-        <record model="country.country" id="ht">
-            <field name="name">Haiti</field>
-            <field name="code">HT</field>
-            <field name="code3">HTI</field>
-            <field name="code_numeric">332</field>
-        </record>
-
-        <record model="country.country" id="hu">
-            <field name="name">Hungary</field>
-            <field name="code">HU</field>
-            <field name="code3">HUN</field>
-            <field name="code_numeric">348</field>
-        </record>
-
-        <record model="country.country" id="id">
-            <field name="name">Indonesia</field>
-            <field name="code">ID</field>
-            <field name="code3">IDN</field>
-            <field name="code_numeric">360</field>
-        </record>
-
-        <record model="country.country" id="im">
-            <field name="name">Isle of Man</field>
-            <field name="code">IM</field>
-            <field name="code3">IMN</field>
-            <field name="code_numeric">833</field>
-        </record>
-
-        <record model="country.country" id="in">
-            <field name="name">India</field>
-            <field name="code">IN</field>
-            <field name="code3">IND</field>
-            <field name="code_numeric">356</field>
-        </record>
-
-        <record model="country.country" id="io">
-            <field name="name">British Indian Ocean Territory</field>
-            <field name="code">IO</field>
-            <field name="code3">IOT</field>
-            <field name="code_numeric">086</field>
-        </record>
-
-        <record model="country.country" id="ie">
-            <field name="name">Ireland</field>
-            <field name="code">IE</field>
-            <field name="code3">IRL</field>
-            <field name="code_numeric">372</field>
-        </record>
-
-        <record model="country.country" id="ir">
-            <field name="name">Iran, Islamic Republic of</field>
-            <field name="code">IR</field>
-            <field name="code3">IRN</field>
-            <field name="code_numeric">364</field>
-        </record>
-
-        <record model="country.country" id="iq">
-            <field name="name">Iraq</field>
-            <field name="code">IQ</field>
-            <field name="code3">IRQ</field>
-            <field name="code_numeric">368</field>
-        </record>
-
-        <record model="country.country" id="is">
-            <field name="name">Iceland</field>
-            <field name="code">IS</field>
-            <field name="code3">ISL</field>
-            <field name="code_numeric">352</field>
-        </record>
-
-        <record model="country.country" id="il">
-            <field name="name">Israel</field>
-            <field name="code">IL</field>
-            <field name="code3">ISR</field>
-            <field name="code_numeric">376</field>
-        </record>
-
-        <record model="country.country" id="it">
-            <field name="name">Italy</field>
-            <field name="code">IT</field>
-            <field name="code3">ITA</field>
-            <field name="code_numeric">380</field>
-        </record>
-
-        <record model="country.country" id="jm">
-            <field name="name">Jamaica</field>
-            <field name="code">JM</field>
-            <field name="code3">JAM</field>
-            <field name="code_numeric">388</field>
-        </record>
-
-        <record model="country.country" id="je">
-            <field name="name">Jersey</field>
-            <field name="code">JE</field>
-            <field name="code3">JEY</field>
-            <field name="code_numeric">832</field>
-        </record>
-
-        <record model="country.country" id="jo">
-            <field name="name">Jordan</field>
-            <field name="code">JO</field>
-            <field name="code3">JOR</field>
-            <field name="code_numeric">400</field>
-        </record>
-
-        <record model="country.country" id="jp">
-            <field name="name">Japan</field>
-            <field name="code">JP</field>
-            <field name="code3">JPN</field>
-            <field name="code_numeric">392</field>
-        </record>
-
-        <record model="country.country" id="kz">
-            <field name="name">Kazakhstan</field>
-            <field name="code">KZ</field>
-            <field name="code3">KAZ</field>
-            <field name="code_numeric">398</field>
-        </record>
-
-        <record model="country.country" id="ke">
-            <field name="name">Kenya</field>
-            <field name="code">KE</field>
-            <field name="code3">KEN</field>
-            <field name="code_numeric">404</field>
-        </record>
-
-        <record model="country.country" id="kg">
-            <field name="name">Kyrgyzstan</field>
-            <field name="code">KG</field>
-            <field name="code3">KGZ</field>
-            <field name="code_numeric">417</field>
-        </record>
-
-        <record model="country.country" id="kh">
-            <field name="name">Cambodia</field>
-            <field name="code">KH</field>
-            <field name="code3">KHM</field>
-            <field name="code_numeric">116</field>
-        </record>
-
-        <record model="country.country" id="ki">
-            <field name="name">Kiribati</field>
-            <field name="code">KI</field>
-            <field name="code3">KIR</field>
-            <field name="code_numeric">296</field>
-        </record>
-
-        <record model="country.country" id="kn">
-            <field name="name">Saint Kitts and Nevis</field>
-            <field name="code">KN</field>
-            <field name="code3">KNA</field>
-            <field name="code_numeric">659</field>
-        </record>
-
-        <record model="country.country" id="kr">
-            <field name="name">Korea, Republic of</field>
-            <field name="code">KR</field>
-            <field name="code3">KOR</field>
-            <field name="code_numeric">410</field>
-        </record>
-
-        <record model="country.country" id="kw">
-            <field name="name">Kuwait</field>
-            <field name="code">KW</field>
-            <field name="code3">KWT</field>
-            <field name="code_numeric">414</field>
-        </record>
-
-        <record model="country.country" id="la">
-            <field name="name">Lao People's Democratic Republic</field>
-            <field name="code">LA</field>
-            <field name="code3">LAO</field>
-            <field name="code_numeric">418</field>
-        </record>
-
-        <record model="country.country" id="lb">
-            <field name="name">Lebanon</field>
-            <field name="code">LB</field>
-            <field name="code3">LBN</field>
-            <field name="code_numeric">422</field>
-        </record>
-
-        <record model="country.country" id="lr">
-            <field name="name">Liberia</field>
-            <field name="code">LR</field>
-            <field name="code3">LBR</field>
-            <field name="code_numeric">430</field>
-        </record>
-
-        <record model="country.country" id="ly">
-            <field name="name">Libya</field>
-            <field name="code">LY</field>
-            <field name="code3">LBY</field>
-            <field name="code_numeric">434</field>
-        </record>
-
-        <record model="country.country" id="lc">
-            <field name="name">Saint Lucia</field>
-            <field name="code">LC</field>
-            <field name="code3">LCA</field>
-            <field name="code_numeric">662</field>
-        </record>
-
-        <record model="country.country" id="li">
-            <field name="name">Liechtenstein</field>
-            <field name="code">LI</field>
-            <field name="code3">LIE</field>
-            <field name="code_numeric">438</field>
-        </record>
-
-        <record model="country.country" id="lk">
-            <field name="name">Sri Lanka</field>
-            <field name="code">LK</field>
-            <field name="code3">LKA</field>
-            <field name="code_numeric">144</field>
-        </record>
-
-        <record model="country.country" id="ls">
-            <field name="name">Lesotho</field>
-            <field name="code">LS</field>
-            <field name="code3">LSO</field>
-            <field name="code_numeric">426</field>
-        </record>
-
-        <record model="country.country" id="lt">
-            <field name="name">Lithuania</field>
-            <field name="code">LT</field>
-            <field name="code3">LTU</field>
-            <field name="code_numeric">440</field>
-        </record>
-
-        <record model="country.country" id="lu">
-            <field name="name">Luxembourg</field>
-            <field name="code">LU</field>
-            <field name="code3">LUX</field>
-            <field name="code_numeric">442</field>
-        </record>
-
-        <record model="country.country" id="lv">
-            <field name="name">Latvia</field>
-            <field name="code">LV</field>
-            <field name="code3">LVA</field>
-            <field name="code_numeric">428</field>
-        </record>
-
-        <record model="country.country" id="mo">
-            <field name="name">Macao</field>
-            <field name="code">MO</field>
-            <field name="code3">MAC</field>
-            <field name="code_numeric">446</field>
-        </record>
-
-        <record model="country.country" id="mf">
-            <field name="name">Saint Martin (French part)</field>
-            <field name="code">MF</field>
-            <field name="code3">MAF</field>
-            <field name="code_numeric">663</field>
-        </record>
-
-        <record model="country.country" id="ma">
-            <field name="name">Morocco</field>
-            <field name="code">MA</field>
-            <field name="code3">MAR</field>
-            <field name="code_numeric">504</field>
-        </record>
-
-        <record model="country.country" id="mc">
-            <field name="name">Monaco</field>
-            <field name="code">MC</field>
-            <field name="code3">MCO</field>
-            <field name="code_numeric">492</field>
-        </record>
-
-        <record model="country.country" id="md">
-            <field name="name">Moldova, Republic of</field>
-            <field name="code">MD</field>
-            <field name="code3">MDA</field>
-            <field name="code_numeric">498</field>
-        </record>
-
-        <record model="country.country" id="mg">
-            <field name="name">Madagascar</field>
-            <field name="code">MG</field>
-            <field name="code3">MDG</field>
-            <field name="code_numeric">450</field>
-        </record>
-
-        <record model="country.country" id="mv">
-            <field name="name">Maldives</field>
-            <field name="code">MV</field>
-            <field name="code3">MDV</field>
-            <field name="code_numeric">462</field>
-        </record>
-
-        <record model="country.country" id="mx">
-            <field name="name">Mexico</field>
-            <field name="code">MX</field>
-            <field name="code3">MEX</field>
-            <field name="code_numeric">484</field>
-        </record>
-
-        <record model="country.country" id="mh">
-            <field name="name">Marshall Islands</field>
-            <field name="code">MH</field>
-            <field name="code3">MHL</field>
-            <field name="code_numeric">584</field>
-        </record>
-
-        <record model="country.country" id="mk">
-            <field name="name">Macedonia, Republic of</field>
-            <field name="code">MK</field>
-            <field name="code3">MKD</field>
-            <field name="code_numeric">807</field>
-        </record>
-
-        <record model="country.country" id="ml">
-            <field name="name">Mali</field>
-            <field name="code">ML</field>
-            <field name="code3">MLI</field>
-            <field name="code_numeric">466</field>
-        </record>
-
-        <record model="country.country" id="mt">
-            <field name="name">Malta</field>
-            <field name="code">MT</field>
-            <field name="code3">MLT</field>
-            <field name="code_numeric">470</field>
-        </record>
-
-        <record model="country.country" id="mm">
-            <field name="name">Myanmar</field>
-            <field name="code">MM</field>
-            <field name="code3">MMR</field>
-            <field name="code_numeric">104</field>
-        </record>
-
-        <record model="country.country" id="me">
-            <field name="name">Montenegro</field>
-            <field name="code">ME</field>
-            <field name="code3">MNE</field>
-            <field name="code_numeric">499</field>
-        </record>
-
-        <record model="country.country" id="mn">
-            <field name="name">Mongolia</field>
-            <field name="code">MN</field>
-            <field name="code3">MNG</field>
-            <field name="code_numeric">496</field>
-        </record>
-
-        <record model="country.country" id="mp">
-            <field name="name">Northern Mariana Islands</field>
-            <field name="code">MP</field>
-            <field name="code3">MNP</field>
-            <field name="code_numeric">580</field>
-        </record>
-
-        <record model="country.country" id="mz">
-            <field name="name">Mozambique</field>
-            <field name="code">MZ</field>
-            <field name="code3">MOZ</field>
-            <field name="code_numeric">508</field>
-        </record>
-
-        <record model="country.country" id="mr">
-            <field name="name">Mauritania</field>
-            <field name="code">MR</field>
-            <field name="code3">MRT</field>
-            <field name="code_numeric">478</field>
-        </record>
-
-        <record model="country.country" id="ms">
-            <field name="name">Montserrat</field>
-            <field name="code">MS</field>
-            <field name="code3">MSR</field>
-            <field name="code_numeric">500</field>
-        </record>
-
-        <record model="country.country" id="mq">
-            <field name="name">Martinique</field>
-            <field name="code">MQ</field>
-            <field name="code3">MTQ</field>
-            <field name="code_numeric">474</field>
-        </record>
-
-        <record model="country.country" id="mu">
-            <field name="name">Mauritius</field>
-            <field name="code">MU</field>
-            <field name="code3">MUS</field>
-            <field name="code_numeric">480</field>
-        </record>
-
-        <record model="country.country" id="mw">
-            <field name="name">Malawi</field>
-            <field name="code">MW</field>
-            <field name="code3">MWI</field>
-            <field name="code_numeric">454</field>
-        </record>
-
-        <record model="country.country" id="my">
-            <field name="name">Malaysia</field>
-            <field name="code">MY</field>
-            <field name="code3">MYS</field>
-            <field name="code_numeric">458</field>
-        </record>
-
-        <record model="country.country" id="yt">
-            <field name="name">Mayotte</field>
-            <field name="code">YT</field>
-            <field name="code3">MYT</field>
-            <field name="code_numeric">175</field>
-        </record>
-
-        <record model="country.country" id="na">
-            <field name="name">Namibia</field>
-            <field name="code">NA</field>
-            <field name="code3">NAM</field>
-            <field name="code_numeric">516</field>
-        </record>
-
-        <record model="country.country" id="nc">
-            <field name="name">New Caledonia</field>
-            <field name="code">NC</field>
-            <field name="code3">NCL</field>
-            <field name="code_numeric">540</field>
-        </record>
-
-        <record model="country.country" id="ne">
-            <field name="name">Niger</field>
-            <field name="code">NE</field>
-            <field name="code3">NER</field>
-            <field name="code_numeric">562</field>
-        </record>
-
-        <record model="country.country" id="nf">
-            <field name="name">Norfolk Island</field>
-            <field name="code">NF</field>
-            <field name="code3">NFK</field>
-            <field name="code_numeric">574</field>
-        </record>
-
-        <record model="country.country" id="ng">
-            <field name="name">Nigeria</field>
-            <field name="code">NG</field>
-            <field name="code3">NGA</field>
-            <field name="code_numeric">566</field>
-        </record>
-
-        <record model="country.country" id="ni">
-            <field name="name">Nicaragua</field>
-            <field name="code">NI</field>
-            <field name="code3">NIC</field>
-            <field name="code_numeric">558</field>
-        </record>
-
-        <record model="country.country" id="nu">
-            <field name="name">Niue</field>
-            <field name="code">NU</field>
-            <field name="code3">NIU</field>
-            <field name="code_numeric">570</field>
-        </record>
-
-        <record model="country.country" id="nl">
-            <field name="name">Netherlands</field>
-            <field name="code">NL</field>
-            <field name="code3">NLD</field>
-            <field name="code_numeric">528</field>
-        </record>
-
-        <record model="country.country" id="no">
-            <field name="name">Norway</field>
-            <field name="code">NO</field>
-            <field name="code3">NOR</field>
-            <field name="code_numeric">578</field>
-        </record>
-
-        <record model="country.country" id="np">
-            <field name="name">Nepal</field>
-            <field name="code">NP</field>
-            <field name="code3">NPL</field>
-            <field name="code_numeric">524</field>
-        </record>
-
-        <record model="country.country" id="nr">
-            <field name="name">Nauru</field>
-            <field name="code">NR</field>
-            <field name="code3">NRU</field>
-            <field name="code_numeric">520</field>
-        </record>
-
-        <record model="country.country" id="nz">
-            <field name="name">New Zealand</field>
-            <field name="code">NZ</field>
-            <field name="code3">NZL</field>
-            <field name="code_numeric">554</field>
-        </record>
-
-        <record model="country.country" id="om">
-            <field name="name">Oman</field>
-            <field name="code">OM</field>
-            <field name="code3">OMN</field>
-            <field name="code_numeric">512</field>
-        </record>
-
-        <record model="country.country" id="pk">
-            <field name="name">Pakistan</field>
-            <field name="code">PK</field>
-            <field name="code3">PAK</field>
-            <field name="code_numeric">586</field>
-        </record>
-
-        <record model="country.country" id="pa">
-            <field name="name">Panama</field>
-            <field name="code">PA</field>
-            <field name="code3">PAN</field>
-            <field name="code_numeric">591</field>
-        </record>
-
-        <record model="country.country" id="pn">
-            <field name="name">Pitcairn</field>
-            <field name="code">PN</field>
-            <field name="code3">PCN</field>
-            <field name="code_numeric">612</field>
-        </record>
-
-        <record model="country.country" id="pe">
-            <field name="name">Peru</field>
-            <field name="code">PE</field>
-            <field name="code3">PER</field>
-            <field name="code_numeric">604</field>
-        </record>
-
-        <record model="country.country" id="ph">
-            <field name="name">Philippines</field>
-            <field name="code">PH</field>
-            <field name="code3">PHL</field>
-            <field name="code_numeric">608</field>
-        </record>
-
-        <record model="country.country" id="pw">
-            <field name="name">Palau</field>
-            <field name="code">PW</field>
-            <field name="code3">PLW</field>
-            <field name="code_numeric">585</field>
-        </record>
-
-        <record model="country.country" id="pg">
-            <field name="name">Papua New Guinea</field>
-            <field name="code">PG</field>
-            <field name="code3">PNG</field>
-            <field name="code_numeric">598</field>
-        </record>
-
-        <record model="country.country" id="pl">
-            <field name="name">Poland</field>
-            <field name="code">PL</field>
-            <field name="code3">POL</field>
-            <field name="code_numeric">616</field>
-        </record>
-
-        <record model="country.country" id="pr">
-            <field name="name">Puerto Rico</field>
-            <field name="code">PR</field>
-            <field name="code3">PRI</field>
-            <field name="code_numeric">630</field>
-        </record>
-
-        <record model="country.country" id="kp">
-            <field name="name">Korea, Democratic People's Republic of</field>
-            <field name="code">KP</field>
-            <field name="code3">PRK</field>
-            <field name="code_numeric">408</field>
-        </record>
-
-        <record model="country.country" id="pt">
-            <field name="name">Portugal</field>
-            <field name="code">PT</field>
-            <field name="code3">PRT</field>
-            <field name="code_numeric">620</field>
-        </record>
-
-        <record model="country.country" id="py">
-            <field name="name">Paraguay</field>
-            <field name="code">PY</field>
-            <field name="code3">PRY</field>
-            <field name="code_numeric">600</field>
-        </record>
-
-        <record model="country.country" id="ps">
-            <field name="name">Palestine, State of</field>
-            <field name="code">PS</field>
-            <field name="code3">PSE</field>
-            <field name="code_numeric">275</field>
-        </record>
-
-        <record model="country.country" id="pf">
-            <field name="name">French Polynesia</field>
-            <field name="code">PF</field>
-            <field name="code3">PYF</field>
-            <field name="code_numeric">258</field>
-        </record>
-
-        <record model="country.country" id="qa">
-            <field name="name">Qatar</field>
-            <field name="code">QA</field>
-            <field name="code3">QAT</field>
-            <field name="code_numeric">634</field>
-        </record>
-
-        <record model="country.country" id="re">
-            <field name="name">Réunion</field>
-            <field name="code">RE</field>
-            <field name="code3">REU</field>
-            <field name="code_numeric">638</field>
-        </record>
-
-        <record model="country.country" id="ro">
-            <field name="name">Romania</field>
-            <field name="code">RO</field>
-            <field name="code3">ROU</field>
-            <field name="code_numeric">642</field>
-        </record>
-
-        <record model="country.country" id="ru">
-            <field name="name">Russian Federation</field>
-            <field name="code">RU</field>
-            <field name="code3">RUS</field>
-            <field name="code_numeric">643</field>
-        </record>
-
-        <record model="country.country" id="rw">
-            <field name="name">Rwanda</field>
-            <field name="code">RW</field>
-            <field name="code3">RWA</field>
-            <field name="code_numeric">646</field>
-        </record>
-
-        <record model="country.country" id="sa">
-            <field name="name">Saudi Arabia</field>
-            <field name="code">SA</field>
-            <field name="code3">SAU</field>
-            <field name="code_numeric">682</field>
-        </record>
-
-        <record model="country.country" id="sd">
-            <field name="name">Sudan</field>
-            <field name="code">SD</field>
-            <field name="code3">SDN</field>
-            <field name="code_numeric">729</field>
-        </record>
-
-        <record model="country.country" id="sn">
-            <field name="name">Senegal</field>
-            <field name="code">SN</field>
-            <field name="code3">SEN</field>
-            <field name="code_numeric">686</field>
-        </record>
-
-        <record model="country.country" id="sg">
-            <field name="name">Singapore</field>
-            <field name="code">SG</field>
-            <field name="code3">SGP</field>
-            <field name="code_numeric">702</field>
-        </record>
-
-        <record model="country.country" id="gs">
-            <field name="name">South Georgia and the South Sandwich Islands</field>
-            <field name="code">GS</field>
-            <field name="code3">SGS</field>
-            <field name="code_numeric">239</field>
-        </record>
-
-        <record model="country.country" id="sh">
-            <field name="name">Saint Helena, Ascension and Tristan da Cunha</field>
-            <field name="code">SH</field>
-            <field name="code3">SHN</field>
-            <field name="code_numeric">654</field>
-        </record>
-
-        <record model="country.country" id="sj">
-            <field name="name">Svalbard and Jan Mayen</field>
-            <field name="code">SJ</field>
-            <field name="code3">SJM</field>
-            <field name="code_numeric">744</field>
-        </record>
-
-        <record model="country.country" id="sb">
-            <field name="name">Solomon Islands</field>
-            <field name="code">SB</field>
-            <field name="code3">SLB</field>
-            <field name="code_numeric">090</field>
-        </record>
-
-        <record model="country.country" id="sl">
-            <field name="name">Sierra Leone</field>
-            <field name="code">SL</field>
-            <field name="code3">SLE</field>
-            <field name="code_numeric">694</field>
-        </record>
-
-        <record model="country.country" id="sv">
-            <field name="name">El Salvador</field>
-            <field name="code">SV</field>
-            <field name="code3">SLV</field>
-            <field name="code_numeric">222</field>
-        </record>
-
-        <record model="country.country" id="sm">
-            <field name="name">San Marino</field>
-            <field name="code">SM</field>
-            <field name="code3">SMR</field>
-            <field name="code_numeric">674</field>
-        </record>
-
-        <record model="country.country" id="so">
-            <field name="name">Somalia</field>
-            <field name="code">SO</field>
-            <field name="code3">SOM</field>
-            <field name="code_numeric">706</field>
-        </record>
-
-        <record model="country.country" id="pm">
-            <field name="name">Saint Pierre and Miquelon</field>
-            <field name="code">PM</field>
-            <field name="code3">SPM</field>
-            <field name="code_numeric">666</field>
-        </record>
-
-        <record model="country.country" id="rs">
-            <field name="name">Serbia</field>
-            <field name="code">RS</field>
-            <field name="code3">SRB</field>
-            <field name="code_numeric">688</field>
-        </record>
-
-        <record model="country.country" id="ss">
-            <field name="name">South Sudan</field>
-            <field name="code">SS</field>
-            <field name="code3">SSD</field>
-            <field name="code_numeric">728</field>
-        </record>
-
-        <record model="country.country" id="st">
-            <field name="name">Sao Tome and Principe</field>
-            <field name="code">ST</field>
-            <field name="code3">STP</field>
-            <field name="code_numeric">678</field>
-        </record>
-
-        <record model="country.country" id="sr">
-            <field name="name">Suriname</field>
-            <field name="code">SR</field>
-            <field name="code3">SUR</field>
-            <field name="code_numeric">740</field>
-        </record>
-
-        <record model="country.country" id="sk">
-            <field name="name">Slovakia</field>
-            <field name="code">SK</field>
-            <field name="code3">SVK</field>
-            <field name="code_numeric">703</field>
-        </record>
-
-        <record model="country.country" id="si">
-            <field name="name">Slovenia</field>
-            <field name="code">SI</field>
-            <field name="code3">SVN</field>
-            <field name="code_numeric">705</field>
-        </record>
-
-        <record model="country.country" id="se">
-            <field name="name">Sweden</field>
-            <field name="code">SE</field>
-            <field name="code3">SWE</field>
-            <field name="code_numeric">752</field>
-        </record>
-
-        <record model="country.country" id="sz">
-            <field name="name">Swaziland</field>
-            <field name="code">SZ</field>
-            <field name="code3">SWZ</field>
-            <field name="code_numeric">748</field>
-        </record>
-
-        <record model="country.country" id="sx">
-            <field name="name">Sint Maarten (Dutch part)</field>
-            <field name="code">SX</field>
-            <field name="code3">SXM</field>
-            <field name="code_numeric">534</field>
-        </record>
-
-        <record model="country.country" id="sc">
-            <field name="name">Seychelles</field>
-            <field name="code">SC</field>
-            <field name="code3">SYC</field>
-            <field name="code_numeric">690</field>
-        </record>
-
-        <record model="country.country" id="sy">
-            <field name="name">Syrian Arab Republic</field>
-            <field name="code">SY</field>
-            <field name="code3">SYR</field>
-            <field name="code_numeric">760</field>
-        </record>
-
-        <record model="country.country" id="tc">
-            <field name="name">Turks and Caicos Islands</field>
-            <field name="code">TC</field>
-            <field name="code3">TCA</field>
-            <field name="code_numeric">796</field>
-        </record>
-
-        <record model="country.country" id="td">
-            <field name="name">Chad</field>
-            <field name="code">TD</field>
-            <field name="code3">TCD</field>
-            <field name="code_numeric">148</field>
-        </record>
-
-        <record model="country.country" id="tg">
-            <field name="name">Togo</field>
-            <field name="code">TG</field>
-            <field name="code3">TGO</field>
-            <field name="code_numeric">768</field>
-        </record>
-
-        <record model="country.country" id="th">
-            <field name="name">Thailand</field>
-            <field name="code">TH</field>
-            <field name="code3">THA</field>
-            <field name="code_numeric">764</field>
-        </record>
-
-        <record model="country.country" id="tj">
-            <field name="name">Tajikistan</field>
-            <field name="code">TJ</field>
-            <field name="code3">TJK</field>
-            <field name="code_numeric">762</field>
-        </record>
-
-        <record model="country.country" id="tk">
-            <field name="name">Tokelau</field>
-            <field name="code">TK</field>
-            <field name="code3">TKL</field>
-            <field name="code_numeric">772</field>
-        </record>
-
-        <record model="country.country" id="tm">
-            <field name="name">Turkmenistan</field>
-            <field name="code">TM</field>
-            <field name="code3">TKM</field>
-            <field name="code_numeric">795</field>
-        </record>
-
-        <record model="country.country" id="tl">
-            <field name="name">Timor-Leste</field>
-            <field name="code">TL</field>
-            <field name="code3">TLS</field>
-            <field name="code_numeric">626</field>
-        </record>
-
-        <record model="country.country" id="to">
-            <field name="name">Tonga</field>
-            <field name="code">TO</field>
-            <field name="code3">TON</field>
-            <field name="code_numeric">776</field>
-        </record>
-
-        <record model="country.country" id="tt">
-            <field name="name">Trinidad and Tobago</field>
-            <field name="code">TT</field>
-            <field name="code3">TTO</field>
-            <field name="code_numeric">780</field>
-        </record>
-
-        <record model="country.country" id="tn">
-            <field name="name">Tunisia</field>
-            <field name="code">TN</field>
-            <field name="code3">TUN</field>
-            <field name="code_numeric">788</field>
-        </record>
-
-        <record model="country.country" id="tr">
-            <field name="name">Turkey</field>
-            <field name="code">TR</field>
-            <field name="code3">TUR</field>
-            <field name="code_numeric">792</field>
-        </record>
-
-        <record model="country.country" id="tv">
-            <field name="name">Tuvalu</field>
-            <field name="code">TV</field>
-            <field name="code3">TUV</field>
-            <field name="code_numeric">798</field>
-        </record>
-
-        <record model="country.country" id="tw">
-            <field name="name">Taiwan, Province of China</field>
-            <field name="code">TW</field>
-            <field name="code3">TWN</field>
-            <field name="code_numeric">158</field>
-        </record>
-
-        <record model="country.country" id="tz">
-            <field name="name">Tanzania, United Republic of</field>
-            <field name="code">TZ</field>
-            <field name="code3">TZA</field>
-            <field name="code_numeric">834</field>
-        </record>
-
-        <record model="country.country" id="ug">
-            <field name="name">Uganda</field>
-            <field name="code">UG</field>
-            <field name="code3">UGA</field>
-            <field name="code_numeric">800</field>
-        </record>
-
-        <record model="country.country" id="ua">
-            <field name="name">Ukraine</field>
-            <field name="code">UA</field>
-            <field name="code3">UKR</field>
-            <field name="code_numeric">804</field>
-        </record>
-
-        <record model="country.country" id="um">
-            <field name="name">United States Minor Outlying Islands</field>
-            <field name="code">UM</field>
-            <field name="code3">UMI</field>
-            <field name="code_numeric">581</field>
-        </record>
-
-        <record model="country.country" id="uy">
-            <field name="name">Uruguay</field>
-            <field name="code">UY</field>
-            <field name="code3">URY</field>
-            <field name="code_numeric">858</field>
-        </record>
-
-        <record model="country.country" id="us">
-            <field name="name">United States</field>
-            <field name="code">US</field>
-            <field name="code3">USA</field>
-            <field name="code_numeric">840</field>
-        </record>
-
-        <record model="country.country" id="uz">
-            <field name="name">Uzbekistan</field>
-            <field name="code">UZ</field>
-            <field name="code3">UZB</field>
-            <field name="code_numeric">860</field>
-        </record>
-
-        <record model="country.country" id="va">
-            <field name="name">Holy See (Vatican City State)</field>
-            <field name="code">VA</field>
-            <field name="code3">VAT</field>
-            <field name="code_numeric">336</field>
-        </record>
-
-        <record model="country.country" id="vc">
-            <field name="name">Saint Vincent and the Grenadines</field>
-            <field name="code">VC</field>
-            <field name="code3">VCT</field>
-            <field name="code_numeric">670</field>
-        </record>
-
-        <record model="country.country" id="ve">
-            <field name="name">Venezuela, Bolivarian Republic of</field>
-            <field name="code">VE</field>
-            <field name="code3">VEN</field>
-            <field name="code_numeric">862</field>
-        </record>
-
-        <record model="country.country" id="vg">
-            <field name="name">Virgin Islands, British</field>
-            <field name="code">VG</field>
-            <field name="code3">VGB</field>
-            <field name="code_numeric">092</field>
-        </record>
-
-        <record model="country.country" id="vi">
-            <field name="name">Virgin Islands, U.S.</field>
-            <field name="code">VI</field>
-            <field name="code3">VIR</field>
-            <field name="code_numeric">850</field>
-        </record>
-
-        <record model="country.country" id="vn">
-            <field name="name">Viet Nam</field>
-            <field name="code">VN</field>
-            <field name="code3">VNM</field>
-            <field name="code_numeric">704</field>
-        </record>
-
-        <record model="country.country" id="vu">
-            <field name="name">Vanuatu</field>
-            <field name="code">VU</field>
-            <field name="code3">VUT</field>
-            <field name="code_numeric">548</field>
-        </record>
-
-        <record model="country.country" id="wf">
-            <field name="name">Wallis and Futuna</field>
-            <field name="code">WF</field>
-            <field name="code3">WLF</field>
-            <field name="code_numeric">876</field>
-        </record>
-
-        <record model="country.country" id="ws">
-            <field name="name">Samoa</field>
-            <field name="code">WS</field>
-            <field name="code3">WSM</field>
-            <field name="code_numeric">882</field>
-        </record>
-
-        <record model="country.country" id="ye">
-            <field name="name">Yemen</field>
-            <field name="code">YE</field>
-            <field name="code3">YEM</field>
-            <field name="code_numeric">887</field>
-        </record>
-
-        <record model="country.country" id="za">
-            <field name="name">South Africa</field>
-            <field name="code">ZA</field>
-            <field name="code3">ZAF</field>
-            <field name="code_numeric">710</field>
-        </record>
-
-        <record model="country.country" id="zm">
-            <field name="name">Zambia</field>
-            <field name="code">ZM</field>
-            <field name="code3">ZMB</field>
-            <field name="code_numeric">894</field>
-        </record>
-
-        <record model="country.country" id="zw">
-            <field name="name">Zimbabwe</field>
-            <field name="code">ZW</field>
-            <field name="code3">ZWE</field>
-            <field name="code_numeric">716</field>
-        </record>
-    </data>
-    <data skiptest="1" grouped="1">
-
-        <record model="country.subdivision" id="ad-02">
-            <field name="name">Canillo</field>
-            <field name="code">AD-02</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ad"/>
-        </record>
-
-        <record model="country.subdivision" id="ad-03">
-            <field name="name">Encamp</field>
-            <field name="code">AD-03</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ad"/>
-        </record>
-
-        <record model="country.subdivision" id="ad-04">
-            <field name="name">La Massana</field>
-            <field name="code">AD-04</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ad"/>
-        </record>
-
-        <record model="country.subdivision" id="ad-05">
-            <field name="name">Ordino</field>
-            <field name="code">AD-05</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ad"/>
-        </record>
-
-        <record model="country.subdivision" id="ad-06">
-            <field name="name">Sant Julià de Lòria</field>
-            <field name="code">AD-06</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ad"/>
-        </record>
-
-        <record model="country.subdivision" id="ad-07">
-            <field name="name">Andorra la Vella</field>
-            <field name="code">AD-07</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ad"/>
-        </record>
-
-        <record model="country.subdivision" id="ad-08">
-            <field name="name">Escaldes-Engordany</field>
-            <field name="code">AD-08</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ad"/>
-        </record>
-
-        <record model="country.subdivision" id="ae-aj">
-            <field name="name">'Ajmān</field>
-            <field name="code">AE-AJ</field>
-            <field name="type">emirate</field>
-            <field name="country" ref="ae"/>
-        </record>
-
-        <record model="country.subdivision" id="ae-az">
-            <field name="name">Abū Ȥaby [Abu Dhabi]</field>
-            <field name="code">AE-AZ</field>
-            <field name="type">emirate</field>
-            <field name="country" ref="ae"/>
-        </record>
-
-        <record model="country.subdivision" id="ae-du">
-            <field name="name">Dubayy</field>
-            <field name="code">AE-DU</field>
-            <field name="type">emirate</field>
-            <field name="country" ref="ae"/>
-        </record>
-
-        <record model="country.subdivision" id="ae-fu">
-            <field name="name">Al Fujayrah</field>
-            <field name="code">AE-FU</field>
-            <field name="type">emirate</field>
-            <field name="country" ref="ae"/>
-        </record>
-
-        <record model="country.subdivision" id="ae-rk">
-            <field name="name">Ra’s al Khaymah</field>
-            <field name="code">AE-RK</field>
-            <field name="type">emirate</field>
-            <field name="country" ref="ae"/>
-        </record>
-
-        <record model="country.subdivision" id="ae-sh">
-            <field name="name">Ash Shāriqah</field>
-            <field name="code">AE-SH</field>
-            <field name="type">emirate</field>
-            <field name="country" ref="ae"/>
-        </record>
-
-        <record model="country.subdivision" id="ae-uq">
-            <field name="name">Umm al Qaywayn</field>
-            <field name="code">AE-UQ</field>
-            <field name="type">emirate</field>
-            <field name="country" ref="ae"/>
-        </record>
-
-        <record model="country.subdivision" id="af-bal">
-            <field name="name">Balkh</field>
-            <field name="code">AF-BAL</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-bam">
-            <field name="name">Bāmyān</field>
-            <field name="code">AF-BAM</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-bdg">
-            <field name="name">Bādghīs</field>
-            <field name="code">AF-BDG</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-bds">
-            <field name="name">Badakhshān</field>
-            <field name="code">AF-BDS</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-bgl">
-            <field name="name">Baghlān</field>
-            <field name="code">AF-BGL</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-day">
-            <field name="name">Dāykundī</field>
-            <field name="code">AF-DAY</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-fra">
-            <field name="name">Farāh</field>
-            <field name="code">AF-FRA</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-fyb">
-            <field name="name">Fāryāb</field>
-            <field name="code">AF-FYB</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-gha">
-            <field name="name">Ghaznī</field>
-            <field name="code">AF-GHA</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-gho">
-            <field name="name">Ghōr</field>
-            <field name="code">AF-GHO</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-hel">
-            <field name="name">Helmand</field>
-            <field name="code">AF-HEL</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-her">
-            <field name="name">Herāt</field>
-            <field name="code">AF-HER</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-jow">
-            <field name="name">Jowzjān</field>
-            <field name="code">AF-JOW</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-kab">
-            <field name="name">Kābul</field>
-            <field name="code">AF-KAB</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-kan">
-            <field name="name">Kandahār</field>
-            <field name="code">AF-KAN</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-kap">
-            <field name="name">Kāpīsā</field>
-            <field name="code">AF-KAP</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-kdz">
-            <field name="name">Kunduz</field>
-            <field name="code">AF-KDZ</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-kho">
-            <field name="name">Khōst</field>
-            <field name="code">AF-KHO</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-knr">
-            <field name="name">Kunar</field>
-            <field name="code">AF-KNR</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-lag">
-            <field name="name">Laghmān</field>
-            <field name="code">AF-LAG</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-log">
-            <field name="name">Lōgar</field>
-            <field name="code">AF-LOG</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-nan">
-            <field name="name">Nangarhār</field>
-            <field name="code">AF-NAN</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-nim">
-            <field name="name">Nīmrōz</field>
-            <field name="code">AF-NIM</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-nur">
-            <field name="name">Nūristān</field>
-            <field name="code">AF-NUR</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-pan">
-            <field name="name">Panjshayr</field>
-            <field name="code">AF-PAN</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-par">
-            <field name="name">Parwān</field>
-            <field name="code">AF-PAR</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-pia">
-            <field name="name">Paktiyā</field>
-            <field name="code">AF-PIA</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-pka">
-            <field name="name">Paktīkā</field>
-            <field name="code">AF-PKA</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-sam">
-            <field name="name">Samangān</field>
-            <field name="code">AF-SAM</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-sar">
-            <field name="name">Sar-e Pul</field>
-            <field name="code">AF-SAR</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-tak">
-            <field name="name">Takhār</field>
-            <field name="code">AF-TAK</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-uru">
-            <field name="name">Uruzgān</field>
-            <field name="code">AF-URU</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-war">
-            <field name="name">Wardak</field>
-            <field name="code">AF-WAR</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="af-zab">
-            <field name="name">Zābul</field>
-            <field name="code">AF-ZAB</field>
-            <field name="type">province</field>
-            <field name="country" ref="af"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-03">
-            <field name="name">Saint George</field>
-            <field name="code">AG-03</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-04">
-            <field name="name">Saint John</field>
-            <field name="code">AG-04</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-05">
-            <field name="name">Saint Mary</field>
-            <field name="code">AG-05</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-06">
-            <field name="name">Saint Paul</field>
-            <field name="code">AG-06</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-07">
-            <field name="name">Saint Peter</field>
-            <field name="code">AG-07</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-08">
-            <field name="name">Saint Philip</field>
-            <field name="code">AG-08</field>
-            <field name="type">parish</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-10">
-            <field name="name">Barbuda</field>
-            <field name="code">AG-10</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="ag-11">
-            <field name="name">Redonda</field>
-            <field name="code">AG-11</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="ag"/>
-        </record>
-
-        <record model="country.subdivision" id="al-01">
-            <field name="name">Berat</field>
-            <field name="code">AL-01</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-02">
-            <field name="name">Durrës</field>
-            <field name="code">AL-02</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-03">
-            <field name="name">Elbasan</field>
-            <field name="code">AL-03</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-04">
-            <field name="name">Fier</field>
-            <field name="code">AL-04</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-05">
-            <field name="name">Gjirokastër</field>
-            <field name="code">AL-05</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-06">
-            <field name="name">Korçë</field>
-            <field name="code">AL-06</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-07">
-            <field name="name">Kukës</field>
-            <field name="code">AL-07</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-08">
-            <field name="name">Lezhë</field>
-            <field name="code">AL-08</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-09">
-            <field name="name">Dibër</field>
-            <field name="code">AL-09</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-10">
-            <field name="name">Shkodër</field>
-            <field name="code">AL-10</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-11">
-            <field name="name">Tiranë</field>
-            <field name="code">AL-11</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-12">
-            <field name="name">Vlorë</field>
-            <field name="code">AL-12</field>
-            <field name="type">county</field>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="am-ag">
-            <field name="name">Aragacotn</field>
-            <field name="code">AM-AG</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-ar">
-            <field name="name">Ararat</field>
-            <field name="code">AM-AR</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-av">
-            <field name="name">Armavir</field>
-            <field name="code">AM-AV</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-er">
-            <field name="name">Erevan</field>
-            <field name="code">AM-ER</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-gr">
-            <field name="name">Gegarkunik'</field>
-            <field name="code">AM-GR</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-kt">
-            <field name="name">Kotayk'</field>
-            <field name="code">AM-KT</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-lo">
-            <field name="name">Lory</field>
-            <field name="code">AM-LO</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-sh">
-            <field name="name">Sirak</field>
-            <field name="code">AM-SH</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-su">
-            <field name="name">Syunik'</field>
-            <field name="code">AM-SU</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-tv">
-            <field name="name">Tavus</field>
-            <field name="code">AM-TV</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="am-vd">
-            <field name="name">Vayoc Jor</field>
-            <field name="code">AM-VD</field>
-            <field name="type">province</field>
-            <field name="country" ref="am"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-bgo">
-            <field name="name">Bengo</field>
-            <field name="code">AO-BGO</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-bgu">
-            <field name="name">Benguela</field>
-            <field name="code">AO-BGU</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-bie">
-            <field name="name">Bié</field>
-            <field name="code">AO-BIE</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-cab">
-            <field name="name">Cabinda</field>
-            <field name="code">AO-CAB</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-ccu">
-            <field name="name">Cuando-Cubango</field>
-            <field name="code">AO-CCU</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-cnn">
-            <field name="name">Cunene</field>
-            <field name="code">AO-CNN</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-cno">
-            <field name="name">Cuanza Norte</field>
-            <field name="code">AO-CNO</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-cus">
-            <field name="name">Cuanza Sul</field>
-            <field name="code">AO-CUS</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-hua">
-            <field name="name">Huambo</field>
-            <field name="code">AO-HUA</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-hui">
-            <field name="name">Huíla</field>
-            <field name="code">AO-HUI</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-lno">
-            <field name="name">Lunda Norte</field>
-            <field name="code">AO-LNO</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-lsu">
-            <field name="name">Lunda Sul</field>
-            <field name="code">AO-LSU</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-lua">
-            <field name="name">Luanda</field>
-            <field name="code">AO-LUA</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-mal">
-            <field name="name">Malange</field>
-            <field name="code">AO-MAL</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-mox">
-            <field name="name">Moxico</field>
-            <field name="code">AO-MOX</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-nam">
-            <field name="name">Namibe</field>
-            <field name="code">AO-NAM</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-uig">
-            <field name="name">Uíge</field>
-            <field name="code">AO-UIG</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ao-zai">
-            <field name="name">Zaire</field>
-            <field name="code">AO-ZAI</field>
-            <field name="type">province</field>
-            <field name="country" ref="ao"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-a">
-            <field name="name">Salta</field>
-            <field name="code">AR-A</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-b">
-            <field name="name">Buenos Aires</field>
-            <field name="code">AR-B</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-c">
-            <field name="name">Ciudad Autónoma de Buenos Aires</field>
-            <field name="code">AR-C</field>
-            <field name="type">city</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-d">
-            <field name="name">San Luis</field>
-            <field name="code">AR-D</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-e">
-            <field name="name">Entre Rios</field>
-            <field name="code">AR-E</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-g">
-            <field name="name">Santiago del Estero</field>
-            <field name="code">AR-G</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-h">
-            <field name="name">Chaco</field>
-            <field name="code">AR-H</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-j">
-            <field name="name">San Juan</field>
-            <field name="code">AR-J</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-k">
-            <field name="name">Catamarca</field>
-            <field name="code">AR-K</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-l">
-            <field name="name">La Pampa</field>
-            <field name="code">AR-L</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-m">
-            <field name="name">Mendoza</field>
-            <field name="code">AR-M</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-n">
-            <field name="name">Misiones</field>
-            <field name="code">AR-N</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-p">
-            <field name="name">Formosa</field>
-            <field name="code">AR-P</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-q">
-            <field name="name">Neuquen</field>
-            <field name="code">AR-Q</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-r">
-            <field name="name">Rio Negro</field>
-            <field name="code">AR-R</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-s">
-            <field name="name">Santa Fe</field>
-            <field name="code">AR-S</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-t">
-            <field name="name">Tucuman</field>
-            <field name="code">AR-T</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-u">
-            <field name="name">Chubut</field>
-            <field name="code">AR-U</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-v">
-            <field name="name">Tierra del Fuego</field>
-            <field name="code">AR-V</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-w">
-            <field name="name">Corrientes</field>
-            <field name="code">AR-W</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-x">
-            <field name="name">Cordoba</field>
-            <field name="code">AR-X</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-y">
-            <field name="name">Jujuy</field>
-            <field name="code">AR-Y</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="ar-z">
-            <field name="name">Santa Cruz</field>
-            <field name="code">AR-Z</field>
-            <field name="type">province</field>
-            <field name="country" ref="ar"/>
-        </record>
-
-        <record model="country.subdivision" id="at-1">
-            <field name="name">Burgenland</field>
-            <field name="code">AT-1</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-2">
-            <field name="name">Kärnten</field>
-            <field name="code">AT-2</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-3">
-            <field name="name">Niederösterreich</field>
-            <field name="code">AT-3</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-4">
-            <field name="name">Oberösterreich</field>
-            <field name="code">AT-4</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-5">
-            <field name="name">Salzburg</field>
-            <field name="code">AT-5</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-6">
-            <field name="name">Steiermark</field>
-            <field name="code">AT-6</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-7">
-            <field name="name">Tirol</field>
-            <field name="code">AT-7</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-8">
-            <field name="name">Vorarlberg</field>
-            <field name="code">AT-8</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="at-9">
-            <field name="name">Wien</field>
-            <field name="code">AT-9</field>
-            <field name="type">state</field>
-            <field name="country" ref="at"/>
-        </record>
-
-        <record model="country.subdivision" id="au-act">
-            <field name="name">Australian Capital Territory</field>
-            <field name="code">AU-ACT</field>
-            <field name="type">territory</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="au-nsw">
-            <field name="name">New South Wales</field>
-            <field name="code">AU-NSW</field>
-            <field name="type">state</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="au-nt">
-            <field name="name">Northern Territory</field>
-            <field name="code">AU-NT</field>
-            <field name="type">territory</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="au-qld">
-            <field name="name">Queensland</field>
-            <field name="code">AU-QLD</field>
-            <field name="type">state</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="au-sa">
-            <field name="name">South Australia</field>
-            <field name="code">AU-SA</field>
-            <field name="type">state</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="au-tas">
-            <field name="name">Tasmania</field>
-            <field name="code">AU-TAS</field>
-            <field name="type">state</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="au-vic">
-            <field name="name">Victoria</field>
-            <field name="code">AU-VIC</field>
-            <field name="type">state</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="au-wa">
-            <field name="name">Western Australia</field>
-            <field name="code">AU-WA</field>
-            <field name="type">state</field>
-            <field name="country" ref="au"/>
-        </record>
-
-        <record model="country.subdivision" id="az-abs">
-            <field name="name">Abşeron</field>
-            <field name="code">AZ-ABS</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-aga">
-            <field name="name">Ağstafa</field>
-            <field name="code">AZ-AGA</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-agc">
-            <field name="name">Ağcabədi</field>
-            <field name="code">AZ-AGC</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-agm">
-            <field name="name">Ağdam</field>
-            <field name="code">AZ-AGM</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ags">
-            <field name="name">Ağdaş</field>
-            <field name="code">AZ-AGS</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-agu">
-            <field name="name">Ağsu</field>
-            <field name="code">AZ-AGU</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ast">
-            <field name="name">Astara</field>
-            <field name="code">AZ-AST</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ba">
-            <field name="name">Bakı</field>
-            <field name="code">AZ-BA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-bal">
-            <field name="name">Balakən</field>
-            <field name="code">AZ-BAL</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-bar">
-            <field name="name">Bərdə</field>
-            <field name="code">AZ-BAR</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-bey">
-            <field name="name">Beyləqan</field>
-            <field name="code">AZ-BEY</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-bil">
-            <field name="name">Biləsuvar</field>
-            <field name="code">AZ-BIL</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-cab">
-            <field name="name">Cəbrayıl</field>
-            <field name="code">AZ-CAB</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-cal">
-            <field name="name">Cəlilabab</field>
-            <field name="code">AZ-CAL</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-das">
-            <field name="name">Daşkəsən</field>
-            <field name="code">AZ-DAS</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-fuz">
-            <field name="name">Füzuli</field>
-            <field name="code">AZ-FUZ</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ga">
-            <field name="name">Gəncə</field>
-            <field name="code">AZ-GA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-gad">
-            <field name="name">Gədəbəy</field>
-            <field name="code">AZ-GAD</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-gor">
-            <field name="name">Goranboy</field>
-            <field name="code">AZ-GOR</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-goy">
-            <field name="name">Göyçay</field>
-            <field name="code">AZ-GOY</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-gyg">
-            <field name="name">Göygöl</field>
-            <field name="code">AZ-GYG</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-hac">
-            <field name="name">Hacıqabul</field>
-            <field name="code">AZ-HAC</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-imi">
-            <field name="name">İmişli</field>
-            <field name="code">AZ-IMI</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ism">
-            <field name="name">İsmayıllı</field>
-            <field name="code">AZ-ISM</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-kal">
-            <field name="name">Kəlbəcər</field>
-            <field name="code">AZ-KAL</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-kur">
-            <field name="name">Kürdəmir</field>
-            <field name="code">AZ-KUR</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-la">
-            <field name="name">Lənkəran</field>
-            <field name="code">AZ-LA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-lac">
-            <field name="name">Laçın</field>
-            <field name="code">AZ-LAC</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-lan">
-            <field name="name">Lənkəran</field>
-            <field name="code">AZ-LAN</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ler">
-            <field name="name">Lerik</field>
-            <field name="code">AZ-LER</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-mas">
-            <field name="name">Masallı</field>
-            <field name="code">AZ-MAS</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-mi">
-            <field name="name">Mingəçevir</field>
-            <field name="code">AZ-MI</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-na">
-            <field name="name">Naftalan</field>
-            <field name="code">AZ-NA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-nef">
-            <field name="name">Neftçala</field>
-            <field name="code">AZ-NEF</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-nx">
-            <field name="name">Naxçıvan</field>
-            <field name="code">AZ-NX</field>
-            <field name="type">autonomous republic</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ogu">
-            <field name="name">Oğuz</field>
-            <field name="code">AZ-OGU</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-qab">
-            <field name="name">Qəbələ</field>
-            <field name="code">AZ-QAB</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-qax">
-            <field name="name">Qax</field>
-            <field name="code">AZ-QAX</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-qaz">
-            <field name="name">Qazax</field>
-            <field name="code">AZ-QAZ</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-qba">
-            <field name="name">Quba</field>
-            <field name="code">AZ-QBA</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-qbi">
-            <field name="name">Qubadlı</field>
-            <field name="code">AZ-QBI</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-qob">
-            <field name="name">Qobustan</field>
-            <field name="code">AZ-QOB</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-qus">
-            <field name="name">Qusar</field>
-            <field name="code">AZ-QUS</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sa">
-            <field name="name">Şəki</field>
-            <field name="code">AZ-SA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sab">
-            <field name="name">Sabirabad</field>
-            <field name="code">AZ-SAB</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sak">
-            <field name="name">Şəki</field>
-            <field name="code">AZ-SAK</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sal">
-            <field name="name">Salyan</field>
-            <field name="code">AZ-SAL</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sat">
-            <field name="name">Saatlı</field>
-            <field name="code">AZ-SAT</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sbn">
-            <field name="name">Şabran</field>
-            <field name="code">AZ-SBN</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-siy">
-            <field name="name">Siyəzən</field>
-            <field name="code">AZ-SIY</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-skr">
-            <field name="name">Şəmkir</field>
-            <field name="code">AZ-SKR</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sm">
-            <field name="name">Sumqayıt</field>
-            <field name="code">AZ-SM</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-smi">
-            <field name="name">Şamaxı</field>
-            <field name="code">AZ-SMI</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-smx">
-            <field name="name">Samux</field>
-            <field name="code">AZ-SMX</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sr">
-            <field name="name">Şirvan</field>
-            <field name="code">AZ-SR</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sus">
-            <field name="name">Şuşa</field>
-            <field name="code">AZ-SUS</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-tar">
-            <field name="name">Tərtər</field>
-            <field name="code">AZ-TAR</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-tov">
-            <field name="name">Tovuz</field>
-            <field name="code">AZ-TOV</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-uca">
-            <field name="name">Ucar</field>
-            <field name="code">AZ-UCA</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-xa">
-            <field name="name">Xankəndi</field>
-            <field name="code">AZ-XA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-xac">
-            <field name="name">Xaçmaz</field>
-            <field name="code">AZ-XAC</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-xci">
-            <field name="name">Xocalı</field>
-            <field name="code">AZ-XCI</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-xiz">
-            <field name="name">Xızı</field>
-            <field name="code">AZ-XIZ</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-xvd">
-            <field name="name">Xocavənd</field>
-            <field name="code">AZ-XVD</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-yar">
-            <field name="name">Yardımlı</field>
-            <field name="code">AZ-YAR</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ye">
-            <field name="name">Yevlax</field>
-            <field name="code">AZ-YE</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-yev">
-            <field name="name">Yevlax</field>
-            <field name="code">AZ-YEV</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-zan">
-            <field name="name">Zəngilan</field>
-            <field name="code">AZ-ZAN</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-zaq">
-            <field name="name">Zaqatala</field>
-            <field name="code">AZ-ZAQ</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-zar">
-            <field name="name">Zərdab</field>
-            <field name="code">AZ-ZAR</field>
-            <field name="type">rayon</field>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-bih">
-            <field name="name">Federacija Bosne i Hercegovine</field>
-            <field name="code">BA-BIH</field>
-            <field name="type">entity</field>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-brc">
-            <field name="name">Brčko distrikt</field>
-            <field name="code">BA-BRC</field>
-            <field name="type">district</field>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-srp">
-            <field name="name">Republika Srpska</field>
-            <field name="code">BA-SRP</field>
-            <field name="type">entity</field>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-01">
-            <field name="name">Christ Church</field>
-            <field name="code">BB-01</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-02">
-            <field name="name">Saint Andrew</field>
-            <field name="code">BB-02</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-03">
-            <field name="name">Saint George</field>
-            <field name="code">BB-03</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-04">
-            <field name="name">Saint James</field>
-            <field name="code">BB-04</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-05">
-            <field name="name">Saint John</field>
-            <field name="code">BB-05</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-06">
-            <field name="name">Saint Joseph</field>
-            <field name="code">BB-06</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-07">
-            <field name="name">Saint Lucy</field>
-            <field name="code">BB-07</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-08">
-            <field name="name">Saint Michael</field>
-            <field name="code">BB-08</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-09">
-            <field name="name">Saint Peter</field>
-            <field name="code">BB-09</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-10">
-            <field name="name">Saint Philip</field>
-            <field name="code">BB-10</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bb-11">
-            <field name="name">Saint Thomas</field>
-            <field name="code">BB-11</field>
-            <field name="type">parish</field>
-            <field name="country" ref="bb"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-a">
-            <field name="name">Barisal</field>
-            <field name="code">BD-A</field>
-            <field name="type">division</field>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-b">
-            <field name="name">Chittagong</field>
-            <field name="code">BD-B</field>
-            <field name="type">division</field>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-c">
-            <field name="name">Dhaka</field>
-            <field name="code">BD-C</field>
-            <field name="type">division</field>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-d">
-            <field name="name">Khulna</field>
-            <field name="code">BD-D</field>
-            <field name="type">division</field>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-e">
-            <field name="name">Rajshahi</field>
-            <field name="code">BD-E</field>
-            <field name="type">division</field>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-f">
-            <field name="name">Rangpur</field>
-            <field name="code">BD-F</field>
-            <field name="type">division</field>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-g">
-            <field name="name">Sylhet</field>
-            <field name="code">BD-G</field>
-            <field name="type">division</field>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="be-bru">
-            <field name="name">Bruxelles-Capitale, Région de;Brussels Hoofdstedelijk Gewest</field>
-            <field name="code">BE-BRU</field>
-            <field name="type">region</field>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-vlg">
-            <field name="name">Vlaams Gewest</field>
-            <field name="code">BE-VLG</field>
-            <field name="type">region</field>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-wal">
-            <field name="name">wallonne, Région</field>
-            <field name="code">BE-WAL</field>
-            <field name="type">region</field>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-01">
-            <field name="name">Boucle du Mouhoun</field>
-            <field name="code">BF-01</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-02">
-            <field name="name">Cascades</field>
-            <field name="code">BF-02</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-03">
-            <field name="name">Centre</field>
-            <field name="code">BF-03</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-04">
-            <field name="name">Centre-Est</field>
-            <field name="code">BF-04</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-05">
-            <field name="name">Centre-Nord</field>
-            <field name="code">BF-05</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-06">
-            <field name="name">Centre-Ouest</field>
-            <field name="code">BF-06</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-07">
-            <field name="name">Centre-Sud</field>
-            <field name="code">BF-07</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-08">
-            <field name="name">Est</field>
-            <field name="code">BF-08</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-09">
-            <field name="name">Hauts-Bassins</field>
-            <field name="code">BF-09</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-10">
-            <field name="name">Nord</field>
-            <field name="code">BF-10</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-11">
-            <field name="name">Plateau-Central</field>
-            <field name="code">BF-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-12">
-            <field name="name">Sahel</field>
-            <field name="code">BF-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-13">
-            <field name="name">Sud-Ouest</field>
-            <field name="code">BF-13</field>
-            <field name="type">region</field>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-01">
-            <field name="name">Blagoevgrad</field>
-            <field name="code">BG-01</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-02">
-            <field name="name">Burgas</field>
-            <field name="code">BG-02</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-03">
-            <field name="name">Varna</field>
-            <field name="code">BG-03</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-04">
-            <field name="name">Veliko Tarnovo</field>
-            <field name="code">BG-04</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-05">
-            <field name="name">Vidin</field>
-            <field name="code">BG-05</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-06">
-            <field name="name">Vratsa</field>
-            <field name="code">BG-06</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-07">
-            <field name="name">Gabrovo</field>
-            <field name="code">BG-07</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-08">
-            <field name="name">Dobrich</field>
-            <field name="code">BG-08</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-09">
-            <field name="name">Kardzhali</field>
-            <field name="code">BG-09</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-10">
-            <field name="name">Kyustendil</field>
-            <field name="code">BG-10</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-11">
-            <field name="name">Lovech</field>
-            <field name="code">BG-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-12">
-            <field name="name">Montana</field>
-            <field name="code">BG-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-13">
-            <field name="name">Pazardzhik</field>
-            <field name="code">BG-13</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-14">
-            <field name="name">Pernik</field>
-            <field name="code">BG-14</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-15">
-            <field name="name">Pleven</field>
-            <field name="code">BG-15</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-16">
-            <field name="name">Plovdiv</field>
-            <field name="code">BG-16</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-17">
-            <field name="name">Razgrad</field>
-            <field name="code">BG-17</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-18">
-            <field name="name">Ruse</field>
-            <field name="code">BG-18</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-19">
-            <field name="name">Silistra</field>
-            <field name="code">BG-19</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-20">
-            <field name="name">Sliven</field>
-            <field name="code">BG-20</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-21">
-            <field name="name">Smolyan</field>
-            <field name="code">BG-21</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-22">
-            <field name="name">Sofia-Grad</field>
-            <field name="code">BG-22</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-23">
-            <field name="name">Sofia</field>
-            <field name="code">BG-23</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-24">
-            <field name="name">Stara Zagora</field>
-            <field name="code">BG-24</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-25">
-            <field name="name">Targovishte</field>
-            <field name="code">BG-25</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-26">
-            <field name="name">Haskovo</field>
-            <field name="code">BG-26</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-27">
-            <field name="name">Shumen</field>
-            <field name="code">BG-27</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bg-28">
-            <field name="name">Yambol</field>
-            <field name="code">BG-28</field>
-            <field name="type">region</field>
-            <field name="country" ref="bg"/>
-        </record>
-
-        <record model="country.subdivision" id="bh-13">
-            <field name="name">Al Manāmah (Al ‘Āşimah)</field>
-            <field name="code">BH-13</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="bh"/>
-        </record>
-
-        <record model="country.subdivision" id="bh-14">
-            <field name="name">Al Janūbīyah</field>
-            <field name="code">BH-14</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="bh"/>
-        </record>
-
-        <record model="country.subdivision" id="bh-15">
-            <field name="name">Al Muḩarraq</field>
-            <field name="code">BH-15</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="bh"/>
-        </record>
-
-        <record model="country.subdivision" id="bh-16">
-            <field name="name">Al Wusţá</field>
-            <field name="code">BH-16</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="bh"/>
-        </record>
-
-        <record model="country.subdivision" id="bh-17">
-            <field name="name">Ash Shamālīyah</field>
-            <field name="code">BH-17</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="bh"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-bb">
-            <field name="name">Bubanza</field>
-            <field name="code">BI-BB</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-bl">
-            <field name="name">Bujumbura Rural</field>
-            <field name="code">BI-BL</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-bm">
-            <field name="name">Bujumbura Mairie</field>
-            <field name="code">BI-BM</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-br">
-            <field name="name">Bururi</field>
-            <field name="code">BI-BR</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-ca">
-            <field name="name">Cankuzo</field>
-            <field name="code">BI-CA</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-ci">
-            <field name="name">Cibitoke</field>
-            <field name="code">BI-CI</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-gi">
-            <field name="name">Gitega</field>
-            <field name="code">BI-GI</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-ki">
-            <field name="name">Kirundo</field>
-            <field name="code">BI-KI</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-kr">
-            <field name="name">Karuzi</field>
-            <field name="code">BI-KR</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-ky">
-            <field name="name">Kayanza</field>
-            <field name="code">BI-KY</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-ma">
-            <field name="name">Makamba</field>
-            <field name="code">BI-MA</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-mu">
-            <field name="name">Muramvya</field>
-            <field name="code">BI-MU</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-mw">
-            <field name="name">Mwaro</field>
-            <field name="code">BI-MW</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-ng">
-            <field name="name">Ngozi</field>
-            <field name="code">BI-NG</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-rt">
-            <field name="name">Rutana</field>
-            <field name="code">BI-RT</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bi-ry">
-            <field name="name">Ruyigi</field>
-            <field name="code">BI-RY</field>
-            <field name="type">province</field>
-            <field name="country" ref="bi"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-ak">
-            <field name="name">Atakora</field>
-            <field name="code">BJ-AK</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-al">
-            <field name="name">Alibori</field>
-            <field name="code">BJ-AL</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-aq">
-            <field name="name">Atlantique</field>
-            <field name="code">BJ-AQ</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-bo">
-            <field name="name">Borgou</field>
-            <field name="code">BJ-BO</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-co">
-            <field name="name">Collines</field>
-            <field name="code">BJ-CO</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-do">
-            <field name="name">Donga</field>
-            <field name="code">BJ-DO</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-ko">
-            <field name="name">Kouffo</field>
-            <field name="code">BJ-KO</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-li">
-            <field name="name">Littoral</field>
-            <field name="code">BJ-LI</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-mo">
-            <field name="name">Mono</field>
-            <field name="code">BJ-MO</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-ou">
-            <field name="name">Ouémé</field>
-            <field name="code">BJ-OU</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-pl">
-            <field name="name">Plateau</field>
-            <field name="code">BJ-PL</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bj-zo">
-            <field name="name">Zou</field>
-            <field name="code">BJ-ZO</field>
-            <field name="type">department</field>
-            <field name="country" ref="bj"/>
-        </record>
-
-        <record model="country.subdivision" id="bn-be">
-            <field name="name">Belait</field>
-            <field name="code">BN-BE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bn"/>
-        </record>
-
-        <record model="country.subdivision" id="bn-bm">
-            <field name="name">Brunei-Muara</field>
-            <field name="code">BN-BM</field>
-            <field name="type">district</field>
-            <field name="country" ref="bn"/>
-        </record>
-
-        <record model="country.subdivision" id="bn-te">
-            <field name="name">Temburong</field>
-            <field name="code">BN-TE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bn"/>
-        </record>
-
-        <record model="country.subdivision" id="bn-tu">
-            <field name="name">Tutong</field>
-            <field name="code">BN-TU</field>
-            <field name="type">district</field>
-            <field name="country" ref="bn"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-b">
-            <field name="name">El Beni</field>
-            <field name="code">BO-B</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-c">
-            <field name="name">Cochabamba</field>
-            <field name="code">BO-C</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-h">
-            <field name="name">Chuquisaca</field>
-            <field name="code">BO-H</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-l">
-            <field name="name">La Paz</field>
-            <field name="code">BO-L</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-n">
-            <field name="name">Pando</field>
-            <field name="code">BO-N</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-o">
-            <field name="name">Oruro</field>
-            <field name="code">BO-O</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-p">
-            <field name="name">Potosí</field>
-            <field name="code">BO-P</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-s">
-            <field name="name">Santa Cruz</field>
-            <field name="code">BO-S</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bo-t">
-            <field name="name">Tarija</field>
-            <field name="code">BO-T</field>
-            <field name="type">department</field>
-            <field name="country" ref="bo"/>
-        </record>
-
-        <record model="country.subdivision" id="bq-bo">
-            <field name="name">Bonaire</field>
-            <field name="code">BQ-BO</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="bq"/>
-        </record>
-
-        <record model="country.subdivision" id="bq-sa">
-            <field name="name">Saba</field>
-            <field name="code">BQ-SA</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="bq"/>
-        </record>
-
-        <record model="country.subdivision" id="bq-se">
-            <field name="name">Sint Eustatius</field>
-            <field name="code">BQ-SE</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="bq"/>
-        </record>
-
-        <record model="country.subdivision" id="br-ac">
-            <field name="name">Acre</field>
-            <field name="code">BR-AC</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-al">
-            <field name="name">Alagoas</field>
-            <field name="code">BR-AL</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-am">
-            <field name="name">Amazonas</field>
-            <field name="code">BR-AM</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-ap">
-            <field name="name">Amapá</field>
-            <field name="code">BR-AP</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-ba">
-            <field name="name">Bahia</field>
-            <field name="code">BR-BA</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-ce">
-            <field name="name">Ceará</field>
-            <field name="code">BR-CE</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-df">
-            <field name="name">Distrito Federal</field>
-            <field name="code">BR-DF</field>
-            <field name="type">federal district</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-es">
-            <field name="name">Espírito Santo</field>
-            <field name="code">BR-ES</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-fn">
-            <field name="name">Fernando de Noronha</field>
-            <field name="code">BR-FN</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-go">
-            <field name="name">Goiás</field>
-            <field name="code">BR-GO</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-ma">
-            <field name="name">Maranhão</field>
-            <field name="code">BR-MA</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-mg">
-            <field name="name">Minas Gerais</field>
-            <field name="code">BR-MG</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-ms">
-            <field name="name">Mato Grosso do Sul</field>
-            <field name="code">BR-MS</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-mt">
-            <field name="name">Mato Grosso</field>
-            <field name="code">BR-MT</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-pa">
-            <field name="name">Pará</field>
-            <field name="code">BR-PA</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-pb">
-            <field name="name">Paraíba</field>
-            <field name="code">BR-PB</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-pe">
-            <field name="name">Pernambuco</field>
-            <field name="code">BR-PE</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-pi">
-            <field name="name">Piauí</field>
-            <field name="code">BR-PI</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-pr">
-            <field name="name">Paraná</field>
-            <field name="code">BR-PR</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-rj">
-            <field name="name">Rio de Janeiro</field>
-            <field name="code">BR-RJ</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-rn">
-            <field name="name">Rio Grande do Norte</field>
-            <field name="code">BR-RN</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-ro">
-            <field name="name">Rondônia</field>
-            <field name="code">BR-RO</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-rr">
-            <field name="name">Roraima</field>
-            <field name="code">BR-RR</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-rs">
-            <field name="name">Rio Grande do Sul</field>
-            <field name="code">BR-RS</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-sc">
-            <field name="name">Santa Catarina</field>
-            <field name="code">BR-SC</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-se">
-            <field name="name">Sergipe</field>
-            <field name="code">BR-SE</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-sp">
-            <field name="name">São Paulo</field>
-            <field name="code">BR-SP</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="br-to">
-            <field name="name">Tocantins</field>
-            <field name="code">BR-TO</field>
-            <field name="type">state</field>
-            <field name="country" ref="br"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ak">
-            <field name="name">Acklins</field>
-            <field name="code">BS-AK</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-bi">
-            <field name="name">Bimini</field>
-            <field name="code">BS-BI</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-bp">
-            <field name="name">Black Point</field>
-            <field name="code">BS-BP</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-by">
-            <field name="name">Berry Islands</field>
-            <field name="code">BS-BY</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ce">
-            <field name="name">Central Eleuthera</field>
-            <field name="code">BS-CE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ci">
-            <field name="name">Cat Island</field>
-            <field name="code">BS-CI</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ck">
-            <field name="name">Crooked Island and Long Cay</field>
-            <field name="code">BS-CK</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-co">
-            <field name="name">Central Abaco</field>
-            <field name="code">BS-CO</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-cs">
-            <field name="name">Central Andros</field>
-            <field name="code">BS-CS</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-eg">
-            <field name="name">East Grand Bahama</field>
-            <field name="code">BS-EG</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ex">
-            <field name="name">Exuma</field>
-            <field name="code">BS-EX</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-fp">
-            <field name="name">City of Freeport</field>
-            <field name="code">BS-FP</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-gc">
-            <field name="name">Grand Cay</field>
-            <field name="code">BS-GC</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-hi">
-            <field name="name">Harbour Island</field>
-            <field name="code">BS-HI</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ht">
-            <field name="name">Hope Town</field>
-            <field name="code">BS-HT</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-in">
-            <field name="name">Inagua</field>
-            <field name="code">BS-IN</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-li">
-            <field name="name">Long Island</field>
-            <field name="code">BS-LI</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-mc">
-            <field name="name">Mangrove Cay</field>
-            <field name="code">BS-MC</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-mg">
-            <field name="name">Mayaguana</field>
-            <field name="code">BS-MG</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-mi">
-            <field name="name">Moore's Island</field>
-            <field name="code">BS-MI</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ne">
-            <field name="name">North Eleuthera</field>
-            <field name="code">BS-NE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-no">
-            <field name="name">North Abaco</field>
-            <field name="code">BS-NO</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ns">
-            <field name="name">North Andros</field>
-            <field name="code">BS-NS</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-rc">
-            <field name="name">Rum Cay</field>
-            <field name="code">BS-RC</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ri">
-            <field name="name">Ragged Island</field>
-            <field name="code">BS-RI</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-sa">
-            <field name="name">South Andros</field>
-            <field name="code">BS-SA</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-se">
-            <field name="name">South Eleuthera</field>
-            <field name="code">BS-SE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-so">
-            <field name="name">South Abaco</field>
-            <field name="code">BS-SO</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-ss">
-            <field name="name">San Salvador</field>
-            <field name="code">BS-SS</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-sw">
-            <field name="name">Spanish Wells</field>
-            <field name="code">BS-SW</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bs-wg">
-            <field name="name">West Grand Bahama</field>
-            <field name="code">BS-WG</field>
-            <field name="type">district</field>
-            <field name="country" ref="bs"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-11">
-            <field name="name">Paro</field>
-            <field name="code">BT-11</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-12">
-            <field name="name">Chhukha</field>
-            <field name="code">BT-12</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-13">
-            <field name="name">Ha</field>
-            <field name="code">BT-13</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-14">
-            <field name="name">Samtee</field>
-            <field name="code">BT-14</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-15">
-            <field name="name">Thimphu</field>
-            <field name="code">BT-15</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-21">
-            <field name="name">Tsirang</field>
-            <field name="code">BT-21</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-22">
-            <field name="name">Dagana</field>
-            <field name="code">BT-22</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-23">
-            <field name="name">Punakha</field>
-            <field name="code">BT-23</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-24">
-            <field name="name">Wangdue Phodrang</field>
-            <field name="code">BT-24</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-31">
-            <field name="name">Sarpang</field>
-            <field name="code">BT-31</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-32">
-            <field name="name">Trongsa</field>
-            <field name="code">BT-32</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-33">
-            <field name="name">Bumthang</field>
-            <field name="code">BT-33</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-34">
-            <field name="name">Zhemgang</field>
-            <field name="code">BT-34</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-41">
-            <field name="name">Trashigang</field>
-            <field name="code">BT-41</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-42">
-            <field name="name">Monggar</field>
-            <field name="code">BT-42</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-43">
-            <field name="name">Pemagatshel</field>
-            <field name="code">BT-43</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-44">
-            <field name="name">Lhuentse</field>
-            <field name="code">BT-44</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-45">
-            <field name="name">Samdrup Jongkha</field>
-            <field name="code">BT-45</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-ga">
-            <field name="name">Gasa</field>
-            <field name="code">BT-GA</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bt-ty">
-            <field name="name">Trashi Yangtse</field>
-            <field name="code">BT-TY</field>
-            <field name="type">district</field>
-            <field name="country" ref="bt"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-ce">
-            <field name="name">Central</field>
-            <field name="code">BW-CE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-gh">
-            <field name="name">Ghanzi</field>
-            <field name="code">BW-GH</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-kg">
-            <field name="name">Kgalagadi</field>
-            <field name="code">BW-KG</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-kl">
-            <field name="name">Kgatleng</field>
-            <field name="code">BW-KL</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-kw">
-            <field name="name">Kweneng</field>
-            <field name="code">BW-KW</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-ne">
-            <field name="name">North-East</field>
-            <field name="code">BW-NE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-nw">
-            <field name="name">North-West</field>
-            <field name="code">BW-NW</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-se">
-            <field name="name">South-East</field>
-            <field name="code">BW-SE</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="bw-so">
-            <field name="name">Southern</field>
-            <field name="code">BW-SO</field>
-            <field name="type">district</field>
-            <field name="country" ref="bw"/>
-        </record>
-
-        <record model="country.subdivision" id="by-br">
-            <field name="name">Brèsckaja voblasc'</field>
-            <field name="code">BY-BR</field>
-            <field name="type">oblast</field>
-            <field name="country" ref="by"/>
-        </record>
-
-        <record model="country.subdivision" id="by-hm">
-            <field name="name">Horad Minsk</field>
-            <field name="code">BY-HM</field>
-            <field name="type">city</field>
-            <field name="country" ref="by"/>
-        </record>
-
-        <record model="country.subdivision" id="by-ho">
-            <field name="name">Homel'skaja voblasc'</field>
-            <field name="code">BY-HO</field>
-            <field name="type">oblast</field>
-            <field name="country" ref="by"/>
-        </record>
-
-        <record model="country.subdivision" id="by-hr">
-            <field name="name">Hrodzenskaja voblasc'</field>
-            <field name="code">BY-HR</field>
-            <field name="type">oblast</field>
-            <field name="country" ref="by"/>
-        </record>
-
-        <record model="country.subdivision" id="by-ma">
-            <field name="name">Mahilëuskaja voblasc'</field>
-            <field name="code">BY-MA</field>
-            <field name="type">oblast</field>
-            <field name="country" ref="by"/>
-        </record>
-
-        <record model="country.subdivision" id="by-mi">
-            <field name="name">Minskaja voblasc'</field>
-            <field name="code">BY-MI</field>
-            <field name="type">oblast</field>
-            <field name="country" ref="by"/>
-        </record>
-
-        <record model="country.subdivision" id="by-vi">
-            <field name="name">Vicebskaja voblasc'</field>
-            <field name="code">BY-VI</field>
-            <field name="type">oblast</field>
-            <field name="country" ref="by"/>
-        </record>
-
-        <record model="country.subdivision" id="bz-bz">
-            <field name="name">Belize</field>
-            <field name="code">BZ-BZ</field>
-            <field name="type">district</field>
-            <field name="country" ref="bz"/>
-        </record>
-
-        <record model="country.subdivision" id="bz-cy">
-            <field name="name">Cayo</field>
-            <field name="code">BZ-CY</field>
-            <field name="type">district</field>
-            <field name="country" ref="bz"/>
-        </record>
-
-        <record model="country.subdivision" id="bz-czl">
-            <field name="name">Corozal</field>
-            <field name="code">BZ-CZL</field>
-            <field name="type">district</field>
-            <field name="country" ref="bz"/>
-        </record>
-
-        <record model="country.subdivision" id="bz-ow">
-            <field name="name">Orange Walk</field>
-            <field name="code">BZ-OW</field>
-            <field name="type">district</field>
-            <field name="country" ref="bz"/>
-        </record>
-
-        <record model="country.subdivision" id="bz-sc">
-            <field name="name">Stann Creek</field>
-            <field name="code">BZ-SC</field>
-            <field name="type">district</field>
-            <field name="country" ref="bz"/>
-        </record>
-
-        <record model="country.subdivision" id="bz-tol">
-            <field name="name">Toledo</field>
-            <field name="code">BZ-TOL</field>
-            <field name="type">district</field>
-            <field name="country" ref="bz"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-ab">
-            <field name="name">Alberta</field>
-            <field name="code">CA-AB</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-bc">
-            <field name="name">British Columbia</field>
-            <field name="code">CA-BC</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-mb">
-            <field name="name">Manitoba</field>
-            <field name="code">CA-MB</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-nb">
-            <field name="name">New Brunswick</field>
-            <field name="code">CA-NB</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-nl">
-            <field name="name">Newfoundland and Labrador</field>
-            <field name="code">CA-NL</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-ns">
-            <field name="name">Nova Scotia</field>
-            <field name="code">CA-NS</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-nt">
-            <field name="name">Northwest Territories</field>
-            <field name="code">CA-NT</field>
-            <field name="type">territory</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-nu">
-            <field name="name">Nunavut</field>
-            <field name="code">CA-NU</field>
-            <field name="type">territory</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-on">
-            <field name="name">Ontario</field>
-            <field name="code">CA-ON</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-pe">
-            <field name="name">Prince Edward Island</field>
-            <field name="code">CA-PE</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-qc">
-            <field name="name">Quebec</field>
-            <field name="code">CA-QC</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-sk">
-            <field name="name">Saskatchewan</field>
-            <field name="code">CA-SK</field>
-            <field name="type">province</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="ca-yt">
-            <field name="name">Yukon Territory</field>
-            <field name="code">CA-YT</field>
-            <field name="type">territory</field>
-            <field name="country" ref="ca"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-bc">
-            <field name="name">Bas-Congo</field>
-            <field name="code">CD-BC</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-bn">
-            <field name="name">Bandundu</field>
-            <field name="code">CD-BN</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-eq">
-            <field name="name">Équateur</field>
-            <field name="code">CD-EQ</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-ka">
-            <field name="name">Katanga</field>
-            <field name="code">CD-KA</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-ke">
-            <field name="name">Kasai-Oriental</field>
-            <field name="code">CD-KE</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-kn">
-            <field name="name">Kinshasa</field>
-            <field name="code">CD-KN</field>
-            <field name="type">city</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-kw">
-            <field name="name">Kasai-Occidental</field>
-            <field name="code">CD-KW</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-ma">
-            <field name="name">Maniema</field>
-            <field name="code">CD-MA</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-nk">
-            <field name="name">Nord-Kivu</field>
-            <field name="code">CD-NK</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-or">
-            <field name="name">Orientale</field>
-            <field name="code">CD-OR</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cd-sk">
-            <field name="name">Sud-Kivu</field>
-            <field name="code">CD-SK</field>
-            <field name="type">province</field>
-            <field name="country" ref="cd"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-ac">
-            <field name="name">Ouham</field>
-            <field name="code">CF-AC</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-bb">
-            <field name="name">Bamingui-Bangoran</field>
-            <field name="code">CF-BB</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-bgf">
-            <field name="name">Bangui</field>
-            <field name="code">CF-BGF</field>
-            <field name="type">commune</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-bk">
-            <field name="name">Basse-Kotto</field>
-            <field name="code">CF-BK</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-hk">
-            <field name="name">Haute-Kotto</field>
-            <field name="code">CF-HK</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-hm">
-            <field name="name">Haut-Mbomou</field>
-            <field name="code">CF-HM</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-hs">
-            <field name="name">Haute-Sangha / Mambéré-Kadéï</field>
-            <field name="code">CF-HS</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-kb">
-            <field name="name">Gribingui</field>
-            <field name="code">CF-KB</field>
-            <field name="type">economic prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-kg">
-            <field name="name">Kémo-Gribingui</field>
-            <field name="code">CF-KG</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-lb">
-            <field name="name">Lobaye</field>
-            <field name="code">CF-LB</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-mb">
-            <field name="name">Mbomou</field>
-            <field name="code">CF-MB</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-mp">
-            <field name="name">Ombella-M'poko</field>
-            <field name="code">CF-MP</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-nm">
-            <field name="name">Nana-Mambéré</field>
-            <field name="code">CF-NM</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-op">
-            <field name="name">Ouham-Pendé</field>
-            <field name="code">CF-OP</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-se">
-            <field name="name">Sangha</field>
-            <field name="code">CF-SE</field>
-            <field name="type">economic prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-uk">
-            <field name="name">Ouaka</field>
-            <field name="code">CF-UK</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cf-vk">
-            <field name="name">Vakaga</field>
-            <field name="code">CF-VK</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="cf"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-11">
-            <field name="name">Bouenza</field>
-            <field name="code">CG-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-12">
-            <field name="name">Pool</field>
-            <field name="code">CG-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-13">
-            <field name="name">Sangha</field>
-            <field name="code">CG-13</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-14">
-            <field name="name">Plateaux</field>
-            <field name="code">CG-14</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-15">
-            <field name="name">Cuvette-Ouest</field>
-            <field name="code">CG-15</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-2">
-            <field name="name">Lékoumou</field>
-            <field name="code">CG-2</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-5">
-            <field name="name">Kouilou</field>
-            <field name="code">CG-5</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-7">
-            <field name="name">Likouala</field>
-            <field name="code">CG-7</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-8">
-            <field name="name">Cuvette</field>
-            <field name="code">CG-8</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-9">
-            <field name="name">Niari</field>
-            <field name="code">CG-9</field>
-            <field name="type">region</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="cg-bzv">
-            <field name="name">Brazzaville</field>
-            <field name="code">CG-BZV</field>
-            <field name="type">capital district</field>
-            <field name="country" ref="cg"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ag">
-            <field name="name">Aargau</field>
-            <field name="code">CH-AG</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ai">
-            <field name="name">Appenzell Innerrhoden</field>
-            <field name="code">CH-AI</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ar">
-            <field name="name">Appenzell Ausserrhoden</field>
-            <field name="code">CH-AR</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-be">
-            <field name="name">Bern</field>
-            <field name="code">CH-BE</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-bl">
-            <field name="name">Basel-Landschaft</field>
-            <field name="code">CH-BL</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-bs">
-            <field name="name">Basel-Stadt</field>
-            <field name="code">CH-BS</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-fr">
-            <field name="name">Fribourg</field>
-            <field name="code">CH-FR</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ge">
-            <field name="name">Genève</field>
-            <field name="code">CH-GE</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-gl">
-            <field name="name">Glarus</field>
-            <field name="code">CH-GL</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-gr">
-            <field name="name">Graubünden</field>
-            <field name="code">CH-GR</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ju">
-            <field name="name">Jura</field>
-            <field name="code">CH-JU</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-lu">
-            <field name="name">Luzern</field>
-            <field name="code">CH-LU</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ne">
-            <field name="name">Neuchâtel</field>
-            <field name="code">CH-NE</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-nw">
-            <field name="name">Nidwalden</field>
-            <field name="code">CH-NW</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ow">
-            <field name="name">Obwalden</field>
-            <field name="code">CH-OW</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-sg">
-            <field name="name">Sankt Gallen</field>
-            <field name="code">CH-SG</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-sh">
-            <field name="name">Schaffhausen</field>
-            <field name="code">CH-SH</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-so">
-            <field name="name">Solothurn</field>
-            <field name="code">CH-SO</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-sz">
-            <field name="name">Schwyz</field>
-            <field name="code">CH-SZ</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-tg">
-            <field name="name">Thurgau</field>
-            <field name="code">CH-TG</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ti">
-            <field name="name">Ticino</field>
-            <field name="code">CH-TI</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-ur">
-            <field name="name">Uri</field>
-            <field name="code">CH-UR</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-vd">
-            <field name="name">Vaud</field>
-            <field name="code">CH-VD</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-vs">
-            <field name="name">Valais</field>
-            <field name="code">CH-VS</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-zg">
-            <field name="name">Zug</field>
-            <field name="code">CH-ZG</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ch-zh">
-            <field name="name">Zürich</field>
-            <field name="code">CH-ZH</field>
-            <field name="type">canton</field>
-            <field name="country" ref="ch"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-01">
-            <field name="name">Lagunes (Région des)</field>
-            <field name="code">CI-01</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-02">
-            <field name="name">Haut-Sassandra (Région du)</field>
-            <field name="code">CI-02</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-03">
-            <field name="name">Savanes (Région des)</field>
-            <field name="code">CI-03</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-04">
-            <field name="name">Vallée du Bandama (Région de la)</field>
-            <field name="code">CI-04</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-05">
-            <field name="name">Moyen-Comoé (Région du)</field>
-            <field name="code">CI-05</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-06">
-            <field name="name">18 Montagnes (Région des)</field>
-            <field name="code">CI-06</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-07">
-            <field name="name">Lacs (Région des)</field>
-            <field name="code">CI-07</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-08">
-            <field name="name">Zanzan (Région du)</field>
-            <field name="code">CI-08</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-09">
-            <field name="name">Bas-Sassandra (Région du)</field>
-            <field name="code">CI-09</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-10">
-            <field name="name">Denguélé (Région du)</field>
-            <field name="code">CI-10</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-11">
-            <field name="name">Nzi-Comoé (Région)</field>
-            <field name="code">CI-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-12">
-            <field name="name">Marahoué (Région de la)</field>
-            <field name="code">CI-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-13">
-            <field name="name">Sud-Comoé (Région du)</field>
-            <field name="code">CI-13</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-14">
-            <field name="name">Worodouqou (Région du)</field>
-            <field name="code">CI-14</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-15">
-            <field name="name">Sud-Bandama (Région du)</field>
-            <field name="code">CI-15</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-16">
-            <field name="name">Agnébi (Région de l')</field>
-            <field name="code">CI-16</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-17">
-            <field name="name">Bafing (Région du)</field>
-            <field name="code">CI-17</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-18">
-            <field name="name">Fromager (Région du)</field>
-            <field name="code">CI-18</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="ci-19">
-            <field name="name">Moyen-Cavally (Région du)</field>
-            <field name="code">CI-19</field>
-            <field name="type">region</field>
-            <field name="country" ref="ci"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-ai">
-            <field name="name">Aisén del General Carlos Ibáñez del Campo</field>
-            <field name="code">CL-AI</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-an">
-            <field name="name">Antofagasta</field>
-            <field name="code">CL-AN</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-ap">
-            <field name="name">Arica y Parinacota</field>
-            <field name="code">CL-AP</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-ar">
-            <field name="name">Araucanía</field>
-            <field name="code">CL-AR</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-at">
-            <field name="name">Atacama</field>
-            <field name="code">CL-AT</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-bi">
-            <field name="name">Bío-Bío</field>
-            <field name="code">CL-BI</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-co">
-            <field name="name">Coquimbo</field>
-            <field name="code">CL-CO</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-li">
-            <field name="name">Libertador General Bernardo O'Higgins</field>
-            <field name="code">CL-LI</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-ll">
-            <field name="name">Los Lagos</field>
-            <field name="code">CL-LL</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-lr">
-            <field name="name">Los Ríos</field>
-            <field name="code">CL-LR</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-ma">
-            <field name="name">Magallanes y Antártica Chilena</field>
-            <field name="code">CL-MA</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-ml">
-            <field name="name">Maule</field>
-            <field name="code">CL-ML</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-rm">
-            <field name="name">Región Metropolitana de Santiago</field>
-            <field name="code">CL-RM</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-ta">
-            <field name="name">Tarapacá</field>
-            <field name="code">CL-TA</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cl-vs">
-            <field name="name">Valparaíso</field>
-            <field name="code">CL-VS</field>
-            <field name="type">region</field>
-            <field name="country" ref="cl"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-ad">
-            <field name="name">Adamaoua</field>
-            <field name="code">CM-AD</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-ce">
-            <field name="name">Centre</field>
-            <field name="code">CM-CE</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-en">
-            <field name="name">Far North</field>
-            <field name="code">CM-EN</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-es">
-            <field name="name">East</field>
-            <field name="code">CM-ES</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-lt">
-            <field name="name">Littoral</field>
-            <field name="code">CM-LT</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-no">
-            <field name="name">North</field>
-            <field name="code">CM-NO</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-nw">
-            <field name="name">North-West (Cameroon)</field>
-            <field name="code">CM-NW</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-ou">
-            <field name="name">West</field>
-            <field name="code">CM-OU</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-su">
-            <field name="name">South</field>
-            <field name="code">CM-SU</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cm-sw">
-            <field name="name">South-West</field>
-            <field name="code">CM-SW</field>
-            <field name="type">province</field>
-            <field name="country" ref="cm"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-11">
-            <field name="name">Beijing</field>
-            <field name="code">CN-11</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-12">
-            <field name="name">Tianjin</field>
-            <field name="code">CN-12</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-13">
-            <field name="name">Hebei</field>
-            <field name="code">CN-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-14">
-            <field name="name">Shanxi</field>
-            <field name="code">CN-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-15">
-            <field name="name">Nei Mongol</field>
-            <field name="code">CN-15</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-21">
-            <field name="name">Liaoning</field>
-            <field name="code">CN-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-22">
-            <field name="name">Jilin</field>
-            <field name="code">CN-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-23">
-            <field name="name">Heilongjiang</field>
-            <field name="code">CN-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-31">
-            <field name="name">Shanghai</field>
-            <field name="code">CN-31</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-32">
-            <field name="name">Jiangsu</field>
-            <field name="code">CN-32</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-33">
-            <field name="name">Zhejiang</field>
-            <field name="code">CN-33</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-34">
-            <field name="name">Anhui</field>
-            <field name="code">CN-34</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-35">
-            <field name="name">Fujian</field>
-            <field name="code">CN-35</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-36">
-            <field name="name">Jiangxi</field>
-            <field name="code">CN-36</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-37">
-            <field name="name">Shandong</field>
-            <field name="code">CN-37</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-41">
-            <field name="name">Henan</field>
-            <field name="code">CN-41</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-42">
-            <field name="name">Hubei</field>
-            <field name="code">CN-42</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-43">
-            <field name="name">Hunan</field>
-            <field name="code">CN-43</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-44">
-            <field name="name">Guangdong</field>
-            <field name="code">CN-44</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-45">
-            <field name="name">Guangxi</field>
-            <field name="code">CN-45</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-46">
-            <field name="name">Hainan</field>
-            <field name="code">CN-46</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-50">
-            <field name="name">Chongqing</field>
-            <field name="code">CN-50</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-51">
-            <field name="name">Sichuan</field>
-            <field name="code">CN-51</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-52">
-            <field name="name">Guizhou</field>
-            <field name="code">CN-52</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-53">
-            <field name="name">Yunnan</field>
-            <field name="code">CN-53</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-54">
-            <field name="name">Xizang</field>
-            <field name="code">CN-54</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-61">
-            <field name="name">Shaanxi</field>
-            <field name="code">CN-61</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-62">
-            <field name="name">Gansu</field>
-            <field name="code">CN-62</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-63">
-            <field name="name">Qinghai</field>
-            <field name="code">CN-63</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-64">
-            <field name="name">Ningxia</field>
-            <field name="code">CN-64</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-65">
-            <field name="name">Xinjiang</field>
-            <field name="code">CN-65</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-71">
-            <field name="name">Taiwan</field>
-            <field name="code">CN-71</field>
-            <field name="type">province</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-91">
-            <field name="name">Xianggang (Hong-Kong)</field>
-            <field name="code">CN-91</field>
-            <field name="type">special administrative region</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="cn-92">
-            <field name="name">Aomen (Macau)</field>
-            <field name="code">CN-92</field>
-            <field name="type">special administrative region</field>
-            <field name="country" ref="cn"/>
-        </record>
-
-        <record model="country.subdivision" id="co-ama">
-            <field name="name">Amazonas</field>
-            <field name="code">CO-AMA</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-ant">
-            <field name="name">Antioquia</field>
-            <field name="code">CO-ANT</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-ara">
-            <field name="name">Arauca</field>
-            <field name="code">CO-ARA</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-atl">
-            <field name="name">Atlántico</field>
-            <field name="code">CO-ATL</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-bol">
-            <field name="name">Bolívar</field>
-            <field name="code">CO-BOL</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-boy">
-            <field name="name">Boyacá</field>
-            <field name="code">CO-BOY</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-cal">
-            <field name="name">Caldas</field>
-            <field name="code">CO-CAL</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-caq">
-            <field name="name">Caquetá</field>
-            <field name="code">CO-CAQ</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-cas">
-            <field name="name">Casanare</field>
-            <field name="code">CO-CAS</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-cau">
-            <field name="name">Cauca</field>
-            <field name="code">CO-CAU</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-ces">
-            <field name="name">Cesar</field>
-            <field name="code">CO-CES</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-cho">
-            <field name="name">Chocó</field>
-            <field name="code">CO-CHO</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-cor">
-            <field name="name">Córdoba</field>
-            <field name="code">CO-COR</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-cun">
-            <field name="name">Cundinamarca</field>
-            <field name="code">CO-CUN</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-dc">
-            <field name="name">Distrito Capital de Bogotá</field>
-            <field name="code">CO-DC</field>
-            <field name="type">capital district</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-gua">
-            <field name="name">Guainía</field>
-            <field name="code">CO-GUA</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-guv">
-            <field name="name">Guaviare</field>
-            <field name="code">CO-GUV</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-hui">
-            <field name="name">Huila</field>
-            <field name="code">CO-HUI</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-lag">
-            <field name="name">La Guajira</field>
-            <field name="code">CO-LAG</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-mag">
-            <field name="name">Magdalena</field>
-            <field name="code">CO-MAG</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-met">
-            <field name="name">Meta</field>
-            <field name="code">CO-MET</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-nar">
-            <field name="name">Nariño</field>
-            <field name="code">CO-NAR</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-nsa">
-            <field name="name">Norte de Santander</field>
-            <field name="code">CO-NSA</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-put">
-            <field name="name">Putumayo</field>
-            <field name="code">CO-PUT</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-qui">
-            <field name="name">Quindío</field>
-            <field name="code">CO-QUI</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-ris">
-            <field name="name">Risaralda</field>
-            <field name="code">CO-RIS</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-san">
-            <field name="name">Santander</field>
-            <field name="code">CO-SAN</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-sap">
-            <field name="name">San Andrés, Providencia y Santa Catalina</field>
-            <field name="code">CO-SAP</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-suc">
-            <field name="name">Sucre</field>
-            <field name="code">CO-SUC</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-tol">
-            <field name="name">Tolima</field>
-            <field name="code">CO-TOL</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-vac">
-            <field name="name">Valle del Cauca</field>
-            <field name="code">CO-VAC</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-vau">
-            <field name="name">Vaupés</field>
-            <field name="code">CO-VAU</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="co-vid">
-            <field name="name">Vichada</field>
-            <field name="code">CO-VID</field>
-            <field name="type">department</field>
-            <field name="country" ref="co"/>
-        </record>
-
-        <record model="country.subdivision" id="cr-a">
-            <field name="name">Alajuela</field>
-            <field name="code">CR-A</field>
-            <field name="type">province</field>
-            <field name="country" ref="cr"/>
-        </record>
-
-        <record model="country.subdivision" id="cr-c">
-            <field name="name">Cartago</field>
-            <field name="code">CR-C</field>
-            <field name="type">province</field>
-            <field name="country" ref="cr"/>
-        </record>
-
-        <record model="country.subdivision" id="cr-g">
-            <field name="name">Guanacaste</field>
-            <field name="code">CR-G</field>
-            <field name="type">province</field>
-            <field name="country" ref="cr"/>
-        </record>
-
-        <record model="country.subdivision" id="cr-h">
-            <field name="name">Heredia</field>
-            <field name="code">CR-H</field>
-            <field name="type">province</field>
-            <field name="country" ref="cr"/>
-        </record>
-
-        <record model="country.subdivision" id="cr-l">
-            <field name="name">Limón</field>
-            <field name="code">CR-L</field>
-            <field name="type">province</field>
-            <field name="country" ref="cr"/>
-        </record>
-
-        <record model="country.subdivision" id="cr-p">
-            <field name="name">Puntarenas</field>
-            <field name="code">CR-P</field>
-            <field name="type">province</field>
-            <field name="country" ref="cr"/>
-        </record>
-
-        <record model="country.subdivision" id="cr-sj">
-            <field name="name">San José</field>
-            <field name="code">CR-SJ</field>
-            <field name="type">province</field>
-            <field name="country" ref="cr"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-01">
-            <field name="name">Pinar del Rio</field>
-            <field name="code">CU-01</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-02">
-            <field name="name">La Habana</field>
-            <field name="code">CU-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-03">
-            <field name="name">Ciudad de La Habana</field>
-            <field name="code">CU-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-04">
-            <field name="name">Matanzas</field>
-            <field name="code">CU-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-05">
-            <field name="name">Villa Clara</field>
-            <field name="code">CU-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-06">
-            <field name="name">Cienfuegos</field>
-            <field name="code">CU-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-07">
-            <field name="name">Sancti Spíritus</field>
-            <field name="code">CU-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-08">
-            <field name="name">Ciego de Ávila</field>
-            <field name="code">CU-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-09">
-            <field name="name">Camagüey</field>
-            <field name="code">CU-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-10">
-            <field name="name">Las Tunas</field>
-            <field name="code">CU-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-11">
-            <field name="name">Holguín</field>
-            <field name="code">CU-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-12">
-            <field name="name">Granma</field>
-            <field name="code">CU-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-13">
-            <field name="name">Santiago de Cuba</field>
-            <field name="code">CU-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-14">
-            <field name="name">Guantánamo</field>
-            <field name="code">CU-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cu-99">
-            <field name="name">Isla de la Juventud</field>
-            <field name="code">CU-99</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="cu"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-b">
-            <field name="name">Ilhas de Barlavento</field>
-            <field name="code">CV-B</field>
-            <field name="type">geographical region</field>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-s">
-            <field name="name">Ilhas de Sotavento</field>
-            <field name="code">CV-S</field>
-            <field name="type">geographical region</field>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cy-01">
-            <field name="name">Lefkosía</field>
-            <field name="code">CY-01</field>
-            <field name="type">district</field>
-            <field name="country" ref="cy"/>
-        </record>
-
-        <record model="country.subdivision" id="cy-02">
-            <field name="name">Lemesós</field>
-            <field name="code">CY-02</field>
-            <field name="type">district</field>
-            <field name="country" ref="cy"/>
-        </record>
-
-        <record model="country.subdivision" id="cy-03">
-            <field name="name">Lárnaka</field>
-            <field name="code">CY-03</field>
-            <field name="type">district</field>
-            <field name="country" ref="cy"/>
-        </record>
-
-        <record model="country.subdivision" id="cy-04">
-            <field name="name">Ammóchostos</field>
-            <field name="code">CY-04</field>
-            <field name="type">district</field>
-            <field name="country" ref="cy"/>
-        </record>
-
-        <record model="country.subdivision" id="cy-05">
-            <field name="name">Páfos</field>
-            <field name="code">CY-05</field>
-            <field name="type">district</field>
-            <field name="country" ref="cy"/>
-        </record>
-
-        <record model="country.subdivision" id="cy-06">
-            <field name="name">Kerýneia</field>
-            <field name="code">CY-06</field>
-            <field name="type">district</field>
-            <field name="country" ref="cy"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-10">
-            <field name="name">Praha, Hlavní mešto</field>
-            <field name="code">CZ-10</field>
-            <field name="type">capital city</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-20">
-            <field name="name">Středočeský kraj</field>
-            <field name="code">CZ-20</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-31">
-            <field name="name">Jihočeský kraj</field>
-            <field name="code">CZ-31</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-32">
-            <field name="name">Plzeňský kraj</field>
-            <field name="code">CZ-32</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-41">
-            <field name="name">Karlovarský kraj</field>
-            <field name="code">CZ-41</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-42">
-            <field name="name">Ústecký kraj</field>
-            <field name="code">CZ-42</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-51">
-            <field name="name">Liberecký kraj</field>
-            <field name="code">CZ-51</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-52">
-            <field name="name">Královéhradecký kraj</field>
-            <field name="code">CZ-52</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-53">
-            <field name="name">Pardubický kraj</field>
-            <field name="code">CZ-53</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-63">
-            <field name="name">Kraj Vysočina</field>
-            <field name="code">CZ-63</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-64">
-            <field name="name">Jihomoravský kraj</field>
-            <field name="code">CZ-64</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-71">
-            <field name="name">Olomoucký kraj</field>
-            <field name="code">CZ-71</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-72">
-            <field name="name">Zlínský kraj</field>
-            <field name="code">CZ-72</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-80">
-            <field name="name">Moravskoslezský kraj</field>
-            <field name="code">CZ-80</field>
-            <field name="type">region</field>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="de-bb">
-            <field name="name">Brandenburg</field>
-            <field name="code">DE-BB</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-be">
-            <field name="name">Berlin</field>
-            <field name="code">DE-BE</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-bw">
-            <field name="name">Baden-Württemberg</field>
-            <field name="code">DE-BW</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-by">
-            <field name="name">Bayern</field>
-            <field name="code">DE-BY</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-hb">
-            <field name="name">Bremen</field>
-            <field name="code">DE-HB</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-he">
-            <field name="name">Hessen</field>
-            <field name="code">DE-HE</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-hh">
-            <field name="name">Hamburg</field>
-            <field name="code">DE-HH</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-mv">
-            <field name="name">Mecklenburg-Vorpommern</field>
-            <field name="code">DE-MV</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-ni">
-            <field name="name">Niedersachsen</field>
-            <field name="code">DE-NI</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-nw">
-            <field name="name">Nordrhein-Westfalen</field>
-            <field name="code">DE-NW</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-rp">
-            <field name="name">Rheinland-Pfalz</field>
-            <field name="code">DE-RP</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-sh">
-            <field name="name">Schleswig-Holstein</field>
-            <field name="code">DE-SH</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-sl">
-            <field name="name">Saarland</field>
-            <field name="code">DE-SL</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-sn">
-            <field name="name">Sachsen</field>
-            <field name="code">DE-SN</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-st">
-            <field name="name">Sachsen-Anhalt</field>
-            <field name="code">DE-ST</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="de-th">
-            <field name="name">Thüringen</field>
-            <field name="code">DE-TH</field>
-            <field name="type">state</field>
-            <field name="country" ref="de"/>
-        </record>
-
-        <record model="country.subdivision" id="dj-ar">
-            <field name="name">Arta</field>
-            <field name="code">DJ-AR</field>
-            <field name="type">region</field>
-            <field name="country" ref="dj"/>
-        </record>
-
-        <record model="country.subdivision" id="dj-as">
-            <field name="name">Ali Sabieh</field>
-            <field name="code">DJ-AS</field>
-            <field name="type">region</field>
-            <field name="country" ref="dj"/>
-        </record>
-
-        <record model="country.subdivision" id="dj-di">
-            <field name="name">Dikhil</field>
-            <field name="code">DJ-DI</field>
-            <field name="type">region</field>
-            <field name="country" ref="dj"/>
-        </record>
-
-        <record model="country.subdivision" id="dj-dj">
-            <field name="name">Djibouti</field>
-            <field name="code">DJ-DJ</field>
-            <field name="type">city</field>
-            <field name="country" ref="dj"/>
-        </record>
-
-        <record model="country.subdivision" id="dj-ob">
-            <field name="name">Obock</field>
-            <field name="code">DJ-OB</field>
-            <field name="type">region</field>
-            <field name="country" ref="dj"/>
-        </record>
-
-        <record model="country.subdivision" id="dj-ta">
-            <field name="name">Tadjourah</field>
-            <field name="code">DJ-TA</field>
-            <field name="type">region</field>
-            <field name="country" ref="dj"/>
-        </record>
-
-        <record model="country.subdivision" id="dk-81">
-            <field name="name">Nordjylland</field>
-            <field name="code">DK-81</field>
-            <field name="type">region</field>
-            <field name="country" ref="dk"/>
-        </record>
-
-        <record model="country.subdivision" id="dk-82">
-            <field name="name">Midtjylland</field>
-            <field name="code">DK-82</field>
-            <field name="type">region</field>
-            <field name="country" ref="dk"/>
-        </record>
-
-        <record model="country.subdivision" id="dk-83">
-            <field name="name">Syddanmark</field>
-            <field name="code">DK-83</field>
-            <field name="type">region</field>
-            <field name="country" ref="dk"/>
-        </record>
-
-        <record model="country.subdivision" id="dk-84">
-            <field name="name">Hovedstaden</field>
-            <field name="code">DK-84</field>
-            <field name="type">region</field>
-            <field name="country" ref="dk"/>
-        </record>
-
-        <record model="country.subdivision" id="dk-85">
-            <field name="name">Sjælland</field>
-            <field name="code">DK-85</field>
-            <field name="type">region</field>
-            <field name="country" ref="dk"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-01">
-            <field name="name">Saint Peter</field>
-            <field name="code">DM-01</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-02">
-            <field name="name">Saint Andrew</field>
-            <field name="code">DM-02</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-03">
-            <field name="name">Saint David</field>
-            <field name="code">DM-03</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-04">
-            <field name="name">Saint George</field>
-            <field name="code">DM-04</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-05">
-            <field name="name">Saint John</field>
-            <field name="code">DM-05</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-06">
-            <field name="name">Saint Joseph</field>
-            <field name="code">DM-06</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-07">
-            <field name="name">Saint Luke</field>
-            <field name="code">DM-07</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-08">
-            <field name="name">Saint Mark</field>
-            <field name="code">DM-08</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-09">
-            <field name="name">Saint Patrick</field>
-            <field name="code">DM-09</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="dm-10">
-            <field name="name">Saint Paul</field>
-            <field name="code">DM-10</field>
-            <field name="type">parish</field>
-            <field name="country" ref="dm"/>
-        </record>
-
-        <record model="country.subdivision" id="do-01">
-            <field name="name">Distrito Nacional (Santo Domingo)</field>
-            <field name="code">DO-01</field>
-            <field name="type">district</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-02">
-            <field name="name">Azua</field>
-            <field name="code">DO-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-03">
-            <field name="name">Bahoruco</field>
-            <field name="code">DO-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-04">
-            <field name="name">Barahona</field>
-            <field name="code">DO-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-05">
-            <field name="name">Dajabón</field>
-            <field name="code">DO-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-06">
-            <field name="name">Duarte</field>
-            <field name="code">DO-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-07">
-            <field name="name">La Estrelleta [Elías Piña]</field>
-            <field name="code">DO-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-08">
-            <field name="name">El Seybo [El Seibo]</field>
-            <field name="code">DO-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-09">
-            <field name="name">Espaillat</field>
-            <field name="code">DO-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-10">
-            <field name="name">Independencia</field>
-            <field name="code">DO-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-11">
-            <field name="name">La Altagracia</field>
-            <field name="code">DO-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-12">
-            <field name="name">La Romana</field>
-            <field name="code">DO-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-13">
-            <field name="name">La Vega</field>
-            <field name="code">DO-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-14">
-            <field name="name">María Trinidad Sánchez</field>
-            <field name="code">DO-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-15">
-            <field name="name">Monte Cristi</field>
-            <field name="code">DO-15</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-16">
-            <field name="name">Pedernales</field>
-            <field name="code">DO-16</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-17">
-            <field name="name">Peravia</field>
-            <field name="code">DO-17</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-18">
-            <field name="name">Puerto Plata</field>
-            <field name="code">DO-18</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-19">
-            <field name="name">Salcedo</field>
-            <field name="code">DO-19</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-20">
-            <field name="name">Samaná</field>
-            <field name="code">DO-20</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-21">
-            <field name="name">San Cristóbal</field>
-            <field name="code">DO-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-22">
-            <field name="name">San Juan</field>
-            <field name="code">DO-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-23">
-            <field name="name">San Pedro de Macorís</field>
-            <field name="code">DO-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-24">
-            <field name="name">Sánchez Ramírez</field>
-            <field name="code">DO-24</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-25">
-            <field name="name">Santiago</field>
-            <field name="code">DO-25</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-26">
-            <field name="name">Santiago Rodríguez</field>
-            <field name="code">DO-26</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-27">
-            <field name="name">Valverde</field>
-            <field name="code">DO-27</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-28">
-            <field name="name">Monseñor Nouel</field>
-            <field name="code">DO-28</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-29">
-            <field name="name">Monte Plata</field>
-            <field name="code">DO-29</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="do-30">
-            <field name="name">Hato Mayor</field>
-            <field name="code">DO-30</field>
-            <field name="type">province</field>
-            <field name="country" ref="do"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-01">
-            <field name="name">Adrar</field>
-            <field name="code">DZ-01</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-02">
-            <field name="name">Chlef</field>
-            <field name="code">DZ-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-03">
-            <field name="name">Laghouat</field>
-            <field name="code">DZ-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-04">
-            <field name="name">Oum el Bouaghi</field>
-            <field name="code">DZ-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-05">
-            <field name="name">Batna</field>
-            <field name="code">DZ-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-06">
-            <field name="name">Béjaïa</field>
-            <field name="code">DZ-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-07">
-            <field name="name">Biskra</field>
-            <field name="code">DZ-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-08">
-            <field name="name">Béchar</field>
-            <field name="code">DZ-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-09">
-            <field name="name">Blida</field>
-            <field name="code">DZ-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-10">
-            <field name="name">Bouira</field>
-            <field name="code">DZ-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-11">
-            <field name="name">Tamanghasset</field>
-            <field name="code">DZ-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-12">
-            <field name="name">Tébessa</field>
-            <field name="code">DZ-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-13">
-            <field name="name">Tlemcen</field>
-            <field name="code">DZ-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-14">
-            <field name="name">Tiaret</field>
-            <field name="code">DZ-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-15">
-            <field name="name">Tizi Ouzou</field>
-            <field name="code">DZ-15</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-16">
-            <field name="name">Alger</field>
-            <field name="code">DZ-16</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-17">
-            <field name="name">Djelfa</field>
-            <field name="code">DZ-17</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-18">
-            <field name="name">Jijel</field>
-            <field name="code">DZ-18</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-19">
-            <field name="name">Sétif</field>
-            <field name="code">DZ-19</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-20">
-            <field name="name">Saïda</field>
-            <field name="code">DZ-20</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-21">
-            <field name="name">Skikda</field>
-            <field name="code">DZ-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-22">
-            <field name="name">Sidi Bel Abbès</field>
-            <field name="code">DZ-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-23">
-            <field name="name">Annaba</field>
-            <field name="code">DZ-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-24">
-            <field name="name">Guelma</field>
-            <field name="code">DZ-24</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-25">
-            <field name="name">Constantine</field>
-            <field name="code">DZ-25</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-26">
-            <field name="name">Médéa</field>
-            <field name="code">DZ-26</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-27">
-            <field name="name">Mostaganem</field>
-            <field name="code">DZ-27</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-28">
-            <field name="name">Msila</field>
-            <field name="code">DZ-28</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-29">
-            <field name="name">Mascara</field>
-            <field name="code">DZ-29</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-30">
-            <field name="name">Ouargla</field>
-            <field name="code">DZ-30</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-31">
-            <field name="name">Oran</field>
-            <field name="code">DZ-31</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-32">
-            <field name="name">El Bayadh</field>
-            <field name="code">DZ-32</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-33">
-            <field name="name">Illizi</field>
-            <field name="code">DZ-33</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-34">
-            <field name="name">Bordj Bou Arréridj</field>
-            <field name="code">DZ-34</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-35">
-            <field name="name">Boumerdès</field>
-            <field name="code">DZ-35</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-36">
-            <field name="name">El Tarf</field>
-            <field name="code">DZ-36</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-37">
-            <field name="name">Tindouf</field>
-            <field name="code">DZ-37</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-38">
-            <field name="name">Tissemsilt</field>
-            <field name="code">DZ-38</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-39">
-            <field name="name">El Oued</field>
-            <field name="code">DZ-39</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-40">
-            <field name="name">Khenchela</field>
-            <field name="code">DZ-40</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-41">
-            <field name="name">Souk Ahras</field>
-            <field name="code">DZ-41</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-42">
-            <field name="name">Tipaza</field>
-            <field name="code">DZ-42</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-43">
-            <field name="name">Mila</field>
-            <field name="code">DZ-43</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-44">
-            <field name="name">Aïn Defla</field>
-            <field name="code">DZ-44</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-45">
-            <field name="name">Naama</field>
-            <field name="code">DZ-45</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-46">
-            <field name="name">Aïn Témouchent</field>
-            <field name="code">DZ-46</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-47">
-            <field name="name">Ghardaïa</field>
-            <field name="code">DZ-47</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="dz-48">
-            <field name="name">Relizane</field>
-            <field name="code">DZ-48</field>
-            <field name="type">province</field>
-            <field name="country" ref="dz"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-a">
-            <field name="name">Azuay</field>
-            <field name="code">EC-A</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-b">
-            <field name="name">Bolívar</field>
-            <field name="code">EC-B</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-c">
-            <field name="name">Carchi</field>
-            <field name="code">EC-C</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-d">
-            <field name="name">Orellana</field>
-            <field name="code">EC-D</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-e">
-            <field name="name">Esmeraldas</field>
-            <field name="code">EC-E</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-f">
-            <field name="name">Cañar</field>
-            <field name="code">EC-F</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-g">
-            <field name="name">Guayas</field>
-            <field name="code">EC-G</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-h">
-            <field name="name">Chimborazo</field>
-            <field name="code">EC-H</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-i">
-            <field name="name">Imbabura</field>
-            <field name="code">EC-I</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-l">
-            <field name="name">Loja</field>
-            <field name="code">EC-L</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-m">
-            <field name="name">Manabí</field>
-            <field name="code">EC-M</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-n">
-            <field name="name">Napo</field>
-            <field name="code">EC-N</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-o">
-            <field name="name">El Oro</field>
-            <field name="code">EC-O</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-p">
-            <field name="name">Pichincha</field>
-            <field name="code">EC-P</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-r">
-            <field name="name">Los Ríos</field>
-            <field name="code">EC-R</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-s">
-            <field name="name">Morona-Santiago</field>
-            <field name="code">EC-S</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-sd">
-            <field name="name">Santo Domingo de los Tsáchilas</field>
-            <field name="code">EC-SD</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-se">
-            <field name="name">Santa Elena</field>
-            <field name="code">EC-SE</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-t">
-            <field name="name">Tungurahua</field>
-            <field name="code">EC-T</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-u">
-            <field name="name">Sucumbíos</field>
-            <field name="code">EC-U</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-w">
-            <field name="name">Galápagos</field>
-            <field name="code">EC-W</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-x">
-            <field name="name">Cotopaxi</field>
-            <field name="code">EC-X</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-y">
-            <field name="name">Pastaza</field>
-            <field name="code">EC-Y</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ec-z">
-            <field name="name">Zamora-Chinchipe</field>
-            <field name="code">EC-Z</field>
-            <field name="type">province</field>
-            <field name="country" ref="ec"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-37">
-            <field name="name">Harjumaa</field>
-            <field name="code">EE-37</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-39">
-            <field name="name">Hiiumaa</field>
-            <field name="code">EE-39</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-44">
-            <field name="name">Ida-Virumaa</field>
-            <field name="code">EE-44</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-49">
-            <field name="name">Jõgevamaa</field>
-            <field name="code">EE-49</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-51">
-            <field name="name">Järvamaa</field>
-            <field name="code">EE-51</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-57">
-            <field name="name">Läänemaa</field>
-            <field name="code">EE-57</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-59">
-            <field name="name">Lääne-Virumaa</field>
-            <field name="code">EE-59</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-65">
-            <field name="name">Põlvamaa</field>
-            <field name="code">EE-65</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-67">
-            <field name="name">Pärnumaa</field>
-            <field name="code">EE-67</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-70">
-            <field name="name">Raplamaa</field>
-            <field name="code">EE-70</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-74">
-            <field name="name">Saaremaa</field>
-            <field name="code">EE-74</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-78">
-            <field name="name">Tartumaa</field>
-            <field name="code">EE-78</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-82">
-            <field name="name">Valgamaa</field>
-            <field name="code">EE-82</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-84">
-            <field name="name">Viljandimaa</field>
-            <field name="code">EE-84</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="ee-86">
-            <field name="name">Võrumaa</field>
-            <field name="code">EE-86</field>
-            <field name="type">county</field>
-            <field name="country" ref="ee"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-alx">
-            <field name="name">Al Iskandarīyah</field>
-            <field name="code">EG-ALX</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-asn">
-            <field name="name">Aswān</field>
-            <field name="code">EG-ASN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-ast">
-            <field name="name">Asyūt</field>
-            <field name="code">EG-AST</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-ba">
-            <field name="name">Al Bahr al Ahmar</field>
-            <field name="code">EG-BA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-bh">
-            <field name="name">Al Buhayrah</field>
-            <field name="code">EG-BH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-bns">
-            <field name="name">Banī Suwayf</field>
-            <field name="code">EG-BNS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-c">
-            <field name="name">Al Qāhirah</field>
-            <field name="code">EG-C</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-dk">
-            <field name="name">Ad Daqahlīyah</field>
-            <field name="code">EG-DK</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-dt">
-            <field name="name">Dumyāt</field>
-            <field name="code">EG-DT</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-fym">
-            <field name="name">Al Fayyūm</field>
-            <field name="code">EG-FYM</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-gh">
-            <field name="name">Al Gharbīyah</field>
-            <field name="code">EG-GH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-gz">
-            <field name="name">Al Jīzah</field>
-            <field name="code">EG-GZ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-hu">
-            <field name="name">Ḩulwān</field>
-            <field name="code">EG-HU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-is">
-            <field name="name">Al Ismā`īlīyah</field>
-            <field name="code">EG-IS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-js">
-            <field name="name">Janūb Sīnā'</field>
-            <field name="code">EG-JS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-kb">
-            <field name="name">Al Qalyūbīyah</field>
-            <field name="code">EG-KB</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-kfs">
-            <field name="name">Kafr ash Shaykh</field>
-            <field name="code">EG-KFS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-kn">
-            <field name="name">Qinā</field>
-            <field name="code">EG-KN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-mn">
-            <field name="name">Al Minyā</field>
-            <field name="code">EG-MN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-mnf">
-            <field name="name">Al Minūfīyah</field>
-            <field name="code">EG-MNF</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-mt">
-            <field name="name">Matrūh</field>
-            <field name="code">EG-MT</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-pts">
-            <field name="name">Būr Sa`īd</field>
-            <field name="code">EG-PTS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-shg">
-            <field name="name">Sūhāj</field>
-            <field name="code">EG-SHG</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-shr">
-            <field name="name">Ash Sharqīyah</field>
-            <field name="code">EG-SHR</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-sin">
-            <field name="name">Shamal Sīnā'</field>
-            <field name="code">EG-SIN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-su">
-            <field name="name">As Sādis min Uktūbar</field>
-            <field name="code">EG-SU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-suz">
-            <field name="name">As Suways</field>
-            <field name="code">EG-SUZ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="eg-wad">
-            <field name="name">Al Wādī al Jadīd</field>
-            <field name="code">EG-WAD</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="eg"/>
-        </record>
-
-        <record model="country.subdivision" id="er-an">
-            <field name="name">Ansabā</field>
-            <field name="code">ER-AN</field>
-            <field name="type">province</field>
-            <field name="country" ref="er"/>
-        </record>
-
-        <record model="country.subdivision" id="er-dk">
-            <field name="name">Janūbī al Baḩrī al Aḩmar</field>
-            <field name="code">ER-DK</field>
-            <field name="type">province</field>
-            <field name="country" ref="er"/>
-        </record>
-
-        <record model="country.subdivision" id="er-du">
-            <field name="name">Al Janūbī</field>
-            <field name="code">ER-DU</field>
-            <field name="type">province</field>
-            <field name="country" ref="er"/>
-        </record>
-
-        <record model="country.subdivision" id="er-gb">
-            <field name="name">Qāsh-Barkah</field>
-            <field name="code">ER-GB</field>
-            <field name="type">province</field>
-            <field name="country" ref="er"/>
-        </record>
-
-        <record model="country.subdivision" id="er-ma">
-            <field name="name">Al Awsaţ</field>
-            <field name="code">ER-MA</field>
-            <field name="type">province</field>
-            <field name="country" ref="er"/>
-        </record>
-
-        <record model="country.subdivision" id="er-sk">
-            <field name="name">Shimālī al Baḩrī al Aḩmar</field>
-            <field name="code">ER-SK</field>
-            <field name="type">province</field>
-            <field name="country" ref="er"/>
-        </record>
-
-        <record model="country.subdivision" id="es-an">
-            <field name="name">Andalucía</field>
-            <field name="code">ES-AN</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ar">
-            <field name="name">Aragón</field>
-            <field name="code">ES-AR</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-as">
-            <field name="name">Asturias, Principado de</field>
-            <field name="code">ES-AS</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cb">
-            <field name="name">Cantabria</field>
-            <field name="code">ES-CB</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ce">
-            <field name="name">Ceuta</field>
-            <field name="code">ES-CE</field>
-            <field name="type">autonomous city</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cl">
-            <field name="name">Castilla y León</field>
-            <field name="code">ES-CL</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cm">
-            <field name="name">Castilla-La Mancha</field>
-            <field name="code">ES-CM</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cn">
-            <field name="name">Canarias</field>
-            <field name="code">ES-CN</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ct">
-            <field name="name">Catalunya</field>
-            <field name="code">ES-CT</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ex">
-            <field name="name">Extremadura</field>
-            <field name="code">ES-EX</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ga">
-            <field name="name">Galicia</field>
-            <field name="code">ES-GA</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ib">
-            <field name="name">Illes Balears</field>
-            <field name="code">ES-IB</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-mc">
-            <field name="name">Murcia, Región de</field>
-            <field name="code">ES-MC</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-md">
-            <field name="name">Madrid, Comunidad de</field>
-            <field name="code">ES-MD</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ml">
-            <field name="name">Melilla</field>
-            <field name="code">ES-ML</field>
-            <field name="type">autonomous city</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-nc">
-            <field name="name">Navarra, Comunidad Foral de / Nafarroako Foru Komunitatea</field>
-            <field name="code">ES-NC</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-pv">
-            <field name="name">País Vasco / Euskal Herria</field>
-            <field name="code">ES-PV</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ri">
-            <field name="name">La Rioja</field>
-            <field name="code">ES-RI</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-vc">
-            <field name="name">Valenciana, Comunidad / Valenciana, Comunitat</field>
-            <field name="code">ES-VC</field>
-            <field name="type">autonomous community</field>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="et-aa">
-            <field name="name">Ādīs Ābeba</field>
-            <field name="code">ET-AA</field>
-            <field name="type">administration</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-af">
-            <field name="name">Āfar</field>
-            <field name="code">ET-AF</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-am">
-            <field name="name">Āmara</field>
-            <field name="code">ET-AM</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-be">
-            <field name="name">Bīnshangul Gumuz</field>
-            <field name="code">ET-BE</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-dd">
-            <field name="name">Dirē Dawa</field>
-            <field name="code">ET-DD</field>
-            <field name="type">administration</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-ga">
-            <field name="name">Gambēla Hizboch</field>
-            <field name="code">ET-GA</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-ha">
-            <field name="name">Hārerī Hizb</field>
-            <field name="code">ET-HA</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-or">
-            <field name="name">Oromīya</field>
-            <field name="code">ET-OR</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-sn">
-            <field name="name">YeDebub Bihēroch Bihēreseboch na Hizboch</field>
-            <field name="code">ET-SN</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-so">
-            <field name="name">Sumalē</field>
-            <field name="code">ET-SO</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="et-ti">
-            <field name="name">Tigray</field>
-            <field name="code">ET-TI</field>
-            <field name="type">state</field>
-            <field name="country" ref="et"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-01">
-            <field name="name">Ahvenanmaan maakunta</field>
-            <field name="code">FI-01</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-02">
-            <field name="name">Etelä-Karjala</field>
-            <field name="code">FI-02</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-03">
-            <field name="name">Etelä-Pohjanmaa</field>
-            <field name="code">FI-03</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-04">
-            <field name="name">Etelä-Savo</field>
-            <field name="code">FI-04</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-05">
-            <field name="name">Kainuu</field>
-            <field name="code">FI-05</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-06">
-            <field name="name">Kanta-Häme</field>
-            <field name="code">FI-06</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-07">
-            <field name="name">Keski-Pohjanmaa</field>
-            <field name="code">FI-07</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-08">
-            <field name="name">Keski-Suomi</field>
-            <field name="code">FI-08</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-09">
-            <field name="name">Kymenlaakso</field>
-            <field name="code">FI-09</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-10">
-            <field name="name">Lappi</field>
-            <field name="code">FI-10</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-11">
-            <field name="name">Pirkanmaa</field>
-            <field name="code">FI-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-12">
-            <field name="name">Pohjanmaa</field>
-            <field name="code">FI-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-13">
-            <field name="name">Pohjois-Karjala</field>
-            <field name="code">FI-13</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-14">
-            <field name="name">Pohjois-Pohjanmaa</field>
-            <field name="code">FI-14</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-15">
-            <field name="name">Pohjois-Savo</field>
-            <field name="code">FI-15</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-16">
-            <field name="name">Päijät-Häme</field>
-            <field name="code">FI-16</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-17">
-            <field name="name">Satakunta</field>
-            <field name="code">FI-17</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-18">
-            <field name="name">Uusimaa</field>
-            <field name="code">FI-18</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fi-19">
-            <field name="name">Varsinais-Suomi</field>
-            <field name="code">FI-19</field>
-            <field name="type">region</field>
-            <field name="country" ref="fi"/>
-        </record>
-
-        <record model="country.subdivision" id="fj-c">
-            <field name="name">Central</field>
-            <field name="code">FJ-C</field>
-            <field name="type">division</field>
-            <field name="country" ref="fj"/>
-        </record>
-
-        <record model="country.subdivision" id="fj-e">
-            <field name="name">Eastern</field>
-            <field name="code">FJ-E</field>
-            <field name="type">division</field>
-            <field name="country" ref="fj"/>
-        </record>
-
-        <record model="country.subdivision" id="fj-n">
-            <field name="name">Northern</field>
-            <field name="code">FJ-N</field>
-            <field name="type">division</field>
-            <field name="country" ref="fj"/>
-        </record>
-
-        <record model="country.subdivision" id="fj-r">
-            <field name="name">Rotuma</field>
-            <field name="code">FJ-R</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="fj"/>
-        </record>
-
-        <record model="country.subdivision" id="fj-w">
-            <field name="name">Western</field>
-            <field name="code">FJ-W</field>
-            <field name="type">division</field>
-            <field name="country" ref="fj"/>
-        </record>
-
-        <record model="country.subdivision" id="fm-ksa">
-            <field name="name">Kosrae</field>
-            <field name="code">FM-KSA</field>
-            <field name="type">state</field>
-            <field name="country" ref="fm"/>
-        </record>
-
-        <record model="country.subdivision" id="fm-pni">
-            <field name="name">Pohnpei</field>
-            <field name="code">FM-PNI</field>
-            <field name="type">state</field>
-            <field name="country" ref="fm"/>
-        </record>
-
-        <record model="country.subdivision" id="fm-trk">
-            <field name="name">Chuuk</field>
-            <field name="code">FM-TRK</field>
-            <field name="type">state</field>
-            <field name="country" ref="fm"/>
-        </record>
-
-        <record model="country.subdivision" id="fm-yap">
-            <field name="name">Yap</field>
-            <field name="code">FM-YAP</field>
-            <field name="type">state</field>
-            <field name="country" ref="fm"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-ara">
-            <field name="name">Auvergne-Rhône-Alpes</field>
-            <field name="code">FR-ARA</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-bfc">
-            <field name="name">Bourgogne-Franche-Comté</field>
-            <field name="code">FR-BFC</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-bl">
-            <field name="name">Saint-Barthélemy</field>
-            <field name="code">FR-BL</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-bre">
-            <field name="name">Bretagne</field>
-            <field name="code">FR-BRE</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-cor">
-            <field name="name">Corse</field>
-            <field name="code">FR-COR</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-cp">
-            <field name="name">Clipperton</field>
-            <field name="code">FR-CP</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-cvl">
-            <field name="name">Centre-Val de Loire</field>
-            <field name="code">FR-CVL</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-ges">
-            <field name="name">Grand-Est</field>
-            <field name="code">FR-GES</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-gf">
-            <field name="name">Guyane (française)</field>
-            <field name="code">FR-GF</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-gua">
-            <field name="name">Guadeloupe</field>
-            <field name="code">FR-GUA</field>
-            <field name="type">overseas region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-hdf">
-            <field name="name">Hauts-de-France</field>
-            <field name="code">FR-HDF</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-idf">
-            <field name="name">Île-de-France</field>
-            <field name="code">FR-IDF</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-lre">
-            <field name="name">La Réunion</field>
-            <field name="code">FR-LRE</field>
-            <field name="type">overseas region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-may">
-            <field name="name">Mayotte</field>
-            <field name="code">FR-MAY</field>
-            <field name="type">overseas region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-mf">
-            <field name="name">Saint-Martin</field>
-            <field name="code">FR-MF</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-mq">
-            <field name="name">Martinique</field>
-            <field name="code">FR-MQ</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-naq">
-            <field name="name">Nouvelle-Aquitaine</field>
-            <field name="code">FR-NAQ</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-nc">
-            <field name="name">Nouvelle-Calédonie</field>
-            <field name="code">FR-NC</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-nor">
-            <field name="name">Normandie</field>
-            <field name="code">FR-NOR</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-occ">
-            <field name="name">Occitanie</field>
-            <field name="code">FR-OCC</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-pac">
-            <field name="name">Provence-Alpes-Côte-d’Azur</field>
-            <field name="code">FR-PAC</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-pdl">
-            <field name="name">Pays-de-la-Loire</field>
-            <field name="code">FR-PDL</field>
-            <field name="type">metropolitan region</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-pf">
-            <field name="name">Polynésie française</field>
-            <field name="code">FR-PF</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-pm">
-            <field name="name">Saint-Pierre-et-Miquelon</field>
-            <field name="code">FR-PM</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-tf">
-            <field name="name">Terres australes françaises</field>
-            <field name="code">FR-TF</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-wf">
-            <field name="name">Wallis-et-Futuna</field>
-            <field name="code">FR-WF</field>
-            <field name="type">overseas territorial collectivity</field>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-1">
-            <field name="name">Estuaire</field>
-            <field name="code">GA-1</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-2">
-            <field name="name">Haut-Ogooué</field>
-            <field name="code">GA-2</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-3">
-            <field name="name">Moyen-Ogooué</field>
-            <field name="code">GA-3</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-4">
-            <field name="name">Ngounié</field>
-            <field name="code">GA-4</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-5">
-            <field name="name">Nyanga</field>
-            <field name="code">GA-5</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-6">
-            <field name="name">Ogooué-Ivindo</field>
-            <field name="code">GA-6</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-7">
-            <field name="name">Ogooué-Lolo</field>
-            <field name="code">GA-7</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-8">
-            <field name="name">Ogooué-Maritime</field>
-            <field name="code">GA-8</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="ga-9">
-            <field name="name">Woleu-Ntem</field>
-            <field name="code">GA-9</field>
-            <field name="type">province</field>
-            <field name="country" ref="ga"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-eaw">
-            <field name="name">England and Wales</field>
-            <field name="code">GB-EAW</field>
-            <field name="type">nation</field>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-eng">
-            <field name="name">England</field>
-            <field name="code">GB-ENG</field>
-            <field name="type">country</field>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-gbn">
-            <field name="name">Great Britain</field>
-            <field name="code">GB-GBN</field>
-            <field name="type">nation</field>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nir">
-            <field name="name">Northern Ireland</field>
-            <field name="code">GB-NIR</field>
-            <field name="type">province</field>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sct">
-            <field name="name">Scotland</field>
-            <field name="code">GB-SCT</field>
-            <field name="type">country</field>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ukm">
-            <field name="name">United Kingdom</field>
-            <field name="code">GB-UKM</field>
-            <field name="type">nation</field>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wls">
-            <field name="name">Wales; Cymru</field>
-            <field name="code">GB-WLS</field>
-            <field name="type">country</field>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gd-01">
-            <field name="name">Saint Andrew</field>
-            <field name="code">GD-01</field>
-            <field name="type">parish</field>
-            <field name="country" ref="gd"/>
-        </record>
-
-        <record model="country.subdivision" id="gd-02">
-            <field name="name">Saint David</field>
-            <field name="code">GD-02</field>
-            <field name="type">parish</field>
-            <field name="country" ref="gd"/>
-        </record>
-
-        <record model="country.subdivision" id="gd-03">
-            <field name="name">Saint George</field>
-            <field name="code">GD-03</field>
-            <field name="type">parish</field>
-            <field name="country" ref="gd"/>
-        </record>
-
-        <record model="country.subdivision" id="gd-04">
-            <field name="name">Saint John</field>
-            <field name="code">GD-04</field>
-            <field name="type">parish</field>
-            <field name="country" ref="gd"/>
-        </record>
-
-        <record model="country.subdivision" id="gd-05">
-            <field name="name">Saint Mark</field>
-            <field name="code">GD-05</field>
-            <field name="type">parish</field>
-            <field name="country" ref="gd"/>
-        </record>
-
-        <record model="country.subdivision" id="gd-06">
-            <field name="name">Saint Patrick</field>
-            <field name="code">GD-06</field>
-            <field name="type">parish</field>
-            <field name="country" ref="gd"/>
-        </record>
-
-        <record model="country.subdivision" id="gd-10">
-            <field name="name">Southern Grenadine Islands</field>
-            <field name="code">GD-10</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="gd"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-ab">
-            <field name="name">Abkhazia</field>
-            <field name="code">GE-AB</field>
-            <field name="type">autonomous republic</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-aj">
-            <field name="name">Ajaria</field>
-            <field name="code">GE-AJ</field>
-            <field name="type">autonomous republic</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-gu">
-            <field name="name">Guria</field>
-            <field name="code">GE-GU</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-im">
-            <field name="name">Imeret’i</field>
-            <field name="code">GE-IM</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-ka">
-            <field name="name">Kakhet’i</field>
-            <field name="code">GE-KA</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-kk">
-            <field name="name">K’vemo K’art’li</field>
-            <field name="code">GE-KK</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-mm">
-            <field name="name">Mts’khet’a-Mt’ianet’i</field>
-            <field name="code">GE-MM</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-rl">
-            <field name="name">Racha-Lech’khumi-K’vemo Svanet’i</field>
-            <field name="code">GE-RL</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-sj">
-            <field name="name">Samts’khe-Javakhet’i</field>
-            <field name="code">GE-SJ</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-sk">
-            <field name="name">Shida K’art’li</field>
-            <field name="code">GE-SK</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-sz">
-            <field name="name">Samegrelo-Zemo Svanet’i</field>
-            <field name="code">GE-SZ</field>
-            <field name="type">region</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="ge-tb">
-            <field name="name">T’bilisi</field>
-            <field name="code">GE-TB</field>
-            <field name="type">city</field>
-            <field name="country" ref="ge"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-aa">
-            <field name="name">Greater Accra</field>
-            <field name="code">GH-AA</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-ah">
-            <field name="name">Ashanti</field>
-            <field name="code">GH-AH</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-ba">
-            <field name="name">Brong-Ahafo</field>
-            <field name="code">GH-BA</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-cp">
-            <field name="name">Central</field>
-            <field name="code">GH-CP</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-ep">
-            <field name="name">Eastern</field>
-            <field name="code">GH-EP</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-np">
-            <field name="name">Northern</field>
-            <field name="code">GH-NP</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-tv">
-            <field name="name">Volta</field>
-            <field name="code">GH-TV</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-ue">
-            <field name="name">Upper East</field>
-            <field name="code">GH-UE</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-uw">
-            <field name="name">Upper West</field>
-            <field name="code">GH-UW</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gh-wp">
-            <field name="name">Western</field>
-            <field name="code">GH-WP</field>
-            <field name="type">region</field>
-            <field name="country" ref="gh"/>
-        </record>
-
-        <record model="country.subdivision" id="gl-ku">
-            <field name="name">Kommune Kujalleq</field>
-            <field name="code">GL-KU</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="gl"/>
-        </record>
-
-        <record model="country.subdivision" id="gl-qa">
-            <field name="name">Qaasuitsup Kommunia</field>
-            <field name="code">GL-QA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="gl"/>
-        </record>
-
-        <record model="country.subdivision" id="gl-qe">
-            <field name="name">Qeqqata Kommunia</field>
-            <field name="code">GL-QE</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="gl"/>
-        </record>
-
-        <record model="country.subdivision" id="gl-sm">
-            <field name="name">Kommuneqarfik Sermersooq</field>
-            <field name="code">GL-SM</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="gl"/>
-        </record>
-
-        <record model="country.subdivision" id="gm-b">
-            <field name="name">Banjul</field>
-            <field name="code">GM-B</field>
-            <field name="type">city</field>
-            <field name="country" ref="gm"/>
-        </record>
-
-        <record model="country.subdivision" id="gm-l">
-            <field name="name">Lower River</field>
-            <field name="code">GM-L</field>
-            <field name="type">division</field>
-            <field name="country" ref="gm"/>
-        </record>
-
-        <record model="country.subdivision" id="gm-m">
-            <field name="name">Central River</field>
-            <field name="code">GM-M</field>
-            <field name="type">division</field>
-            <field name="country" ref="gm"/>
-        </record>
-
-        <record model="country.subdivision" id="gm-n">
-            <field name="name">North Bank</field>
-            <field name="code">GM-N</field>
-            <field name="type">division</field>
-            <field name="country" ref="gm"/>
-        </record>
-
-        <record model="country.subdivision" id="gm-u">
-            <field name="name">Upper River</field>
-            <field name="code">GM-U</field>
-            <field name="type">division</field>
-            <field name="country" ref="gm"/>
-        </record>
-
-        <record model="country.subdivision" id="gm-w">
-            <field name="name">Western</field>
-            <field name="code">GM-W</field>
-            <field name="type">division</field>
-            <field name="country" ref="gm"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-b">
-            <field name="name">Boké</field>
-            <field name="code">GN-B</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-c">
-            <field name="name">Conakry</field>
-            <field name="code">GN-C</field>
-            <field name="type">special zone</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-d">
-            <field name="name">Kindia</field>
-            <field name="code">GN-D</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-f">
-            <field name="name">Faranah</field>
-            <field name="code">GN-F</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-k">
-            <field name="name">Kankan</field>
-            <field name="code">GN-K</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-l">
-            <field name="name">Labé</field>
-            <field name="code">GN-L</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-m">
-            <field name="name">Mamou</field>
-            <field name="code">GN-M</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-n">
-            <field name="name">Nzérékoré</field>
-            <field name="code">GN-N</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-c">
-            <field name="name">Región Continental</field>
-            <field name="code">GQ-C</field>
-            <field name="type">region</field>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-i">
-            <field name="name">Región Insular</field>
-            <field name="code">GQ-I</field>
-            <field name="type">region</field>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-69">
-            <field name="name">Agio Oros</field>
-            <field name="code">GR-69</field>
-            <field name="type">self-governed part</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-a">
-            <field name="name">Anatoliki Makedonia kai Thraki</field>
-            <field name="code">GR-A</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-b">
-            <field name="name">Kentriki Makedonia</field>
-            <field name="code">GR-B</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-c">
-            <field name="name">Dytiki Makedonia</field>
-            <field name="code">GR-C</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-d">
-            <field name="name">Ipeiros</field>
-            <field name="code">GR-D</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-e">
-            <field name="name">Thessalia</field>
-            <field name="code">GR-E</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-f">
-            <field name="name">Ionia Nisia</field>
-            <field name="code">GR-F</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-g">
-            <field name="name">Dytiki Ellada</field>
-            <field name="code">GR-G</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-h">
-            <field name="name">Sterea Ellada</field>
-            <field name="code">GR-H</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-i">
-            <field name="name">Attiki</field>
-            <field name="code">GR-I</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-j">
-            <field name="name">Peloponnisos</field>
-            <field name="code">GR-J</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-k">
-            <field name="name">Voreio Aigaio</field>
-            <field name="code">GR-K</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-l">
-            <field name="name">Notio Aigaio</field>
-            <field name="code">GR-L</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-m">
-            <field name="name">Kriti</field>
-            <field name="code">GR-M</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-av">
-            <field name="name">Alta Verapaz</field>
-            <field name="code">GT-AV</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-bv">
-            <field name="name">Baja Verapaz</field>
-            <field name="code">GT-BV</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-cm">
-            <field name="name">Chimaltenango</field>
-            <field name="code">GT-CM</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-cq">
-            <field name="name">Chiquimula</field>
-            <field name="code">GT-CQ</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-es">
-            <field name="name">Escuintla</field>
-            <field name="code">GT-ES</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-gu">
-            <field name="name">Guatemala</field>
-            <field name="code">GT-GU</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-hu">
-            <field name="name">Huehuetenango</field>
-            <field name="code">GT-HU</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-iz">
-            <field name="name">Izabal</field>
-            <field name="code">GT-IZ</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-ja">
-            <field name="name">Jalapa</field>
-            <field name="code">GT-JA</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-ju">
-            <field name="name">Jutiapa</field>
-            <field name="code">GT-JU</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-pe">
-            <field name="name">Petén</field>
-            <field name="code">GT-PE</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-pr">
-            <field name="name">El Progreso</field>
-            <field name="code">GT-PR</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-qc">
-            <field name="name">Quiché</field>
-            <field name="code">GT-QC</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-qz">
-            <field name="name">Quetzaltenango</field>
-            <field name="code">GT-QZ</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-re">
-            <field name="name">Retalhuleu</field>
-            <field name="code">GT-RE</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-sa">
-            <field name="name">Sacatepéquez</field>
-            <field name="code">GT-SA</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-sm">
-            <field name="name">San Marcos</field>
-            <field name="code">GT-SM</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-so">
-            <field name="name">Sololá</field>
-            <field name="code">GT-SO</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-sr">
-            <field name="name">Santa Rosa</field>
-            <field name="code">GT-SR</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-su">
-            <field name="name">Suchitepéquez</field>
-            <field name="code">GT-SU</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-to">
-            <field name="name">Totonicapán</field>
-            <field name="code">GT-TO</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gt-za">
-            <field name="name">Zacapa</field>
-            <field name="code">GT-ZA</field>
-            <field name="type">department</field>
-            <field name="country" ref="gt"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-bs">
-            <field name="name">Bissau</field>
-            <field name="code">GW-BS</field>
-            <field name="type">autonomous sector</field>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-l">
-            <field name="name">Leste</field>
-            <field name="code">GW-L</field>
-            <field name="type">province</field>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-n">
-            <field name="name">Norte</field>
-            <field name="code">GW-N</field>
-            <field name="type">province</field>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-s">
-            <field name="name">Sul</field>
-            <field name="code">GW-S</field>
-            <field name="type">province</field>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-ba">
-            <field name="name">Barima-Waini</field>
-            <field name="code">GY-BA</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-cu">
-            <field name="name">Cuyuni-Mazaruni</field>
-            <field name="code">GY-CU</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-de">
-            <field name="name">Demerara-Mahaica</field>
-            <field name="code">GY-DE</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-eb">
-            <field name="name">East Berbice-Corentyne</field>
-            <field name="code">GY-EB</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-es">
-            <field name="name">Essequibo Islands-West Demerara</field>
-            <field name="code">GY-ES</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-ma">
-            <field name="name">Mahaica-Berbice</field>
-            <field name="code">GY-MA</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-pm">
-            <field name="name">Pomeroon-Supenaam</field>
-            <field name="code">GY-PM</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-pt">
-            <field name="name">Potaro-Siparuni</field>
-            <field name="code">GY-PT</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-ud">
-            <field name="name">Upper Demerara-Berbice</field>
-            <field name="code">GY-UD</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="gy-ut">
-            <field name="name">Upper Takutu-Upper Essequibo</field>
-            <field name="code">GY-UT</field>
-            <field name="type">region</field>
-            <field name="country" ref="gy"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-at">
-            <field name="name">Atlántida</field>
-            <field name="code">HN-AT</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-ch">
-            <field name="name">Choluteca</field>
-            <field name="code">HN-CH</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-cl">
-            <field name="name">Colón</field>
-            <field name="code">HN-CL</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-cm">
-            <field name="name">Comayagua</field>
-            <field name="code">HN-CM</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-cp">
-            <field name="name">Copán</field>
-            <field name="code">HN-CP</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-cr">
-            <field name="name">Cortés</field>
-            <field name="code">HN-CR</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-ep">
-            <field name="name">El Paraíso</field>
-            <field name="code">HN-EP</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-fm">
-            <field name="name">Francisco Morazán</field>
-            <field name="code">HN-FM</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-gd">
-            <field name="name">Gracias a Dios</field>
-            <field name="code">HN-GD</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-ib">
-            <field name="name">Islas de la Bahía</field>
-            <field name="code">HN-IB</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-in">
-            <field name="name">Intibucá</field>
-            <field name="code">HN-IN</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-le">
-            <field name="name">Lempira</field>
-            <field name="code">HN-LE</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-lp">
-            <field name="name">La Paz</field>
-            <field name="code">HN-LP</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-oc">
-            <field name="name">Ocotepeque</field>
-            <field name="code">HN-OC</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-ol">
-            <field name="name">Olancho</field>
-            <field name="code">HN-OL</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-sb">
-            <field name="name">Santa Bárbara</field>
-            <field name="code">HN-SB</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-va">
-            <field name="name">Valle</field>
-            <field name="code">HN-VA</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hn-yo">
-            <field name="name">Yoro</field>
-            <field name="code">HN-YO</field>
-            <field name="type">department</field>
-            <field name="country" ref="hn"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-01">
-            <field name="name">Zagrebačka županija</field>
-            <field name="code">HR-01</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-02">
-            <field name="name">Krapinsko-zagorska županija</field>
-            <field name="code">HR-02</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-03">
-            <field name="name">Sisačko-moslavačka županija</field>
-            <field name="code">HR-03</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-04">
-            <field name="name">Karlovačka županija</field>
-            <field name="code">HR-04</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-05">
-            <field name="name">Varaždinska županija</field>
-            <field name="code">HR-05</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-06">
-            <field name="name">Koprivničko-križevačka županija</field>
-            <field name="code">HR-06</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-07">
-            <field name="name">Bjelovarsko-bilogorska županija</field>
-            <field name="code">HR-07</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-08">
-            <field name="name">Primorsko-goranska županija</field>
-            <field name="code">HR-08</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-09">
-            <field name="name">Ličko-senjska županija</field>
-            <field name="code">HR-09</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-10">
-            <field name="name">Virovitičko-podravska županija</field>
-            <field name="code">HR-10</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-11">
-            <field name="name">Požeško-slavonska županija</field>
-            <field name="code">HR-11</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-12">
-            <field name="name">Brodsko-posavska županija</field>
-            <field name="code">HR-12</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-13">
-            <field name="name">Zadarska županija</field>
-            <field name="code">HR-13</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-14">
-            <field name="name">Osječko-baranjska županija</field>
-            <field name="code">HR-14</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-15">
-            <field name="name">Šibensko-kninska županija</field>
-            <field name="code">HR-15</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-16">
-            <field name="name">Vukovarsko-srijemska županija</field>
-            <field name="code">HR-16</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-17">
-            <field name="name">Splitsko-dalmatinska županija</field>
-            <field name="code">HR-17</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-18">
-            <field name="name">Istarska županija</field>
-            <field name="code">HR-18</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-19">
-            <field name="name">Dubrovačko-neretvanska županija</field>
-            <field name="code">HR-19</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-20">
-            <field name="name">Međimurska županija</field>
-            <field name="code">HR-20</field>
-            <field name="type">county</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="hr-21">
-            <field name="name">Grad Zagreb</field>
-            <field name="code">HR-21</field>
-            <field name="type">city</field>
-            <field name="country" ref="hr"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-ar">
-            <field name="name">Artibonite</field>
-            <field name="code">HT-AR</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-ce">
-            <field name="name">Centre</field>
-            <field name="code">HT-CE</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-ga">
-            <field name="name">Grande-Anse</field>
-            <field name="code">HT-GA</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-nd">
-            <field name="name">Nord</field>
-            <field name="code">HT-ND</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-ne">
-            <field name="name">Nord-Est</field>
-            <field name="code">HT-NE</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-no">
-            <field name="name">Nord-Ouest</field>
-            <field name="code">HT-NO</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-ou">
-            <field name="name">Ouest</field>
-            <field name="code">HT-OU</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-sd">
-            <field name="name">Sud</field>
-            <field name="code">HT-SD</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="ht-se">
-            <field name="name">Sud-Est</field>
-            <field name="code">HT-SE</field>
-            <field name="type">department</field>
-            <field name="country" ref="ht"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-ba">
-            <field name="name">Baranya</field>
-            <field name="code">HU-BA</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-bc">
-            <field name="name">Békéscsaba</field>
-            <field name="code">HU-BC</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-be">
-            <field name="name">Békés</field>
-            <field name="code">HU-BE</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-bk">
-            <field name="name">Bács-Kiskun</field>
-            <field name="code">HU-BK</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-bu">
-            <field name="name">Budapest</field>
-            <field name="code">HU-BU</field>
-            <field name="type">capital city</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-bz">
-            <field name="name">Borsod-Abaúj-Zemplén</field>
-            <field name="code">HU-BZ</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-cs">
-            <field name="name">Csongrád</field>
-            <field name="code">HU-CS</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-de">
-            <field name="name">Debrecen</field>
-            <field name="code">HU-DE</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-du">
-            <field name="name">Dunaújváros</field>
-            <field name="code">HU-DU</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-eg">
-            <field name="name">Eger</field>
-            <field name="code">HU-EG</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-er">
-            <field name="name">Érd</field>
-            <field name="code">HU-ER</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-fe">
-            <field name="name">Fejér</field>
-            <field name="code">HU-FE</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-gs">
-            <field name="name">Győr-Moson-Sopron</field>
-            <field name="code">HU-GS</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-gy">
-            <field name="name">Győr</field>
-            <field name="code">HU-GY</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-hb">
-            <field name="name">Hajdú-Bihar</field>
-            <field name="code">HU-HB</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-he">
-            <field name="name">Heves</field>
-            <field name="code">HU-HE</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-hv">
-            <field name="name">Hódmezővásárhely</field>
-            <field name="code">HU-HV</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-jn">
-            <field name="name">Jász-Nagykun-Szolnok</field>
-            <field name="code">HU-JN</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-ke">
-            <field name="name">Komárom-Esztergom</field>
-            <field name="code">HU-KE</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-km">
-            <field name="name">Kecskemét</field>
-            <field name="code">HU-KM</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-kv">
-            <field name="name">Kaposvár</field>
-            <field name="code">HU-KV</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-mi">
-            <field name="name">Miskolc</field>
-            <field name="code">HU-MI</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-nk">
-            <field name="name">Nagykanizsa</field>
-            <field name="code">HU-NK</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-no">
-            <field name="name">Nógrád</field>
-            <field name="code">HU-NO</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-ny">
-            <field name="name">Nyíregyháza</field>
-            <field name="code">HU-NY</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-pe">
-            <field name="name">Pest</field>
-            <field name="code">HU-PE</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-ps">
-            <field name="name">Pécs</field>
-            <field name="code">HU-PS</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-sd">
-            <field name="name">Szeged</field>
-            <field name="code">HU-SD</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-sf">
-            <field name="name">Székesfehérvár</field>
-            <field name="code">HU-SF</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-sh">
-            <field name="name">Szombathely</field>
-            <field name="code">HU-SH</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-sk">
-            <field name="name">Szolnok</field>
-            <field name="code">HU-SK</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-sn">
-            <field name="name">Sopron</field>
-            <field name="code">HU-SN</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-so">
-            <field name="name">Somogy</field>
-            <field name="code">HU-SO</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-ss">
-            <field name="name">Szekszárd</field>
-            <field name="code">HU-SS</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-st">
-            <field name="name">Salgótarján</field>
-            <field name="code">HU-ST</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-sz">
-            <field name="name">Szabolcs-Szatmár-Bereg</field>
-            <field name="code">HU-SZ</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-tb">
-            <field name="name">Tatabánya</field>
-            <field name="code">HU-TB</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-to">
-            <field name="name">Tolna</field>
-            <field name="code">HU-TO</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-va">
-            <field name="name">Vas</field>
-            <field name="code">HU-VA</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-ve">
-            <field name="name">Veszprém (county)</field>
-            <field name="code">HU-VE</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-vm">
-            <field name="name">Veszprém</field>
-            <field name="code">HU-VM</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-za">
-            <field name="name">Zala</field>
-            <field name="code">HU-ZA</field>
-            <field name="type">county</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="hu-ze">
-            <field name="name">Zalaegerszeg</field>
-            <field name="code">HU-ZE</field>
-            <field name="type">city with county rights</field>
-            <field name="country" ref="hu"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ij">
-            <field name="name">Papua</field>
-            <field name="code">ID-IJ</field>
-            <field name="type">geographical unit</field>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-jw">
-            <field name="name">Jawa</field>
-            <field name="code">ID-JW</field>
-            <field name="type">geographical unit</field>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ka">
-            <field name="name">Kalimantan</field>
-            <field name="code">ID-KA</field>
-            <field name="type">geographical unit</field>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ml">
-            <field name="name">Maluku</field>
-            <field name="code">ID-ML</field>
-            <field name="type">geographical unit</field>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-nu">
-            <field name="name">Nusa Tenggara</field>
-            <field name="code">ID-NU</field>
-            <field name="type">geographical unit</field>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-sl">
-            <field name="name">Sulawesi</field>
-            <field name="code">ID-SL</field>
-            <field name="type">geographical unit</field>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-sm">
-            <field name="name">Sumatera</field>
-            <field name="code">ID-SM</field>
-            <field name="type">geographical unit</field>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-c">
-            <field name="name">Connacht</field>
-            <field name="code">IE-C</field>
-            <field name="type">province</field>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-l">
-            <field name="name">Leinster</field>
-            <field name="code">IE-L</field>
-            <field name="type">province</field>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-m">
-            <field name="name">Munster</field>
-            <field name="code">IE-M</field>
-            <field name="type">province</field>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-u">
-            <field name="name">Ulster</field>
-            <field name="code">IE-U</field>
-            <field name="type">province</field>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="il-d">
-            <field name="name">HaDarom</field>
-            <field name="code">IL-D</field>
-            <field name="type">district</field>
-            <field name="country" ref="il"/>
-        </record>
-
-        <record model="country.subdivision" id="il-ha">
-            <field name="name">Hefa</field>
-            <field name="code">IL-HA</field>
-            <field name="type">district</field>
-            <field name="country" ref="il"/>
-        </record>
-
-        <record model="country.subdivision" id="il-jm">
-            <field name="name">Yerushalayim Al Quds</field>
-            <field name="code">IL-JM</field>
-            <field name="type">district</field>
-            <field name="country" ref="il"/>
-        </record>
-
-        <record model="country.subdivision" id="il-m">
-            <field name="name">HaMerkaz</field>
-            <field name="code">IL-M</field>
-            <field name="type">district</field>
-            <field name="country" ref="il"/>
-        </record>
-
-        <record model="country.subdivision" id="il-ta">
-            <field name="name">Tel-Aviv</field>
-            <field name="code">IL-TA</field>
-            <field name="type">district</field>
-            <field name="country" ref="il"/>
-        </record>
-
-        <record model="country.subdivision" id="il-z">
-            <field name="name">HaZafon</field>
-            <field name="code">IL-Z</field>
-            <field name="type">district</field>
-            <field name="country" ref="il"/>
-        </record>
-
-        <record model="country.subdivision" id="in-an">
-            <field name="name">Andaman and Nicobar Islands</field>
-            <field name="code">IN-AN</field>
-            <field name="type">union territory</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ap">
-            <field name="name">Andhra Pradesh</field>
-            <field name="code">IN-AP</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ar">
-            <field name="name">Arunachal Pradesh</field>
-            <field name="code">IN-AR</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-as">
-            <field name="name">Assam</field>
-            <field name="code">IN-AS</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-br">
-            <field name="name">Bihar</field>
-            <field name="code">IN-BR</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ch">
-            <field name="name">Chandigarh</field>
-            <field name="code">IN-CH</field>
-            <field name="type">union territory</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ct">
-            <field name="name">Chhattisgarh</field>
-            <field name="code">IN-CT</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-dd">
-            <field name="name">Daman and Diu</field>
-            <field name="code">IN-DD</field>
-            <field name="type">union territory</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-dl">
-            <field name="name">Delhi</field>
-            <field name="code">IN-DL</field>
-            <field name="type">union territory</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-dn">
-            <field name="name">Dadra and Nagar Haveli</field>
-            <field name="code">IN-DN</field>
-            <field name="type">union territory</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ga">
-            <field name="name">Goa</field>
-            <field name="code">IN-GA</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-gj">
-            <field name="name">Gujarat</field>
-            <field name="code">IN-GJ</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-hp">
-            <field name="name">Himachal Pradesh</field>
-            <field name="code">IN-HP</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-hr">
-            <field name="name">Haryana</field>
-            <field name="code">IN-HR</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-jh">
-            <field name="name">Jharkhand</field>
-            <field name="code">IN-JH</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-jk">
-            <field name="name">Jammu and Kashmir</field>
-            <field name="code">IN-JK</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ka">
-            <field name="name">Karnataka</field>
-            <field name="code">IN-KA</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-kl">
-            <field name="name">Kerala</field>
-            <field name="code">IN-KL</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ld">
-            <field name="name">Lakshadweep</field>
-            <field name="code">IN-LD</field>
-            <field name="type">union territory</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-mh">
-            <field name="name">Maharashtra</field>
-            <field name="code">IN-MH</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ml">
-            <field name="name">Meghalaya</field>
-            <field name="code">IN-ML</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-mn">
-            <field name="name">Manipur</field>
-            <field name="code">IN-MN</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-mp">
-            <field name="name">Madhya Pradesh</field>
-            <field name="code">IN-MP</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-mz">
-            <field name="name">Mizoram</field>
-            <field name="code">IN-MZ</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-nl">
-            <field name="name">Nagaland</field>
-            <field name="code">IN-NL</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-or">
-            <field name="name">Odisha</field>
-            <field name="code">IN-OR</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-pb">
-            <field name="name">Punjab</field>
-            <field name="code">IN-PB</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-py">
-            <field name="name">Puducherry</field>
-            <field name="code">IN-PY</field>
-            <field name="type">union territory</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-rj">
-            <field name="name">Rajasthan</field>
-            <field name="code">IN-RJ</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-sk">
-            <field name="name">Sikkim</field>
-            <field name="code">IN-SK</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-tg">
-            <field name="name">Telangana</field>
-            <field name="code">IN-TG</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-tn">
-            <field name="name">Tamil Nadu</field>
-            <field name="code">IN-TN</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-tr">
-            <field name="name">Tripura</field>
-            <field name="code">IN-TR</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-up">
-            <field name="name">Uttar Pradesh</field>
-            <field name="code">IN-UP</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-ut">
-            <field name="name">Uttarakhand</field>
-            <field name="code">IN-UT</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="in-wb">
-            <field name="name">West Bengal</field>
-            <field name="code">IN-WB</field>
-            <field name="type">state</field>
-            <field name="country" ref="in"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-an">
-            <field name="name">Al Anbar</field>
-            <field name="code">IQ-AN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-ar">
-            <field name="name">Arbil</field>
-            <field name="code">IQ-AR</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-ba">
-            <field name="name">Al Basrah</field>
-            <field name="code">IQ-BA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-bb">
-            <field name="name">Babil</field>
-            <field name="code">IQ-BB</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-bg">
-            <field name="name">Baghdad</field>
-            <field name="code">IQ-BG</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-da">
-            <field name="name">Dahuk</field>
-            <field name="code">IQ-DA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-di">
-            <field name="name">Diyala</field>
-            <field name="code">IQ-DI</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-dq">
-            <field name="name">Dhi Qar</field>
-            <field name="code">IQ-DQ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-ka">
-            <field name="name">Karbala'</field>
-            <field name="code">IQ-KA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-ma">
-            <field name="name">Maysan</field>
-            <field name="code">IQ-MA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-mu">
-            <field name="name">Al Muthanna</field>
-            <field name="code">IQ-MU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-na">
-            <field name="name">An Najef</field>
-            <field name="code">IQ-NA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-ni">
-            <field name="name">Ninawa</field>
-            <field name="code">IQ-NI</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-qa">
-            <field name="name">Al Qadisiyah</field>
-            <field name="code">IQ-QA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-sd">
-            <field name="name">Salah ad Din</field>
-            <field name="code">IQ-SD</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-sw">
-            <field name="name">As Sulaymaniyah</field>
-            <field name="code">IQ-SW</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-ts">
-            <field name="name">At Ta'mim</field>
-            <field name="code">IQ-TS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="iq-wa">
-            <field name="name">Wasit</field>
-            <field name="code">IQ-WA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="iq"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-01">
-            <field name="name">Āzarbāyjān-e Sharqī</field>
-            <field name="code">IR-01</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-02">
-            <field name="name">Āzarbāyjān-e Gharbī</field>
-            <field name="code">IR-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-03">
-            <field name="name">Ardabīl</field>
-            <field name="code">IR-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-04">
-            <field name="name">Eşfahān</field>
-            <field name="code">IR-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-05">
-            <field name="name">Īlām</field>
-            <field name="code">IR-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-06">
-            <field name="name">Būshehr</field>
-            <field name="code">IR-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-07">
-            <field name="name">Tehrān</field>
-            <field name="code">IR-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-08">
-            <field name="name">Chahār Mahāll va Bakhtīārī</field>
-            <field name="code">IR-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-10">
-            <field name="name">Khūzestān</field>
-            <field name="code">IR-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-11">
-            <field name="name">Zanjān</field>
-            <field name="code">IR-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-12">
-            <field name="name">Semnān</field>
-            <field name="code">IR-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-13">
-            <field name="name">Sīstān va Balūchestān</field>
-            <field name="code">IR-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-14">
-            <field name="name">Fārs</field>
-            <field name="code">IR-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-15">
-            <field name="name">Kermān</field>
-            <field name="code">IR-15</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-16">
-            <field name="name">Kordestān</field>
-            <field name="code">IR-16</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-17">
-            <field name="name">Kermānshāh</field>
-            <field name="code">IR-17</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-18">
-            <field name="name">Kohgīlūyeh va Būyer Ahmad</field>
-            <field name="code">IR-18</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-19">
-            <field name="name">Gīlān</field>
-            <field name="code">IR-19</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-20">
-            <field name="name">Lorestān</field>
-            <field name="code">IR-20</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-21">
-            <field name="name">Māzandarān</field>
-            <field name="code">IR-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-22">
-            <field name="name">Markazī</field>
-            <field name="code">IR-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-23">
-            <field name="name">Hormozgān</field>
-            <field name="code">IR-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-24">
-            <field name="name">Hamadān</field>
-            <field name="code">IR-24</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-25">
-            <field name="name">Yazd</field>
-            <field name="code">IR-25</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-26">
-            <field name="name">Qom</field>
-            <field name="code">IR-26</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-27">
-            <field name="name">Golestān</field>
-            <field name="code">IR-27</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-28">
-            <field name="name">Qazvīn</field>
-            <field name="code">IR-28</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-29">
-            <field name="name">Khorāsān-e Janūbī</field>
-            <field name="code">IR-29</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-30">
-            <field name="name">Khorāsān-e Razavī</field>
-            <field name="code">IR-30</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="ir-31">
-            <field name="name">Khorāsān-e Shemālī</field>
-            <field name="code">IR-31</field>
-            <field name="type">province</field>
-            <field name="country" ref="ir"/>
-        </record>
-
-        <record model="country.subdivision" id="is-0">
-            <field name="name">Reykjavík</field>
-            <field name="code">IS-0</field>
-            <field name="type">city</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-1">
-            <field name="name">Höfuðborgarsvæðið</field>
-            <field name="code">IS-1</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-2">
-            <field name="name">Suðurnes</field>
-            <field name="code">IS-2</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-3">
-            <field name="name">Vesturland</field>
-            <field name="code">IS-3</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-4">
-            <field name="name">Vestfirðir</field>
-            <field name="code">IS-4</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-5">
-            <field name="name">Norðurland vestra</field>
-            <field name="code">IS-5</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-6">
-            <field name="name">Norðurland eystra</field>
-            <field name="code">IS-6</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-7">
-            <field name="name">Austurland</field>
-            <field name="code">IS-7</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="is-8">
-            <field name="name">Suðurland</field>
-            <field name="code">IS-8</field>
-            <field name="type">region</field>
-            <field name="country" ref="is"/>
-        </record>
-
-        <record model="country.subdivision" id="it-21">
-            <field name="name">Piemonte</field>
-            <field name="code">IT-21</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-23">
-            <field name="name">Valle d'Aosta</field>
-            <field name="code">IT-23</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-25">
-            <field name="name">Lombardia</field>
-            <field name="code">IT-25</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-32">
-            <field name="name">Trentino-Alto Adige</field>
-            <field name="code">IT-32</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-34">
-            <field name="name">Veneto</field>
-            <field name="code">IT-34</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-36">
-            <field name="name">Friuli-Venezia Giulia</field>
-            <field name="code">IT-36</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-42">
-            <field name="name">Liguria</field>
-            <field name="code">IT-42</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-45">
-            <field name="name">Emilia-Romagna</field>
-            <field name="code">IT-45</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-52">
-            <field name="name">Toscana</field>
-            <field name="code">IT-52</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-55">
-            <field name="name">Umbria</field>
-            <field name="code">IT-55</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-57">
-            <field name="name">Marche</field>
-            <field name="code">IT-57</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-62">
-            <field name="name">Lazio</field>
-            <field name="code">IT-62</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-65">
-            <field name="name">Abruzzo</field>
-            <field name="code">IT-65</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-67">
-            <field name="name">Molise</field>
-            <field name="code">IT-67</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-72">
-            <field name="name">Campania</field>
-            <field name="code">IT-72</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-75">
-            <field name="name">Puglia</field>
-            <field name="code">IT-75</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-77">
-            <field name="name">Basilicata</field>
-            <field name="code">IT-77</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-78">
-            <field name="name">Calabria</field>
-            <field name="code">IT-78</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-82">
-            <field name="name">Sicilia</field>
-            <field name="code">IT-82</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-88">
-            <field name="name">Sardegna</field>
-            <field name="code">IT-88</field>
-            <field name="type">region</field>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-01">
-            <field name="name">Kingston</field>
-            <field name="code">JM-01</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-02">
-            <field name="name">Saint Andrew</field>
-            <field name="code">JM-02</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-03">
-            <field name="name">Saint Thomas</field>
-            <field name="code">JM-03</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-04">
-            <field name="name">Portland</field>
-            <field name="code">JM-04</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-05">
-            <field name="name">Saint Mary</field>
-            <field name="code">JM-05</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-06">
-            <field name="name">Saint Ann</field>
-            <field name="code">JM-06</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-07">
-            <field name="name">Trelawny</field>
-            <field name="code">JM-07</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-08">
-            <field name="name">Saint James</field>
-            <field name="code">JM-08</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-09">
-            <field name="name">Hanover</field>
-            <field name="code">JM-09</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-10">
-            <field name="name">Westmoreland</field>
-            <field name="code">JM-10</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-11">
-            <field name="name">Saint Elizabeth</field>
-            <field name="code">JM-11</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-12">
-            <field name="name">Manchester</field>
-            <field name="code">JM-12</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-13">
-            <field name="name">Clarendon</field>
-            <field name="code">JM-13</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jm-14">
-            <field name="name">Saint Catherine</field>
-            <field name="code">JM-14</field>
-            <field name="type">parish</field>
-            <field name="country" ref="jm"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-aj">
-            <field name="name">‘Ajlūn</field>
-            <field name="code">JO-AJ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-am">
-            <field name="name">‘Ammān (Al ‘Aşimah)</field>
-            <field name="code">JO-AM</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-aq">
-            <field name="name">Al ‘Aqabah</field>
-            <field name="code">JO-AQ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-at">
-            <field name="name">Aţ Ţafīlah</field>
-            <field name="code">JO-AT</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-az">
-            <field name="name">Az Zarqā'</field>
-            <field name="code">JO-AZ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-ba">
-            <field name="name">Al Balqā'</field>
-            <field name="code">JO-BA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-ir">
-            <field name="name">Irbid</field>
-            <field name="code">JO-IR</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-ja">
-            <field name="name">Jarash</field>
-            <field name="code">JO-JA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-ka">
-            <field name="name">Al Karak</field>
-            <field name="code">JO-KA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-ma">
-            <field name="name">Al Mafraq</field>
-            <field name="code">JO-MA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-md">
-            <field name="name">Mādabā</field>
-            <field name="code">JO-MD</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jo-mn">
-            <field name="name">Ma‘ān</field>
-            <field name="code">JO-MN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="jo"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-01">
-            <field name="name">Hokkaido</field>
-            <field name="code">JP-01</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-02">
-            <field name="name">Aomori</field>
-            <field name="code">JP-02</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-03">
-            <field name="name">Iwate</field>
-            <field name="code">JP-03</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-04">
-            <field name="name">Miyagi</field>
-            <field name="code">JP-04</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-05">
-            <field name="name">Akita</field>
-            <field name="code">JP-05</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-06">
-            <field name="name">Yamagata</field>
-            <field name="code">JP-06</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-07">
-            <field name="name">Fukushima</field>
-            <field name="code">JP-07</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-08">
-            <field name="name">Ibaraki</field>
-            <field name="code">JP-08</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-09">
-            <field name="name">Tochigi</field>
-            <field name="code">JP-09</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-10">
-            <field name="name">Gunma</field>
-            <field name="code">JP-10</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-11">
-            <field name="name">Saitama</field>
-            <field name="code">JP-11</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-12">
-            <field name="name">Chiba</field>
-            <field name="code">JP-12</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-13">
-            <field name="name">Tokyo</field>
-            <field name="code">JP-13</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-14">
-            <field name="name">Kanagawa</field>
-            <field name="code">JP-14</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-15">
-            <field name="name">Niigata</field>
-            <field name="code">JP-15</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-16">
-            <field name="name">Toyama</field>
-            <field name="code">JP-16</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-17">
-            <field name="name">Ishikawa</field>
-            <field name="code">JP-17</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-18">
-            <field name="name">Fukui</field>
-            <field name="code">JP-18</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-19">
-            <field name="name">Yamanashi</field>
-            <field name="code">JP-19</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-20">
-            <field name="name">Nagano</field>
-            <field name="code">JP-20</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-21">
-            <field name="name">Gifu</field>
-            <field name="code">JP-21</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-22">
-            <field name="name">Shizuoka</field>
-            <field name="code">JP-22</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-23">
-            <field name="name">Aichi</field>
-            <field name="code">JP-23</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-24">
-            <field name="name">Mie</field>
-            <field name="code">JP-24</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-25">
-            <field name="name">Shiga</field>
-            <field name="code">JP-25</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-26">
-            <field name="name">Kyoto</field>
-            <field name="code">JP-26</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-27">
-            <field name="name">Osaka</field>
-            <field name="code">JP-27</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-28">
-            <field name="name">Hyogo</field>
-            <field name="code">JP-28</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-29">
-            <field name="name">Nara</field>
-            <field name="code">JP-29</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-30">
-            <field name="name">Wakayama</field>
-            <field name="code">JP-30</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-31">
-            <field name="name">Tottori</field>
-            <field name="code">JP-31</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-32">
-            <field name="name">Shimane</field>
-            <field name="code">JP-32</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-33">
-            <field name="name">Okayama</field>
-            <field name="code">JP-33</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-34">
-            <field name="name">Hiroshima</field>
-            <field name="code">JP-34</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-35">
-            <field name="name">Yamaguchi</field>
-            <field name="code">JP-35</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-36">
-            <field name="name">Tokushima</field>
-            <field name="code">JP-36</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-37">
-            <field name="name">Kagawa</field>
-            <field name="code">JP-37</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-38">
-            <field name="name">Ehime</field>
-            <field name="code">JP-38</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-39">
-            <field name="name">Kochi</field>
-            <field name="code">JP-39</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-40">
-            <field name="name">Fukuoka</field>
-            <field name="code">JP-40</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-41">
-            <field name="name">Saga</field>
-            <field name="code">JP-41</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-42">
-            <field name="name">Nagasaki</field>
-            <field name="code">JP-42</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-43">
-            <field name="name">Kumamoto</field>
-            <field name="code">JP-43</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-44">
-            <field name="name">Oita</field>
-            <field name="code">JP-44</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-45">
-            <field name="name">Miyazaki</field>
-            <field name="code">JP-45</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-46">
-            <field name="name">Kagoshima</field>
-            <field name="code">JP-46</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="jp-47">
-            <field name="name">Okinawa</field>
-            <field name="code">JP-47</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="jp"/>
-        </record>
-
-        <record model="country.subdivision" id="ke-110">
-            <field name="name">Nairobi Municipality</field>
-            <field name="code">KE-110</field>
-            <field name="type">province</field>
-            <field name="country" ref="ke"/>
-        </record>
-
-        <record model="country.subdivision" id="ke-200">
-            <field name="name">Central</field>
-            <field name="code">KE-200</field>
-            <field name="type">province</field>
-            <field name="country" ref="ke"/>
-        </record>
-
-        <record model="country.subdivision" id="ke-300">
-            <field name="name">Coast</field>
-            <field name="code">KE-300</field>
-            <field name="type">province</field>
-            <field name="country" ref="ke"/>
-        </record>
-
-        <record model="country.subdivision" id="ke-400">
-            <field name="name">Eastern</field>
-            <field name="code">KE-400</field>
-            <field name="type">province</field>
-            <field name="country" ref="ke"/>
-        </record>
-
-        <record model="country.subdivision" id="ke-500">
-            <field name="name">North-Eastern Kaskazini Mashariki</field>
-            <field name="code">KE-500</field>
-            <field name="type">province</field>
-            <field name="country" ref="ke"/>
-        </record>
-
-        <record model="country.subdivision" id="ke-700">
-            <field name="name">Rift Valley</field>
-            <field name="code">KE-700</field>
-            <field name="type">province</field>
-            <field name="country" ref="ke"/>
-        </record>
-
-        <record model="country.subdivision" id="ke-800">
-            <field name="name">Western Magharibi</field>
-            <field name="code">KE-800</field>
-            <field name="type">province</field>
-            <field name="country" ref="ke"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-b">
-            <field name="name">Batken</field>
-            <field name="code">KG-B</field>
-            <field name="type">region</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-c">
-            <field name="name">Chü</field>
-            <field name="code">KG-C</field>
-            <field name="type">region</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-gb">
-            <field name="name">Bishkek</field>
-            <field name="code">KG-GB</field>
-            <field name="type">city</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-j">
-            <field name="name">Jalal-Abad</field>
-            <field name="code">KG-J</field>
-            <field name="type">region</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-n">
-            <field name="name">Naryn</field>
-            <field name="code">KG-N</field>
-            <field name="type">region</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-o">
-            <field name="name">Osh</field>
-            <field name="code">KG-O</field>
-            <field name="type">region</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-t">
-            <field name="name">Talas</field>
-            <field name="code">KG-T</field>
-            <field name="type">region</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kg-y">
-            <field name="name">Ysyk-Köl</field>
-            <field name="code">KG-Y</field>
-            <field name="type">region</field>
-            <field name="country" ref="kg"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-1">
-            <field name="name">Banteay Mean Chey</field>
-            <field name="code">KH-1</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-10">
-            <field name="name">Krachoh</field>
-            <field name="code">KH-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-11">
-            <field name="name">Mondol Kiri</field>
-            <field name="code">KH-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-12">
-            <field name="name">Phnom Penh</field>
-            <field name="code">KH-12</field>
-            <field name="type">autonomous municipality</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-13">
-            <field name="name">Preah Vihear</field>
-            <field name="code">KH-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-14">
-            <field name="name">Prey Veaeng</field>
-            <field name="code">KH-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-15">
-            <field name="name">Pousaat</field>
-            <field name="code">KH-15</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-16">
-            <field name="name">Rotanak Kiri</field>
-            <field name="code">KH-16</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-17">
-            <field name="name">Siem Reab</field>
-            <field name="code">KH-17</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-18">
-            <field name="name">Krong Preah Sihanouk</field>
-            <field name="code">KH-18</field>
-            <field name="type">autonomous municipality</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-19">
-            <field name="name">Stueng Traeng</field>
-            <field name="code">KH-19</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-2">
-            <field name="name">Battambang</field>
-            <field name="code">KH-2</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-20">
-            <field name="name">Svaay Rieng</field>
-            <field name="code">KH-20</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-21">
-            <field name="name">Taakaev</field>
-            <field name="code">KH-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-22">
-            <field name="name">Otdar Mean Chey</field>
-            <field name="code">KH-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-23">
-            <field name="name">Krong Kaeb</field>
-            <field name="code">KH-23</field>
-            <field name="type">autonomous municipality</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-24">
-            <field name="name">Krong Pailin</field>
-            <field name="code">KH-24</field>
-            <field name="type">autonomous municipality</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-3">
-            <field name="name">Kampong Cham</field>
-            <field name="code">KH-3</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-4">
-            <field name="name">Kampong Chhnang</field>
-            <field name="code">KH-4</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-5">
-            <field name="name">Kampong Speu</field>
-            <field name="code">KH-5</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-6">
-            <field name="name">Kampong Thom</field>
-            <field name="code">KH-6</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-7">
-            <field name="name">Kampot</field>
-            <field name="code">KH-7</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-8">
-            <field name="name">Kandal</field>
-            <field name="code">KH-8</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="kh-9">
-            <field name="name">Kach Kong</field>
-            <field name="code">KH-9</field>
-            <field name="type">province</field>
-            <field name="country" ref="kh"/>
-        </record>
-
-        <record model="country.subdivision" id="ki-g">
-            <field name="name">Gilbert Islands</field>
-            <field name="code">KI-G</field>
-            <field name="type">island group</field>
-            <field name="country" ref="ki"/>
-        </record>
-
-        <record model="country.subdivision" id="ki-l">
-            <field name="name">Line Islands</field>
-            <field name="code">KI-L</field>
-            <field name="type">island group</field>
-            <field name="country" ref="ki"/>
-        </record>
-
-        <record model="country.subdivision" id="ki-p">
-            <field name="name">Phoenix Islands</field>
-            <field name="code">KI-P</field>
-            <field name="type">island group</field>
-            <field name="country" ref="ki"/>
-        </record>
-
-        <record model="country.subdivision" id="km-a">
-            <field name="name">Andjouân (Anjwān)</field>
-            <field name="code">KM-A</field>
-            <field name="type">island</field>
-            <field name="country" ref="km"/>
-        </record>
-
-        <record model="country.subdivision" id="km-g">
-            <field name="name">Andjazîdja (Anjazījah)</field>
-            <field name="code">KM-G</field>
-            <field name="type">island</field>
-            <field name="country" ref="km"/>
-        </record>
-
-        <record model="country.subdivision" id="km-m">
-            <field name="name">Moûhîlî (Mūhīlī)</field>
-            <field name="code">KM-M</field>
-            <field name="type">island</field>
-            <field name="country" ref="km"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-k">
-            <field name="name">Saint Kitts</field>
-            <field name="code">KN-K</field>
-            <field name="type">state</field>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-n">
-            <field name="name">Nevis</field>
-            <field name="code">KN-N</field>
-            <field name="type">state</field>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-01">
-            <field name="name">P’yŏngyang</field>
-            <field name="code">KP-01</field>
-            <field name="type">capital city</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-02">
-            <field name="name">P’yŏngan-namdo</field>
-            <field name="code">KP-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-03">
-            <field name="name">P’yŏngan-bukto</field>
-            <field name="code">KP-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-04">
-            <field name="name">Chagang-do</field>
-            <field name="code">KP-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-05">
-            <field name="name">Hwanghae-namdo</field>
-            <field name="code">KP-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-06">
-            <field name="name">Hwanghae-bukto</field>
-            <field name="code">KP-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-07">
-            <field name="name">Kangwŏn-do</field>
-            <field name="code">KP-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-08">
-            <field name="name">Hamgyŏng-namdo</field>
-            <field name="code">KP-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-09">
-            <field name="name">Hamgyŏng-bukto</field>
-            <field name="code">KP-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-10">
-            <field name="name">Yanggang-do</field>
-            <field name="code">KP-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kp-13">
-            <field name="name">Nasŏn (Najin-Sŏnbong)</field>
-            <field name="code">KP-13</field>
-            <field name="type">special city</field>
-            <field name="country" ref="kp"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-11">
-            <field name="name">Seoul Teugbyeolsi</field>
-            <field name="code">KR-11</field>
-            <field name="type">capital metropolitan city</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-26">
-            <field name="name">Busan Gwang'yeogsi</field>
-            <field name="code">KR-26</field>
-            <field name="type">metropolitan cities</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-27">
-            <field name="name">Daegu Gwang'yeogsi</field>
-            <field name="code">KR-27</field>
-            <field name="type">metropolitan cities</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-28">
-            <field name="name">Incheon Gwang'yeogsi</field>
-            <field name="code">KR-28</field>
-            <field name="type">metropolitan cities</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-29">
-            <field name="name">Gwangju Gwang'yeogsi</field>
-            <field name="code">KR-29</field>
-            <field name="type">metropolitan cities</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-30">
-            <field name="name">Daejeon Gwang'yeogsi</field>
-            <field name="code">KR-30</field>
-            <field name="type">metropolitan cities</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-31">
-            <field name="name">Ulsan Gwang'yeogsi</field>
-            <field name="code">KR-31</field>
-            <field name="type">metropolitan cities</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-41">
-            <field name="name">Gyeonggido</field>
-            <field name="code">KR-41</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-42">
-            <field name="name">Gang'weondo</field>
-            <field name="code">KR-42</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-43">
-            <field name="name">Chungcheongbukdo</field>
-            <field name="code">KR-43</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-44">
-            <field name="name">Chungcheongnamdo</field>
-            <field name="code">KR-44</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-45">
-            <field name="name">Jeonrabukdo</field>
-            <field name="code">KR-45</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-46">
-            <field name="name">Jeonranamdo</field>
-            <field name="code">KR-46</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-47">
-            <field name="name">Gyeongsangbukdo</field>
-            <field name="code">KR-47</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-48">
-            <field name="name">Gyeongsangnamdo</field>
-            <field name="code">KR-48</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kr-49">
-            <field name="name">Jejudo</field>
-            <field name="code">KR-49</field>
-            <field name="type">province</field>
-            <field name="country" ref="kr"/>
-        </record>
-
-        <record model="country.subdivision" id="kw-ah">
-            <field name="name">Al Ahmadi</field>
-            <field name="code">KW-AH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="kw"/>
-        </record>
-
-        <record model="country.subdivision" id="kw-fa">
-            <field name="name">Al Farwānīyah</field>
-            <field name="code">KW-FA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="kw"/>
-        </record>
-
-        <record model="country.subdivision" id="kw-ha">
-            <field name="name">Hawallī</field>
-            <field name="code">KW-HA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="kw"/>
-        </record>
-
-        <record model="country.subdivision" id="kw-ja">
-            <field name="name">Al Jahrrā’</field>
-            <field name="code">KW-JA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="kw"/>
-        </record>
-
-        <record model="country.subdivision" id="kw-ku">
-            <field name="name">Al Kuwayt (Al ‘Āşimah)</field>
-            <field name="code">KW-KU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="kw"/>
-        </record>
-
-        <record model="country.subdivision" id="kw-mu">
-            <field name="name">Mubārak al Kabīr</field>
-            <field name="code">KW-MU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="kw"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-akm">
-            <field name="name">Aqmola oblysy</field>
-            <field name="code">KZ-AKM</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-akt">
-            <field name="name">Aqtöbe oblysy</field>
-            <field name="code">KZ-AKT</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-ala">
-            <field name="name">Almaty</field>
-            <field name="code">KZ-ALA</field>
-            <field name="type">city</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-alm">
-            <field name="name">Almaty oblysy</field>
-            <field name="code">KZ-ALM</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-ast">
-            <field name="name">Astana</field>
-            <field name="code">KZ-AST</field>
-            <field name="type">city</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-aty">
-            <field name="name">Atyraū oblysy</field>
-            <field name="code">KZ-ATY</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-kar">
-            <field name="name">Qaraghandy oblysy</field>
-            <field name="code">KZ-KAR</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-kus">
-            <field name="name">Qostanay oblysy</field>
-            <field name="code">KZ-KUS</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-kzy">
-            <field name="name">Qyzylorda oblysy</field>
-            <field name="code">KZ-KZY</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-man">
-            <field name="name">Mangghystaū oblysy</field>
-            <field name="code">KZ-MAN</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-pav">
-            <field name="name">Pavlodar oblysy</field>
-            <field name="code">KZ-PAV</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-sev">
-            <field name="name">Soltüstik Quzaqstan oblysy</field>
-            <field name="code">KZ-SEV</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-vos">
-            <field name="name">Shyghys Qazaqstan oblysy</field>
-            <field name="code">KZ-VOS</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-yuz">
-            <field name="name">Ongtüstik Qazaqstan oblysy</field>
-            <field name="code">KZ-YUZ</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-zap">
-            <field name="name">Batys Quzaqstan oblysy</field>
-            <field name="code">KZ-ZAP</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="kz-zha">
-            <field name="name">Zhambyl oblysy</field>
-            <field name="code">KZ-ZHA</field>
-            <field name="type">region</field>
-            <field name="country" ref="kz"/>
-        </record>
-
-        <record model="country.subdivision" id="la-at">
-            <field name="name">Attapu</field>
-            <field name="code">LA-AT</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-bk">
-            <field name="name">Bokèo</field>
-            <field name="code">LA-BK</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-bl">
-            <field name="name">Bolikhamxai</field>
-            <field name="code">LA-BL</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-ch">
-            <field name="name">Champasak</field>
-            <field name="code">LA-CH</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-ho">
-            <field name="name">Houaphan</field>
-            <field name="code">LA-HO</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-kh">
-            <field name="name">Khammouan</field>
-            <field name="code">LA-KH</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-lm">
-            <field name="name">Louang Namtha</field>
-            <field name="code">LA-LM</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-lp">
-            <field name="name">Louangphabang</field>
-            <field name="code">LA-LP</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-ou">
-            <field name="name">Oudômxai</field>
-            <field name="code">LA-OU</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-ph">
-            <field name="name">Phôngsali</field>
-            <field name="code">LA-PH</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-sl">
-            <field name="name">Salavan</field>
-            <field name="code">LA-SL</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-sv">
-            <field name="name">Savannakhét</field>
-            <field name="code">LA-SV</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-vi">
-            <field name="name">Vientiane</field>
-            <field name="code">LA-VI</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-vt">
-            <field name="name">Vientiane</field>
-            <field name="code">LA-VT</field>
-            <field name="type">prefecture</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-xa">
-            <field name="name">Xaignabouli</field>
-            <field name="code">LA-XA</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-xe">
-            <field name="name">Xékong</field>
-            <field name="code">LA-XE</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-xi">
-            <field name="name">Xiangkhouang</field>
-            <field name="code">LA-XI</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="la-xs">
-            <field name="name">Xaisômboun</field>
-            <field name="code">LA-XS</field>
-            <field name="type">province</field>
-            <field name="country" ref="la"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-ak">
-            <field name="name">Aakkâr</field>
-            <field name="code">LB-AK</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-as">
-            <field name="name">Liban-Nord</field>
-            <field name="code">LB-AS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-ba">
-            <field name="name">Beyrouth</field>
-            <field name="code">LB-BA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-bh">
-            <field name="name">Baalbek-Hermel</field>
-            <field name="code">LB-BH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-bi">
-            <field name="name">Béqaa</field>
-            <field name="code">LB-BI</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-ja">
-            <field name="name">Liban-Sud</field>
-            <field name="code">LB-JA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-jl">
-            <field name="name">Mont-Liban</field>
-            <field name="code">LB-JL</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="lb-na">
-            <field name="name">Nabatîyé</field>
-            <field name="code">LB-NA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="lb"/>
-        </record>
-
-        <record model="country.subdivision" id="li-01">
-            <field name="name">Balzers</field>
-            <field name="code">LI-01</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-02">
-            <field name="name">Eschen</field>
-            <field name="code">LI-02</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-03">
-            <field name="name">Gamprin</field>
-            <field name="code">LI-03</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-04">
-            <field name="name">Mauren</field>
-            <field name="code">LI-04</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-05">
-            <field name="name">Planken</field>
-            <field name="code">LI-05</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-06">
-            <field name="name">Ruggell</field>
-            <field name="code">LI-06</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-07">
-            <field name="name">Schaan</field>
-            <field name="code">LI-07</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-08">
-            <field name="name">Schellenberg</field>
-            <field name="code">LI-08</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-09">
-            <field name="name">Triesen</field>
-            <field name="code">LI-09</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-10">
-            <field name="name">Triesenberg</field>
-            <field name="code">LI-10</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="li-11">
-            <field name="name">Vaduz</field>
-            <field name="code">LI-11</field>
-            <field name="type">commune</field>
-            <field name="country" ref="li"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-1">
-            <field name="name">Basnāhira paḷāta</field>
-            <field name="code">LK-1</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-2">
-            <field name="name">Madhyama paḷāta</field>
-            <field name="code">LK-2</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-3">
-            <field name="name">Dakuṇu paḷāta</field>
-            <field name="code">LK-3</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-4">
-            <field name="name">Uturu paḷāta</field>
-            <field name="code">LK-4</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-5">
-            <field name="name">Næ̆gĕnahira paḷāta</field>
-            <field name="code">LK-5</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-6">
-            <field name="name">Vayamba paḷāta</field>
-            <field name="code">LK-6</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-7">
-            <field name="name">Uturumæ̆da paḷāta</field>
-            <field name="code">LK-7</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-8">
-            <field name="name">Ūva paḷāta</field>
-            <field name="code">LK-8</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-9">
-            <field name="name">Sabaragamuva paḷāta</field>
-            <field name="code">LK-9</field>
-            <field name="type">province</field>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-bg">
-            <field name="name">Bong</field>
-            <field name="code">LR-BG</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-bm">
-            <field name="name">Bomi</field>
-            <field name="code">LR-BM</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-cm">
-            <field name="name">Grand Cape Mount</field>
-            <field name="code">LR-CM</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-gb">
-            <field name="name">Grand Bassa</field>
-            <field name="code">LR-GB</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-gg">
-            <field name="name">Grand Gedeh</field>
-            <field name="code">LR-GG</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-gk">
-            <field name="name">Grand Kru</field>
-            <field name="code">LR-GK</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-lo">
-            <field name="name">Lofa</field>
-            <field name="code">LR-LO</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-mg">
-            <field name="name">Margibi</field>
-            <field name="code">LR-MG</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-mo">
-            <field name="name">Montserrado</field>
-            <field name="code">LR-MO</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-my">
-            <field name="name">Maryland</field>
-            <field name="code">LR-MY</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-ni">
-            <field name="name">Nimba</field>
-            <field name="code">LR-NI</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-ri">
-            <field name="name">Rivercess</field>
-            <field name="code">LR-RI</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="lr-si">
-            <field name="name">Sinoe</field>
-            <field name="code">LR-SI</field>
-            <field name="type">county</field>
-            <field name="country" ref="lr"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-a">
-            <field name="name">Maseru</field>
-            <field name="code">LS-A</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-b">
-            <field name="name">Butha-Buthe</field>
-            <field name="code">LS-B</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-c">
-            <field name="name">Leribe</field>
-            <field name="code">LS-C</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-d">
-            <field name="name">Berea</field>
-            <field name="code">LS-D</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-e">
-            <field name="name">Mafeteng</field>
-            <field name="code">LS-E</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-f">
-            <field name="name">Mohale's Hoek</field>
-            <field name="code">LS-F</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-g">
-            <field name="name">Quthing</field>
-            <field name="code">LS-G</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-h">
-            <field name="name">Qacha's Nek</field>
-            <field name="code">LS-H</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-j">
-            <field name="name">Mokhotlong</field>
-            <field name="code">LS-J</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="ls-k">
-            <field name="name">Thaba-Tseka</field>
-            <field name="code">LS-K</field>
-            <field name="type">district</field>
-            <field name="country" ref="ls"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-al">
-            <field name="name">Alytaus Apskritis</field>
-            <field name="code">LT-AL</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-kl">
-            <field name="name">Klaipėdos Apskritis</field>
-            <field name="code">LT-KL</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-ku">
-            <field name="name">Kauno Apskritis</field>
-            <field name="code">LT-KU</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-mr">
-            <field name="name">Marijampolės Apskritis</field>
-            <field name="code">LT-MR</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-pn">
-            <field name="name">Panevėžio Apskritis</field>
-            <field name="code">LT-PN</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-sa">
-            <field name="name">Šiaulių Apskritis</field>
-            <field name="code">LT-SA</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-ta">
-            <field name="name">Tauragés Apskritis</field>
-            <field name="code">LT-TA</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-te">
-            <field name="name">Telšių Apskritis</field>
-            <field name="code">LT-TE</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-ut">
-            <field name="name">Utenos Apskritis</field>
-            <field name="code">LT-UT</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lt-vl">
-            <field name="name">Vilniaus Apskritis</field>
-            <field name="code">LT-VL</field>
-            <field name="type">county</field>
-            <field name="country" ref="lt"/>
-        </record>
-
-        <record model="country.subdivision" id="lu-d">
-            <field name="name">Diekirch</field>
-            <field name="code">LU-D</field>
-            <field name="type">district</field>
-            <field name="country" ref="lu"/>
-        </record>
-
-        <record model="country.subdivision" id="lu-g">
-            <field name="name">Grevenmacher</field>
-            <field name="code">LU-G</field>
-            <field name="type">district</field>
-            <field name="country" ref="lu"/>
-        </record>
-
-        <record model="country.subdivision" id="lu-l">
-            <field name="name">Luxembourg</field>
-            <field name="code">LU-L</field>
-            <field name="type">district</field>
-            <field name="country" ref="lu"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-001">
-            <field name="name">Aglonas novads</field>
-            <field name="code">LV-001</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-002">
-            <field name="name">Aizkraukles novads</field>
-            <field name="code">LV-002</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-003">
-            <field name="name">Aizputes novads</field>
-            <field name="code">LV-003</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-004">
-            <field name="name">Aknīstes novads</field>
-            <field name="code">LV-004</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-005">
-            <field name="name">Alojas novads</field>
-            <field name="code">LV-005</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-006">
-            <field name="name">Alsungas novads</field>
-            <field name="code">LV-006</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-007">
-            <field name="name">Alūksnes novads</field>
-            <field name="code">LV-007</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-008">
-            <field name="name">Amatas novads</field>
-            <field name="code">LV-008</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-009">
-            <field name="name">Apes novads</field>
-            <field name="code">LV-009</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-010">
-            <field name="name">Auces novads</field>
-            <field name="code">LV-010</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-011">
-            <field name="name">Ādažu novads</field>
-            <field name="code">LV-011</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-012">
-            <field name="name">Babītes novads</field>
-            <field name="code">LV-012</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-013">
-            <field name="name">Baldones novads</field>
-            <field name="code">LV-013</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-014">
-            <field name="name">Baltinavas novads</field>
-            <field name="code">LV-014</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-015">
-            <field name="name">Balvu novads</field>
-            <field name="code">LV-015</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-016">
-            <field name="name">Bauskas novads</field>
-            <field name="code">LV-016</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-017">
-            <field name="name">Beverīnas novads</field>
-            <field name="code">LV-017</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-018">
-            <field name="name">Brocēnu novads</field>
-            <field name="code">LV-018</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-019">
-            <field name="name">Burtnieku novads</field>
-            <field name="code">LV-019</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-020">
-            <field name="name">Carnikavas novads</field>
-            <field name="code">LV-020</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-021">
-            <field name="name">Cesvaines novads</field>
-            <field name="code">LV-021</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-022">
-            <field name="name">Cēsu novads</field>
-            <field name="code">LV-022</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-023">
-            <field name="name">Ciblas novads</field>
-            <field name="code">LV-023</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-024">
-            <field name="name">Dagdas novads</field>
-            <field name="code">LV-024</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-025">
-            <field name="name">Daugavpils novads</field>
-            <field name="code">LV-025</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-026">
-            <field name="name">Dobeles novads</field>
-            <field name="code">LV-026</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-027">
-            <field name="name">Dundagas novads</field>
-            <field name="code">LV-027</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-028">
-            <field name="name">Durbes novads</field>
-            <field name="code">LV-028</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-029">
-            <field name="name">Engures novads</field>
-            <field name="code">LV-029</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-030">
-            <field name="name">Ērgļu novads</field>
-            <field name="code">LV-030</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-031">
-            <field name="name">Garkalnes novads</field>
-            <field name="code">LV-031</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-032">
-            <field name="name">Grobiņas novads</field>
-            <field name="code">LV-032</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-033">
-            <field name="name">Gulbenes novads</field>
-            <field name="code">LV-033</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-034">
-            <field name="name">Iecavas novads</field>
-            <field name="code">LV-034</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-035">
-            <field name="name">Ikšķiles novads</field>
-            <field name="code">LV-035</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-036">
-            <field name="name">Ilūkstes novads</field>
-            <field name="code">LV-036</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-037">
-            <field name="name">Inčukalna novads</field>
-            <field name="code">LV-037</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-038">
-            <field name="name">Jaunjelgavas novads</field>
-            <field name="code">LV-038</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-039">
-            <field name="name">Jaunpiebalgas novads</field>
-            <field name="code">LV-039</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-040">
-            <field name="name">Jaunpils novads</field>
-            <field name="code">LV-040</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-041">
-            <field name="name">Jelgavas novads</field>
-            <field name="code">LV-041</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-042">
-            <field name="name">Jēkabpils novads</field>
-            <field name="code">LV-042</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-043">
-            <field name="name">Kandavas novads</field>
-            <field name="code">LV-043</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-044">
-            <field name="name">Kārsavas novads</field>
-            <field name="code">LV-044</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-045">
-            <field name="name">Kocēnu novads</field>
-            <field name="code">LV-045</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-046">
-            <field name="name">Kokneses novads</field>
-            <field name="code">LV-046</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-047">
-            <field name="name">Krāslavas novads</field>
-            <field name="code">LV-047</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-048">
-            <field name="name">Krimuldas novads</field>
-            <field name="code">LV-048</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-049">
-            <field name="name">Krustpils novads</field>
-            <field name="code">LV-049</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-050">
-            <field name="name">Kuldīgas novads</field>
-            <field name="code">LV-050</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-051">
-            <field name="name">Ķeguma novads</field>
-            <field name="code">LV-051</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-052">
-            <field name="name">Ķekavas novads</field>
-            <field name="code">LV-052</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-053">
-            <field name="name">Lielvārdes novads</field>
-            <field name="code">LV-053</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-054">
-            <field name="name">Limbažu novads</field>
-            <field name="code">LV-054</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-055">
-            <field name="name">Līgatnes novads</field>
-            <field name="code">LV-055</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-056">
-            <field name="name">Līvānu novads</field>
-            <field name="code">LV-056</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-057">
-            <field name="name">Lubānas novads</field>
-            <field name="code">LV-057</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-058">
-            <field name="name">Ludzas novads</field>
-            <field name="code">LV-058</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-059">
-            <field name="name">Madonas novads</field>
-            <field name="code">LV-059</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-060">
-            <field name="name">Mazsalacas novads</field>
-            <field name="code">LV-060</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-061">
-            <field name="name">Mālpils novads</field>
-            <field name="code">LV-061</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-062">
-            <field name="name">Mārupes novads</field>
-            <field name="code">LV-062</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-063">
-            <field name="name">Mērsraga novads</field>
-            <field name="code">LV-063</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-064">
-            <field name="name">Naukšēnu novads</field>
-            <field name="code">LV-064</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-065">
-            <field name="name">Neretas novads</field>
-            <field name="code">LV-065</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-066">
-            <field name="name">Nīcas novads</field>
-            <field name="code">LV-066</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-067">
-            <field name="name">Ogres novads</field>
-            <field name="code">LV-067</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-068">
-            <field name="name">Olaines novads</field>
-            <field name="code">LV-068</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-069">
-            <field name="name">Ozolnieku novads</field>
-            <field name="code">LV-069</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-070">
-            <field name="name">Pārgaujas novads</field>
-            <field name="code">LV-070</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-071">
-            <field name="name">Pāvilostas novads</field>
-            <field name="code">LV-071</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-072">
-            <field name="name">Pļaviņu novads</field>
-            <field name="code">LV-072</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-073">
-            <field name="name">Preiļu novads</field>
-            <field name="code">LV-073</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-074">
-            <field name="name">Priekules novads</field>
-            <field name="code">LV-074</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-075">
-            <field name="name">Priekuļu novads</field>
-            <field name="code">LV-075</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-076">
-            <field name="name">Raunas novads</field>
-            <field name="code">LV-076</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-077">
-            <field name="name">Rēzeknes novads</field>
-            <field name="code">LV-077</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-078">
-            <field name="name">Riebiņu novads</field>
-            <field name="code">LV-078</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-079">
-            <field name="name">Rojas novads</field>
-            <field name="code">LV-079</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-080">
-            <field name="name">Ropažu novads</field>
-            <field name="code">LV-080</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-081">
-            <field name="name">Rucavas novads</field>
-            <field name="code">LV-081</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-082">
-            <field name="name">Rugāju novads</field>
-            <field name="code">LV-082</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-083">
-            <field name="name">Rundāles novads</field>
-            <field name="code">LV-083</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-084">
-            <field name="name">Rūjienas novads</field>
-            <field name="code">LV-084</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-085">
-            <field name="name">Salas novads</field>
-            <field name="code">LV-085</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-086">
-            <field name="name">Salacgrīvas novads</field>
-            <field name="code">LV-086</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-087">
-            <field name="name">Salaspils novads</field>
-            <field name="code">LV-087</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-088">
-            <field name="name">Saldus novads</field>
-            <field name="code">LV-088</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-089">
-            <field name="name">Saulkrastu novads</field>
-            <field name="code">LV-089</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-090">
-            <field name="name">Sējas novads</field>
-            <field name="code">LV-090</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-091">
-            <field name="name">Siguldas novads</field>
-            <field name="code">LV-091</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-092">
-            <field name="name">Skrīveru novads</field>
-            <field name="code">LV-092</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-093">
-            <field name="name">Skrundas novads</field>
-            <field name="code">LV-093</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-094">
-            <field name="name">Smiltenes novads</field>
-            <field name="code">LV-094</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-095">
-            <field name="name">Stopiņu novads</field>
-            <field name="code">LV-095</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-096">
-            <field name="name">Strenču novads</field>
-            <field name="code">LV-096</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-097">
-            <field name="name">Talsu novads</field>
-            <field name="code">LV-097</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-098">
-            <field name="name">Tērvetes novads</field>
-            <field name="code">LV-098</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-099">
-            <field name="name">Tukuma novads</field>
-            <field name="code">LV-099</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-100">
-            <field name="name">Vaiņodes novads</field>
-            <field name="code">LV-100</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-101">
-            <field name="name">Valkas novads</field>
-            <field name="code">LV-101</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-102">
-            <field name="name">Varakļānu novads</field>
-            <field name="code">LV-102</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-103">
-            <field name="name">Vārkavas novads</field>
-            <field name="code">LV-103</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-104">
-            <field name="name">Vecpiebalgas novads</field>
-            <field name="code">LV-104</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-105">
-            <field name="name">Vecumnieku novads</field>
-            <field name="code">LV-105</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-106">
-            <field name="name">Ventspils novads</field>
-            <field name="code">LV-106</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-107">
-            <field name="name">Viesītes novads</field>
-            <field name="code">LV-107</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-108">
-            <field name="name">Viļakas novads</field>
-            <field name="code">LV-108</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-109">
-            <field name="name">Viļānu novads</field>
-            <field name="code">LV-109</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-110">
-            <field name="name">Zilupes novads</field>
-            <field name="code">LV-110</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-dgv">
-            <field name="name">Daugavpils</field>
-            <field name="code">LV-DGV</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-jel">
-            <field name="name">Jelgava</field>
-            <field name="code">LV-JEL</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-jkb">
-            <field name="name">Jēkabpils</field>
-            <field name="code">LV-JKB</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-jur">
-            <field name="name">Jūrmala</field>
-            <field name="code">LV-JUR</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-lpx">
-            <field name="name">Liepāja</field>
-            <field name="code">LV-LPX</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-rez">
-            <field name="name">Rēzekne</field>
-            <field name="code">LV-REZ</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-rix">
-            <field name="name">Rīga</field>
-            <field name="code">LV-RIX</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-ven">
-            <field name="name">Ventspils</field>
-            <field name="code">LV-VEN</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="lv-vmr">
-            <field name="name">Valmiera</field>
-            <field name="code">LV-VMR</field>
-            <field name="type">republican city</field>
-            <field name="country" ref="lv"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-ba">
-            <field name="name">Banghāzī</field>
-            <field name="code">LY-BA</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-bu">
-            <field name="name">Al Buţnān</field>
-            <field name="code">LY-BU</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-dr">
-            <field name="name">Darnah</field>
-            <field name="code">LY-DR</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-gt">
-            <field name="name">Ghāt</field>
-            <field name="code">LY-GT</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-ja">
-            <field name="name">Al Jabal al Akhḑar</field>
-            <field name="code">LY-JA</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-jb">
-            <field name="name">Jaghbūb</field>
-            <field name="code">LY-JB</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-jg">
-            <field name="name">Al Jabal al Gharbī</field>
-            <field name="code">LY-JG</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-ji">
-            <field name="name">Al Jifārah</field>
-            <field name="code">LY-JI</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-ju">
-            <field name="name">Al Jufrah</field>
-            <field name="code">LY-JU</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-kf">
-            <field name="name">Al Kufrah</field>
-            <field name="code">LY-KF</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-mb">
-            <field name="name">Al Marqab</field>
-            <field name="code">LY-MB</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-mi">
-            <field name="name">Mişrātah</field>
-            <field name="code">LY-MI</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-mj">
-            <field name="name">Al Marj</field>
-            <field name="code">LY-MJ</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-mq">
-            <field name="name">Murzuq</field>
-            <field name="code">LY-MQ</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-nl">
-            <field name="name">Nālūt</field>
-            <field name="code">LY-NL</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-nq">
-            <field name="name">An Nuqaţ al Khams</field>
-            <field name="code">LY-NQ</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-sb">
-            <field name="name">Sabhā</field>
-            <field name="code">LY-SB</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-sr">
-            <field name="name">Surt</field>
-            <field name="code">LY-SR</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-tb">
-            <field name="name">Ţarābulus</field>
-            <field name="code">LY-TB</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-wa">
-            <field name="name">Al Wāḩāt</field>
-            <field name="code">LY-WA</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-wd">
-            <field name="name">Wādī al Ḩayāt</field>
-            <field name="code">LY-WD</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-ws">
-            <field name="name">Wādī ash Shāţiʾ</field>
-            <field name="code">LY-WS</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ly-za">
-            <field name="name">Az Zāwiyah</field>
-            <field name="code">LY-ZA</field>
-            <field name="type">popularates</field>
-            <field name="country" ref="ly"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-01">
-            <field name="name">Tanger-Tétouan</field>
-            <field name="code">MA-01</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-02">
-            <field name="name">Gharb-Chrarda-Beni Hssen</field>
-            <field name="code">MA-02</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-03">
-            <field name="name">Taza-Al Hoceima-Taounate</field>
-            <field name="code">MA-03</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-04">
-            <field name="name">L'Oriental</field>
-            <field name="code">MA-04</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-05">
-            <field name="name">Fès-Boulemane</field>
-            <field name="code">MA-05</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-06">
-            <field name="name">Meknès-Tafilalet</field>
-            <field name="code">MA-06</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-07">
-            <field name="name">Rabat-Salé-Zemmour-Zaer</field>
-            <field name="code">MA-07</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-08">
-            <field name="name">Grand Casablanca</field>
-            <field name="code">MA-08</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-09">
-            <field name="name">Chaouia-Ouardigha</field>
-            <field name="code">MA-09</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-10">
-            <field name="name">Doukhala-Abda</field>
-            <field name="code">MA-10</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-11">
-            <field name="name">Marrakech-Tensift-Al Haouz</field>
-            <field name="code">MA-11</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-12">
-            <field name="name">Tadla-Azilal</field>
-            <field name="code">MA-12</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-13">
-            <field name="name">Sous-Massa-Draa</field>
-            <field name="code">MA-13</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-14">
-            <field name="name">Guelmim-Es Smara</field>
-            <field name="code">MA-14</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-15">
-            <field name="name">Laâyoune-Boujdour-Sakia el Hamra</field>
-            <field name="code">MA-15</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-16">
-            <field name="name">Oued ed Dahab-Lagouira</field>
-            <field name="code">MA-16</field>
-            <field name="type">economic region</field>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-cl">
-            <field name="name">La Colle</field>
-            <field name="code">MC-CL</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-co">
-            <field name="name">La Condamine</field>
-            <field name="code">MC-CO</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-fo">
-            <field name="name">Fontvieille</field>
-            <field name="code">MC-FO</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-ga">
-            <field name="name">La Gare</field>
-            <field name="code">MC-GA</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-je">
-            <field name="name">Jardin Exotique</field>
-            <field name="code">MC-JE</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-la">
-            <field name="name">Larvotto</field>
-            <field name="code">MC-LA</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-ma">
-            <field name="name">Malbousquet</field>
-            <field name="code">MC-MA</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-mc">
-            <field name="name">Monte-Carlo</field>
-            <field name="code">MC-MC</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-mg">
-            <field name="name">Moneghetti</field>
-            <field name="code">MC-MG</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-mo">
-            <field name="name">Monaco-Ville</field>
-            <field name="code">MC-MO</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-mu">
-            <field name="name">Moulins</field>
-            <field name="code">MC-MU</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-ph">
-            <field name="name">Port-Hercule</field>
-            <field name="code">MC-PH</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-sd">
-            <field name="name">Sainte-Dévote</field>
-            <field name="code">MC-SD</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-so">
-            <field name="name">La Source</field>
-            <field name="code">MC-SO</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-sp">
-            <field name="name">Spélugues</field>
-            <field name="code">MC-SP</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-sr">
-            <field name="name">Saint-Roman</field>
-            <field name="code">MC-SR</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="mc-vr">
-            <field name="name">Vallon de la Rousse</field>
-            <field name="code">MC-VR</field>
-            <field name="type">quarter</field>
-            <field name="country" ref="mc"/>
-        </record>
-
-        <record model="country.subdivision" id="md-an">
-            <field name="name">Anenii Noi</field>
-            <field name="code">MD-AN</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ba">
-            <field name="name">Bălți</field>
-            <field name="code">MD-BA</field>
-            <field name="type">city</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-bd">
-            <field name="name">Tighina</field>
-            <field name="code">MD-BD</field>
-            <field name="type">city</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-br">
-            <field name="name">Briceni</field>
-            <field name="code">MD-BR</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-bs">
-            <field name="name">Basarabeasca</field>
-            <field name="code">MD-BS</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ca">
-            <field name="name">Cahul</field>
-            <field name="code">MD-CA</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-cl">
-            <field name="name">Călărași</field>
-            <field name="code">MD-CL</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-cm">
-            <field name="name">Cimișlia</field>
-            <field name="code">MD-CM</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-cr">
-            <field name="name">Criuleni</field>
-            <field name="code">MD-CR</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-cs">
-            <field name="name">Căușeni</field>
-            <field name="code">MD-CS</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ct">
-            <field name="name">Cantemir</field>
-            <field name="code">MD-CT</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-cu">
-            <field name="name">Chișinău</field>
-            <field name="code">MD-CU</field>
-            <field name="type">city</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-do">
-            <field name="name">Dondușeni</field>
-            <field name="code">MD-DO</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-dr">
-            <field name="name">Drochia</field>
-            <field name="code">MD-DR</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-du">
-            <field name="name">Dubăsari</field>
-            <field name="code">MD-DU</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ed">
-            <field name="name">Edineț</field>
-            <field name="code">MD-ED</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-fa">
-            <field name="name">Fălești</field>
-            <field name="code">MD-FA</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-fl">
-            <field name="name">Florești</field>
-            <field name="code">MD-FL</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ga">
-            <field name="name">Găgăuzia, Unitatea teritorială autonomă</field>
-            <field name="code">MD-GA</field>
-            <field name="type">autonomous territorial unit</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-gl">
-            <field name="name">Glodeni</field>
-            <field name="code">MD-GL</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-hi">
-            <field name="name">Hîncești</field>
-            <field name="code">MD-HI</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ia">
-            <field name="name">Ialoveni</field>
-            <field name="code">MD-IA</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-le">
-            <field name="name">Leova</field>
-            <field name="code">MD-LE</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ni">
-            <field name="name">Nisporeni</field>
-            <field name="code">MD-NI</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-oc">
-            <field name="name">Ocnița</field>
-            <field name="code">MD-OC</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-or">
-            <field name="name">Orhei</field>
-            <field name="code">MD-OR</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-re">
-            <field name="name">Rezina</field>
-            <field name="code">MD-RE</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ri">
-            <field name="name">Rîșcani</field>
-            <field name="code">MD-RI</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-sd">
-            <field name="name">Șoldănești</field>
-            <field name="code">MD-SD</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-si">
-            <field name="name">Sîngerei</field>
-            <field name="code">MD-SI</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-sn">
-            <field name="name">Stînga Nistrului, unitatea teritorială din</field>
-            <field name="code">MD-SN</field>
-            <field name="type">territorial unit</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-so">
-            <field name="name">Soroca</field>
-            <field name="code">MD-SO</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-st">
-            <field name="name">Strășeni</field>
-            <field name="code">MD-ST</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-sv">
-            <field name="name">Ștefan Vodă</field>
-            <field name="code">MD-SV</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-ta">
-            <field name="name">Taraclia</field>
-            <field name="code">MD-TA</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-te">
-            <field name="name">Telenești</field>
-            <field name="code">MD-TE</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="md-un">
-            <field name="name">Ungheni</field>
-            <field name="code">MD-UN</field>
-            <field name="type">district</field>
-            <field name="country" ref="md"/>
-        </record>
-
-        <record model="country.subdivision" id="me-01">
-            <field name="name">Andrijevica</field>
-            <field name="code">ME-01</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-02">
-            <field name="name">Bar</field>
-            <field name="code">ME-02</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-03">
-            <field name="name">Berane</field>
-            <field name="code">ME-03</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-04">
-            <field name="name">Bijelo Polje</field>
-            <field name="code">ME-04</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-05">
-            <field name="name">Budva</field>
-            <field name="code">ME-05</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-06">
-            <field name="name">Cetinje</field>
-            <field name="code">ME-06</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-07">
-            <field name="name">Danilovgrad</field>
-            <field name="code">ME-07</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-08">
-            <field name="name">Herceg-Novi</field>
-            <field name="code">ME-08</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-09">
-            <field name="name">Kolašin</field>
-            <field name="code">ME-09</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-10">
-            <field name="name">Kotor</field>
-            <field name="code">ME-10</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-11">
-            <field name="name">Mojkovac</field>
-            <field name="code">ME-11</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-12">
-            <field name="name">Nikšić</field>
-            <field name="code">ME-12</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-13">
-            <field name="name">Plav</field>
-            <field name="code">ME-13</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-14">
-            <field name="name">Pljevlja</field>
-            <field name="code">ME-14</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-15">
-            <field name="name">Plužine</field>
-            <field name="code">ME-15</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-16">
-            <field name="name">Podgorica</field>
-            <field name="code">ME-16</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-17">
-            <field name="name">Rožaje</field>
-            <field name="code">ME-17</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-18">
-            <field name="name">Šavnik</field>
-            <field name="code">ME-18</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-19">
-            <field name="name">Tivat</field>
-            <field name="code">ME-19</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-20">
-            <field name="name">Ulcinj</field>
-            <field name="code">ME-20</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="me-21">
-            <field name="name">Žabljak</field>
-            <field name="code">ME-21</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="me"/>
-        </record>
-
-        <record model="country.subdivision" id="mg-a">
-            <field name="name">Toamasina</field>
-            <field name="code">MG-A</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="mg"/>
-        </record>
-
-        <record model="country.subdivision" id="mg-d">
-            <field name="name">Antsiranana</field>
-            <field name="code">MG-D</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="mg"/>
-        </record>
-
-        <record model="country.subdivision" id="mg-f">
-            <field name="name">Fianarantsoa</field>
-            <field name="code">MG-F</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="mg"/>
-        </record>
-
-        <record model="country.subdivision" id="mg-m">
-            <field name="name">Mahajanga</field>
-            <field name="code">MG-M</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="mg"/>
-        </record>
-
-        <record model="country.subdivision" id="mg-t">
-            <field name="name">Antananarivo</field>
-            <field name="code">MG-T</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="mg"/>
-        </record>
-
-        <record model="country.subdivision" id="mg-u">
-            <field name="name">Toliara</field>
-            <field name="code">MG-U</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="mg"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-l">
-            <field name="name">Ralik chain</field>
-            <field name="code">MH-L</field>
-            <field name="type">chains (of islands)</field>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-t">
-            <field name="name">Ratak chain</field>
-            <field name="code">MH-T</field>
-            <field name="type">chains (of islands)</field>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-01">
-            <field name="name">Aerodrom</field>
-            <field name="code">MK-01</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-02">
-            <field name="name">Aračinovo</field>
-            <field name="code">MK-02</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-03">
-            <field name="name">Berovo</field>
-            <field name="code">MK-03</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-04">
-            <field name="name">Bitola</field>
-            <field name="code">MK-04</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-05">
-            <field name="name">Bogdanci</field>
-            <field name="code">MK-05</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-06">
-            <field name="name">Bogovinje</field>
-            <field name="code">MK-06</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-07">
-            <field name="name">Bosilovo</field>
-            <field name="code">MK-07</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-08">
-            <field name="name">Brvenica</field>
-            <field name="code">MK-08</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-09">
-            <field name="name">Butel</field>
-            <field name="code">MK-09</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-10">
-            <field name="name">Valandovo</field>
-            <field name="code">MK-10</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-11">
-            <field name="name">Vasilevo</field>
-            <field name="code">MK-11</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-12">
-            <field name="name">Vevčani</field>
-            <field name="code">MK-12</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-13">
-            <field name="name">Veles</field>
-            <field name="code">MK-13</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-14">
-            <field name="name">Vinica</field>
-            <field name="code">MK-14</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-15">
-            <field name="name">Vraneštica</field>
-            <field name="code">MK-15</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-16">
-            <field name="name">Vrapčište</field>
-            <field name="code">MK-16</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-17">
-            <field name="name">Gazi Baba</field>
-            <field name="code">MK-17</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-18">
-            <field name="name">Gevgelija</field>
-            <field name="code">MK-18</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-19">
-            <field name="name">Gostivar</field>
-            <field name="code">MK-19</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-20">
-            <field name="name">Gradsko</field>
-            <field name="code">MK-20</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-21">
-            <field name="name">Debar</field>
-            <field name="code">MK-21</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-22">
-            <field name="name">Debarca</field>
-            <field name="code">MK-22</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-23">
-            <field name="name">Delčevo</field>
-            <field name="code">MK-23</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-24">
-            <field name="name">Demir Kapija</field>
-            <field name="code">MK-24</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-25">
-            <field name="name">Demir Hisar</field>
-            <field name="code">MK-25</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-26">
-            <field name="name">Dojran</field>
-            <field name="code">MK-26</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-27">
-            <field name="name">Dolneni</field>
-            <field name="code">MK-27</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-28">
-            <field name="name">Drugovo</field>
-            <field name="code">MK-28</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-29">
-            <field name="name">Gjorče Petrov</field>
-            <field name="code">MK-29</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-30">
-            <field name="name">Želino</field>
-            <field name="code">MK-30</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-31">
-            <field name="name">Zajas</field>
-            <field name="code">MK-31</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-32">
-            <field name="name">Zelenikovo</field>
-            <field name="code">MK-32</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-33">
-            <field name="name">Zrnovci</field>
-            <field name="code">MK-33</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-34">
-            <field name="name">Ilinden</field>
-            <field name="code">MK-34</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-35">
-            <field name="name">Jegunovce</field>
-            <field name="code">MK-35</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-36">
-            <field name="name">Kavadarci</field>
-            <field name="code">MK-36</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-37">
-            <field name="name">Karbinci</field>
-            <field name="code">MK-37</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-38">
-            <field name="name">Karpoš</field>
-            <field name="code">MK-38</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-39">
-            <field name="name">Kisela Voda</field>
-            <field name="code">MK-39</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-40">
-            <field name="name">Kičevo</field>
-            <field name="code">MK-40</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-41">
-            <field name="name">Konče</field>
-            <field name="code">MK-41</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-42">
-            <field name="name">Kočani</field>
-            <field name="code">MK-42</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-43">
-            <field name="name">Kratovo</field>
-            <field name="code">MK-43</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-44">
-            <field name="name">Kriva Palanka</field>
-            <field name="code">MK-44</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-45">
-            <field name="name">Krivogaštani</field>
-            <field name="code">MK-45</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-46">
-            <field name="name">Kruševo</field>
-            <field name="code">MK-46</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-47">
-            <field name="name">Kumanovo</field>
-            <field name="code">MK-47</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-48">
-            <field name="name">Lipkovo</field>
-            <field name="code">MK-48</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-49">
-            <field name="name">Lozovo</field>
-            <field name="code">MK-49</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-50">
-            <field name="name">Mavrovo-i-Rostuša</field>
-            <field name="code">MK-50</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-51">
-            <field name="name">Makedonska Kamenica</field>
-            <field name="code">MK-51</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-52">
-            <field name="name">Makedonski Brod</field>
-            <field name="code">MK-52</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-53">
-            <field name="name">Mogila</field>
-            <field name="code">MK-53</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-54">
-            <field name="name">Negotino</field>
-            <field name="code">MK-54</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-55">
-            <field name="name">Novaci</field>
-            <field name="code">MK-55</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-56">
-            <field name="name">Novo Selo</field>
-            <field name="code">MK-56</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-57">
-            <field name="name">Oslomej</field>
-            <field name="code">MK-57</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-58">
-            <field name="name">Ohrid</field>
-            <field name="code">MK-58</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-59">
-            <field name="name">Petrovec</field>
-            <field name="code">MK-59</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-60">
-            <field name="name">Pehčevo</field>
-            <field name="code">MK-60</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-61">
-            <field name="name">Plasnica</field>
-            <field name="code">MK-61</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-62">
-            <field name="name">Prilep</field>
-            <field name="code">MK-62</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-63">
-            <field name="name">Probištip</field>
-            <field name="code">MK-63</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-64">
-            <field name="name">Radoviš</field>
-            <field name="code">MK-64</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-65">
-            <field name="name">Rankovce</field>
-            <field name="code">MK-65</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-66">
-            <field name="name">Resen</field>
-            <field name="code">MK-66</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-67">
-            <field name="name">Rosoman</field>
-            <field name="code">MK-67</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-68">
-            <field name="name">Saraj</field>
-            <field name="code">MK-68</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-69">
-            <field name="name">Sveti Nikole</field>
-            <field name="code">MK-69</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-70">
-            <field name="name">Sopište</field>
-            <field name="code">MK-70</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-71">
-            <field name="name">Staro Nagoričane</field>
-            <field name="code">MK-71</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-72">
-            <field name="name">Struga</field>
-            <field name="code">MK-72</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-73">
-            <field name="name">Strumica</field>
-            <field name="code">MK-73</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-74">
-            <field name="name">Studeničani</field>
-            <field name="code">MK-74</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-75">
-            <field name="name">Tearce</field>
-            <field name="code">MK-75</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-76">
-            <field name="name">Tetovo</field>
-            <field name="code">MK-76</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-77">
-            <field name="name">Centar</field>
-            <field name="code">MK-77</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-78">
-            <field name="name">Centar Župa</field>
-            <field name="code">MK-78</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-79">
-            <field name="name">Čair</field>
-            <field name="code">MK-79</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-80">
-            <field name="name">Čaška</field>
-            <field name="code">MK-80</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-81">
-            <field name="name">Češinovo-Obleševo</field>
-            <field name="code">MK-81</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-82">
-            <field name="name">Čučer Sandevo</field>
-            <field name="code">MK-82</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-83">
-            <field name="name">Štip</field>
-            <field name="code">MK-83</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="mk-84">
-            <field name="name">Šuto Orizari</field>
-            <field name="code">MK-84</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mk"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-1">
-            <field name="name">Kayes</field>
-            <field name="code">ML-1</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-2">
-            <field name="name">Koulikoro</field>
-            <field name="code">ML-2</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-3">
-            <field name="name">Sikasso</field>
-            <field name="code">ML-3</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-4">
-            <field name="name">Ségou</field>
-            <field name="code">ML-4</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-5">
-            <field name="name">Mopti</field>
-            <field name="code">ML-5</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-6">
-            <field name="name">Tombouctou</field>
-            <field name="code">ML-6</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-7">
-            <field name="name">Gao</field>
-            <field name="code">ML-7</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-8">
-            <field name="name">Kidal</field>
-            <field name="code">ML-8</field>
-            <field name="type">region</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="ml-bk0">
-            <field name="name">Bamako</field>
-            <field name="code">ML-BK0</field>
-            <field name="type">district</field>
-            <field name="country" ref="ml"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-01">
-            <field name="name">Sagaing</field>
-            <field name="code">MM-01</field>
-            <field name="type">division</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-02">
-            <field name="name">Bago</field>
-            <field name="code">MM-02</field>
-            <field name="type">division</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-03">
-            <field name="name">Magway</field>
-            <field name="code">MM-03</field>
-            <field name="type">division</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-04">
-            <field name="name">Mandalay</field>
-            <field name="code">MM-04</field>
-            <field name="type">division</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-05">
-            <field name="name">Tanintharyi</field>
-            <field name="code">MM-05</field>
-            <field name="type">division</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-06">
-            <field name="name">Yangon</field>
-            <field name="code">MM-06</field>
-            <field name="type">division</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-07">
-            <field name="name">Ayeyarwady</field>
-            <field name="code">MM-07</field>
-            <field name="type">division</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-11">
-            <field name="name">Kachin</field>
-            <field name="code">MM-11</field>
-            <field name="type">state</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-12">
-            <field name="name">Kayah</field>
-            <field name="code">MM-12</field>
-            <field name="type">state</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-13">
-            <field name="name">Kayin</field>
-            <field name="code">MM-13</field>
-            <field name="type">state</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-14">
-            <field name="name">Chin</field>
-            <field name="code">MM-14</field>
-            <field name="type">state</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-15">
-            <field name="name">Mon</field>
-            <field name="code">MM-15</field>
-            <field name="type">state</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-16">
-            <field name="name">Rakhine</field>
-            <field name="code">MM-16</field>
-            <field name="type">state</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mm-17">
-            <field name="name">Shan</field>
-            <field name="code">MM-17</field>
-            <field name="type">state</field>
-            <field name="country" ref="mm"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-035">
-            <field name="name">Orhon</field>
-            <field name="code">MN-035</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-037">
-            <field name="name">Darhan uul</field>
-            <field name="code">MN-037</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-039">
-            <field name="name">Hentiy</field>
-            <field name="code">MN-039</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-041">
-            <field name="name">Hövsgöl</field>
-            <field name="code">MN-041</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-043">
-            <field name="name">Hovd</field>
-            <field name="code">MN-043</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-046">
-            <field name="name">Uvs</field>
-            <field name="code">MN-046</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-047">
-            <field name="name">Töv</field>
-            <field name="code">MN-047</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-049">
-            <field name="name">Selenge</field>
-            <field name="code">MN-049</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-051">
-            <field name="name">Sühbaatar</field>
-            <field name="code">MN-051</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-053">
-            <field name="name">Ömnögovi</field>
-            <field name="code">MN-053</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-055">
-            <field name="name">Övörhangay</field>
-            <field name="code">MN-055</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-057">
-            <field name="name">Dzavhan</field>
-            <field name="code">MN-057</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-059">
-            <field name="name">Dundgovi</field>
-            <field name="code">MN-059</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-061">
-            <field name="name">Dornod</field>
-            <field name="code">MN-061</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-063">
-            <field name="name">Dornogovi</field>
-            <field name="code">MN-063</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-064">
-            <field name="name">Govi-Sumber</field>
-            <field name="code">MN-064</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-065">
-            <field name="name">Govi-Altay</field>
-            <field name="code">MN-065</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-067">
-            <field name="name">Bulgan</field>
-            <field name="code">MN-067</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-069">
-            <field name="name">Bayanhongor</field>
-            <field name="code">MN-069</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-071">
-            <field name="name">Bayan-Ölgiy</field>
-            <field name="code">MN-071</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-073">
-            <field name="name">Arhangay</field>
-            <field name="code">MN-073</field>
-            <field name="type">province</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mn-1">
-            <field name="name">Ulanbaatar</field>
-            <field name="code">MN-1</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="mn"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-01">
-            <field name="name">Hodh ech Chargui</field>
-            <field name="code">MR-01</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-02">
-            <field name="name">Hodh el Charbi</field>
-            <field name="code">MR-02</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-03">
-            <field name="name">Assaba</field>
-            <field name="code">MR-03</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-04">
-            <field name="name">Gorgol</field>
-            <field name="code">MR-04</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-05">
-            <field name="name">Brakna</field>
-            <field name="code">MR-05</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-06">
-            <field name="name">Trarza</field>
-            <field name="code">MR-06</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-07">
-            <field name="name">Adrar</field>
-            <field name="code">MR-07</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-08">
-            <field name="name">Dakhlet Nouadhibou</field>
-            <field name="code">MR-08</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-09">
-            <field name="name">Tagant</field>
-            <field name="code">MR-09</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-10">
-            <field name="name">Guidimaka</field>
-            <field name="code">MR-10</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-11">
-            <field name="name">Tiris Zemmour</field>
-            <field name="code">MR-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-12">
-            <field name="name">Inchiri</field>
-            <field name="code">MR-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mr-nkc">
-            <field name="name">Nouakchott</field>
-            <field name="code">MR-NKC</field>
-            <field name="type">district</field>
-            <field name="country" ref="mr"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-01">
-            <field name="name">Attard</field>
-            <field name="code">MT-01</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-02">
-            <field name="name">Balzan</field>
-            <field name="code">MT-02</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-03">
-            <field name="name">Birgu</field>
-            <field name="code">MT-03</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-04">
-            <field name="name">Birkirkara</field>
-            <field name="code">MT-04</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-05">
-            <field name="name">Birżebbuġa</field>
-            <field name="code">MT-05</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-06">
-            <field name="name">Bormla</field>
-            <field name="code">MT-06</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-07">
-            <field name="name">Dingli</field>
-            <field name="code">MT-07</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-08">
-            <field name="name">Fgura</field>
-            <field name="code">MT-08</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-09">
-            <field name="name">Floriana</field>
-            <field name="code">MT-09</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-10">
-            <field name="name">Fontana</field>
-            <field name="code">MT-10</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-11">
-            <field name="name">Gudja</field>
-            <field name="code">MT-11</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-12">
-            <field name="name">Gżira</field>
-            <field name="code">MT-12</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-13">
-            <field name="name">Għajnsielem</field>
-            <field name="code">MT-13</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-14">
-            <field name="name">Għarb</field>
-            <field name="code">MT-14</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-15">
-            <field name="name">Għargħur</field>
-            <field name="code">MT-15</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-16">
-            <field name="name">Għasri</field>
-            <field name="code">MT-16</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-17">
-            <field name="name">Għaxaq</field>
-            <field name="code">MT-17</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-18">
-            <field name="name">Ħamrun</field>
-            <field name="code">MT-18</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-19">
-            <field name="name">Iklin</field>
-            <field name="code">MT-19</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-20">
-            <field name="name">Isla</field>
-            <field name="code">MT-20</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-21">
-            <field name="name">Kalkara</field>
-            <field name="code">MT-21</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-22">
-            <field name="name">Kerċem</field>
-            <field name="code">MT-22</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-23">
-            <field name="name">Kirkop</field>
-            <field name="code">MT-23</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-24">
-            <field name="name">Lija</field>
-            <field name="code">MT-24</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-25">
-            <field name="name">Luqa</field>
-            <field name="code">MT-25</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-26">
-            <field name="name">Marsa</field>
-            <field name="code">MT-26</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-27">
-            <field name="name">Marsaskala</field>
-            <field name="code">MT-27</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-28">
-            <field name="name">Marsaxlokk</field>
-            <field name="code">MT-28</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-29">
-            <field name="name">Mdina</field>
-            <field name="code">MT-29</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-30">
-            <field name="name">Mellieħa</field>
-            <field name="code">MT-30</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-31">
-            <field name="name">Mġarr</field>
-            <field name="code">MT-31</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-32">
-            <field name="name">Mosta</field>
-            <field name="code">MT-32</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-33">
-            <field name="name">Mqabba</field>
-            <field name="code">MT-33</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-34">
-            <field name="name">Msida</field>
-            <field name="code">MT-34</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-35">
-            <field name="name">Mtarfa</field>
-            <field name="code">MT-35</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-36">
-            <field name="name">Munxar</field>
-            <field name="code">MT-36</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-37">
-            <field name="name">Nadur</field>
-            <field name="code">MT-37</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-38">
-            <field name="name">Naxxar</field>
-            <field name="code">MT-38</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-39">
-            <field name="name">Paola</field>
-            <field name="code">MT-39</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-40">
-            <field name="name">Pembroke</field>
-            <field name="code">MT-40</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-41">
-            <field name="name">Pietà</field>
-            <field name="code">MT-41</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-42">
-            <field name="name">Qala</field>
-            <field name="code">MT-42</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-43">
-            <field name="name">Qormi</field>
-            <field name="code">MT-43</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-44">
-            <field name="name">Qrendi</field>
-            <field name="code">MT-44</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-45">
-            <field name="name">Rabat Għawdex</field>
-            <field name="code">MT-45</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-46">
-            <field name="name">Rabat Malta</field>
-            <field name="code">MT-46</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-47">
-            <field name="name">Safi</field>
-            <field name="code">MT-47</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-48">
-            <field name="name">San Ġiljan</field>
-            <field name="code">MT-48</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-49">
-            <field name="name">San Ġwann</field>
-            <field name="code">MT-49</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-50">
-            <field name="name">San Lawrenz</field>
-            <field name="code">MT-50</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-51">
-            <field name="name">San Pawl il-Baħar</field>
-            <field name="code">MT-51</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-52">
-            <field name="name">Sannat</field>
-            <field name="code">MT-52</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-53">
-            <field name="name">Santa Luċija</field>
-            <field name="code">MT-53</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-54">
-            <field name="name">Santa Venera</field>
-            <field name="code">MT-54</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-55">
-            <field name="name">Siġġiewi</field>
-            <field name="code">MT-55</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-56">
-            <field name="name">Sliema</field>
-            <field name="code">MT-56</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-57">
-            <field name="name">Swieqi</field>
-            <field name="code">MT-57</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-58">
-            <field name="name">Ta’ Xbiex</field>
-            <field name="code">MT-58</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-59">
-            <field name="name">Tarxien</field>
-            <field name="code">MT-59</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-60">
-            <field name="name">Valletta</field>
-            <field name="code">MT-60</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-61">
-            <field name="name">Xagħra</field>
-            <field name="code">MT-61</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-62">
-            <field name="name">Xewkija</field>
-            <field name="code">MT-62</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-63">
-            <field name="name">Xgħajra</field>
-            <field name="code">MT-63</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-64">
-            <field name="name">Żabbar</field>
-            <field name="code">MT-64</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-65">
-            <field name="name">Żebbuġ Għawdex</field>
-            <field name="code">MT-65</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-66">
-            <field name="name">Żebbuġ Malta</field>
-            <field name="code">MT-66</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-67">
-            <field name="name">Żejtun</field>
-            <field name="code">MT-67</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mt-68">
-            <field name="name">Żurrieq</field>
-            <field name="code">MT-68</field>
-            <field name="type">local council</field>
-            <field name="country" ref="mt"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-ag">
-            <field name="name">Agalega Islands</field>
-            <field name="code">MU-AG</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-bl">
-            <field name="name">Black River</field>
-            <field name="code">MU-BL</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-br">
-            <field name="name">Beau Bassin-Rose Hill</field>
-            <field name="code">MU-BR</field>
-            <field name="type">city</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-cc">
-            <field name="name">Cargados Carajos Shoals</field>
-            <field name="code">MU-CC</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-cu">
-            <field name="name">Curepipe</field>
-            <field name="code">MU-CU</field>
-            <field name="type">city</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-fl">
-            <field name="name">Flacq</field>
-            <field name="code">MU-FL</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-gp">
-            <field name="name">Grand Port</field>
-            <field name="code">MU-GP</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-mo">
-            <field name="name">Moka</field>
-            <field name="code">MU-MO</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-pa">
-            <field name="name">Pamplemousses</field>
-            <field name="code">MU-PA</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-pl">
-            <field name="name">Port Louis</field>
-            <field name="code">MU-PL</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-pu">
-            <field name="name">Port Louis</field>
-            <field name="code">MU-PU</field>
-            <field name="type">city</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-pw">
-            <field name="name">Plaines Wilhems</field>
-            <field name="code">MU-PW</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-qb">
-            <field name="name">Quatre Bornes</field>
-            <field name="code">MU-QB</field>
-            <field name="type">city</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-ro">
-            <field name="name">Rodrigues Island</field>
-            <field name="code">MU-RO</field>
-            <field name="type">dependency</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-rp">
-            <field name="name">Rivière du Rempart</field>
-            <field name="code">MU-RP</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-sa">
-            <field name="name">Savanne</field>
-            <field name="code">MU-SA</field>
-            <field name="type">district</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mu-vp">
-            <field name="name">Vacoas-Phoenix</field>
-            <field name="code">MU-VP</field>
-            <field name="type">city</field>
-            <field name="country" ref="mu"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-ce">
-            <field name="name">Central</field>
-            <field name="code">MV-CE</field>
-            <field name="type">province</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-mle">
-            <field name="name">Male</field>
-            <field name="code">MV-MLE</field>
-            <field name="type">city</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-nc">
-            <field name="name">North Central</field>
-            <field name="code">MV-NC</field>
-            <field name="type">province</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-no">
-            <field name="name">North</field>
-            <field name="code">MV-NO</field>
-            <field name="type">province</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-sc">
-            <field name="name">South Central</field>
-            <field name="code">MV-SC</field>
-            <field name="type">province</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-su">
-            <field name="name">South</field>
-            <field name="code">MV-SU</field>
-            <field name="type">province</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-un">
-            <field name="name">Upper North</field>
-            <field name="code">MV-UN</field>
-            <field name="type">province</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-us">
-            <field name="name">Upper South</field>
-            <field name="code">MV-US</field>
-            <field name="type">province</field>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-c">
-            <field name="name">Central Region</field>
-            <field name="code">MW-C</field>
-            <field name="type">region</field>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-n">
-            <field name="name">Northern Region</field>
-            <field name="code">MW-N</field>
-            <field name="type">region</field>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-s">
-            <field name="name">Southern Region</field>
-            <field name="code">MW-S</field>
-            <field name="type">region</field>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-agu">
-            <field name="name">Aguascalientes</field>
-            <field name="code">MX-AGU</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-bcn">
-            <field name="name">Baja California</field>
-            <field name="code">MX-BCN</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-bcs">
-            <field name="name">Baja California Sur</field>
-            <field name="code">MX-BCS</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-cam">
-            <field name="name">Campeche</field>
-            <field name="code">MX-CAM</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-chh">
-            <field name="name">Chihuahua</field>
-            <field name="code">MX-CHH</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-chp">
-            <field name="name">Chiapas</field>
-            <field name="code">MX-CHP</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-coa">
-            <field name="name">Coahuila</field>
-            <field name="code">MX-COA</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-col">
-            <field name="name">Colima</field>
-            <field name="code">MX-COL</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-dif">
-            <field name="name">Distrito Federal</field>
-            <field name="code">MX-DIF</field>
-            <field name="type">federal district</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-dur">
-            <field name="name">Durango</field>
-            <field name="code">MX-DUR</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-gro">
-            <field name="name">Guerrero</field>
-            <field name="code">MX-GRO</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-gua">
-            <field name="name">Guanajuato</field>
-            <field name="code">MX-GUA</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-hid">
-            <field name="name">Hidalgo</field>
-            <field name="code">MX-HID</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-jal">
-            <field name="name">Jalisco</field>
-            <field name="code">MX-JAL</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-mex">
-            <field name="name">México</field>
-            <field name="code">MX-MEX</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-mic">
-            <field name="name">Michoacán</field>
-            <field name="code">MX-MIC</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-mor">
-            <field name="name">Morelos</field>
-            <field name="code">MX-MOR</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-nay">
-            <field name="name">Nayarit</field>
-            <field name="code">MX-NAY</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-nle">
-            <field name="name">Nuevo León</field>
-            <field name="code">MX-NLE</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-oax">
-            <field name="name">Oaxaca</field>
-            <field name="code">MX-OAX</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-pue">
-            <field name="name">Puebla</field>
-            <field name="code">MX-PUE</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-que">
-            <field name="name">Querétaro</field>
-            <field name="code">MX-QUE</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-roo">
-            <field name="name">Quintana Roo</field>
-            <field name="code">MX-ROO</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-sin">
-            <field name="name">Sinaloa</field>
-            <field name="code">MX-SIN</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-slp">
-            <field name="name">San Luis Potosí</field>
-            <field name="code">MX-SLP</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-son">
-            <field name="name">Sonora</field>
-            <field name="code">MX-SON</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-tab">
-            <field name="name">Tabasco</field>
-            <field name="code">MX-TAB</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-tam">
-            <field name="name">Tamaulipas</field>
-            <field name="code">MX-TAM</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-tla">
-            <field name="name">Tlaxcala</field>
-            <field name="code">MX-TLA</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-ver">
-            <field name="name">Veracruz</field>
-            <field name="code">MX-VER</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-yuc">
-            <field name="name">Yucatán</field>
-            <field name="code">MX-YUC</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="mx-zac">
-            <field name="name">Zacatecas</field>
-            <field name="code">MX-ZAC</field>
-            <field name="type">state</field>
-            <field name="country" ref="mx"/>
-        </record>
-
-        <record model="country.subdivision" id="my-01">
-            <field name="name">Johor</field>
-            <field name="code">MY-01</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-02">
-            <field name="name">Kedah</field>
-            <field name="code">MY-02</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-03">
-            <field name="name">Kelantan</field>
-            <field name="code">MY-03</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-04">
-            <field name="name">Melaka</field>
-            <field name="code">MY-04</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-05">
-            <field name="name">Negeri Sembilan</field>
-            <field name="code">MY-05</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-06">
-            <field name="name">Pahang</field>
-            <field name="code">MY-06</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-07">
-            <field name="name">Pulau Pinang</field>
-            <field name="code">MY-07</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-08">
-            <field name="name">Perak</field>
-            <field name="code">MY-08</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-09">
-            <field name="name">Perlis</field>
-            <field name="code">MY-09</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-10">
-            <field name="name">Selangor</field>
-            <field name="code">MY-10</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-11">
-            <field name="name">Terengganu</field>
-            <field name="code">MY-11</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-12">
-            <field name="name">Sabah</field>
-            <field name="code">MY-12</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-13">
-            <field name="name">Sarawak</field>
-            <field name="code">MY-13</field>
-            <field name="type">state</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-14">
-            <field name="name">Wilayah Persekutuan Kuala Lumpur</field>
-            <field name="code">MY-14</field>
-            <field name="type">federal territories</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-15">
-            <field name="name">Wilayah Persekutuan Labuan</field>
-            <field name="code">MY-15</field>
-            <field name="type">federal territories</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="my-16">
-            <field name="name">Wilayah Persekutuan Putrajaya</field>
-            <field name="code">MY-16</field>
-            <field name="type">federal territories</field>
-            <field name="country" ref="my"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-a">
-            <field name="name">Niassa</field>
-            <field name="code">MZ-A</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-b">
-            <field name="name">Manica</field>
-            <field name="code">MZ-B</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-g">
-            <field name="name">Gaza</field>
-            <field name="code">MZ-G</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-i">
-            <field name="name">Inhambane</field>
-            <field name="code">MZ-I</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-l">
-            <field name="name">Maputo</field>
-            <field name="code">MZ-L</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-mpm">
-            <field name="name">Maputo (city)</field>
-            <field name="code">MZ-MPM</field>
-            <field name="type">city</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-n">
-            <field name="name">Numpula</field>
-            <field name="code">MZ-N</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-p">
-            <field name="name">Cabo Delgado</field>
-            <field name="code">MZ-P</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-q">
-            <field name="name">Zambezia</field>
-            <field name="code">MZ-Q</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-s">
-            <field name="name">Sofala</field>
-            <field name="code">MZ-S</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="mz-t">
-            <field name="name">Tete</field>
-            <field name="code">MZ-T</field>
-            <field name="type">province</field>
-            <field name="country" ref="mz"/>
-        </record>
-
-        <record model="country.subdivision" id="na-ca">
-            <field name="name">Caprivi</field>
-            <field name="code">NA-CA</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-er">
-            <field name="name">Erongo</field>
-            <field name="code">NA-ER</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-ha">
-            <field name="name">Hardap</field>
-            <field name="code">NA-HA</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-ka">
-            <field name="name">Karas</field>
-            <field name="code">NA-KA</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-kh">
-            <field name="name">Khomas</field>
-            <field name="code">NA-KH</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-ku">
-            <field name="name">Kunene</field>
-            <field name="code">NA-KU</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-od">
-            <field name="name">Otjozondjupa</field>
-            <field name="code">NA-OD</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-oh">
-            <field name="name">Omaheke</field>
-            <field name="code">NA-OH</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-ok">
-            <field name="name">Okavango</field>
-            <field name="code">NA-OK</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-on">
-            <field name="name">Oshana</field>
-            <field name="code">NA-ON</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-os">
-            <field name="name">Omusati</field>
-            <field name="code">NA-OS</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-ot">
-            <field name="name">Oshikoto</field>
-            <field name="code">NA-OT</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="na-ow">
-            <field name="name">Ohangwena</field>
-            <field name="code">NA-OW</field>
-            <field name="type">region</field>
-            <field name="country" ref="na"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-1">
-            <field name="name">Agadez</field>
-            <field name="code">NE-1</field>
-            <field name="type">department</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-2">
-            <field name="name">Diffa</field>
-            <field name="code">NE-2</field>
-            <field name="type">department</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-3">
-            <field name="name">Dosso</field>
-            <field name="code">NE-3</field>
-            <field name="type">department</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-4">
-            <field name="name">Maradi</field>
-            <field name="code">NE-4</field>
-            <field name="type">department</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-5">
-            <field name="name">Tahoua</field>
-            <field name="code">NE-5</field>
-            <field name="type">department</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-6">
-            <field name="name">Tillabéri</field>
-            <field name="code">NE-6</field>
-            <field name="type">department</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-7">
-            <field name="name">Zinder</field>
-            <field name="code">NE-7</field>
-            <field name="type">department</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ne-8">
-            <field name="name">Niamey</field>
-            <field name="code">NE-8</field>
-            <field name="type">capital district</field>
-            <field name="country" ref="ne"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ab">
-            <field name="name">Abia</field>
-            <field name="code">NG-AB</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ad">
-            <field name="name">Adamawa</field>
-            <field name="code">NG-AD</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ak">
-            <field name="name">Akwa Ibom</field>
-            <field name="code">NG-AK</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-an">
-            <field name="name">Anambra</field>
-            <field name="code">NG-AN</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ba">
-            <field name="name">Bauchi</field>
-            <field name="code">NG-BA</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-be">
-            <field name="name">Benue</field>
-            <field name="code">NG-BE</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-bo">
-            <field name="name">Borno</field>
-            <field name="code">NG-BO</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-by">
-            <field name="name">Bayelsa</field>
-            <field name="code">NG-BY</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-cr">
-            <field name="name">Cross River</field>
-            <field name="code">NG-CR</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-de">
-            <field name="name">Delta</field>
-            <field name="code">NG-DE</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-eb">
-            <field name="name">Ebonyi</field>
-            <field name="code">NG-EB</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ed">
-            <field name="name">Edo</field>
-            <field name="code">NG-ED</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ek">
-            <field name="name">Ekiti</field>
-            <field name="code">NG-EK</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-en">
-            <field name="name">Enugu</field>
-            <field name="code">NG-EN</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-fc">
-            <field name="name">Abuja Capital Territory</field>
-            <field name="code">NG-FC</field>
-            <field name="type">capital territory</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-go">
-            <field name="name">Gombe</field>
-            <field name="code">NG-GO</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-im">
-            <field name="name">Imo</field>
-            <field name="code">NG-IM</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ji">
-            <field name="name">Jigawa</field>
-            <field name="code">NG-JI</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-kd">
-            <field name="name">Kaduna</field>
-            <field name="code">NG-KD</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ke">
-            <field name="name">Kebbi</field>
-            <field name="code">NG-KE</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-kn">
-            <field name="name">Kano</field>
-            <field name="code">NG-KN</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ko">
-            <field name="name">Kogi</field>
-            <field name="code">NG-KO</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-kt">
-            <field name="name">Katsina</field>
-            <field name="code">NG-KT</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-kw">
-            <field name="name">Kwara</field>
-            <field name="code">NG-KW</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-la">
-            <field name="name">Lagos</field>
-            <field name="code">NG-LA</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-na">
-            <field name="name">Nassarawa</field>
-            <field name="code">NG-NA</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ni">
-            <field name="name">Niger</field>
-            <field name="code">NG-NI</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-og">
-            <field name="name">Ogun</field>
-            <field name="code">NG-OG</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-on">
-            <field name="name">Ondo</field>
-            <field name="code">NG-ON</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-os">
-            <field name="name">Osun</field>
-            <field name="code">NG-OS</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-oy">
-            <field name="name">Oyo</field>
-            <field name="code">NG-OY</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-pl">
-            <field name="name">Plateau</field>
-            <field name="code">NG-PL</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ri">
-            <field name="name">Rivers</field>
-            <field name="code">NG-RI</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-so">
-            <field name="name">Sokoto</field>
-            <field name="code">NG-SO</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-ta">
-            <field name="name">Taraba</field>
-            <field name="code">NG-TA</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-yo">
-            <field name="name">Yobe</field>
-            <field name="code">NG-YO</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ng-za">
-            <field name="name">Zamfara</field>
-            <field name="code">NG-ZA</field>
-            <field name="type">state</field>
-            <field name="country" ref="ng"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-an">
-            <field name="name">Atlántico Norte</field>
-            <field name="code">NI-AN</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-as">
-            <field name="name">Atlántico Sur</field>
-            <field name="code">NI-AS</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-bo">
-            <field name="name">Boaco</field>
-            <field name="code">NI-BO</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-ca">
-            <field name="name">Carazo</field>
-            <field name="code">NI-CA</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-ci">
-            <field name="name">Chinandega</field>
-            <field name="code">NI-CI</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-co">
-            <field name="name">Chontales</field>
-            <field name="code">NI-CO</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-es">
-            <field name="name">Estelí</field>
-            <field name="code">NI-ES</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-gr">
-            <field name="name">Granada</field>
-            <field name="code">NI-GR</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-ji">
-            <field name="name">Jinotega</field>
-            <field name="code">NI-JI</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-le">
-            <field name="name">León</field>
-            <field name="code">NI-LE</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-md">
-            <field name="name">Madriz</field>
-            <field name="code">NI-MD</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-mn">
-            <field name="name">Managua</field>
-            <field name="code">NI-MN</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-ms">
-            <field name="name">Masaya</field>
-            <field name="code">NI-MS</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-mt">
-            <field name="name">Matagalpa</field>
-            <field name="code">NI-MT</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-ns">
-            <field name="name">Nueva Segovia</field>
-            <field name="code">NI-NS</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-ri">
-            <field name="name">Rivas</field>
-            <field name="code">NI-RI</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="ni-sj">
-            <field name="name">Río San Juan</field>
-            <field name="code">NI-SJ</field>
-            <field name="type">department</field>
-            <field name="country" ref="ni"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-aw">
-            <field name="name">Aruba</field>
-            <field name="code">NL-AW</field>
-            <field name="type">country</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-bq1">
-            <field name="name">Bonaire</field>
-            <field name="code">NL-BQ1</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-bq2">
-            <field name="name">Saba</field>
-            <field name="code">NL-BQ2</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-bq3">
-            <field name="name">Sint Eustatius</field>
-            <field name="code">NL-BQ3</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-cw">
-            <field name="name">Curaçao</field>
-            <field name="code">NL-CW</field>
-            <field name="type">country</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-dr">
-            <field name="name">Drenthe</field>
-            <field name="code">NL-DR</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-fl">
-            <field name="name">Flevoland</field>
-            <field name="code">NL-FL</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-fr">
-            <field name="name">Friesland</field>
-            <field name="code">NL-FR</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-ge">
-            <field name="name">Gelderland</field>
-            <field name="code">NL-GE</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-gr">
-            <field name="name">Groningen</field>
-            <field name="code">NL-GR</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-li">
-            <field name="name">Limburg</field>
-            <field name="code">NL-LI</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-nb">
-            <field name="name">Noord-Brabant</field>
-            <field name="code">NL-NB</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-nh">
-            <field name="name">Noord-Holland</field>
-            <field name="code">NL-NH</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-ov">
-            <field name="name">Overijssel</field>
-            <field name="code">NL-OV</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-sx">
-            <field name="name">Sint Maarten</field>
-            <field name="code">NL-SX</field>
-            <field name="type">country</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-ut">
-            <field name="name">Utrecht</field>
-            <field name="code">NL-UT</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-ze">
-            <field name="name">Zeeland</field>
-            <field name="code">NL-ZE</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="nl-zh">
-            <field name="name">Zuid-Holland</field>
-            <field name="code">NL-ZH</field>
-            <field name="type">province</field>
-            <field name="country" ref="nl"/>
-        </record>
-
-        <record model="country.subdivision" id="no-01">
-            <field name="name">Østfold</field>
-            <field name="code">NO-01</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-02">
-            <field name="name">Akershus</field>
-            <field name="code">NO-02</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-03">
-            <field name="name">Oslo</field>
-            <field name="code">NO-03</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-04">
-            <field name="name">Hedmark</field>
-            <field name="code">NO-04</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-05">
-            <field name="name">Oppland</field>
-            <field name="code">NO-05</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-06">
-            <field name="name">Buskerud</field>
-            <field name="code">NO-06</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-07">
-            <field name="name">Vestfold</field>
-            <field name="code">NO-07</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-08">
-            <field name="name">Telemark</field>
-            <field name="code">NO-08</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-09">
-            <field name="name">Aust-Agder</field>
-            <field name="code">NO-09</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-10">
-            <field name="name">Vest-Agder</field>
-            <field name="code">NO-10</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-11">
-            <field name="name">Rogaland</field>
-            <field name="code">NO-11</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-12">
-            <field name="name">Hordaland</field>
-            <field name="code">NO-12</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-14">
-            <field name="name">Sogn og Fjordane</field>
-            <field name="code">NO-14</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-15">
-            <field name="name">Møre og Romsdal</field>
-            <field name="code">NO-15</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-16">
-            <field name="name">Sør-Trøndelag</field>
-            <field name="code">NO-16</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-17">
-            <field name="name">Nord-Trøndelag</field>
-            <field name="code">NO-17</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-18">
-            <field name="name">Nordland</field>
-            <field name="code">NO-18</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-19">
-            <field name="name">Troms</field>
-            <field name="code">NO-19</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-20">
-            <field name="name">Finnmark</field>
-            <field name="code">NO-20</field>
-            <field name="type">county</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-21">
-            <field name="name">Svalbard (Arctic Region)</field>
-            <field name="code">NO-21</field>
-            <field name="type">arctic region</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="no-22">
-            <field name="name">Jan Mayen (Arctic Region)</field>
-            <field name="code">NO-22</field>
-            <field name="type">arctic region</field>
-            <field name="country" ref="no"/>
-        </record>
-
-        <record model="country.subdivision" id="np-1">
-            <field name="name">Madhyamanchal</field>
-            <field name="code">NP-1</field>
-            <field name="type">development region</field>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-2">
-            <field name="name">Madhya Pashchimanchal</field>
-            <field name="code">NP-2</field>
-            <field name="type">development region</field>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-3">
-            <field name="name">Pashchimanchal</field>
-            <field name="code">NP-3</field>
-            <field name="type">development region</field>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-4">
-            <field name="name">Purwanchal</field>
-            <field name="code">NP-4</field>
-            <field name="type">development region</field>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-5">
-            <field name="name">Sudur Pashchimanchal</field>
-            <field name="code">NP-5</field>
-            <field name="type">development region</field>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-01">
-            <field name="name">Aiwo</field>
-            <field name="code">NR-01</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-02">
-            <field name="name">Anabar</field>
-            <field name="code">NR-02</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-03">
-            <field name="name">Anetan</field>
-            <field name="code">NR-03</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-04">
-            <field name="name">Anibare</field>
-            <field name="code">NR-04</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-05">
-            <field name="name">Baiti</field>
-            <field name="code">NR-05</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-06">
-            <field name="name">Boe</field>
-            <field name="code">NR-06</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-07">
-            <field name="name">Buada</field>
-            <field name="code">NR-07</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-08">
-            <field name="name">Denigomodu</field>
-            <field name="code">NR-08</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-09">
-            <field name="name">Ewa</field>
-            <field name="code">NR-09</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-10">
-            <field name="name">Ijuw</field>
-            <field name="code">NR-10</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-11">
-            <field name="name">Meneng</field>
-            <field name="code">NR-11</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-12">
-            <field name="name">Nibok</field>
-            <field name="code">NR-12</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-13">
-            <field name="name">Uaboe</field>
-            <field name="code">NR-13</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nr-14">
-            <field name="name">Yaren</field>
-            <field name="code">NR-14</field>
-            <field name="type">district</field>
-            <field name="country" ref="nr"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-cit">
-            <field name="name">Chatham Islands Territory</field>
-            <field name="code">NZ-CIT</field>
-            <field name="type">special island authority</field>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-n">
-            <field name="name">North Island</field>
-            <field name="code">NZ-N</field>
-            <field name="type">island</field>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-s">
-            <field name="name">South Island</field>
-            <field name="code">NZ-S</field>
-            <field name="type">island</field>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="om-ba">
-            <field name="name">Al Bāţinah</field>
-            <field name="code">OM-BA</field>
-            <field name="type">region</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-bu">
-            <field name="name">Al Buraymī</field>
-            <field name="code">OM-BU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-da">
-            <field name="name">Ad Dākhilīya</field>
-            <field name="code">OM-DA</field>
-            <field name="type">region</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-ma">
-            <field name="name">Masqaţ</field>
-            <field name="code">OM-MA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-mu">
-            <field name="name">Musandam</field>
-            <field name="code">OM-MU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-sh">
-            <field name="name">Ash Sharqīyah</field>
-            <field name="code">OM-SH</field>
-            <field name="type">region</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-wu">
-            <field name="name">Al Wusţá</field>
-            <field name="code">OM-WU</field>
-            <field name="type">region</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-za">
-            <field name="name">Az̧ Z̧āhirah</field>
-            <field name="code">OM-ZA</field>
-            <field name="type">region</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="om-zu">
-            <field name="name">Z̧ufār</field>
-            <field name="code">OM-ZU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="om"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-1">
-            <field name="name">Bocas del Toro</field>
-            <field name="code">PA-1</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-2">
-            <field name="name">Coclé</field>
-            <field name="code">PA-2</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-3">
-            <field name="name">Colón</field>
-            <field name="code">PA-3</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-4">
-            <field name="name">Chiriquí</field>
-            <field name="code">PA-4</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-5">
-            <field name="name">Darién</field>
-            <field name="code">PA-5</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-6">
-            <field name="name">Herrera</field>
-            <field name="code">PA-6</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-7">
-            <field name="name">Los Santos</field>
-            <field name="code">PA-7</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-8">
-            <field name="name">Panamá</field>
-            <field name="code">PA-8</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-9">
-            <field name="name">Veraguas</field>
-            <field name="code">PA-9</field>
-            <field name="type">province</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-em">
-            <field name="name">Emberá</field>
-            <field name="code">PA-EM</field>
-            <field name="type">indigenous region</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-ky">
-            <field name="name">Kuna Yala</field>
-            <field name="code">PA-KY</field>
-            <field name="type">indigenous region</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pa-nb">
-            <field name="name">Ngöbe-Buglé</field>
-            <field name="code">PA-NB</field>
-            <field name="type">indigenous region</field>
-            <field name="country" ref="pa"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-ama">
-            <field name="name">Amazonas</field>
-            <field name="code">PE-AMA</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-anc">
-            <field name="name">Ancash</field>
-            <field name="code">PE-ANC</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-apu">
-            <field name="name">Apurímac</field>
-            <field name="code">PE-APU</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-are">
-            <field name="name">Arequipa</field>
-            <field name="code">PE-ARE</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-aya">
-            <field name="name">Ayacucho</field>
-            <field name="code">PE-AYA</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-caj">
-            <field name="name">Cajamarca</field>
-            <field name="code">PE-CAJ</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-cal">
-            <field name="name">El Callao</field>
-            <field name="code">PE-CAL</field>
-            <field name="type">constitutional province</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-cus">
-            <field name="name">Cusco [Cuzco]</field>
-            <field name="code">PE-CUS</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-huc">
-            <field name="name">Huánuco</field>
-            <field name="code">PE-HUC</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-huv">
-            <field name="name">Huancavelica</field>
-            <field name="code">PE-HUV</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-ica">
-            <field name="name">Ica</field>
-            <field name="code">PE-ICA</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-jun">
-            <field name="name">Junín</field>
-            <field name="code">PE-JUN</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-lal">
-            <field name="name">La Libertad</field>
-            <field name="code">PE-LAL</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-lam">
-            <field name="name">Lambayeque</field>
-            <field name="code">PE-LAM</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-lim">
-            <field name="name">Lima</field>
-            <field name="code">PE-LIM</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-lma">
-            <field name="name">Municipalidad Metropolitana de Lima</field>
-            <field name="code">PE-LMA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-lor">
-            <field name="name">Loreto</field>
-            <field name="code">PE-LOR</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-mdd">
-            <field name="name">Madre de Dios</field>
-            <field name="code">PE-MDD</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-moq">
-            <field name="name">Moquegua</field>
-            <field name="code">PE-MOQ</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-pas">
-            <field name="name">Pasco</field>
-            <field name="code">PE-PAS</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-piu">
-            <field name="name">Piura</field>
-            <field name="code">PE-PIU</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-pun">
-            <field name="name">Puno</field>
-            <field name="code">PE-PUN</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-sam">
-            <field name="name">San Martín</field>
-            <field name="code">PE-SAM</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-tac">
-            <field name="name">Tacna</field>
-            <field name="code">PE-TAC</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-tum">
-            <field name="name">Tumbes</field>
-            <field name="code">PE-TUM</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pe-uca">
-            <field name="name">Ucayali</field>
-            <field name="code">PE-UCA</field>
-            <field name="type">region</field>
-            <field name="country" ref="pe"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-cpk">
-            <field name="name">Chimbu</field>
-            <field name="code">PG-CPK</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-cpm">
-            <field name="name">Central</field>
-            <field name="code">PG-CPM</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-ebr">
-            <field name="name">East New Britain</field>
-            <field name="code">PG-EBR</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-ehg">
-            <field name="name">Eastern Highlands</field>
-            <field name="code">PG-EHG</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-epw">
-            <field name="name">Enga</field>
-            <field name="code">PG-EPW</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-esw">
-            <field name="name">East Sepik</field>
-            <field name="code">PG-ESW</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-gpk">
-            <field name="name">Gulf</field>
-            <field name="code">PG-GPK</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-mba">
-            <field name="name">Milne Bay</field>
-            <field name="code">PG-MBA</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-mpl">
-            <field name="name">Morobe</field>
-            <field name="code">PG-MPL</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-mpm">
-            <field name="name">Madang</field>
-            <field name="code">PG-MPM</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-mrl">
-            <field name="name">Manus</field>
-            <field name="code">PG-MRL</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-ncd">
-            <field name="name">National Capital District (Port Moresby)</field>
-            <field name="code">PG-NCD</field>
-            <field name="type">district</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-nik">
-            <field name="name">New Ireland</field>
-            <field name="code">PG-NIK</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-npp">
-            <field name="name">Northern</field>
-            <field name="code">PG-NPP</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-nsb">
-            <field name="name">Bougainville</field>
-            <field name="code">PG-NSB</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-san">
-            <field name="name">Sandaun</field>
-            <field name="code">PG-SAN</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-shm">
-            <field name="name">Southern Highlands</field>
-            <field name="code">PG-SHM</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-wbk">
-            <field name="name">West New Britain</field>
-            <field name="code">PG-WBK</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-whm">
-            <field name="name">Western Highlands</field>
-            <field name="code">PG-WHM</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="pg-wpd">
-            <field name="name">Western</field>
-            <field name="code">PG-WPD</field>
-            <field name="type">province</field>
-            <field name="country" ref="pg"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-00">
-            <field name="name">National Capital Region</field>
-            <field name="code">PH-00</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-01">
-            <field name="name">Ilocos (Region I)</field>
-            <field name="code">PH-01</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-02">
-            <field name="name">Cagayan Valley (Region II)</field>
-            <field name="code">PH-02</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-03">
-            <field name="name">Central Luzon (Region III)</field>
-            <field name="code">PH-03</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-05">
-            <field name="name">Bicol (Region V)</field>
-            <field name="code">PH-05</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-06">
-            <field name="name">Western Visayas (Region VI)</field>
-            <field name="code">PH-06</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-07">
-            <field name="name">Central Visayas (Region VII)</field>
-            <field name="code">PH-07</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-08">
-            <field name="name">Eastern Visayas (Region VIII)</field>
-            <field name="code">PH-08</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-09">
-            <field name="name">Zamboanga Peninsula (Region IX)</field>
-            <field name="code">PH-09</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-10">
-            <field name="name">Northern Mindanao (Region X)</field>
-            <field name="code">PH-10</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-11">
-            <field name="name">Davao (Region XI)</field>
-            <field name="code">PH-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-12">
-            <field name="name">Soccsksargen (Region XII)</field>
-            <field name="code">PH-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-13">
-            <field name="name">Caraga (Region XIII)</field>
-            <field name="code">PH-13</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-14">
-            <field name="name">Autonomous Region in Muslim Mindanao (ARMM)</field>
-            <field name="code">PH-14</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-15">
-            <field name="name">Cordillera Administrative Region (CAR)</field>
-            <field name="code">PH-15</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-40">
-            <field name="name">CALABARZON (Region IV-A)</field>
-            <field name="code">PH-40</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-41">
-            <field name="name">MIMAROPA (Region IV-B)</field>
-            <field name="code">PH-41</field>
-            <field name="type">region</field>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-ba">
-            <field name="name">Balochistan</field>
-            <field name="code">PK-BA</field>
-            <field name="type">province</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-gb">
-            <field name="name">Gilgit-Baltistan</field>
-            <field name="code">PK-GB</field>
-            <field name="type">area</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-is">
-            <field name="name">Islamabad</field>
-            <field name="code">PK-IS</field>
-            <field name="type">capital territory</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-jk">
-            <field name="name">Azad Kashmir</field>
-            <field name="code">PK-JK</field>
-            <field name="type">area</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-kp">
-            <field name="name">Khyber Pakhtunkhwa</field>
-            <field name="code">PK-KP</field>
-            <field name="type">province</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-pb">
-            <field name="name">Punjab</field>
-            <field name="code">PK-PB</field>
-            <field name="type">province</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-sd">
-            <field name="name">Sindh</field>
-            <field name="code">PK-SD</field>
-            <field name="type">province</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pk-ta">
-            <field name="name">Federally Administered Tribal Areas</field>
-            <field name="code">PK-TA</field>
-            <field name="type">territory</field>
-            <field name="country" ref="pk"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-ds">
-            <field name="name">Dolnośląskie</field>
-            <field name="code">PL-DS</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-kp">
-            <field name="name">Kujawsko-pomorskie</field>
-            <field name="code">PL-KP</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-lb">
-            <field name="name">Lubuskie</field>
-            <field name="code">PL-LB</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-ld">
-            <field name="name">Łódzkie</field>
-            <field name="code">PL-LD</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-lu">
-            <field name="name">Lubelskie</field>
-            <field name="code">PL-LU</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-ma">
-            <field name="name">Małopolskie</field>
-            <field name="code">PL-MA</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-mz">
-            <field name="name">Mazowieckie</field>
-            <field name="code">PL-MZ</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-op">
-            <field name="name">Opolskie</field>
-            <field name="code">PL-OP</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-pd">
-            <field name="name">Podlaskie</field>
-            <field name="code">PL-PD</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-pk">
-            <field name="name">Podkarpackie</field>
-            <field name="code">PL-PK</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-pm">
-            <field name="name">Pomorskie</field>
-            <field name="code">PL-PM</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-sk">
-            <field name="name">Świętokrzyskie</field>
-            <field name="code">PL-SK</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-sl">
-            <field name="name">Śląskie</field>
-            <field name="code">PL-SL</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-wn">
-            <field name="name">Warmińsko-mazurskie</field>
-            <field name="code">PL-WN</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-wp">
-            <field name="name">Wielkopolskie</field>
-            <field name="code">PL-WP</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="pl-zp">
-            <field name="name">Zachodniopomorskie</field>
-            <field name="code">PL-ZP</field>
-            <field name="type">province</field>
-            <field name="country" ref="pl"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-bth">
-            <field name="name">Bethlehem</field>
-            <field name="code">PS-BTH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-deb">
-            <field name="name">Deir El Balah</field>
-            <field name="code">PS-DEB</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-gza">
-            <field name="name">Gaza</field>
-            <field name="code">PS-GZA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-hbn">
-            <field name="name">Hebron</field>
-            <field name="code">PS-HBN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-jem">
-            <field name="name">Jerusalem</field>
-            <field name="code">PS-JEM</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-jen">
-            <field name="name">Jenin</field>
-            <field name="code">PS-JEN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-jrh">
-            <field name="name">Jericho - Al Aghwar</field>
-            <field name="code">PS-JRH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-kys">
-            <field name="name">Khan Yunis</field>
-            <field name="code">PS-KYS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-nbs">
-            <field name="name">Nablus</field>
-            <field name="code">PS-NBS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-ngz">
-            <field name="name">North Gaza</field>
-            <field name="code">PS-NGZ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-qqa">
-            <field name="name">Qalqilya</field>
-            <field name="code">PS-QQA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-rbh">
-            <field name="name">Ramallah</field>
-            <field name="code">PS-RBH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-rfh">
-            <field name="name">Rafah</field>
-            <field name="code">PS-RFH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-slt">
-            <field name="name">Salfit</field>
-            <field name="code">PS-SLT</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-tbs">
-            <field name="name">Tubas</field>
-            <field name="code">PS-TBS</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="ps-tkm">
-            <field name="name">Tulkarm</field>
-            <field name="code">PS-TKM</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ps"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-01">
-            <field name="name">Aveiro</field>
-            <field name="code">PT-01</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-02">
-            <field name="name">Beja</field>
-            <field name="code">PT-02</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-03">
-            <field name="name">Braga</field>
-            <field name="code">PT-03</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-04">
-            <field name="name">Bragança</field>
-            <field name="code">PT-04</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-05">
-            <field name="name">Castelo Branco</field>
-            <field name="code">PT-05</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-06">
-            <field name="name">Coimbra</field>
-            <field name="code">PT-06</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-07">
-            <field name="name">Évora</field>
-            <field name="code">PT-07</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-08">
-            <field name="name">Faro</field>
-            <field name="code">PT-08</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-09">
-            <field name="name">Guarda</field>
-            <field name="code">PT-09</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-10">
-            <field name="name">Leiria</field>
-            <field name="code">PT-10</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-11">
-            <field name="name">Lisboa</field>
-            <field name="code">PT-11</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-12">
-            <field name="name">Portalegre</field>
-            <field name="code">PT-12</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-13">
-            <field name="name">Porto</field>
-            <field name="code">PT-13</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-14">
-            <field name="name">Santarém</field>
-            <field name="code">PT-14</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-15">
-            <field name="name">Setúbal</field>
-            <field name="code">PT-15</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-16">
-            <field name="name">Viana do Castelo</field>
-            <field name="code">PT-16</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-17">
-            <field name="name">Vila Real</field>
-            <field name="code">PT-17</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-18">
-            <field name="name">Viseu</field>
-            <field name="code">PT-18</field>
-            <field name="type">district</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-20">
-            <field name="name">Região Autónoma dos Açores</field>
-            <field name="code">PT-20</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pt-30">
-            <field name="name">Região Autónoma da Madeira</field>
-            <field name="code">PT-30</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="pt"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-002">
-            <field name="name">Aimeliik</field>
-            <field name="code">PW-002</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-004">
-            <field name="name">Airai</field>
-            <field name="code">PW-004</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-010">
-            <field name="name">Angaur</field>
-            <field name="code">PW-010</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-050">
-            <field name="name">Hatobohei</field>
-            <field name="code">PW-050</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-100">
-            <field name="name">Kayangel</field>
-            <field name="code">PW-100</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-150">
-            <field name="name">Koror</field>
-            <field name="code">PW-150</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-212">
-            <field name="name">Melekeok</field>
-            <field name="code">PW-212</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-214">
-            <field name="name">Ngaraard</field>
-            <field name="code">PW-214</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-218">
-            <field name="name">Ngarchelong</field>
-            <field name="code">PW-218</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-222">
-            <field name="name">Ngardmau</field>
-            <field name="code">PW-222</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-224">
-            <field name="name">Ngatpang</field>
-            <field name="code">PW-224</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-226">
-            <field name="name">Ngchesar</field>
-            <field name="code">PW-226</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-227">
-            <field name="name">Ngeremlengui</field>
-            <field name="code">PW-227</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-228">
-            <field name="name">Ngiwal</field>
-            <field name="code">PW-228</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-350">
-            <field name="name">Peleliu</field>
-            <field name="code">PW-350</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="pw-370">
-            <field name="name">Sonsorol</field>
-            <field name="code">PW-370</field>
-            <field name="type">state</field>
-            <field name="country" ref="pw"/>
-        </record>
-
-        <record model="country.subdivision" id="py-1">
-            <field name="name">Concepción</field>
-            <field name="code">PY-1</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-10">
-            <field name="name">Alto Paraná</field>
-            <field name="code">PY-10</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-11">
-            <field name="name">Central</field>
-            <field name="code">PY-11</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-12">
-            <field name="name">Ñeembucú</field>
-            <field name="code">PY-12</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-13">
-            <field name="name">Amambay</field>
-            <field name="code">PY-13</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-14">
-            <field name="name">Canindeyú</field>
-            <field name="code">PY-14</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-15">
-            <field name="name">Presidente Hayes</field>
-            <field name="code">PY-15</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-16">
-            <field name="name">Alto Paraguay</field>
-            <field name="code">PY-16</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-19">
-            <field name="name">Boquerón</field>
-            <field name="code">PY-19</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-2">
-            <field name="name">San Pedro</field>
-            <field name="code">PY-2</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-3">
-            <field name="name">Cordillera</field>
-            <field name="code">PY-3</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-4">
-            <field name="name">Guairá</field>
-            <field name="code">PY-4</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-5">
-            <field name="name">Caaguazú</field>
-            <field name="code">PY-5</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-6">
-            <field name="name">Caazapá</field>
-            <field name="code">PY-6</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-7">
-            <field name="name">Itapúa</field>
-            <field name="code">PY-7</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-8">
-            <field name="name">Misiones</field>
-            <field name="code">PY-8</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-9">
-            <field name="name">Paraguarí</field>
-            <field name="code">PY-9</field>
-            <field name="type">department</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="py-asu">
-            <field name="name">Asunción</field>
-            <field name="code">PY-ASU</field>
-            <field name="type">capital district</field>
-            <field name="country" ref="py"/>
-        </record>
-
-        <record model="country.subdivision" id="qa-da">
-            <field name="name">Ad Dawhah</field>
-            <field name="code">QA-DA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="qa"/>
-        </record>
-
-        <record model="country.subdivision" id="qa-kh">
-            <field name="name">Al Khawr wa adh Dhakhīrah</field>
-            <field name="code">QA-KH</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="qa"/>
-        </record>
-
-        <record model="country.subdivision" id="qa-ms">
-            <field name="name">Ash Shamal</field>
-            <field name="code">QA-MS</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="qa"/>
-        </record>
-
-        <record model="country.subdivision" id="qa-ra">
-            <field name="name">Ar Rayyan</field>
-            <field name="code">QA-RA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="qa"/>
-        </record>
-
-        <record model="country.subdivision" id="qa-us">
-            <field name="name">Umm Salal</field>
-            <field name="code">QA-US</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="qa"/>
-        </record>
-
-        <record model="country.subdivision" id="qa-wa">
-            <field name="name">Al Wakrah</field>
-            <field name="code">QA-WA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="qa"/>
-        </record>
-
-        <record model="country.subdivision" id="qa-za">
-            <field name="name">Az̧ Z̧a‘āyin</field>
-            <field name="code">QA-ZA</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="qa"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-ab">
-            <field name="name">Alba</field>
-            <field name="code">RO-AB</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-ag">
-            <field name="name">Argeș</field>
-            <field name="code">RO-AG</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-ar">
-            <field name="name">Arad</field>
-            <field name="code">RO-AR</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-b">
-            <field name="name">București</field>
-            <field name="code">RO-B</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-bc">
-            <field name="name">Bacău</field>
-            <field name="code">RO-BC</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-bh">
-            <field name="name">Bihor</field>
-            <field name="code">RO-BH</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-bn">
-            <field name="name">Bistrița-Năsăud</field>
-            <field name="code">RO-BN</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-br">
-            <field name="name">Brăila</field>
-            <field name="code">RO-BR</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-bt">
-            <field name="name">Botoșani</field>
-            <field name="code">RO-BT</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-bv">
-            <field name="name">Brașov</field>
-            <field name="code">RO-BV</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-bz">
-            <field name="name">Buzău</field>
-            <field name="code">RO-BZ</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-cj">
-            <field name="name">Cluj</field>
-            <field name="code">RO-CJ</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-cl">
-            <field name="name">Călărași</field>
-            <field name="code">RO-CL</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-cs">
-            <field name="name">Caraș-Severin</field>
-            <field name="code">RO-CS</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-ct">
-            <field name="name">Constanța</field>
-            <field name="code">RO-CT</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-cv">
-            <field name="name">Covasna</field>
-            <field name="code">RO-CV</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-db">
-            <field name="name">Dâmbovița</field>
-            <field name="code">RO-DB</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-dj">
-            <field name="name">Dolj</field>
-            <field name="code">RO-DJ</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-gj">
-            <field name="name">Gorj</field>
-            <field name="code">RO-GJ</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-gl">
-            <field name="name">Galați</field>
-            <field name="code">RO-GL</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-gr">
-            <field name="name">Giurgiu</field>
-            <field name="code">RO-GR</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-hd">
-            <field name="name">Hunedoara</field>
-            <field name="code">RO-HD</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-hr">
-            <field name="name">Harghita</field>
-            <field name="code">RO-HR</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-if">
-            <field name="name">Ilfov</field>
-            <field name="code">RO-IF</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-il">
-            <field name="name">Ialomița</field>
-            <field name="code">RO-IL</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-is">
-            <field name="name">Iași</field>
-            <field name="code">RO-IS</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-mh">
-            <field name="name">Mehedinți</field>
-            <field name="code">RO-MH</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-mm">
-            <field name="name">Maramureș</field>
-            <field name="code">RO-MM</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-ms">
-            <field name="name">Mureș</field>
-            <field name="code">RO-MS</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-nt">
-            <field name="name">Neamț</field>
-            <field name="code">RO-NT</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-ot">
-            <field name="name">Olt</field>
-            <field name="code">RO-OT</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-ph">
-            <field name="name">Prahova</field>
-            <field name="code">RO-PH</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-sb">
-            <field name="name">Sibiu</field>
-            <field name="code">RO-SB</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-sj">
-            <field name="name">Sălaj</field>
-            <field name="code">RO-SJ</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-sm">
-            <field name="name">Satu Mare</field>
-            <field name="code">RO-SM</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-sv">
-            <field name="name">Suceava</field>
-            <field name="code">RO-SV</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-tl">
-            <field name="name">Tulcea</field>
-            <field name="code">RO-TL</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-tm">
-            <field name="name">Timiș</field>
-            <field name="code">RO-TM</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-tr">
-            <field name="name">Teleorman</field>
-            <field name="code">RO-TR</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-vl">
-            <field name="name">Vâlcea</field>
-            <field name="code">RO-VL</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-vn">
-            <field name="name">Vrancea</field>
-            <field name="code">RO-VN</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="ro-vs">
-            <field name="name">Vaslui</field>
-            <field name="code">RO-VS</field>
-            <field name="type">department</field>
-            <field name="country" ref="ro"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-00">
-            <field name="name">Beograd</field>
-            <field name="code">RS-00</field>
-            <field name="type">city</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-08">
-            <field name="name">Mačvanski okrug</field>
-            <field name="code">RS-08</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-09">
-            <field name="name">Kolubarski okrug</field>
-            <field name="code">RS-09</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-10">
-            <field name="name">Podunavski okrug</field>
-            <field name="code">RS-10</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-11">
-            <field name="name">Braničevski okrug</field>
-            <field name="code">RS-11</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-12">
-            <field name="name">Šumadijski okrug</field>
-            <field name="code">RS-12</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-13">
-            <field name="name">Pomoravski okrug</field>
-            <field name="code">RS-13</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-14">
-            <field name="name">Borski okrug</field>
-            <field name="code">RS-14</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-15">
-            <field name="name">Zaječarski okrug</field>
-            <field name="code">RS-15</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-16">
-            <field name="name">Zlatiborski okrug</field>
-            <field name="code">RS-16</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-17">
-            <field name="name">Moravički okrug</field>
-            <field name="code">RS-17</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-18">
-            <field name="name">Raški okrug</field>
-            <field name="code">RS-18</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-19">
-            <field name="name">Rasinski okrug</field>
-            <field name="code">RS-19</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-20">
-            <field name="name">Nišavski okrug</field>
-            <field name="code">RS-20</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-21">
-            <field name="name">Toplički okrug</field>
-            <field name="code">RS-21</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-22">
-            <field name="name">Pirotski okrug</field>
-            <field name="code">RS-22</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-23">
-            <field name="name">Jablanički okrug</field>
-            <field name="code">RS-23</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-24">
-            <field name="name">Pčinjski okrug</field>
-            <field name="code">RS-24</field>
-            <field name="type">district</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-km">
-            <field name="name">Kosovo-Metohija</field>
-            <field name="code">RS-KM</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-vo">
-            <field name="name">Vojvodina</field>
-            <field name="code">RS-VO</field>
-            <field name="type">autonomous province</field>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ad">
-            <field name="name">Adygeya, Respublika</field>
-            <field name="code">RU-AD</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-al">
-            <field name="name">Altay, Respublika</field>
-            <field name="code">RU-AL</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-alt">
-            <field name="name">Altayskiy kray</field>
-            <field name="code">RU-ALT</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-amu">
-            <field name="name">Amurskaya oblast'</field>
-            <field name="code">RU-AMU</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ark">
-            <field name="name">Arkhangel'skaya oblast'</field>
-            <field name="code">RU-ARK</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ast">
-            <field name="name">Astrakhanskaya oblast'</field>
-            <field name="code">RU-AST</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ba">
-            <field name="name">Bashkortostan, Respublika</field>
-            <field name="code">RU-BA</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-bel">
-            <field name="name">Belgorodskaya oblast'</field>
-            <field name="code">RU-BEL</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-bry">
-            <field name="name">Bryanskaya oblast'</field>
-            <field name="code">RU-BRY</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-bu">
-            <field name="name">Buryatiya, Respublika</field>
-            <field name="code">RU-BU</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ce">
-            <field name="name">Chechenskaya Respublika</field>
-            <field name="code">RU-CE</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-che">
-            <field name="name">Chelyabinskaya oblast'</field>
-            <field name="code">RU-CHE</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-chu">
-            <field name="name">Chukotskiy avtonomnyy okrug</field>
-            <field name="code">RU-CHU</field>
-            <field name="type">autonomous district</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-cu">
-            <field name="name">Chuvashskaya Respublika</field>
-            <field name="code">RU-CU</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-da">
-            <field name="name">Dagestan, Respublika</field>
-            <field name="code">RU-DA</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-in">
-            <field name="name">Respublika Ingushetiya</field>
-            <field name="code">RU-IN</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-irk">
-            <field name="name">Irkutiskaya oblast'</field>
-            <field name="code">RU-IRK</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-iva">
-            <field name="name">Ivanovskaya oblast'</field>
-            <field name="code">RU-IVA</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kam">
-            <field name="name">Kamchatskiy kray</field>
-            <field name="code">RU-KAM</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kb">
-            <field name="name">Kabardino-Balkarskaya Respublika</field>
-            <field name="code">RU-KB</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kc">
-            <field name="name">Karachayevo-Cherkesskaya Respublika</field>
-            <field name="code">RU-KC</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kda">
-            <field name="name">Krasnodarskiy kray</field>
-            <field name="code">RU-KDA</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kem">
-            <field name="name">Kemerovskaya oblast'</field>
-            <field name="code">RU-KEM</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kgd">
-            <field name="name">Kaliningradskaya oblast'</field>
-            <field name="code">RU-KGD</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kgn">
-            <field name="name">Kurganskaya oblast'</field>
-            <field name="code">RU-KGN</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kha">
-            <field name="name">Khabarovskiy kray</field>
-            <field name="code">RU-KHA</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-khm">
-            <field name="name">Khanty-Mansiysky avtonomnyy okrug-Yugra</field>
-            <field name="code">RU-KHM</field>
-            <field name="type">autonomous district</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kir">
-            <field name="name">Kirovskaya oblast'</field>
-            <field name="code">RU-KIR</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kk">
-            <field name="name">Khakasiya, Respublika</field>
-            <field name="code">RU-KK</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kl">
-            <field name="name">Kalmykiya, Respublika</field>
-            <field name="code">RU-KL</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-klu">
-            <field name="name">Kaluzhskaya oblast'</field>
-            <field name="code">RU-KLU</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ko">
-            <field name="name">Komi, Respublika</field>
-            <field name="code">RU-KO</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kos">
-            <field name="name">Kostromskaya oblast'</field>
-            <field name="code">RU-KOS</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kr">
-            <field name="name">Kareliya, Respublika</field>
-            <field name="code">RU-KR</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-krs">
-            <field name="name">Kurskaya oblast'</field>
-            <field name="code">RU-KRS</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-kya">
-            <field name="name">Krasnoyarskiy kray</field>
-            <field name="code">RU-KYA</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-len">
-            <field name="name">Leningradskaya oblast'</field>
-            <field name="code">RU-LEN</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-lip">
-            <field name="name">Lipetskaya oblast'</field>
-            <field name="code">RU-LIP</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-mag">
-            <field name="name">Magadanskaya oblast'</field>
-            <field name="code">RU-MAG</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-me">
-            <field name="name">Mariy El, Respublika</field>
-            <field name="code">RU-ME</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-mo">
-            <field name="name">Mordoviya, Respublika</field>
-            <field name="code">RU-MO</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-mos">
-            <field name="name">Moskovskaya oblast'</field>
-            <field name="code">RU-MOS</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-mow">
-            <field name="name">Moskva</field>
-            <field name="code">RU-MOW</field>
-            <field name="type">autonomous city</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-mur">
-            <field name="name">Murmanskaya oblast'</field>
-            <field name="code">RU-MUR</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-nen">
-            <field name="name">Nenetskiy avtonomnyy okrug</field>
-            <field name="code">RU-NEN</field>
-            <field name="type">autonomous district</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ngr">
-            <field name="name">Novgorodskaya oblast'</field>
-            <field name="code">RU-NGR</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-niz">
-            <field name="name">Nizhegorodskaya oblast'</field>
-            <field name="code">RU-NIZ</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-nvs">
-            <field name="name">Novosibirskaya oblast'</field>
-            <field name="code">RU-NVS</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-oms">
-            <field name="name">Omskaya oblast'</field>
-            <field name="code">RU-OMS</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ore">
-            <field name="name">Orenburgskaya oblast'</field>
-            <field name="code">RU-ORE</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-orl">
-            <field name="name">Orlovskaya oblast'</field>
-            <field name="code">RU-ORL</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-per">
-            <field name="name">Permskiy kray</field>
-            <field name="code">RU-PER</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-pnz">
-            <field name="name">Penzenskaya oblast'</field>
-            <field name="code">RU-PNZ</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-pri">
-            <field name="name">Primorskiy kray</field>
-            <field name="code">RU-PRI</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-psk">
-            <field name="name">Pskovskaya oblast'</field>
-            <field name="code">RU-PSK</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ros">
-            <field name="name">Rostovskaya oblast'</field>
-            <field name="code">RU-ROS</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-rya">
-            <field name="name">Ryazanskaya oblast'</field>
-            <field name="code">RU-RYA</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-sa">
-            <field name="name">Sakha, Respublika [Yakutiya]</field>
-            <field name="code">RU-SA</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-sak">
-            <field name="name">Sakhalinskaya oblast'</field>
-            <field name="code">RU-SAK</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-sam">
-            <field name="name">Samaraskaya oblast'</field>
-            <field name="code">RU-SAM</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-sar">
-            <field name="name">Saratovskaya oblast'</field>
-            <field name="code">RU-SAR</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-se">
-            <field name="name">Severnaya Osetiya-Alaniya, Respublika</field>
-            <field name="code">RU-SE</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-smo">
-            <field name="name">Smolenskaya oblast'</field>
-            <field name="code">RU-SMO</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-spe">
-            <field name="name">Sankt-Peterburg</field>
-            <field name="code">RU-SPE</field>
-            <field name="type">autonomous city</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-sta">
-            <field name="name">Stavropol'skiy kray</field>
-            <field name="code">RU-STA</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-sve">
-            <field name="name">Sverdlovskaya oblast'</field>
-            <field name="code">RU-SVE</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ta">
-            <field name="name">Tatarstan, Respublika</field>
-            <field name="code">RU-TA</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-tam">
-            <field name="name">Tambovskaya oblast'</field>
-            <field name="code">RU-TAM</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-tom">
-            <field name="name">Tomskaya oblast'</field>
-            <field name="code">RU-TOM</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-tul">
-            <field name="name">Tul'skaya oblast'</field>
-            <field name="code">RU-TUL</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-tve">
-            <field name="name">Tverskaya oblast'</field>
-            <field name="code">RU-TVE</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ty">
-            <field name="name">Tyva, Respublika [Tuva]</field>
-            <field name="code">RU-TY</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-tyu">
-            <field name="name">Tyumenskaya oblast'</field>
-            <field name="code">RU-TYU</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-ud">
-            <field name="name">Udmurtskaya Respublika</field>
-            <field name="code">RU-UD</field>
-            <field name="type">republic</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-uly">
-            <field name="name">Ul'yanovskaya oblast'</field>
-            <field name="code">RU-ULY</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-vgg">
-            <field name="name">Volgogradskaya oblast'</field>
-            <field name="code">RU-VGG</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-vla">
-            <field name="name">Vladimirskaya oblast'</field>
-            <field name="code">RU-VLA</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-vlg">
-            <field name="name">Vologodskaya oblast'</field>
-            <field name="code">RU-VLG</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-vor">
-            <field name="name">Voronezhskaya oblast'</field>
-            <field name="code">RU-VOR</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-yan">
-            <field name="name">Yamalo-Nenetskiy avtonomnyy okrug</field>
-            <field name="code">RU-YAN</field>
-            <field name="type">autonomous district</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-yar">
-            <field name="name">Yaroslavskaya oblast'</field>
-            <field name="code">RU-YAR</field>
-            <field name="type">administrative region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-yev">
-            <field name="name">Yevreyskaya avtonomnaya oblast'</field>
-            <field name="code">RU-YEV</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="ru-zab">
-            <field name="name">Zabajkal'skij kraj</field>
-            <field name="code">RU-ZAB</field>
-            <field name="type">administrative territory</field>
-            <field name="country" ref="ru"/>
-        </record>
-
-        <record model="country.subdivision" id="rw-01">
-            <field name="name">Ville de Kigali</field>
-            <field name="code">RW-01</field>
-            <field name="type">town council</field>
-            <field name="country" ref="rw"/>
-        </record>
-
-        <record model="country.subdivision" id="rw-02">
-            <field name="name">Est</field>
-            <field name="code">RW-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="rw"/>
-        </record>
-
-        <record model="country.subdivision" id="rw-03">
-            <field name="name">Nord</field>
-            <field name="code">RW-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="rw"/>
-        </record>
-
-        <record model="country.subdivision" id="rw-04">
-            <field name="name">Ouest</field>
-            <field name="code">RW-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="rw"/>
-        </record>
-
-        <record model="country.subdivision" id="rw-05">
-            <field name="name">Sud</field>
-            <field name="code">RW-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="rw"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-01">
-            <field name="name">Ar Riyāḍ</field>
-            <field name="code">SA-01</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-02">
-            <field name="name">Makkah</field>
-            <field name="code">SA-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-03">
-            <field name="name">Al Madīnah</field>
-            <field name="code">SA-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-04">
-            <field name="name">Ash Sharqīyah</field>
-            <field name="code">SA-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-05">
-            <field name="name">Al Qaşīm</field>
-            <field name="code">SA-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-06">
-            <field name="name">Ḥā'il</field>
-            <field name="code">SA-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-07">
-            <field name="name">Tabūk</field>
-            <field name="code">SA-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-08">
-            <field name="name">Al Ḥudūd ash Shamāliyah</field>
-            <field name="code">SA-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-09">
-            <field name="name">Jīzan</field>
-            <field name="code">SA-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-10">
-            <field name="name">Najrān</field>
-            <field name="code">SA-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-11">
-            <field name="name">Al Bāhah</field>
-            <field name="code">SA-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-12">
-            <field name="name">Al Jawf</field>
-            <field name="code">SA-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sa-14">
-            <field name="name">`Asīr</field>
-            <field name="code">SA-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="sa"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-ce">
-            <field name="name">Central</field>
-            <field name="code">SB-CE</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-ch">
-            <field name="name">Choiseul</field>
-            <field name="code">SB-CH</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-ct">
-            <field name="name">Capital Territory (Honiara)</field>
-            <field name="code">SB-CT</field>
-            <field name="type">capital territory</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-gu">
-            <field name="name">Guadalcanal</field>
-            <field name="code">SB-GU</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-is">
-            <field name="name">Isabel</field>
-            <field name="code">SB-IS</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-mk">
-            <field name="name">Makira</field>
-            <field name="code">SB-MK</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-ml">
-            <field name="name">Malaita</field>
-            <field name="code">SB-ML</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-rb">
-            <field name="name">Rennell and Bellona</field>
-            <field name="code">SB-RB</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-te">
-            <field name="name">Temotu</field>
-            <field name="code">SB-TE</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sb-we">
-            <field name="name">Western</field>
-            <field name="code">SB-WE</field>
-            <field name="type">province</field>
-            <field name="country" ref="sb"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-01">
-            <field name="name">Anse aux Pins</field>
-            <field name="code">SC-01</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-02">
-            <field name="name">Anse Boileau</field>
-            <field name="code">SC-02</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-03">
-            <field name="name">Anse Etoile</field>
-            <field name="code">SC-03</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-04">
-            <field name="name">Anse Louis</field>
-            <field name="code">SC-04</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-05">
-            <field name="name">Anse Royale</field>
-            <field name="code">SC-05</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-06">
-            <field name="name">Baie Lazare</field>
-            <field name="code">SC-06</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-07">
-            <field name="name">Baie Sainte Anne</field>
-            <field name="code">SC-07</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-08">
-            <field name="name">Beau Vallon</field>
-            <field name="code">SC-08</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-09">
-            <field name="name">Bel Air</field>
-            <field name="code">SC-09</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-10">
-            <field name="name">Bel Ombre</field>
-            <field name="code">SC-10</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-11">
-            <field name="name">Cascade</field>
-            <field name="code">SC-11</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-12">
-            <field name="name">Glacis</field>
-            <field name="code">SC-12</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-13">
-            <field name="name">Grand Anse Mahe</field>
-            <field name="code">SC-13</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-14">
-            <field name="name">Grand Anse Praslin</field>
-            <field name="code">SC-14</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-15">
-            <field name="name">La Digue</field>
-            <field name="code">SC-15</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-16">
-            <field name="name">English River</field>
-            <field name="code">SC-16</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-17">
-            <field name="name">Mont Buxton</field>
-            <field name="code">SC-17</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-18">
-            <field name="name">Mont Fleuri</field>
-            <field name="code">SC-18</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-19">
-            <field name="name">Plaisance</field>
-            <field name="code">SC-19</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-20">
-            <field name="name">Pointe Larue</field>
-            <field name="code">SC-20</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-21">
-            <field name="name">Port Glaud</field>
-            <field name="code">SC-21</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-22">
-            <field name="name">Saint Louis</field>
-            <field name="code">SC-22</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-23">
-            <field name="name">Takamaka</field>
-            <field name="code">SC-23</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-24">
-            <field name="name">Les Mamelles</field>
-            <field name="code">SC-24</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sc-25">
-            <field name="name">Roche Caiman</field>
-            <field name="code">SC-25</field>
-            <field name="type">district</field>
-            <field name="country" ref="sc"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-dc">
-            <field name="name">Zalingei</field>
-            <field name="code">SD-DC</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-de">
-            <field name="name">Sharq Dārfūr</field>
-            <field name="code">SD-DE</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-dn">
-            <field name="name">Shamāl Dārfūr</field>
-            <field name="code">SD-DN</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-ds">
-            <field name="name">Janūb Dārfūr</field>
-            <field name="code">SD-DS</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-dw">
-            <field name="name">Gharb Dārfūr</field>
-            <field name="code">SD-DW</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-gd">
-            <field name="name">Al Qaḑārif</field>
-            <field name="code">SD-GD</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-gz">
-            <field name="name">Al Jazīrah</field>
-            <field name="code">SD-GZ</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-ka">
-            <field name="name">Kassalā</field>
-            <field name="code">SD-KA</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-kh">
-            <field name="name">Al Kharţūm</field>
-            <field name="code">SD-KH</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-kn">
-            <field name="name">Shamāl Kurdufān</field>
-            <field name="code">SD-KN</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-ks">
-            <field name="name">Janūb Kurdufān</field>
-            <field name="code">SD-KS</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-nb">
-            <field name="name">An Nīl al Azraq</field>
-            <field name="code">SD-NB</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-no">
-            <field name="name">Ash Shamālīyah</field>
-            <field name="code">SD-NO</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-nr">
-            <field name="name">An Nīl</field>
-            <field name="code">SD-NR</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-nw">
-            <field name="name">An Nīl al Abyaḑ</field>
-            <field name="code">SD-NW</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-rs">
-            <field name="name">Al Baḩr al Aḩmar</field>
-            <field name="code">SD-RS</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="sd-si">
-            <field name="name">Sinnār</field>
-            <field name="code">SD-SI</field>
-            <field name="type">state</field>
-            <field name="country" ref="sd"/>
-        </record>
-
-        <record model="country.subdivision" id="se-ab">
-            <field name="name">Stockholms län</field>
-            <field name="code">SE-AB</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-ac">
-            <field name="name">Västerbottens län</field>
-            <field name="code">SE-AC</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-bd">
-            <field name="name">Norrbottens län</field>
-            <field name="code">SE-BD</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-c">
-            <field name="name">Uppsala län</field>
-            <field name="code">SE-C</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-d">
-            <field name="name">Södermanlands län</field>
-            <field name="code">SE-D</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-e">
-            <field name="name">Östergötlands län</field>
-            <field name="code">SE-E</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-f">
-            <field name="name">Jönköpings län</field>
-            <field name="code">SE-F</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-g">
-            <field name="name">Kronobergs län</field>
-            <field name="code">SE-G</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-h">
-            <field name="name">Kalmar län</field>
-            <field name="code">SE-H</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-i">
-            <field name="name">Gotlands län</field>
-            <field name="code">SE-I</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-k">
-            <field name="name">Blekinge län</field>
-            <field name="code">SE-K</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-m">
-            <field name="name">Skåne län</field>
-            <field name="code">SE-M</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-n">
-            <field name="name">Hallands län</field>
-            <field name="code">SE-N</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-o">
-            <field name="name">Västra Götalands län</field>
-            <field name="code">SE-O</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-s">
-            <field name="name">Värmlands län</field>
-            <field name="code">SE-S</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-t">
-            <field name="name">Örebro län</field>
-            <field name="code">SE-T</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-u">
-            <field name="name">Västmanlands län</field>
-            <field name="code">SE-U</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-w">
-            <field name="name">Dalarnas län</field>
-            <field name="code">SE-W</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-x">
-            <field name="name">Gävleborgs län</field>
-            <field name="code">SE-X</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-y">
-            <field name="name">Västernorrlands län</field>
-            <field name="code">SE-Y</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="se-z">
-            <field name="name">Jämtlands län</field>
-            <field name="code">SE-Z</field>
-            <field name="type">county</field>
-            <field name="country" ref="se"/>
-        </record>
-
-        <record model="country.subdivision" id="sg-01">
-            <field name="name">Central Singapore</field>
-            <field name="code">SG-01</field>
-            <field name="type">district</field>
-            <field name="country" ref="sg"/>
-        </record>
-
-        <record model="country.subdivision" id="sg-02">
-            <field name="name">North East</field>
-            <field name="code">SG-02</field>
-            <field name="type">district</field>
-            <field name="country" ref="sg"/>
-        </record>
-
-        <record model="country.subdivision" id="sg-03">
-            <field name="name">North West</field>
-            <field name="code">SG-03</field>
-            <field name="type">district</field>
-            <field name="country" ref="sg"/>
-        </record>
-
-        <record model="country.subdivision" id="sg-04">
-            <field name="name">South East</field>
-            <field name="code">SG-04</field>
-            <field name="type">district</field>
-            <field name="country" ref="sg"/>
-        </record>
-
-        <record model="country.subdivision" id="sg-05">
-            <field name="name">South West</field>
-            <field name="code">SG-05</field>
-            <field name="type">district</field>
-            <field name="country" ref="sg"/>
-        </record>
-
-        <record model="country.subdivision" id="sh-ac">
-            <field name="name">Ascension</field>
-            <field name="code">SH-AC</field>
-            <field name="type">geographical entity</field>
-            <field name="country" ref="sh"/>
-        </record>
-
-        <record model="country.subdivision" id="sh-hl">
-            <field name="name">Saint Helena</field>
-            <field name="code">SH-HL</field>
-            <field name="type">geographical entity</field>
-            <field name="country" ref="sh"/>
-        </record>
-
-        <record model="country.subdivision" id="sh-ta">
-            <field name="name">Tristan da Cunha</field>
-            <field name="code">SH-TA</field>
-            <field name="type">geographical entity</field>
-            <field name="country" ref="sh"/>
-        </record>
-
-        <record model="country.subdivision" id="si-001">
-            <field name="name">Ajdovščina</field>
-            <field name="code">SI-001</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-002">
-            <field name="name">Beltinci</field>
-            <field name="code">SI-002</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-003">
-            <field name="name">Bled</field>
-            <field name="code">SI-003</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-004">
-            <field name="name">Bohinj</field>
-            <field name="code">SI-004</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-005">
-            <field name="name">Borovnica</field>
-            <field name="code">SI-005</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-006">
-            <field name="name">Bovec</field>
-            <field name="code">SI-006</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-007">
-            <field name="name">Brda</field>
-            <field name="code">SI-007</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-008">
-            <field name="name">Brezovica</field>
-            <field name="code">SI-008</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-009">
-            <field name="name">Brežice</field>
-            <field name="code">SI-009</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-010">
-            <field name="name">Tišina</field>
-            <field name="code">SI-010</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-011">
-            <field name="name">Celje</field>
-            <field name="code">SI-011</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-012">
-            <field name="name">Cerklje na Gorenjskem</field>
-            <field name="code">SI-012</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-013">
-            <field name="name">Cerknica</field>
-            <field name="code">SI-013</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-014">
-            <field name="name">Cerkno</field>
-            <field name="code">SI-014</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-015">
-            <field name="name">Črenšovci</field>
-            <field name="code">SI-015</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-016">
-            <field name="name">Črna na Koroškem</field>
-            <field name="code">SI-016</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-017">
-            <field name="name">Črnomelj</field>
-            <field name="code">SI-017</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-018">
-            <field name="name">Destrnik</field>
-            <field name="code">SI-018</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-019">
-            <field name="name">Divača</field>
-            <field name="code">SI-019</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-020">
-            <field name="name">Dobrepolje</field>
-            <field name="code">SI-020</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-021">
-            <field name="name">Dobrova-Polhov Gradec</field>
-            <field name="code">SI-021</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-022">
-            <field name="name">Dol pri Ljubljani</field>
-            <field name="code">SI-022</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-023">
-            <field name="name">Domžale</field>
-            <field name="code">SI-023</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-024">
-            <field name="name">Dornava</field>
-            <field name="code">SI-024</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-025">
-            <field name="name">Dravograd</field>
-            <field name="code">SI-025</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-026">
-            <field name="name">Duplek</field>
-            <field name="code">SI-026</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-027">
-            <field name="name">Gorenja vas-Poljane</field>
-            <field name="code">SI-027</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-028">
-            <field name="name">Gorišnica</field>
-            <field name="code">SI-028</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-029">
-            <field name="name">Gornja Radgona</field>
-            <field name="code">SI-029</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-030">
-            <field name="name">Gornji Grad</field>
-            <field name="code">SI-030</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-031">
-            <field name="name">Gornji Petrovci</field>
-            <field name="code">SI-031</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-032">
-            <field name="name">Grosuplje</field>
-            <field name="code">SI-032</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-033">
-            <field name="name">Šalovci</field>
-            <field name="code">SI-033</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-034">
-            <field name="name">Hrastnik</field>
-            <field name="code">SI-034</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-035">
-            <field name="name">Hrpelje-Kozina</field>
-            <field name="code">SI-035</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-036">
-            <field name="name">Idrija</field>
-            <field name="code">SI-036</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-037">
-            <field name="name">Ig</field>
-            <field name="code">SI-037</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-038">
-            <field name="name">Ilirska Bistrica</field>
-            <field name="code">SI-038</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-039">
-            <field name="name">Ivančna Gorica</field>
-            <field name="code">SI-039</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-040">
-            <field name="name">Izola/Isola</field>
-            <field name="code">SI-040</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-041">
-            <field name="name">Jesenice</field>
-            <field name="code">SI-041</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-042">
-            <field name="name">Juršinci</field>
-            <field name="code">SI-042</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-043">
-            <field name="name">Kamnik</field>
-            <field name="code">SI-043</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-044">
-            <field name="name">Kanal</field>
-            <field name="code">SI-044</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-045">
-            <field name="name">Kidričevo</field>
-            <field name="code">SI-045</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-046">
-            <field name="name">Kobarid</field>
-            <field name="code">SI-046</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-047">
-            <field name="name">Kobilje</field>
-            <field name="code">SI-047</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-048">
-            <field name="name">Kočevje</field>
-            <field name="code">SI-048</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-049">
-            <field name="name">Komen</field>
-            <field name="code">SI-049</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-050">
-            <field name="name">Koper/Capodistria</field>
-            <field name="code">SI-050</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-051">
-            <field name="name">Kozje</field>
-            <field name="code">SI-051</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-052">
-            <field name="name">Kranj</field>
-            <field name="code">SI-052</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-053">
-            <field name="name">Kranjska Gora</field>
-            <field name="code">SI-053</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-054">
-            <field name="name">Krško</field>
-            <field name="code">SI-054</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-055">
-            <field name="name">Kungota</field>
-            <field name="code">SI-055</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-056">
-            <field name="name">Kuzma</field>
-            <field name="code">SI-056</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-057">
-            <field name="name">Laško</field>
-            <field name="code">SI-057</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-058">
-            <field name="name">Lenart</field>
-            <field name="code">SI-058</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-059">
-            <field name="name">Lendava/Lendva</field>
-            <field name="code">SI-059</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-060">
-            <field name="name">Litija</field>
-            <field name="code">SI-060</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-061">
-            <field name="name">Ljubljana</field>
-            <field name="code">SI-061</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-062">
-            <field name="name">Ljubno</field>
-            <field name="code">SI-062</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-063">
-            <field name="name">Ljutomer</field>
-            <field name="code">SI-063</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-064">
-            <field name="name">Logatec</field>
-            <field name="code">SI-064</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-065">
-            <field name="name">Loška dolina</field>
-            <field name="code">SI-065</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-066">
-            <field name="name">Loški Potok</field>
-            <field name="code">SI-066</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-067">
-            <field name="name">Luče</field>
-            <field name="code">SI-067</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-068">
-            <field name="name">Lukovica</field>
-            <field name="code">SI-068</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-069">
-            <field name="name">Majšperk</field>
-            <field name="code">SI-069</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-070">
-            <field name="name">Maribor</field>
-            <field name="code">SI-070</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-071">
-            <field name="name">Medvode</field>
-            <field name="code">SI-071</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-072">
-            <field name="name">Mengeš</field>
-            <field name="code">SI-072</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-073">
-            <field name="name">Metlika</field>
-            <field name="code">SI-073</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-074">
-            <field name="name">Mežica</field>
-            <field name="code">SI-074</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-075">
-            <field name="name">Miren-Kostanjevica</field>
-            <field name="code">SI-075</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-076">
-            <field name="name">Mislinja</field>
-            <field name="code">SI-076</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-077">
-            <field name="name">Moravče</field>
-            <field name="code">SI-077</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-078">
-            <field name="name">Moravske Toplice</field>
-            <field name="code">SI-078</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-079">
-            <field name="name">Mozirje</field>
-            <field name="code">SI-079</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-080">
-            <field name="name">Murska Sobota</field>
-            <field name="code">SI-080</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-081">
-            <field name="name">Muta</field>
-            <field name="code">SI-081</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-082">
-            <field name="name">Naklo</field>
-            <field name="code">SI-082</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-083">
-            <field name="name">Nazarje</field>
-            <field name="code">SI-083</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-084">
-            <field name="name">Nova Gorica</field>
-            <field name="code">SI-084</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-085">
-            <field name="name">Novo mesto</field>
-            <field name="code">SI-085</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-086">
-            <field name="name">Odranci</field>
-            <field name="code">SI-086</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-087">
-            <field name="name">Ormož</field>
-            <field name="code">SI-087</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-088">
-            <field name="name">Osilnica</field>
-            <field name="code">SI-088</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-089">
-            <field name="name">Pesnica</field>
-            <field name="code">SI-089</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-090">
-            <field name="name">Piran/Pirano</field>
-            <field name="code">SI-090</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-091">
-            <field name="name">Pivka</field>
-            <field name="code">SI-091</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-092">
-            <field name="name">Podčetrtek</field>
-            <field name="code">SI-092</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-093">
-            <field name="name">Podvelka</field>
-            <field name="code">SI-093</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-094">
-            <field name="name">Postojna</field>
-            <field name="code">SI-094</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-095">
-            <field name="name">Preddvor</field>
-            <field name="code">SI-095</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-096">
-            <field name="name">Ptuj</field>
-            <field name="code">SI-096</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-097">
-            <field name="name">Puconci</field>
-            <field name="code">SI-097</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-098">
-            <field name="name">Rače-Fram</field>
-            <field name="code">SI-098</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-099">
-            <field name="name">Radeče</field>
-            <field name="code">SI-099</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-100">
-            <field name="name">Radenci</field>
-            <field name="code">SI-100</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-101">
-            <field name="name">Radlje ob Dravi</field>
-            <field name="code">SI-101</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-102">
-            <field name="name">Radovljica</field>
-            <field name="code">SI-102</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-103">
-            <field name="name">Ravne na Koroškem</field>
-            <field name="code">SI-103</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-104">
-            <field name="name">Ribnica</field>
-            <field name="code">SI-104</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-105">
-            <field name="name">Rogašovci</field>
-            <field name="code">SI-105</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-106">
-            <field name="name">Rogaška Slatina</field>
-            <field name="code">SI-106</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-107">
-            <field name="name">Rogatec</field>
-            <field name="code">SI-107</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-108">
-            <field name="name">Ruše</field>
-            <field name="code">SI-108</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-109">
-            <field name="name">Semič</field>
-            <field name="code">SI-109</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-110">
-            <field name="name">Sevnica</field>
-            <field name="code">SI-110</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-111">
-            <field name="name">Sežana</field>
-            <field name="code">SI-111</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-112">
-            <field name="name">Slovenj Gradec</field>
-            <field name="code">SI-112</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-113">
-            <field name="name">Slovenska Bistrica</field>
-            <field name="code">SI-113</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-114">
-            <field name="name">Slovenske Konjice</field>
-            <field name="code">SI-114</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-115">
-            <field name="name">Starče</field>
-            <field name="code">SI-115</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-116">
-            <field name="name">Sveti Jurij</field>
-            <field name="code">SI-116</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-117">
-            <field name="name">Šenčur</field>
-            <field name="code">SI-117</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-118">
-            <field name="name">Šentilj</field>
-            <field name="code">SI-118</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-119">
-            <field name="name">Šentjernej</field>
-            <field name="code">SI-119</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-120">
-            <field name="name">Šentjur</field>
-            <field name="code">SI-120</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-121">
-            <field name="name">Škocjan</field>
-            <field name="code">SI-121</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-122">
-            <field name="name">Škofja Loka</field>
-            <field name="code">SI-122</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-123">
-            <field name="name">Škofljica</field>
-            <field name="code">SI-123</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-124">
-            <field name="name">Šmarje pri Jelšah</field>
-            <field name="code">SI-124</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-125">
-            <field name="name">Šmartno ob Paki</field>
-            <field name="code">SI-125</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-126">
-            <field name="name">Šoštanj</field>
-            <field name="code">SI-126</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-127">
-            <field name="name">Štore</field>
-            <field name="code">SI-127</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-128">
-            <field name="name">Tolmin</field>
-            <field name="code">SI-128</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-129">
-            <field name="name">Trbovlje</field>
-            <field name="code">SI-129</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-130">
-            <field name="name">Trebnje</field>
-            <field name="code">SI-130</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-131">
-            <field name="name">Tržič</field>
-            <field name="code">SI-131</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-132">
-            <field name="name">Turnišče</field>
-            <field name="code">SI-132</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-133">
-            <field name="name">Velenje</field>
-            <field name="code">SI-133</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-134">
-            <field name="name">Velike Lašče</field>
-            <field name="code">SI-134</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-135">
-            <field name="name">Videm</field>
-            <field name="code">SI-135</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-136">
-            <field name="name">Vipava</field>
-            <field name="code">SI-136</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-137">
-            <field name="name">Vitanje</field>
-            <field name="code">SI-137</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-138">
-            <field name="name">Vodice</field>
-            <field name="code">SI-138</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-139">
-            <field name="name">Vojnik</field>
-            <field name="code">SI-139</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-140">
-            <field name="name">Vrhnika</field>
-            <field name="code">SI-140</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-141">
-            <field name="name">Vuzenica</field>
-            <field name="code">SI-141</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-142">
-            <field name="name">Zagorje ob Savi</field>
-            <field name="code">SI-142</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-143">
-            <field name="name">Zavrč</field>
-            <field name="code">SI-143</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-144">
-            <field name="name">Zreče</field>
-            <field name="code">SI-144</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-146">
-            <field name="name">Železniki</field>
-            <field name="code">SI-146</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-147">
-            <field name="name">Žiri</field>
-            <field name="code">SI-147</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-148">
-            <field name="name">Benedikt</field>
-            <field name="code">SI-148</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-149">
-            <field name="name">Bistrica ob Sotli</field>
-            <field name="code">SI-149</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-150">
-            <field name="name">Bloke</field>
-            <field name="code">SI-150</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-151">
-            <field name="name">Braslovče</field>
-            <field name="code">SI-151</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-152">
-            <field name="name">Cankova</field>
-            <field name="code">SI-152</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-153">
-            <field name="name">Cerkvenjak</field>
-            <field name="code">SI-153</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-154">
-            <field name="name">Dobje</field>
-            <field name="code">SI-154</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-155">
-            <field name="name">Dobrna</field>
-            <field name="code">SI-155</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-156">
-            <field name="name">Dobrovnik/Dobronak</field>
-            <field name="code">SI-156</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-157">
-            <field name="name">Dolenjske Toplice</field>
-            <field name="code">SI-157</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-158">
-            <field name="name">Grad</field>
-            <field name="code">SI-158</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-159">
-            <field name="name">Hajdina</field>
-            <field name="code">SI-159</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-160">
-            <field name="name">Hoče-Slivnica</field>
-            <field name="code">SI-160</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-161">
-            <field name="name">Hodoš/Hodos</field>
-            <field name="code">SI-161</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-162">
-            <field name="name">Horjul</field>
-            <field name="code">SI-162</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-163">
-            <field name="name">Jezersko</field>
-            <field name="code">SI-163</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-164">
-            <field name="name">Komenda</field>
-            <field name="code">SI-164</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-165">
-            <field name="name">Kostel</field>
-            <field name="code">SI-165</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-166">
-            <field name="name">Križevci</field>
-            <field name="code">SI-166</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-167">
-            <field name="name">Lovrenc na Pohorju</field>
-            <field name="code">SI-167</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-168">
-            <field name="name">Markovci</field>
-            <field name="code">SI-168</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-169">
-            <field name="name">Miklavž na Dravskem polju</field>
-            <field name="code">SI-169</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-170">
-            <field name="name">Mirna Peč</field>
-            <field name="code">SI-170</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-171">
-            <field name="name">Oplotnica</field>
-            <field name="code">SI-171</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-172">
-            <field name="name">Podlehnik</field>
-            <field name="code">SI-172</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-173">
-            <field name="name">Polzela</field>
-            <field name="code">SI-173</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-174">
-            <field name="name">Prebold</field>
-            <field name="code">SI-174</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-175">
-            <field name="name">Prevalje</field>
-            <field name="code">SI-175</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-176">
-            <field name="name">Razkrižje</field>
-            <field name="code">SI-176</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-177">
-            <field name="name">Ribnica na Pohorju</field>
-            <field name="code">SI-177</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-178">
-            <field name="name">Selnica ob Dravi</field>
-            <field name="code">SI-178</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-179">
-            <field name="name">Sodražica</field>
-            <field name="code">SI-179</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-180">
-            <field name="name">Solčava</field>
-            <field name="code">SI-180</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-181">
-            <field name="name">Sveta Ana</field>
-            <field name="code">SI-181</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-182">
-            <field name="name">Sveta Andraž v Slovenskih Goricah</field>
-            <field name="code">SI-182</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-183">
-            <field name="name">Šempeter-Vrtojba</field>
-            <field name="code">SI-183</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-184">
-            <field name="name">Tabor</field>
-            <field name="code">SI-184</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-185">
-            <field name="name">Trnovska vas</field>
-            <field name="code">SI-185</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-186">
-            <field name="name">Trzin</field>
-            <field name="code">SI-186</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-187">
-            <field name="name">Velika Polana</field>
-            <field name="code">SI-187</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-188">
-            <field name="name">Veržej</field>
-            <field name="code">SI-188</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-189">
-            <field name="name">Vransko</field>
-            <field name="code">SI-189</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-190">
-            <field name="name">Žalec</field>
-            <field name="code">SI-190</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-191">
-            <field name="name">Žetale</field>
-            <field name="code">SI-191</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-192">
-            <field name="name">Žirovnica</field>
-            <field name="code">SI-192</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-193">
-            <field name="name">Žužemberk</field>
-            <field name="code">SI-193</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-194">
-            <field name="name">Šmartno pri Litiji</field>
-            <field name="code">SI-194</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-195">
-            <field name="name">Apače</field>
-            <field name="code">SI-195</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-196">
-            <field name="name">Cirkulane</field>
-            <field name="code">SI-196</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-197">
-            <field name="name">Kosanjevica na Krki</field>
-            <field name="code">SI-197</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-198">
-            <field name="name">Makole</field>
-            <field name="code">SI-198</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-199">
-            <field name="name">Mokronog-Trebelno</field>
-            <field name="code">SI-199</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-200">
-            <field name="name">Poljčane</field>
-            <field name="code">SI-200</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-201">
-            <field name="name">Renče-Vogrsko</field>
-            <field name="code">SI-201</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-202">
-            <field name="name">Središče ob Dravi</field>
-            <field name="code">SI-202</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-203">
-            <field name="name">Straža</field>
-            <field name="code">SI-203</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-204">
-            <field name="name">Sveta Trojica v Slovenskih Goricah</field>
-            <field name="code">SI-204</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-205">
-            <field name="name">Sveti Tomaž</field>
-            <field name="code">SI-205</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-206">
-            <field name="name">Šmarjeske Topliče</field>
-            <field name="code">SI-206</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-207">
-            <field name="name">Gorje</field>
-            <field name="code">SI-207</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-208">
-            <field name="name">Log-Dragomer</field>
-            <field name="code">SI-208</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-209">
-            <field name="name">Rečica ob Savinji</field>
-            <field name="code">SI-209</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-210">
-            <field name="name">Sveti Jurij v Slovenskih Goricah</field>
-            <field name="code">SI-210</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="si-211">
-            <field name="name">Šentrupert</field>
-            <field name="code">SI-211</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="si"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-bc">
-            <field name="name">Banskobystrický kraj</field>
-            <field name="code">SK-BC</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-bl">
-            <field name="name">Bratislavský kraj</field>
-            <field name="code">SK-BL</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-ki">
-            <field name="name">Košický kraj</field>
-            <field name="code">SK-KI</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-ni">
-            <field name="name">Nitriansky kraj</field>
-            <field name="code">SK-NI</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-pv">
-            <field name="name">Prešovský kraj</field>
-            <field name="code">SK-PV</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-ta">
-            <field name="name">Trnavský kraj</field>
-            <field name="code">SK-TA</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-tc">
-            <field name="name">Trenčiansky kraj</field>
-            <field name="code">SK-TC</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sk-zi">
-            <field name="name">Žilinský kraj</field>
-            <field name="code">SK-ZI</field>
-            <field name="type">region</field>
-            <field name="country" ref="sk"/>
-        </record>
-
-        <record model="country.subdivision" id="sl-e">
-            <field name="name">Eastern</field>
-            <field name="code">SL-E</field>
-            <field name="type">province</field>
-            <field name="country" ref="sl"/>
-        </record>
-
-        <record model="country.subdivision" id="sl-n">
-            <field name="name">Northern</field>
-            <field name="code">SL-N</field>
-            <field name="type">province</field>
-            <field name="country" ref="sl"/>
-        </record>
-
-        <record model="country.subdivision" id="sl-s">
-            <field name="name">Southern (Sierra Leone)</field>
-            <field name="code">SL-S</field>
-            <field name="type">province</field>
-            <field name="country" ref="sl"/>
-        </record>
-
-        <record model="country.subdivision" id="sl-w">
-            <field name="name">Western Area (Freetown)</field>
-            <field name="code">SL-W</field>
-            <field name="type">area</field>
-            <field name="country" ref="sl"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-01">
-            <field name="name">Acquaviva</field>
-            <field name="code">SM-01</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-02">
-            <field name="name">Chiesanuova</field>
-            <field name="code">SM-02</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-03">
-            <field name="name">Domagnano</field>
-            <field name="code">SM-03</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-04">
-            <field name="name">Faetano</field>
-            <field name="code">SM-04</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-05">
-            <field name="name">Fiorentino</field>
-            <field name="code">SM-05</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-06">
-            <field name="name">Borgo Maggiore</field>
-            <field name="code">SM-06</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-07">
-            <field name="name">San Marino</field>
-            <field name="code">SM-07</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-08">
-            <field name="name">Montegiardino</field>
-            <field name="code">SM-08</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sm-09">
-            <field name="name">Serravalle</field>
-            <field name="code">SM-09</field>
-            <field name="type">municipalities</field>
-            <field name="country" ref="sm"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-db">
-            <field name="name">Diourbel</field>
-            <field name="code">SN-DB</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-dk">
-            <field name="name">Dakar</field>
-            <field name="code">SN-DK</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-fk">
-            <field name="name">Fatick</field>
-            <field name="code">SN-FK</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-ka">
-            <field name="name">Kaffrine</field>
-            <field name="code">SN-KA</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-kd">
-            <field name="name">Kolda</field>
-            <field name="code">SN-KD</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-ke">
-            <field name="name">Kédougou</field>
-            <field name="code">SN-KE</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-kl">
-            <field name="name">Kaolack</field>
-            <field name="code">SN-KL</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-lg">
-            <field name="name">Louga</field>
-            <field name="code">SN-LG</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-mt">
-            <field name="name">Matam</field>
-            <field name="code">SN-MT</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-se">
-            <field name="name">Sédhiou</field>
-            <field name="code">SN-SE</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-sl">
-            <field name="name">Saint-Louis</field>
-            <field name="code">SN-SL</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-tc">
-            <field name="name">Tambacounda</field>
-            <field name="code">SN-TC</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-th">
-            <field name="name">Thiès</field>
-            <field name="code">SN-TH</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="sn-zg">
-            <field name="name">Ziguinchor</field>
-            <field name="code">SN-ZG</field>
-            <field name="type">region</field>
-            <field name="country" ref="sn"/>
-        </record>
-
-        <record model="country.subdivision" id="so-aw">
-            <field name="name">Awdal</field>
-            <field name="code">SO-AW</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-bk">
-            <field name="name">Bakool</field>
-            <field name="code">SO-BK</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-bn">
-            <field name="name">Banaadir</field>
-            <field name="code">SO-BN</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-br">
-            <field name="name">Bari</field>
-            <field name="code">SO-BR</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-by">
-            <field name="name">Bay</field>
-            <field name="code">SO-BY</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-ga">
-            <field name="name">Galguduud</field>
-            <field name="code">SO-GA</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-ge">
-            <field name="name">Gedo</field>
-            <field name="code">SO-GE</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-hi">
-            <field name="name">Hiirsan</field>
-            <field name="code">SO-HI</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-jd">
-            <field name="name">Jubbada Dhexe</field>
-            <field name="code">SO-JD</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-jh">
-            <field name="name">Jubbada Hoose</field>
-            <field name="code">SO-JH</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-mu">
-            <field name="name">Mudug</field>
-            <field name="code">SO-MU</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-nu">
-            <field name="name">Nugaal</field>
-            <field name="code">SO-NU</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-sa">
-            <field name="name">Saneag</field>
-            <field name="code">SO-SA</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-sd">
-            <field name="name">Shabeellaha Dhexe</field>
-            <field name="code">SO-SD</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-sh">
-            <field name="name">Shabeellaha Hoose</field>
-            <field name="code">SO-SH</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-so">
-            <field name="name">Sool</field>
-            <field name="code">SO-SO</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-to">
-            <field name="name">Togdheer</field>
-            <field name="code">SO-TO</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="so-wo">
-            <field name="name">Woqooyi Galbeed</field>
-            <field name="code">SO-WO</field>
-            <field name="type">region</field>
-            <field name="country" ref="so"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-br">
-            <field name="name">Brokopondo</field>
-            <field name="code">SR-BR</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-cm">
-            <field name="name">Commewijne</field>
-            <field name="code">SR-CM</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-cr">
-            <field name="name">Coronie</field>
-            <field name="code">SR-CR</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-ma">
-            <field name="name">Marowijne</field>
-            <field name="code">SR-MA</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-ni">
-            <field name="name">Nickerie</field>
-            <field name="code">SR-NI</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-pm">
-            <field name="name">Paramaribo</field>
-            <field name="code">SR-PM</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-pr">
-            <field name="name">Para</field>
-            <field name="code">SR-PR</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-sa">
-            <field name="name">Saramacca</field>
-            <field name="code">SR-SA</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-si">
-            <field name="name">Sipaliwini</field>
-            <field name="code">SR-SI</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="sr-wa">
-            <field name="name">Wanica</field>
-            <field name="code">SR-WA</field>
-            <field name="type">district</field>
-            <field name="country" ref="sr"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-bn">
-            <field name="name">Northern Bahr el-Ghazal</field>
-            <field name="code">SS-BN</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-bw">
-            <field name="name">Western Bahr el-Ghazal</field>
-            <field name="code">SS-BW</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-ec">
-            <field name="name">Central Equatoria</field>
-            <field name="code">SS-EC</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-ee8">
-            <field name="name">Eastern Equatoria</field>
-            <field name="code">SS-EE8</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-ew">
-            <field name="name">Western Equatoria</field>
-            <field name="code">SS-EW</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-jg">
-            <field name="name">Jonglei</field>
-            <field name="code">SS-JG</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-lk">
-            <field name="name">Lakes</field>
-            <field name="code">SS-LK</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-nu">
-            <field name="name">Upper Nile</field>
-            <field name="code">SS-NU</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-uy">
-            <field name="name">Unity</field>
-            <field name="code">SS-UY</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="ss-wr">
-            <field name="name">Warrap</field>
-            <field name="code">SS-WR</field>
-            <field name="type">state</field>
-            <field name="country" ref="ss"/>
-        </record>
-
-        <record model="country.subdivision" id="st-p">
-            <field name="name">Príncipe</field>
-            <field name="code">ST-P</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="st"/>
-        </record>
-
-        <record model="country.subdivision" id="st-s">
-            <field name="name">São Tomé</field>
-            <field name="code">ST-S</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="st"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-ah">
-            <field name="name">Ahuachapán</field>
-            <field name="code">SV-AH</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-ca">
-            <field name="name">Cabañas</field>
-            <field name="code">SV-CA</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-ch">
-            <field name="name">Chalatenango</field>
-            <field name="code">SV-CH</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-cu">
-            <field name="name">Cuscatlán</field>
-            <field name="code">SV-CU</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-li">
-            <field name="name">La Libertad</field>
-            <field name="code">SV-LI</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-mo">
-            <field name="name">Morazán</field>
-            <field name="code">SV-MO</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-pa">
-            <field name="name">La Paz</field>
-            <field name="code">SV-PA</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-sa">
-            <field name="name">Santa Ana</field>
-            <field name="code">SV-SA</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-sm">
-            <field name="name">San Miguel</field>
-            <field name="code">SV-SM</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-so">
-            <field name="name">Sonsonate</field>
-            <field name="code">SV-SO</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-ss">
-            <field name="name">San Salvador</field>
-            <field name="code">SV-SS</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-sv">
-            <field name="name">San Vicente</field>
-            <field name="code">SV-SV</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-un">
-            <field name="name">La Unión</field>
-            <field name="code">SV-UN</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sv-us">
-            <field name="name">Usulután</field>
-            <field name="code">SV-US</field>
-            <field name="type">department</field>
-            <field name="country" ref="sv"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-di">
-            <field name="name">Dimashq</field>
-            <field name="code">SY-DI</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-dr">
-            <field name="name">Dar'a</field>
-            <field name="code">SY-DR</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-dy">
-            <field name="name">Dayr az Zawr</field>
-            <field name="code">SY-DY</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-ha">
-            <field name="name">Al Hasakah</field>
-            <field name="code">SY-HA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-hi">
-            <field name="name">Homs</field>
-            <field name="code">SY-HI</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-hl">
-            <field name="name">Halab</field>
-            <field name="code">SY-HL</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-hm">
-            <field name="name">Hamah</field>
-            <field name="code">SY-HM</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-id">
-            <field name="name">Idlib</field>
-            <field name="code">SY-ID</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-la">
-            <field name="name">Al Ladhiqiyah</field>
-            <field name="code">SY-LA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-qu">
-            <field name="name">Al Qunaytirah</field>
-            <field name="code">SY-QU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-ra">
-            <field name="name">Ar Raqqah</field>
-            <field name="code">SY-RA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-rd">
-            <field name="name">Rif Dimashq</field>
-            <field name="code">SY-RD</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-su">
-            <field name="name">As Suwayda'</field>
-            <field name="code">SY-SU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sy-ta">
-            <field name="name">Tartus</field>
-            <field name="code">SY-TA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="sy"/>
-        </record>
-
-        <record model="country.subdivision" id="sz-hh">
-            <field name="name">Hhohho</field>
-            <field name="code">SZ-HH</field>
-            <field name="type">district</field>
-            <field name="country" ref="sz"/>
-        </record>
-
-        <record model="country.subdivision" id="sz-lu">
-            <field name="name">Lubombo</field>
-            <field name="code">SZ-LU</field>
-            <field name="type">district</field>
-            <field name="country" ref="sz"/>
-        </record>
-
-        <record model="country.subdivision" id="sz-ma">
-            <field name="name">Manzini</field>
-            <field name="code">SZ-MA</field>
-            <field name="type">district</field>
-            <field name="country" ref="sz"/>
-        </record>
-
-        <record model="country.subdivision" id="sz-sh">
-            <field name="name">Shiselweni</field>
-            <field name="code">SZ-SH</field>
-            <field name="type">district</field>
-            <field name="country" ref="sz"/>
-        </record>
-
-        <record model="country.subdivision" id="td-ba">
-            <field name="name">Al Baṭḩah</field>
-            <field name="code">TD-BA</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-bg">
-            <field name="name">Baḩr al Ghazāl</field>
-            <field name="code">TD-BG</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-bo">
-            <field name="name">Būrkū</field>
-            <field name="code">TD-BO</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-cb">
-            <field name="name">Shārī Bāqirmī</field>
-            <field name="code">TD-CB</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-en">
-            <field name="name">Innīdī</field>
-            <field name="code">TD-EN</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-gr">
-            <field name="name">Qīrā</field>
-            <field name="code">TD-GR</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-hl">
-            <field name="name">Ḥajjar Lamīs</field>
-            <field name="code">TD-HL</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-ka">
-            <field name="name">Kānim</field>
-            <field name="code">TD-KA</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-lc">
-            <field name="name">Al Buḩayrah</field>
-            <field name="code">TD-LC</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-lo">
-            <field name="name">Lūqūn al Gharbī</field>
-            <field name="code">TD-LO</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-lr">
-            <field name="name">Lūqūn ash Sharqī</field>
-            <field name="code">TD-LR</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-ma">
-            <field name="name">Māndūl</field>
-            <field name="code">TD-MA</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-mc">
-            <field name="name">Shārī al Awsaṭ</field>
-            <field name="code">TD-MC</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-me">
-            <field name="name">Māyū Kībbī ash Sharqī</field>
-            <field name="code">TD-ME</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-mo">
-            <field name="name">Māyū Kībbī al Gharbī</field>
-            <field name="code">TD-MO</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-nd">
-            <field name="name">Madīnat Injamīnā</field>
-            <field name="code">TD-ND</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-od">
-            <field name="name">Waddāy</field>
-            <field name="code">TD-OD</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-sa">
-            <field name="name">Salāmāt</field>
-            <field name="code">TD-SA</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-si">
-            <field name="name">Sīlā</field>
-            <field name="code">TD-SI</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-ta">
-            <field name="name">Tānjilī</field>
-            <field name="code">TD-TA</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-ti">
-            <field name="name">Tibastī</field>
-            <field name="code">TD-TI</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="td-wf">
-            <field name="name">Wādī Fīrā</field>
-            <field name="code">TD-WF</field>
-            <field name="type">region</field>
-            <field name="country" ref="td"/>
-        </record>
-
-        <record model="country.subdivision" id="tg-c">
-            <field name="name">Région du Centre</field>
-            <field name="code">TG-C</field>
-            <field name="type">region</field>
-            <field name="country" ref="tg"/>
-        </record>
-
-        <record model="country.subdivision" id="tg-k">
-            <field name="name">Région de la Kara</field>
-            <field name="code">TG-K</field>
-            <field name="type">region</field>
-            <field name="country" ref="tg"/>
-        </record>
-
-        <record model="country.subdivision" id="tg-m">
-            <field name="name">Région Maritime</field>
-            <field name="code">TG-M</field>
-            <field name="type">region</field>
-            <field name="country" ref="tg"/>
-        </record>
-
-        <record model="country.subdivision" id="tg-p">
-            <field name="name">Région des Plateaux</field>
-            <field name="code">TG-P</field>
-            <field name="type">region</field>
-            <field name="country" ref="tg"/>
-        </record>
-
-        <record model="country.subdivision" id="tg-s">
-            <field name="name">Région des Savannes</field>
-            <field name="code">TG-S</field>
-            <field name="type">region</field>
-            <field name="country" ref="tg"/>
-        </record>
-
-        <record model="country.subdivision" id="th-10">
-            <field name="name">Krung Thep Maha Nakhon Bangkok</field>
-            <field name="code">TH-10</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-11">
-            <field name="name">Samut Prakan</field>
-            <field name="code">TH-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-12">
-            <field name="name">Nonthaburi</field>
-            <field name="code">TH-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-13">
-            <field name="name">Pathum Thani</field>
-            <field name="code">TH-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-14">
-            <field name="name">Phra Nakhon Si Ayutthaya</field>
-            <field name="code">TH-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-15">
-            <field name="name">Ang Thong</field>
-            <field name="code">TH-15</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-16">
-            <field name="name">Lop Buri</field>
-            <field name="code">TH-16</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-17">
-            <field name="name">Sing Buri</field>
-            <field name="code">TH-17</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-18">
-            <field name="name">Chai Nat</field>
-            <field name="code">TH-18</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-19">
-            <field name="name">Saraburi</field>
-            <field name="code">TH-19</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-20">
-            <field name="name">Chon Buri</field>
-            <field name="code">TH-20</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-21">
-            <field name="name">Rayong</field>
-            <field name="code">TH-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-22">
-            <field name="name">Chanthaburi</field>
-            <field name="code">TH-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-23">
-            <field name="name">Trat</field>
-            <field name="code">TH-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-24">
-            <field name="name">Chachoengsao</field>
-            <field name="code">TH-24</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-25">
-            <field name="name">Prachin Buri</field>
-            <field name="code">TH-25</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-26">
-            <field name="name">Nakhon Nayok</field>
-            <field name="code">TH-26</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-27">
-            <field name="name">Sa Kaeo</field>
-            <field name="code">TH-27</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-30">
-            <field name="name">Nakhon Ratchasima</field>
-            <field name="code">TH-30</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-31">
-            <field name="name">Buri Ram</field>
-            <field name="code">TH-31</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-32">
-            <field name="name">Surin</field>
-            <field name="code">TH-32</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-33">
-            <field name="name">Si Sa Ket</field>
-            <field name="code">TH-33</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-34">
-            <field name="name">Ubon Ratchathani</field>
-            <field name="code">TH-34</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-35">
-            <field name="name">Yasothon</field>
-            <field name="code">TH-35</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-36">
-            <field name="name">Chaiyaphum</field>
-            <field name="code">TH-36</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-37">
-            <field name="name">Amnat Charoen</field>
-            <field name="code">TH-37</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-39">
-            <field name="name">Nong Bua Lam Phu</field>
-            <field name="code">TH-39</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-40">
-            <field name="name">Khon Kaen</field>
-            <field name="code">TH-40</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-41">
-            <field name="name">Udon Thani</field>
-            <field name="code">TH-41</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-42">
-            <field name="name">Loei</field>
-            <field name="code">TH-42</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-43">
-            <field name="name">Nong Khai</field>
-            <field name="code">TH-43</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-44">
-            <field name="name">Maha Sarakham</field>
-            <field name="code">TH-44</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-45">
-            <field name="name">Roi Et</field>
-            <field name="code">TH-45</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-46">
-            <field name="name">Kalasin</field>
-            <field name="code">TH-46</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-47">
-            <field name="name">Sakon Nakhon</field>
-            <field name="code">TH-47</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-48">
-            <field name="name">Nakhon Phanom</field>
-            <field name="code">TH-48</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-49">
-            <field name="name">Mukdahan</field>
-            <field name="code">TH-49</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-50">
-            <field name="name">Chiang Mai</field>
-            <field name="code">TH-50</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-51">
-            <field name="name">Lamphun</field>
-            <field name="code">TH-51</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-52">
-            <field name="name">Lampang</field>
-            <field name="code">TH-52</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-53">
-            <field name="name">Uttaradit</field>
-            <field name="code">TH-53</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-54">
-            <field name="name">Phrae</field>
-            <field name="code">TH-54</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-55">
-            <field name="name">Nan</field>
-            <field name="code">TH-55</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-56">
-            <field name="name">Phayao</field>
-            <field name="code">TH-56</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-57">
-            <field name="name">Chiang Rai</field>
-            <field name="code">TH-57</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-58">
-            <field name="name">Mae Hong Son</field>
-            <field name="code">TH-58</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-60">
-            <field name="name">Nakhon Sawan</field>
-            <field name="code">TH-60</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-61">
-            <field name="name">Uthai Thani</field>
-            <field name="code">TH-61</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-62">
-            <field name="name">Kamphaeng Phet</field>
-            <field name="code">TH-62</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-63">
-            <field name="name">Tak</field>
-            <field name="code">TH-63</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-64">
-            <field name="name">Sukhothai</field>
-            <field name="code">TH-64</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-65">
-            <field name="name">Phitsanulok</field>
-            <field name="code">TH-65</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-66">
-            <field name="name">Phichit</field>
-            <field name="code">TH-66</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-67">
-            <field name="name">Phetchabun</field>
-            <field name="code">TH-67</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-70">
-            <field name="name">Ratchaburi</field>
-            <field name="code">TH-70</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-71">
-            <field name="name">Kanchanaburi</field>
-            <field name="code">TH-71</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-72">
-            <field name="name">Suphan Buri</field>
-            <field name="code">TH-72</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-73">
-            <field name="name">Nakhon Pathom</field>
-            <field name="code">TH-73</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-74">
-            <field name="name">Samut Sakhon</field>
-            <field name="code">TH-74</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-75">
-            <field name="name">Samut Songkhram</field>
-            <field name="code">TH-75</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-76">
-            <field name="name">Phetchaburi</field>
-            <field name="code">TH-76</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-77">
-            <field name="name">Prachuap Khiri Khan</field>
-            <field name="code">TH-77</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-80">
-            <field name="name">Nakhon Si Thammarat</field>
-            <field name="code">TH-80</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-81">
-            <field name="name">Krabi</field>
-            <field name="code">TH-81</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-82">
-            <field name="name">Phangnga</field>
-            <field name="code">TH-82</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-83">
-            <field name="name">Phuket</field>
-            <field name="code">TH-83</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-84">
-            <field name="name">Surat Thani</field>
-            <field name="code">TH-84</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-85">
-            <field name="name">Ranong</field>
-            <field name="code">TH-85</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-86">
-            <field name="name">Chumphon</field>
-            <field name="code">TH-86</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-90">
-            <field name="name">Songkhla</field>
-            <field name="code">TH-90</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-91">
-            <field name="name">Satun</field>
-            <field name="code">TH-91</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-92">
-            <field name="name">Trang</field>
-            <field name="code">TH-92</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-93">
-            <field name="name">Phatthalung</field>
-            <field name="code">TH-93</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-94">
-            <field name="name">Pattani</field>
-            <field name="code">TH-94</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-95">
-            <field name="name">Yala</field>
-            <field name="code">TH-95</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-96">
-            <field name="name">Narathiwat</field>
-            <field name="code">TH-96</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="th-s">
-            <field name="name">Phatthaya</field>
-            <field name="code">TH-S</field>
-            <field name="type">province</field>
-            <field name="country" ref="th"/>
-        </record>
-
-        <record model="country.subdivision" id="tj-gb">
-            <field name="name">Gorno-Badakhshan</field>
-            <field name="code">TJ-GB</field>
-            <field name="type">autonomous region</field>
-            <field name="country" ref="tj"/>
-        </record>
-
-        <record model="country.subdivision" id="tj-kt">
-            <field name="name">Khatlon</field>
-            <field name="code">TJ-KT</field>
-            <field name="type">region</field>
-            <field name="country" ref="tj"/>
-        </record>
-
-        <record model="country.subdivision" id="tj-su">
-            <field name="name">Sughd</field>
-            <field name="code">TJ-SU</field>
-            <field name="type">region</field>
-            <field name="country" ref="tj"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-al">
-            <field name="name">Aileu</field>
-            <field name="code">TL-AL</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-an">
-            <field name="name">Ainaro</field>
-            <field name="code">TL-AN</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-ba">
-            <field name="name">Baucau</field>
-            <field name="code">TL-BA</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-bo">
-            <field name="name">Bobonaro</field>
-            <field name="code">TL-BO</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-co">
-            <field name="name">Cova Lima</field>
-            <field name="code">TL-CO</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-di">
-            <field name="name">Díli</field>
-            <field name="code">TL-DI</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-er">
-            <field name="name">Ermera</field>
-            <field name="code">TL-ER</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-la">
-            <field name="name">Lautem</field>
-            <field name="code">TL-LA</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-li">
-            <field name="name">Liquiça</field>
-            <field name="code">TL-LI</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-mf">
-            <field name="name">Manufahi</field>
-            <field name="code">TL-MF</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-mt">
-            <field name="name">Manatuto</field>
-            <field name="code">TL-MT</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-oe">
-            <field name="name">Oecussi</field>
-            <field name="code">TL-OE</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tl-vi">
-            <field name="name">Viqueque</field>
-            <field name="code">TL-VI</field>
-            <field name="type">district</field>
-            <field name="country" ref="tl"/>
-        </record>
-
-        <record model="country.subdivision" id="tm-a">
-            <field name="name">Ahal</field>
-            <field name="code">TM-A</field>
-            <field name="type">region</field>
-            <field name="country" ref="tm"/>
-        </record>
-
-        <record model="country.subdivision" id="tm-b">
-            <field name="name">Balkan</field>
-            <field name="code">TM-B</field>
-            <field name="type">region</field>
-            <field name="country" ref="tm"/>
-        </record>
-
-        <record model="country.subdivision" id="tm-d">
-            <field name="name">Daşoguz</field>
-            <field name="code">TM-D</field>
-            <field name="type">region</field>
-            <field name="country" ref="tm"/>
-        </record>
-
-        <record model="country.subdivision" id="tm-l">
-            <field name="name">Lebap</field>
-            <field name="code">TM-L</field>
-            <field name="type">region</field>
-            <field name="country" ref="tm"/>
-        </record>
-
-        <record model="country.subdivision" id="tm-m">
-            <field name="name">Mary</field>
-            <field name="code">TM-M</field>
-            <field name="type">region</field>
-            <field name="country" ref="tm"/>
-        </record>
-
-        <record model="country.subdivision" id="tm-s">
-            <field name="name">Aşgabat</field>
-            <field name="code">TM-S</field>
-            <field name="type">city</field>
-            <field name="country" ref="tm"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-11">
-            <field name="name">Tunis</field>
-            <field name="code">TN-11</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-12">
-            <field name="name">Ariana</field>
-            <field name="code">TN-12</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-13">
-            <field name="name">Ben Arous</field>
-            <field name="code">TN-13</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-14">
-            <field name="name">La Manouba</field>
-            <field name="code">TN-14</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-21">
-            <field name="name">Nabeul</field>
-            <field name="code">TN-21</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-22">
-            <field name="name">Zaghouan</field>
-            <field name="code">TN-22</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-23">
-            <field name="name">Bizerte</field>
-            <field name="code">TN-23</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-31">
-            <field name="name">Béja</field>
-            <field name="code">TN-31</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-32">
-            <field name="name">Jendouba</field>
-            <field name="code">TN-32</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-33">
-            <field name="name">Le Kef</field>
-            <field name="code">TN-33</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-34">
-            <field name="name">Siliana</field>
-            <field name="code">TN-34</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-41">
-            <field name="name">Kairouan</field>
-            <field name="code">TN-41</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-42">
-            <field name="name">Kasserine</field>
-            <field name="code">TN-42</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-43">
-            <field name="name">Sidi Bouzid</field>
-            <field name="code">TN-43</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-51">
-            <field name="name">Sousse</field>
-            <field name="code">TN-51</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-52">
-            <field name="name">Monastir</field>
-            <field name="code">TN-52</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-53">
-            <field name="name">Mahdia</field>
-            <field name="code">TN-53</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-61">
-            <field name="name">Sfax</field>
-            <field name="code">TN-61</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-71">
-            <field name="name">Gafsa</field>
-            <field name="code">TN-71</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-72">
-            <field name="name">Tozeur</field>
-            <field name="code">TN-72</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-73">
-            <field name="name">Kebili</field>
-            <field name="code">TN-73</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-81">
-            <field name="name">Gabès</field>
-            <field name="code">TN-81</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-82">
-            <field name="name">Medenine</field>
-            <field name="code">TN-82</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="tn-83">
-            <field name="name">Tataouine</field>
-            <field name="code">TN-83</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="tn"/>
-        </record>
-
-        <record model="country.subdivision" id="to-01">
-            <field name="name">'Eua</field>
-            <field name="code">TO-01</field>
-            <field name="type">division</field>
-            <field name="country" ref="to"/>
-        </record>
-
-        <record model="country.subdivision" id="to-02">
-            <field name="name">Ha'apai</field>
-            <field name="code">TO-02</field>
-            <field name="type">division</field>
-            <field name="country" ref="to"/>
-        </record>
-
-        <record model="country.subdivision" id="to-03">
-            <field name="name">Niuas</field>
-            <field name="code">TO-03</field>
-            <field name="type">division</field>
-            <field name="country" ref="to"/>
-        </record>
-
-        <record model="country.subdivision" id="to-04">
-            <field name="name">Tongatapu</field>
-            <field name="code">TO-04</field>
-            <field name="type">division</field>
-            <field name="country" ref="to"/>
-        </record>
-
-        <record model="country.subdivision" id="to-05">
-            <field name="name">Vava'u</field>
-            <field name="code">TO-05</field>
-            <field name="type">division</field>
-            <field name="country" ref="to"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-01">
-            <field name="name">Adana</field>
-            <field name="code">TR-01</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-02">
-            <field name="name">Adıyaman</field>
-            <field name="code">TR-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-03">
-            <field name="name">Afyonkarahisar</field>
-            <field name="code">TR-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-04">
-            <field name="name">Ağrı</field>
-            <field name="code">TR-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-05">
-            <field name="name">Amasya</field>
-            <field name="code">TR-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-06">
-            <field name="name">Ankara</field>
-            <field name="code">TR-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-07">
-            <field name="name">Antalya</field>
-            <field name="code">TR-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-08">
-            <field name="name">Artvin</field>
-            <field name="code">TR-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-09">
-            <field name="name">Aydın</field>
-            <field name="code">TR-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-10">
-            <field name="name">Balıkesir</field>
-            <field name="code">TR-10</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-11">
-            <field name="name">Bilecik</field>
-            <field name="code">TR-11</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-12">
-            <field name="name">Bingöl</field>
-            <field name="code">TR-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-13">
-            <field name="name">Bitlis</field>
-            <field name="code">TR-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-14">
-            <field name="name">Bolu</field>
-            <field name="code">TR-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-15">
-            <field name="name">Burdur</field>
-            <field name="code">TR-15</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-16">
-            <field name="name">Bursa</field>
-            <field name="code">TR-16</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-17">
-            <field name="name">Çanakkale</field>
-            <field name="code">TR-17</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-18">
-            <field name="name">Çankırı</field>
-            <field name="code">TR-18</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-19">
-            <field name="name">Çorum</field>
-            <field name="code">TR-19</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-20">
-            <field name="name">Denizli</field>
-            <field name="code">TR-20</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-21">
-            <field name="name">Diyarbakır</field>
-            <field name="code">TR-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-22">
-            <field name="name">Edirne</field>
-            <field name="code">TR-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-23">
-            <field name="name">Elazığ</field>
-            <field name="code">TR-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-24">
-            <field name="name">Erzincan</field>
-            <field name="code">TR-24</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-25">
-            <field name="name">Erzurum</field>
-            <field name="code">TR-25</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-26">
-            <field name="name">Eskişehir</field>
-            <field name="code">TR-26</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-27">
-            <field name="name">Gaziantep</field>
-            <field name="code">TR-27</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-28">
-            <field name="name">Giresun</field>
-            <field name="code">TR-28</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-29">
-            <field name="name">Gümüşhane</field>
-            <field name="code">TR-29</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-30">
-            <field name="name">Hakkâri</field>
-            <field name="code">TR-30</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-31">
-            <field name="name">Hatay</field>
-            <field name="code">TR-31</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-32">
-            <field name="name">Isparta</field>
-            <field name="code">TR-32</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-33">
-            <field name="name">Mersin</field>
-            <field name="code">TR-33</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-34">
-            <field name="name">İstanbul</field>
-            <field name="code">TR-34</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-35">
-            <field name="name">İzmir</field>
-            <field name="code">TR-35</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-36">
-            <field name="name">Kars</field>
-            <field name="code">TR-36</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-37">
-            <field name="name">Kastamonu</field>
-            <field name="code">TR-37</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-38">
-            <field name="name">Kayseri</field>
-            <field name="code">TR-38</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-39">
-            <field name="name">Kırklareli</field>
-            <field name="code">TR-39</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-40">
-            <field name="name">Kırşehir</field>
-            <field name="code">TR-40</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-41">
-            <field name="name">Kocaeli</field>
-            <field name="code">TR-41</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-42">
-            <field name="name">Konya</field>
-            <field name="code">TR-42</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-43">
-            <field name="name">Kütahya</field>
-            <field name="code">TR-43</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-44">
-            <field name="name">Malatya</field>
-            <field name="code">TR-44</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-45">
-            <field name="name">Manisa</field>
-            <field name="code">TR-45</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-46">
-            <field name="name">Kahramanmaraş</field>
-            <field name="code">TR-46</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-47">
-            <field name="name">Mardin</field>
-            <field name="code">TR-47</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-48">
-            <field name="name">Muğla</field>
-            <field name="code">TR-48</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-49">
-            <field name="name">Muş</field>
-            <field name="code">TR-49</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-50">
-            <field name="name">Nevşehir</field>
-            <field name="code">TR-50</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-51">
-            <field name="name">Niğde</field>
-            <field name="code">TR-51</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-52">
-            <field name="name">Ordu</field>
-            <field name="code">TR-52</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-53">
-            <field name="name">Rize</field>
-            <field name="code">TR-53</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-54">
-            <field name="name">Sakarya</field>
-            <field name="code">TR-54</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-55">
-            <field name="name">Samsun</field>
-            <field name="code">TR-55</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-56">
-            <field name="name">Siirt</field>
-            <field name="code">TR-56</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-57">
-            <field name="name">Sinop</field>
-            <field name="code">TR-57</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-58">
-            <field name="name">Sivas</field>
-            <field name="code">TR-58</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-59">
-            <field name="name">Tekirdağ</field>
-            <field name="code">TR-59</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-60">
-            <field name="name">Tokat</field>
-            <field name="code">TR-60</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-61">
-            <field name="name">Trabzon</field>
-            <field name="code">TR-61</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-62">
-            <field name="name">Tunceli</field>
-            <field name="code">TR-62</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-63">
-            <field name="name">Şanlıurfa</field>
-            <field name="code">TR-63</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-64">
-            <field name="name">Uşak</field>
-            <field name="code">TR-64</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-65">
-            <field name="name">Van</field>
-            <field name="code">TR-65</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-66">
-            <field name="name">Yozgat</field>
-            <field name="code">TR-66</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-67">
-            <field name="name">Zonguldak</field>
-            <field name="code">TR-67</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-68">
-            <field name="name">Aksaray</field>
-            <field name="code">TR-68</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-69">
-            <field name="name">Bayburt</field>
-            <field name="code">TR-69</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-70">
-            <field name="name">Karaman</field>
-            <field name="code">TR-70</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-71">
-            <field name="name">Kırıkkale</field>
-            <field name="code">TR-71</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-72">
-            <field name="name">Batman</field>
-            <field name="code">TR-72</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-73">
-            <field name="name">Şırnak</field>
-            <field name="code">TR-73</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-74">
-            <field name="name">Bartın</field>
-            <field name="code">TR-74</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-75">
-            <field name="name">Ardahan</field>
-            <field name="code">TR-75</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-76">
-            <field name="name">Iğdır</field>
-            <field name="code">TR-76</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-77">
-            <field name="name">Yalova</field>
-            <field name="code">TR-77</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-78">
-            <field name="name">Karabük</field>
-            <field name="code">TR-78</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-79">
-            <field name="name">Kilis</field>
-            <field name="code">TR-79</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-80">
-            <field name="name">Osmaniye</field>
-            <field name="code">TR-80</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tr-81">
-            <field name="name">Düzce</field>
-            <field name="code">TR-81</field>
-            <field name="type">province</field>
-            <field name="country" ref="tr"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-ari">
-            <field name="name">Arima</field>
-            <field name="code">TT-ARI</field>
-            <field name="type">borough</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-cha">
-            <field name="name">Chaguanas</field>
-            <field name="code">TT-CHA</field>
-            <field name="type">borough</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-ctt">
-            <field name="name">Couva-Tabaquite-Talparo</field>
-            <field name="code">TT-CTT</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-dmn">
-            <field name="name">Diego Martin</field>
-            <field name="code">TT-DMN</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-eto">
-            <field name="name">Eastern Tobago</field>
-            <field name="code">TT-ETO</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-ped">
-            <field name="name">Penal-Debe</field>
-            <field name="code">TT-PED</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-pos">
-            <field name="name">Port of Spain</field>
-            <field name="code">TT-POS</field>
-            <field name="type">city</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-prt">
-            <field name="name">Princes Town</field>
-            <field name="code">TT-PRT</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-ptf">
-            <field name="name">Point Fortin</field>
-            <field name="code">TT-PTF</field>
-            <field name="type">borough</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-rcm">
-            <field name="name">Rio Claro-Mayaro</field>
-            <field name="code">TT-RCM</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-sfo">
-            <field name="name">San Fernando</field>
-            <field name="code">TT-SFO</field>
-            <field name="type">city</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-sge">
-            <field name="name">Sangre Grande</field>
-            <field name="code">TT-SGE</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-sip">
-            <field name="name">Siparia</field>
-            <field name="code">TT-SIP</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-sjl">
-            <field name="name">San Juan-Laventille</field>
-            <field name="code">TT-SJL</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-tup">
-            <field name="name">Tunapuna-Piarco</field>
-            <field name="code">TT-TUP</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tt-wto">
-            <field name="name">Western Tobago</field>
-            <field name="code">TT-WTO</field>
-            <field name="type">region</field>
-            <field name="country" ref="tt"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-fun">
-            <field name="name">Funafuti</field>
-            <field name="code">TV-FUN</field>
-            <field name="type">town council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-nit">
-            <field name="name">Niutao</field>
-            <field name="code">TV-NIT</field>
-            <field name="type">island council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-nkf">
-            <field name="name">Nukufetau</field>
-            <field name="code">TV-NKF</field>
-            <field name="type">island council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-nkl">
-            <field name="name">Nukulaelae</field>
-            <field name="code">TV-NKL</field>
-            <field name="type">island council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-nma">
-            <field name="name">Nanumea</field>
-            <field name="code">TV-NMA</field>
-            <field name="type">island council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-nmg">
-            <field name="name">Nanumanga</field>
-            <field name="code">TV-NMG</field>
-            <field name="type">island council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-nui">
-            <field name="name">Nui</field>
-            <field name="code">TV-NUI</field>
-            <field name="type">island council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tv-vai">
-            <field name="name">Vaitupu</field>
-            <field name="code">TV-VAI</field>
-            <field name="type">island council</field>
-            <field name="country" ref="tv"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-cha">
-            <field name="name">Changhua</field>
-            <field name="code">TW-CHA</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-cyi">
-            <field name="name">Chiay City</field>
-            <field name="code">TW-CYI</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-cyq">
-            <field name="name">Chiayi</field>
-            <field name="code">TW-CYQ</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-hsq">
-            <field name="name">Hsinchu</field>
-            <field name="code">TW-HSQ</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-hsz">
-            <field name="name">Hsinchui City</field>
-            <field name="code">TW-HSZ</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-hua">
-            <field name="name">Hualien</field>
-            <field name="code">TW-HUA</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-ila">
-            <field name="name">Ilan</field>
-            <field name="code">TW-ILA</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-kee">
-            <field name="name">Keelung City</field>
-            <field name="code">TW-KEE</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-khh">
-            <field name="name">Kaohsiung City</field>
-            <field name="code">TW-KHH</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-khq">
-            <field name="name">Kaohsiung</field>
-            <field name="code">TW-KHQ</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-mia">
-            <field name="name">Miaoli</field>
-            <field name="code">TW-MIA</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-nan">
-            <field name="name">Nantou</field>
-            <field name="code">TW-NAN</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-pen">
-            <field name="name">Penghu</field>
-            <field name="code">TW-PEN</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-pif">
-            <field name="name">Pingtung</field>
-            <field name="code">TW-PIF</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-tao">
-            <field name="name">Taoyuan</field>
-            <field name="code">TW-TAO</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-tnn">
-            <field name="name">Tainan City</field>
-            <field name="code">TW-TNN</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-tnq">
-            <field name="name">Tainan</field>
-            <field name="code">TW-TNQ</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-tpe">
-            <field name="name">Taipei City</field>
-            <field name="code">TW-TPE</field>
-            <field name="type">special municipality</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-tpq">
-            <field name="name">Taipei</field>
-            <field name="code">TW-TPQ</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-ttt">
-            <field name="name">Taitung</field>
-            <field name="code">TW-TTT</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-txg">
-            <field name="name">Taichung City</field>
-            <field name="code">TW-TXG</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-txq">
-            <field name="name">Taichung</field>
-            <field name="code">TW-TXQ</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tw-yun">
-            <field name="name">Yunlin</field>
-            <field name="code">TW-YUN</field>
-            <field name="type">district</field>
-            <field name="country" ref="tw"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-01">
-            <field name="name">Arusha</field>
-            <field name="code">TZ-01</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-02">
-            <field name="name">Dar-es-Salaam</field>
-            <field name="code">TZ-02</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-03">
-            <field name="name">Dodoma</field>
-            <field name="code">TZ-03</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-04">
-            <field name="name">Iringa</field>
-            <field name="code">TZ-04</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-05">
-            <field name="name">Kagera</field>
-            <field name="code">TZ-05</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-06">
-            <field name="name">Kaskazini Pemba</field>
-            <field name="code">TZ-06</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-07">
-            <field name="name">Kaskazini Unguja</field>
-            <field name="code">TZ-07</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-08">
-            <field name="name">Kigoma</field>
-            <field name="code">TZ-08</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-09">
-            <field name="name">Kilimanjaro</field>
-            <field name="code">TZ-09</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-10">
-            <field name="name">Kusini Pemba</field>
-            <field name="code">TZ-10</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-11">
-            <field name="name">Kusini Unguja</field>
-            <field name="code">TZ-11</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-12">
-            <field name="name">Lindi</field>
-            <field name="code">TZ-12</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-13">
-            <field name="name">Mara</field>
-            <field name="code">TZ-13</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-14">
-            <field name="name">Mbeya</field>
-            <field name="code">TZ-14</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-15">
-            <field name="name">Mjini Magharibi</field>
-            <field name="code">TZ-15</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-16">
-            <field name="name">Morogoro</field>
-            <field name="code">TZ-16</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-17">
-            <field name="name">Mtwara</field>
-            <field name="code">TZ-17</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-18">
-            <field name="name">Mwanza</field>
-            <field name="code">TZ-18</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-19">
-            <field name="name">Pwani</field>
-            <field name="code">TZ-19</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-20">
-            <field name="name">Rukwa</field>
-            <field name="code">TZ-20</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-21">
-            <field name="name">Ruvuma</field>
-            <field name="code">TZ-21</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-22">
-            <field name="name">Shinyanga</field>
-            <field name="code">TZ-22</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-23">
-            <field name="name">Singida</field>
-            <field name="code">TZ-23</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-24">
-            <field name="name">Tabora</field>
-            <field name="code">TZ-24</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-25">
-            <field name="name">Tanga</field>
-            <field name="code">TZ-25</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="tz-26">
-            <field name="name">Manyara</field>
-            <field name="code">TZ-26</field>
-            <field name="type">region</field>
-            <field name="country" ref="tz"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-05">
-            <field name="name">Vinnyts'ka Oblast'</field>
-            <field name="code">UA-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-07">
-            <field name="name">Volyns'ka Oblast'</field>
-            <field name="code">UA-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-09">
-            <field name="name">Luhans'ka Oblast'</field>
-            <field name="code">UA-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-12">
-            <field name="name">Dnipropetrovs'ka Oblast'</field>
-            <field name="code">UA-12</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-14">
-            <field name="name">Donets'ka Oblast'</field>
-            <field name="code">UA-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-18">
-            <field name="name">Zhytomyrs'ka Oblast'</field>
-            <field name="code">UA-18</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-21">
-            <field name="name">Zakarpats'ka Oblast'</field>
-            <field name="code">UA-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-23">
-            <field name="name">Zaporiz'ka Oblast'</field>
-            <field name="code">UA-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-26">
-            <field name="name">Ivano-Frankivs'ka Oblast'</field>
-            <field name="code">UA-26</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-30">
-            <field name="name">Kyïvs'ka mis'ka rada</field>
-            <field name="code">UA-30</field>
-            <field name="type">city</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-32">
-            <field name="name">Kyïvs'ka Oblast'</field>
-            <field name="code">UA-32</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-35">
-            <field name="name">Kirovohrads'ka Oblast'</field>
-            <field name="code">UA-35</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-40">
-            <field name="name">Sevastopol</field>
-            <field name="code">UA-40</field>
-            <field name="type">city</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-43">
-            <field name="name">Respublika Krym</field>
-            <field name="code">UA-43</field>
-            <field name="type">autonomous republic</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-46">
-            <field name="name">L'vivs'ka Oblast'</field>
-            <field name="code">UA-46</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-48">
-            <field name="name">Mykolaïvs'ka Oblast'</field>
-            <field name="code">UA-48</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-51">
-            <field name="name">Odes'ka Oblast'</field>
-            <field name="code">UA-51</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-53">
-            <field name="name">Poltavs'ka Oblast'</field>
-            <field name="code">UA-53</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-56">
-            <field name="name">Rivnens'ka Oblast'</field>
-            <field name="code">UA-56</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-59">
-            <field name="name">Sums 'ka Oblast'</field>
-            <field name="code">UA-59</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-61">
-            <field name="name">Ternopil's'ka Oblast'</field>
-            <field name="code">UA-61</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-63">
-            <field name="name">Kharkivs'ka Oblast'</field>
-            <field name="code">UA-63</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-65">
-            <field name="name">Khersons'ka Oblast'</field>
-            <field name="code">UA-65</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-68">
-            <field name="name">Khmel'nyts'ka Oblast'</field>
-            <field name="code">UA-68</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-71">
-            <field name="name">Cherkas'ka Oblast'</field>
-            <field name="code">UA-71</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-74">
-            <field name="name">Chernihivs'ka Oblast'</field>
-            <field name="code">UA-74</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ua-77">
-            <field name="name">Chernivets'ka Oblast'</field>
-            <field name="code">UA-77</field>
-            <field name="type">province</field>
-            <field name="country" ref="ua"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-c">
-            <field name="name">Central</field>
-            <field name="code">UG-C</field>
-            <field name="type">geographical region</field>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-e">
-            <field name="name">Eastern</field>
-            <field name="code">UG-E</field>
-            <field name="type">geographical region</field>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-n">
-            <field name="name">Northern</field>
-            <field name="code">UG-N</field>
-            <field name="type">geographical region</field>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-w">
-            <field name="name">Western</field>
-            <field name="code">UG-W</field>
-            <field name="type">geographical region</field>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="um-67">
-            <field name="name">Johnston Atoll</field>
-            <field name="code">UM-67</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-71">
-            <field name="name">Midway Islands</field>
-            <field name="code">UM-71</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-76">
-            <field name="name">Navassa Island</field>
-            <field name="code">UM-76</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-79">
-            <field name="name">Wake Island</field>
-            <field name="code">UM-79</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-81">
-            <field name="name">Baker Island</field>
-            <field name="code">UM-81</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-84">
-            <field name="name">Howland Island</field>
-            <field name="code">UM-84</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-86">
-            <field name="name">Jarvis Island</field>
-            <field name="code">UM-86</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-89">
-            <field name="name">Kingman Reef</field>
-            <field name="code">UM-89</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="um-95">
-            <field name="name">Palmyra Atoll</field>
-            <field name="code">UM-95</field>
-            <field name="type">territory</field>
-            <field name="country" ref="um"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ak">
-            <field name="name">Alaska</field>
-            <field name="code">US-AK</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-al">
-            <field name="name">Alabama</field>
-            <field name="code">US-AL</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ar">
-            <field name="name">Arkansas</field>
-            <field name="code">US-AR</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-as">
-            <field name="name">American Samoa</field>
-            <field name="code">US-AS</field>
-            <field name="type">outlying area</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-az">
-            <field name="name">Arizona</field>
-            <field name="code">US-AZ</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ca">
-            <field name="name">California</field>
-            <field name="code">US-CA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-co">
-            <field name="name">Colorado</field>
-            <field name="code">US-CO</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ct">
-            <field name="name">Connecticut</field>
-            <field name="code">US-CT</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-dc">
-            <field name="name">District of Columbia</field>
-            <field name="code">US-DC</field>
-            <field name="type">district</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-de">
-            <field name="name">Delaware</field>
-            <field name="code">US-DE</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-fl">
-            <field name="name">Florida</field>
-            <field name="code">US-FL</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ga">
-            <field name="name">Georgia</field>
-            <field name="code">US-GA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-gu">
-            <field name="name">Guam</field>
-            <field name="code">US-GU</field>
-            <field name="type">outlying area</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-hi">
-            <field name="name">Hawaii</field>
-            <field name="code">US-HI</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ia">
-            <field name="name">Iowa</field>
-            <field name="code">US-IA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-id">
-            <field name="name">Idaho</field>
-            <field name="code">US-ID</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-il">
-            <field name="name">Illinois</field>
-            <field name="code">US-IL</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-in">
-            <field name="name">Indiana</field>
-            <field name="code">US-IN</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ks">
-            <field name="name">Kansas</field>
-            <field name="code">US-KS</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ky">
-            <field name="name">Kentucky</field>
-            <field name="code">US-KY</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-la">
-            <field name="name">Louisiana</field>
-            <field name="code">US-LA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ma">
-            <field name="name">Massachusetts</field>
-            <field name="code">US-MA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-md">
-            <field name="name">Maryland</field>
-            <field name="code">US-MD</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-me">
-            <field name="name">Maine</field>
-            <field name="code">US-ME</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-mi">
-            <field name="name">Michigan</field>
-            <field name="code">US-MI</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-mn">
-            <field name="name">Minnesota</field>
-            <field name="code">US-MN</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-mo">
-            <field name="name">Missouri</field>
-            <field name="code">US-MO</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-mp">
-            <field name="name">Northern Mariana Islands</field>
-            <field name="code">US-MP</field>
-            <field name="type">outlying area</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ms">
-            <field name="name">Mississippi</field>
-            <field name="code">US-MS</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-mt">
-            <field name="name">Montana</field>
-            <field name="code">US-MT</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-nc">
-            <field name="name">North Carolina</field>
-            <field name="code">US-NC</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-nd">
-            <field name="name">North Dakota</field>
-            <field name="code">US-ND</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ne">
-            <field name="name">Nebraska</field>
-            <field name="code">US-NE</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-nh">
-            <field name="name">New Hampshire</field>
-            <field name="code">US-NH</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-nj">
-            <field name="name">New Jersey</field>
-            <field name="code">US-NJ</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-nm">
-            <field name="name">New Mexico</field>
-            <field name="code">US-NM</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-nv">
-            <field name="name">Nevada</field>
-            <field name="code">US-NV</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ny">
-            <field name="name">New York</field>
-            <field name="code">US-NY</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-oh">
-            <field name="name">Ohio</field>
-            <field name="code">US-OH</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ok">
-            <field name="name">Oklahoma</field>
-            <field name="code">US-OK</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-or">
-            <field name="name">Oregon</field>
-            <field name="code">US-OR</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-pa">
-            <field name="name">Pennsylvania</field>
-            <field name="code">US-PA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-pr">
-            <field name="name">Puerto Rico</field>
-            <field name="code">US-PR</field>
-            <field name="type">outlying area</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ri">
-            <field name="name">Rhode Island</field>
-            <field name="code">US-RI</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-sc">
-            <field name="name">South Carolina</field>
-            <field name="code">US-SC</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-sd">
-            <field name="name">South Dakota</field>
-            <field name="code">US-SD</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-tn">
-            <field name="name">Tennessee</field>
-            <field name="code">US-TN</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-tx">
-            <field name="name">Texas</field>
-            <field name="code">US-TX</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-um">
-            <field name="name">United States Minor Outlying Islands</field>
-            <field name="code">US-UM</field>
-            <field name="type">outlying area</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-ut">
-            <field name="name">Utah</field>
-            <field name="code">US-UT</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-va">
-            <field name="name">Virginia</field>
-            <field name="code">US-VA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-vi">
-            <field name="name">Virgin Islands</field>
-            <field name="code">US-VI</field>
-            <field name="type">outlying area</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-vt">
-            <field name="name">Vermont</field>
-            <field name="code">US-VT</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-wa">
-            <field name="name">Washington</field>
-            <field name="code">US-WA</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-wi">
-            <field name="name">Wisconsin</field>
-            <field name="code">US-WI</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-wv">
-            <field name="name">West Virginia</field>
-            <field name="code">US-WV</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="us-wy">
-            <field name="name">Wyoming</field>
-            <field name="code">US-WY</field>
-            <field name="type">state</field>
-            <field name="country" ref="us"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-ar">
-            <field name="name">Artigas</field>
-            <field name="code">UY-AR</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-ca">
-            <field name="name">Canelones</field>
-            <field name="code">UY-CA</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-cl">
-            <field name="name">Cerro Largo</field>
-            <field name="code">UY-CL</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-co">
-            <field name="name">Colonia</field>
-            <field name="code">UY-CO</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-du">
-            <field name="name">Durazno</field>
-            <field name="code">UY-DU</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-fd">
-            <field name="name">Florida</field>
-            <field name="code">UY-FD</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-fs">
-            <field name="name">Flores</field>
-            <field name="code">UY-FS</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-la">
-            <field name="name">Lavalleja</field>
-            <field name="code">UY-LA</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-ma">
-            <field name="name">Maldonado</field>
-            <field name="code">UY-MA</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-mo">
-            <field name="name">Montevideo</field>
-            <field name="code">UY-MO</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-pa">
-            <field name="name">Paysandú</field>
-            <field name="code">UY-PA</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-rn">
-            <field name="name">Río Negro</field>
-            <field name="code">UY-RN</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-ro">
-            <field name="name">Rocha</field>
-            <field name="code">UY-RO</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-rv">
-            <field name="name">Rivera</field>
-            <field name="code">UY-RV</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-sa">
-            <field name="name">Salto</field>
-            <field name="code">UY-SA</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-sj">
-            <field name="name">San José</field>
-            <field name="code">UY-SJ</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-so">
-            <field name="name">Soriano</field>
-            <field name="code">UY-SO</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-ta">
-            <field name="name">Tacuarembó</field>
-            <field name="code">UY-TA</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uy-tt">
-            <field name="name">Treinta y Tres</field>
-            <field name="code">UY-TT</field>
-            <field name="type">department</field>
-            <field name="country" ref="uy"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-an">
-            <field name="name">Andijon</field>
-            <field name="code">UZ-AN</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-bu">
-            <field name="name">Buxoro</field>
-            <field name="code">UZ-BU</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-fa">
-            <field name="name">Farg'ona</field>
-            <field name="code">UZ-FA</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-ji">
-            <field name="name">Jizzax</field>
-            <field name="code">UZ-JI</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-ng">
-            <field name="name">Namangan</field>
-            <field name="code">UZ-NG</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-nw">
-            <field name="name">Navoiy</field>
-            <field name="code">UZ-NW</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-qa">
-            <field name="name">Qashqadaryo</field>
-            <field name="code">UZ-QA</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-qr">
-            <field name="name">Qoraqalpog'iston Respublikasi</field>
-            <field name="code">UZ-QR</field>
-            <field name="type">republic</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-sa">
-            <field name="name">Samarqand</field>
-            <field name="code">UZ-SA</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-si">
-            <field name="name">Sirdaryo</field>
-            <field name="code">UZ-SI</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-su">
-            <field name="name">Surxondaryo</field>
-            <field name="code">UZ-SU</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-tk">
-            <field name="name">Toshkent</field>
-            <field name="code">UZ-TK</field>
-            <field name="type">city</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-to">
-            <field name="name">Toshkent</field>
-            <field name="code">UZ-TO</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="uz-xo">
-            <field name="name">Xorazm</field>
-            <field name="code">UZ-XO</field>
-            <field name="type">region</field>
-            <field name="country" ref="uz"/>
-        </record>
-
-        <record model="country.subdivision" id="vc-01">
-            <field name="name">Charlotte</field>
-            <field name="code">VC-01</field>
-            <field name="type">parish</field>
-            <field name="country" ref="vc"/>
-        </record>
-
-        <record model="country.subdivision" id="vc-02">
-            <field name="name">Saint Andrew</field>
-            <field name="code">VC-02</field>
-            <field name="type">parish</field>
-            <field name="country" ref="vc"/>
-        </record>
-
-        <record model="country.subdivision" id="vc-03">
-            <field name="name">Saint David</field>
-            <field name="code">VC-03</field>
-            <field name="type">parish</field>
-            <field name="country" ref="vc"/>
-        </record>
-
-        <record model="country.subdivision" id="vc-04">
-            <field name="name">Saint George</field>
-            <field name="code">VC-04</field>
-            <field name="type">parish</field>
-            <field name="country" ref="vc"/>
-        </record>
-
-        <record model="country.subdivision" id="vc-05">
-            <field name="name">Saint Patrick</field>
-            <field name="code">VC-05</field>
-            <field name="type">parish</field>
-            <field name="country" ref="vc"/>
-        </record>
-
-        <record model="country.subdivision" id="vc-06">
-            <field name="name">Grenadines</field>
-            <field name="code">VC-06</field>
-            <field name="type">parish</field>
-            <field name="country" ref="vc"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-a">
-            <field name="name">Distrito Federal</field>
-            <field name="code">VE-A</field>
-            <field name="type">federal district</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-b">
-            <field name="name">Anzoátegui</field>
-            <field name="code">VE-B</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-c">
-            <field name="name">Apure</field>
-            <field name="code">VE-C</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-d">
-            <field name="name">Aragua</field>
-            <field name="code">VE-D</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-e">
-            <field name="name">Barinas</field>
-            <field name="code">VE-E</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-f">
-            <field name="name">Bolívar</field>
-            <field name="code">VE-F</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-g">
-            <field name="name">Carabobo</field>
-            <field name="code">VE-G</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-h">
-            <field name="name">Cojedes</field>
-            <field name="code">VE-H</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-i">
-            <field name="name">Falcón</field>
-            <field name="code">VE-I</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-j">
-            <field name="name">Guárico</field>
-            <field name="code">VE-J</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-k">
-            <field name="name">Lara</field>
-            <field name="code">VE-K</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-l">
-            <field name="name">Mérida</field>
-            <field name="code">VE-L</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-m">
-            <field name="name">Miranda</field>
-            <field name="code">VE-M</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-n">
-            <field name="name">Monagas</field>
-            <field name="code">VE-N</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-o">
-            <field name="name">Nueva Esparta</field>
-            <field name="code">VE-O</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-p">
-            <field name="name">Portuguesa</field>
-            <field name="code">VE-P</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-r">
-            <field name="name">Sucre</field>
-            <field name="code">VE-R</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-s">
-            <field name="name">Táchira</field>
-            <field name="code">VE-S</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-t">
-            <field name="name">Trujillo</field>
-            <field name="code">VE-T</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-u">
-            <field name="name">Yaracuy</field>
-            <field name="code">VE-U</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-v">
-            <field name="name">Zulia</field>
-            <field name="code">VE-V</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-w">
-            <field name="name">Dependencias Federales</field>
-            <field name="code">VE-W</field>
-            <field name="type">federal dependency</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-x">
-            <field name="name">Vargas</field>
-            <field name="code">VE-X</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-y">
-            <field name="name">Delta Amacuro</field>
-            <field name="code">VE-Y</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="ve-z">
-            <field name="name">Amazonas</field>
-            <field name="code">VE-Z</field>
-            <field name="type">state</field>
-            <field name="country" ref="ve"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-01">
-            <field name="name">Lai Châu</field>
-            <field name="code">VN-01</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-02">
-            <field name="name">Lào Cai</field>
-            <field name="code">VN-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-03">
-            <field name="name">Hà Giang</field>
-            <field name="code">VN-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-04">
-            <field name="name">Cao Bằng</field>
-            <field name="code">VN-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-05">
-            <field name="name">Sơn La</field>
-            <field name="code">VN-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-06">
-            <field name="name">Yên Bái</field>
-            <field name="code">VN-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-07">
-            <field name="name">Tuyên Quang</field>
-            <field name="code">VN-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-09">
-            <field name="name">Lạng Sơn</field>
-            <field name="code">VN-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-13">
-            <field name="name">Quảng Ninh</field>
-            <field name="code">VN-13</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-14">
-            <field name="name">Hoà Bình</field>
-            <field name="code">VN-14</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-15">
-            <field name="name">Hà Tây</field>
-            <field name="code">VN-15</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-18">
-            <field name="name">Ninh Bình</field>
-            <field name="code">VN-18</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-20">
-            <field name="name">Thái Bình</field>
-            <field name="code">VN-20</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-21">
-            <field name="name">Thanh Hóa</field>
-            <field name="code">VN-21</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-22">
-            <field name="name">Nghệ An</field>
-            <field name="code">VN-22</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-23">
-            <field name="name">Hà Tỉnh</field>
-            <field name="code">VN-23</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-24">
-            <field name="name">Quảng Bình</field>
-            <field name="code">VN-24</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-25">
-            <field name="name">Quảng Trị</field>
-            <field name="code">VN-25</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-26">
-            <field name="name">Thừa Thiên-Huế</field>
-            <field name="code">VN-26</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-27">
-            <field name="name">Quảng Nam</field>
-            <field name="code">VN-27</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-28">
-            <field name="name">Kon Tum</field>
-            <field name="code">VN-28</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-29">
-            <field name="name">Quảng Ngãi</field>
-            <field name="code">VN-29</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-30">
-            <field name="name">Gia Lai</field>
-            <field name="code">VN-30</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-31">
-            <field name="name">Bình Định</field>
-            <field name="code">VN-31</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-32">
-            <field name="name">Phú Yên</field>
-            <field name="code">VN-32</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-33">
-            <field name="name">Đắc Lắk</field>
-            <field name="code">VN-33</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-34">
-            <field name="name">Khánh Hòa</field>
-            <field name="code">VN-34</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-35">
-            <field name="name">Lâm Đồng</field>
-            <field name="code">VN-35</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-36">
-            <field name="name">Ninh Thuận</field>
-            <field name="code">VN-36</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-37">
-            <field name="name">Tây Ninh</field>
-            <field name="code">VN-37</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-39">
-            <field name="name">Đồng Nai</field>
-            <field name="code">VN-39</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-40">
-            <field name="name">Bình Thuận</field>
-            <field name="code">VN-40</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-41">
-            <field name="name">Long An</field>
-            <field name="code">VN-41</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-43">
-            <field name="name">Bà Rịa-Vũng Tàu</field>
-            <field name="code">VN-43</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-44">
-            <field name="name">An Giang</field>
-            <field name="code">VN-44</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-45">
-            <field name="name">Đồng Tháp</field>
-            <field name="code">VN-45</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-46">
-            <field name="name">Tiền Giang</field>
-            <field name="code">VN-46</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-47">
-            <field name="name">Kiên Giang</field>
-            <field name="code">VN-47</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-49">
-            <field name="name">Vĩnh Long</field>
-            <field name="code">VN-49</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-50">
-            <field name="name">Bến Tre</field>
-            <field name="code">VN-50</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-51">
-            <field name="name">Trà Vinh</field>
-            <field name="code">VN-51</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-52">
-            <field name="name">Sóc Trăng</field>
-            <field name="code">VN-52</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-53">
-            <field name="name">Bắc Kạn</field>
-            <field name="code">VN-53</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-54">
-            <field name="name">Bắc Giang</field>
-            <field name="code">VN-54</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-55">
-            <field name="name">Bạc Liêu</field>
-            <field name="code">VN-55</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-56">
-            <field name="name">Bắc Ninh</field>
-            <field name="code">VN-56</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-57">
-            <field name="name">Bình Dương</field>
-            <field name="code">VN-57</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-58">
-            <field name="name">Bình Phước</field>
-            <field name="code">VN-58</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-59">
-            <field name="name">Cà Mau</field>
-            <field name="code">VN-59</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-61">
-            <field name="name">Hải Duong</field>
-            <field name="code">VN-61</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-63">
-            <field name="name">Hà Nam</field>
-            <field name="code">VN-63</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-66">
-            <field name="name">Hưng Yên</field>
-            <field name="code">VN-66</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-67">
-            <field name="name">Nam Định</field>
-            <field name="code">VN-67</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-68">
-            <field name="name">Phú Thọ</field>
-            <field name="code">VN-68</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-69">
-            <field name="name">Thái Nguyên</field>
-            <field name="code">VN-69</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-70">
-            <field name="name">Vĩnh Phúc</field>
-            <field name="code">VN-70</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-71">
-            <field name="name">Điện Biên</field>
-            <field name="code">VN-71</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-72">
-            <field name="name">Đắk Nông</field>
-            <field name="code">VN-72</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-73">
-            <field name="name">Hậu Giang</field>
-            <field name="code">VN-73</field>
-            <field name="type">province</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-ct">
-            <field name="name">Cần Thơ</field>
-            <field name="code">VN-CT</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-dn">
-            <field name="name">Đà Nẵng</field>
-            <field name="code">VN-DN</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-hn">
-            <field name="name">Hà Nội</field>
-            <field name="code">VN-HN</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-hp">
-            <field name="name">Hải Phòng</field>
-            <field name="code">VN-HP</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vn-sg">
-            <field name="name">Hồ Chí Minh [Sài Gòn]</field>
-            <field name="code">VN-SG</field>
-            <field name="type">municipality</field>
-            <field name="country" ref="vn"/>
-        </record>
-
-        <record model="country.subdivision" id="vu-map">
-            <field name="name">Malampa</field>
-            <field name="code">VU-MAP</field>
-            <field name="type">province</field>
-            <field name="country" ref="vu"/>
-        </record>
-
-        <record model="country.subdivision" id="vu-pam">
-            <field name="name">Pénama</field>
-            <field name="code">VU-PAM</field>
-            <field name="type">province</field>
-            <field name="country" ref="vu"/>
-        </record>
-
-        <record model="country.subdivision" id="vu-sam">
-            <field name="name">Sanma</field>
-            <field name="code">VU-SAM</field>
-            <field name="type">province</field>
-            <field name="country" ref="vu"/>
-        </record>
-
-        <record model="country.subdivision" id="vu-see">
-            <field name="name">Shéfa</field>
-            <field name="code">VU-SEE</field>
-            <field name="type">province</field>
-            <field name="country" ref="vu"/>
-        </record>
-
-        <record model="country.subdivision" id="vu-tae">
-            <field name="name">Taféa</field>
-            <field name="code">VU-TAE</field>
-            <field name="type">province</field>
-            <field name="country" ref="vu"/>
-        </record>
-
-        <record model="country.subdivision" id="vu-tob">
-            <field name="name">Torba</field>
-            <field name="code">VU-TOB</field>
-            <field name="type">province</field>
-            <field name="country" ref="vu"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-aa">
-            <field name="name">A'ana</field>
-            <field name="code">WS-AA</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-al">
-            <field name="name">Aiga-i-le-Tai</field>
-            <field name="code">WS-AL</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-at">
-            <field name="name">Atua</field>
-            <field name="code">WS-AT</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-fa">
-            <field name="name">Fa'asaleleaga</field>
-            <field name="code">WS-FA</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-ge">
-            <field name="name">Gaga'emauga</field>
-            <field name="code">WS-GE</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-gi">
-            <field name="name">Gagaifomauga</field>
-            <field name="code">WS-GI</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-pa">
-            <field name="name">Palauli</field>
-            <field name="code">WS-PA</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-sa">
-            <field name="name">Satupa'itea</field>
-            <field name="code">WS-SA</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-tu">
-            <field name="name">Tuamasaga</field>
-            <field name="code">WS-TU</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-vf">
-            <field name="name">Va'a-o-Fonoti</field>
-            <field name="code">WS-VF</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ws-vs">
-            <field name="name">Vaisigano</field>
-            <field name="code">WS-VS</field>
-            <field name="type">district</field>
-            <field name="country" ref="ws"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ab">
-            <field name="name">Abyān</field>
-            <field name="code">YE-AB</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ad">
-            <field name="name">'Adan</field>
-            <field name="code">YE-AD</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-am">
-            <field name="name">'Amrān</field>
-            <field name="code">YE-AM</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ba">
-            <field name="name">Al Bayḑā'</field>
-            <field name="code">YE-BA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-da">
-            <field name="name">Aḑ Ḑāli‘</field>
-            <field name="code">YE-DA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-dh">
-            <field name="name">Dhamār</field>
-            <field name="code">YE-DH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-hd">
-            <field name="name">Ḩaḑramawt</field>
-            <field name="code">YE-HD</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-hj">
-            <field name="name">Ḩajjah</field>
-            <field name="code">YE-HJ</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ib">
-            <field name="name">Ibb</field>
-            <field name="code">YE-IB</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ja">
-            <field name="name">Al Jawf</field>
-            <field name="code">YE-JA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-la">
-            <field name="name">Laḩij</field>
-            <field name="code">YE-LA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ma">
-            <field name="name">Ma'rib</field>
-            <field name="code">YE-MA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-mr">
-            <field name="name">Al Mahrah</field>
-            <field name="code">YE-MR</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-mu">
-            <field name="name">Al Ḩudaydah</field>
-            <field name="code">YE-MU</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-mw">
-            <field name="name">Al Maḩwīt</field>
-            <field name="code">YE-MW</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ra">
-            <field name="name">Raymah</field>
-            <field name="code">YE-RA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-sd">
-            <field name="name">Şa'dah</field>
-            <field name="code">YE-SD</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-sh">
-            <field name="name">Shabwah</field>
-            <field name="code">YE-SH</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-sn">
-            <field name="name">Şan'ā'</field>
-            <field name="code">YE-SN</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="ye-ta">
-            <field name="name">Tā'izz</field>
-            <field name="code">YE-TA</field>
-            <field name="type">governorate</field>
-            <field name="country" ref="ye"/>
-        </record>
-
-        <record model="country.subdivision" id="za-ec">
-            <field name="name">Eastern Cape</field>
-            <field name="code">ZA-EC</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-fs">
-            <field name="name">Free State</field>
-            <field name="code">ZA-FS</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-gt">
-            <field name="name">Gauteng</field>
-            <field name="code">ZA-GT</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-lp">
-            <field name="name">Limpopo</field>
-            <field name="code">ZA-LP</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-mp">
-            <field name="name">Mpumalanga</field>
-            <field name="code">ZA-MP</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-nc">
-            <field name="name">Northern Cape</field>
-            <field name="code">ZA-NC</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-nl">
-            <field name="name">Kwazulu-Natal</field>
-            <field name="code">ZA-NL</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-nw">
-            <field name="name">North-West (South Africa)</field>
-            <field name="code">ZA-NW</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="za-wc">
-            <field name="name">Western Cape</field>
-            <field name="code">ZA-WC</field>
-            <field name="type">province</field>
-            <field name="country" ref="za"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-01">
-            <field name="name">Western</field>
-            <field name="code">ZM-01</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-02">
-            <field name="name">Central</field>
-            <field name="code">ZM-02</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-03">
-            <field name="name">Eastern</field>
-            <field name="code">ZM-03</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-04">
-            <field name="name">Luapula</field>
-            <field name="code">ZM-04</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-05">
-            <field name="name">Northern</field>
-            <field name="code">ZM-05</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-06">
-            <field name="name">North-Western</field>
-            <field name="code">ZM-06</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-07">
-            <field name="name">Southern (Zambia)</field>
-            <field name="code">ZM-07</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-08">
-            <field name="name">Copperbelt</field>
-            <field name="code">ZM-08</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zm-09">
-            <field name="name">Lusaka</field>
-            <field name="code">ZM-09</field>
-            <field name="type">province</field>
-            <field name="country" ref="zm"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-bu">
-            <field name="name">Bulawayo</field>
-            <field name="code">ZW-BU</field>
-            <field name="type">city</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-ha">
-            <field name="name">Harare</field>
-            <field name="code">ZW-HA</field>
-            <field name="type">city</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-ma">
-            <field name="name">Manicaland</field>
-            <field name="code">ZW-MA</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-mc">
-            <field name="name">Mashonaland Central</field>
-            <field name="code">ZW-MC</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-me">
-            <field name="name">Mashonaland East</field>
-            <field name="code">ZW-ME</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-mi">
-            <field name="name">Midlands</field>
-            <field name="code">ZW-MI</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-mn">
-            <field name="name">Matabeleland North</field>
-            <field name="code">ZW-MN</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-ms">
-            <field name="name">Matabeleland South</field>
-            <field name="code">ZW-MS</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-mv">
-            <field name="name">Masvingo</field>
-            <field name="code">ZW-MV</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-
-        <record model="country.subdivision" id="zw-mw">
-            <field name="name">Mashonaland West</field>
-            <field name="code">ZW-MW</field>
-            <field name="type">province</field>
-            <field name="country" ref="zw"/>
-        </record>
-    </data>
-    <data skiptest="1" grouped="1">
-
-        <record model="country.subdivision" id="al-br">
-            <field name="name">Berat</field>
-            <field name="code">AL-BR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-01"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-bu">
-            <field name="name">Bulqizë</field>
-            <field name="code">AL-BU</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-09"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-di">
-            <field name="name">Dibër</field>
-            <field name="code">AL-DI</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-09"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-dl">
-            <field name="name">Delvinë</field>
-            <field name="code">AL-DL</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-12"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-dr">
-            <field name="name">Durrës</field>
-            <field name="code">AL-DR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-02"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-dv">
-            <field name="name">Devoll</field>
-            <field name="code">AL-DV</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-06"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-el">
-            <field name="name">Elbasan</field>
-            <field name="code">AL-EL</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-03"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-er">
-            <field name="name">Kolonjë</field>
-            <field name="code">AL-ER</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-06"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-fr">
-            <field name="name">Fier</field>
-            <field name="code">AL-FR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-04"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-gj">
-            <field name="name">Gjirokastër</field>
-            <field name="code">AL-GJ</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-05"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-gr">
-            <field name="name">Gramsh</field>
-            <field name="code">AL-GR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-03"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-ha">
-            <field name="name">Has</field>
-            <field name="code">AL-HA</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-07"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-ka">
-            <field name="name">Kavajë</field>
-            <field name="code">AL-KA</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-11"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-kb">
-            <field name="name">Kurbin</field>
-            <field name="code">AL-KB</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-08"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-kc">
-            <field name="name">Kuçovë</field>
-            <field name="code">AL-KC</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-01"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-ko">
-            <field name="name">Korçë</field>
-            <field name="code">AL-KO</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-06"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-kr">
-            <field name="name">Krujë</field>
-            <field name="code">AL-KR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-02"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-ku">
-            <field name="name">Kukës</field>
-            <field name="code">AL-KU</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-07"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-lb">
-            <field name="name">Librazhd</field>
-            <field name="code">AL-LB</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-03"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-le">
-            <field name="name">Lezhë</field>
-            <field name="code">AL-LE</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-08"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-lu">
-            <field name="name">Lushnjë</field>
-            <field name="code">AL-LU</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-04"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-mk">
-            <field name="name">Mallakastër</field>
-            <field name="code">AL-MK</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-04"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-mm">
-            <field name="name">Malësi e Madhe</field>
-            <field name="code">AL-MM</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-10"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-mr">
-            <field name="name">Mirditë</field>
-            <field name="code">AL-MR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-08"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-mt">
-            <field name="name">Mat</field>
-            <field name="code">AL-MT</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-09"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-pg">
-            <field name="name">Pogradec</field>
-            <field name="code">AL-PG</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-06"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-pq">
-            <field name="name">Peqin</field>
-            <field name="code">AL-PQ</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-03"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-pr">
-            <field name="name">Përmet</field>
-            <field name="code">AL-PR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-05"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-pu">
-            <field name="name">Pukë</field>
-            <field name="code">AL-PU</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-10"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-sh">
-            <field name="name">Shkodër</field>
-            <field name="code">AL-SH</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-10"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-sk">
-            <field name="name">Skrapar</field>
-            <field name="code">AL-SK</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-01"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-sr">
-            <field name="name">Sarandë</field>
-            <field name="code">AL-SR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-12"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-te">
-            <field name="name">Tepelenë</field>
-            <field name="code">AL-TE</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-05"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-tp">
-            <field name="name">Tropojë</field>
-            <field name="code">AL-TP</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-07"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-tr">
-            <field name="name">Tiranë</field>
-            <field name="code">AL-TR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-11"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="al-vl">
-            <field name="name">Vlorë</field>
-            <field name="code">AL-VL</field>
-            <field name="type">district</field>
-            <field name="parent" ref="al-12"/>
-            <field name="country" ref="al"/>
-        </record>
-
-        <record model="country.subdivision" id="az-bab">
-            <field name="name">Babək</field>
-            <field name="code">AZ-BAB</field>
-            <field name="type">rayon</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-cul">
-            <field name="name">Culfa</field>
-            <field name="code">AZ-CUL</field>
-            <field name="type">rayon</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-kan">
-            <field name="name">Kǝngǝrli</field>
-            <field name="code">AZ-KAN</field>
-            <field name="type">rayon</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-nv">
-            <field name="name">Naxçıvan</field>
-            <field name="code">AZ-NV</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-ord">
-            <field name="name">Ordubad</field>
-            <field name="code">AZ-ORD</field>
-            <field name="type">rayon</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sad">
-            <field name="name">Sədərək</field>
-            <field name="code">AZ-SAD</field>
-            <field name="type">rayon</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sah">
-            <field name="name">Şahbuz</field>
-            <field name="code">AZ-SAH</field>
-            <field name="type">rayon</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="az-sar">
-            <field name="name">Şərur</field>
-            <field name="code">AZ-SAR</field>
-            <field name="type">rayon</field>
-            <field name="parent" ref="az-nx"/>
-            <field name="country" ref="az"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-01">
-            <field name="name">Unsko-sanski kanton</field>
-            <field name="code">BA-01</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-02">
-            <field name="name">Posavski kanton</field>
-            <field name="code">BA-02</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-03">
-            <field name="name">Tuzlanski kanton</field>
-            <field name="code">BA-03</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-04">
-            <field name="name">Zeničko-dobojski kanton</field>
-            <field name="code">BA-04</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-05">
-            <field name="name">Bosansko-podrinjski kanton</field>
-            <field name="code">BA-05</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-06">
-            <field name="name">Srednjobosanski kanton</field>
-            <field name="code">BA-06</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-07">
-            <field name="name">Hercegovačko-neretvanski kanton</field>
-            <field name="code">BA-07</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-08">
-            <field name="name">Zapadnohercegovački kanton</field>
-            <field name="code">BA-08</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-09">
-            <field name="name">Kanton Sarajevo</field>
-            <field name="code">BA-09</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="ba-10">
-            <field name="name">Kanton br. 10 (Livanjski kanton)</field>
-            <field name="code">BA-10</field>
-            <field name="type">canton</field>
-            <field name="parent" ref="ba-bih"/>
-            <field name="country" ref="ba"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-01">
-            <field name="name">Bandarban</field>
-            <field name="code">BD-01</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-02">
-            <field name="name">Barguna</field>
-            <field name="code">BD-02</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-a"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-03">
-            <field name="name">Bogra</field>
-            <field name="code">BD-03</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-04">
-            <field name="name">Brahmanbaria</field>
-            <field name="code">BD-04</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-05">
-            <field name="name">Bagerhat</field>
-            <field name="code">BD-05</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-06">
-            <field name="name">Barisal</field>
-            <field name="code">BD-06</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-a"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-07">
-            <field name="name">Bhola</field>
-            <field name="code">BD-07</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-a"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-08">
-            <field name="name">Comilla</field>
-            <field name="code">BD-08</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-09">
-            <field name="name">Chandpur</field>
-            <field name="code">BD-09</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-10">
-            <field name="name">Chittagong</field>
-            <field name="code">BD-10</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-11">
-            <field name="name">Cox's Bazar</field>
-            <field name="code">BD-11</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-12">
-            <field name="name">Chuadanga</field>
-            <field name="code">BD-12</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-13">
-            <field name="name">Dhaka</field>
-            <field name="code">BD-13</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-14">
-            <field name="name">Dinajpur</field>
-            <field name="code">BD-14</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-15">
-            <field name="name">Faridpur</field>
-            <field name="code">BD-15</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-16">
-            <field name="name">Feni</field>
-            <field name="code">BD-16</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-17">
-            <field name="name">Gopalganj</field>
-            <field name="code">BD-17</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-18">
-            <field name="name">Gazipur</field>
-            <field name="code">BD-18</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-19">
-            <field name="name">Gaibandha</field>
-            <field name="code">BD-19</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-20">
-            <field name="name">Habiganj</field>
-            <field name="code">BD-20</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-g"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-21">
-            <field name="name">Jamalpur</field>
-            <field name="code">BD-21</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-22">
-            <field name="name">Jessore</field>
-            <field name="code">BD-22</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-23">
-            <field name="name">Jhenaidah</field>
-            <field name="code">BD-23</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-24">
-            <field name="name">Jaipurhat</field>
-            <field name="code">BD-24</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-25">
-            <field name="name">Jhalakati</field>
-            <field name="code">BD-25</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-a"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-26">
-            <field name="name">Kishorganj</field>
-            <field name="code">BD-26</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-27">
-            <field name="name">Khulna</field>
-            <field name="code">BD-27</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-28">
-            <field name="name">Kurigram</field>
-            <field name="code">BD-28</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-29">
-            <field name="name">Khagrachari</field>
-            <field name="code">BD-29</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-30">
-            <field name="name">Kushtia</field>
-            <field name="code">BD-30</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-31">
-            <field name="name">Lakshmipur</field>
-            <field name="code">BD-31</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-32">
-            <field name="name">Lalmonirhat</field>
-            <field name="code">BD-32</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-33">
-            <field name="name">Manikganj</field>
-            <field name="code">BD-33</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-34">
-            <field name="name">Mymensingh</field>
-            <field name="code">BD-34</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-35">
-            <field name="name">Munshiganj</field>
-            <field name="code">BD-35</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-36">
-            <field name="name">Madaripur</field>
-            <field name="code">BD-36</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-37">
-            <field name="name">Magura</field>
-            <field name="code">BD-37</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-38">
-            <field name="name">Moulvibazar</field>
-            <field name="code">BD-38</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-g"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-39">
-            <field name="name">Meherpur</field>
-            <field name="code">BD-39</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-40">
-            <field name="name">Narayanganj</field>
-            <field name="code">BD-40</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-41">
-            <field name="name">Netrakona</field>
-            <field name="code">BD-41</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-42">
-            <field name="name">Narsingdi</field>
-            <field name="code">BD-42</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-43">
-            <field name="name">Narail</field>
-            <field name="code">BD-43</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-44">
-            <field name="name">Natore</field>
-            <field name="code">BD-44</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-45">
-            <field name="name">Nawabganj</field>
-            <field name="code">BD-45</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-46">
-            <field name="name">Nilphamari</field>
-            <field name="code">BD-46</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-47">
-            <field name="name">Noakhali</field>
-            <field name="code">BD-47</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-48">
-            <field name="name">Naogaon</field>
-            <field name="code">BD-48</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-49">
-            <field name="name">Pabna</field>
-            <field name="code">BD-49</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-50">
-            <field name="name">Pirojpur</field>
-            <field name="code">BD-50</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-a"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-51">
-            <field name="name">Patuakhali</field>
-            <field name="code">BD-51</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-a"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-52">
-            <field name="name">Panchagarh</field>
-            <field name="code">BD-52</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-53">
-            <field name="name">Rajbari</field>
-            <field name="code">BD-53</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-54">
-            <field name="name">Rajshahi</field>
-            <field name="code">BD-54</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-55">
-            <field name="name">Rangpur</field>
-            <field name="code">BD-55</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-56">
-            <field name="name">Rangamati</field>
-            <field name="code">BD-56</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-b"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-57">
-            <field name="name">Sherpur</field>
-            <field name="code">BD-57</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-58">
-            <field name="name">Satkhira</field>
-            <field name="code">BD-58</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-d"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-59">
-            <field name="name">Sirajganj</field>
-            <field name="code">BD-59</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-e"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-60">
-            <field name="name">Sylhet</field>
-            <field name="code">BD-60</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-g"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-61">
-            <field name="name">Sunamganj</field>
-            <field name="code">BD-61</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-g"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-62">
-            <field name="name">Shariatpur</field>
-            <field name="code">BD-62</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-63">
-            <field name="name">Tangail</field>
-            <field name="code">BD-63</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-c"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="bd-64">
-            <field name="name">Thakurgaon</field>
-            <field name="code">BD-64</field>
-            <field name="type">district</field>
-            <field name="parent" ref="bd-f"/>
-            <field name="country" ref="bd"/>
-        </record>
-
-        <record model="country.subdivision" id="be-van">
-            <field name="name">Antwerpen</field>
-            <field name="code">BE-VAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-vlg"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-vbr">
-            <field name="name">Vlaams-Brabant</field>
-            <field name="code">BE-VBR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-vlg"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-vli">
-            <field name="name">Limburg</field>
-            <field name="code">BE-VLI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-vlg"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-vov">
-            <field name="name">Oost-Vlaanderen</field>
-            <field name="code">BE-VOV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-vlg"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-vwv">
-            <field name="name">West-Vlaanderen</field>
-            <field name="code">BE-VWV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-vlg"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-wbr">
-            <field name="name">Brabant wallon</field>
-            <field name="code">BE-WBR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-wal"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-wht">
-            <field name="name">Hainaut</field>
-            <field name="code">BE-WHT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-wal"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-wlg">
-            <field name="name">Liège</field>
-            <field name="code">BE-WLG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-wal"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-wlx">
-            <field name="name">Luxembourg</field>
-            <field name="code">BE-WLX</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-wal"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="be-wna">
-            <field name="name">Namur</field>
-            <field name="code">BE-WNA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="be-wal"/>
-            <field name="country" ref="be"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-bal">
-            <field name="name">Balé</field>
-            <field name="code">BF-BAL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-01"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-bam">
-            <field name="name">Bam</field>
-            <field name="code">BF-BAM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-05"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-ban">
-            <field name="name">Banwa</field>
-            <field name="code">BF-BAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-01"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-baz">
-            <field name="name">Bazèga</field>
-            <field name="code">BF-BAZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-07"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-bgr">
-            <field name="name">Bougouriba</field>
-            <field name="code">BF-BGR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-13"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-blg">
-            <field name="name">Boulgou</field>
-            <field name="code">BF-BLG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-04"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-blk">
-            <field name="name">Boulkiemdé</field>
-            <field name="code">BF-BLK</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-06"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-com">
-            <field name="name">Comoé</field>
-            <field name="code">BF-COM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-02"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-gan">
-            <field name="name">Ganzourgou</field>
-            <field name="code">BF-GAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-11"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-gna">
-            <field name="name">Gnagna</field>
-            <field name="code">BF-GNA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-08"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-gou">
-            <field name="name">Gourma</field>
-            <field name="code">BF-GOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-08"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-hou">
-            <field name="name">Houet</field>
-            <field name="code">BF-HOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-09"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-iob">
-            <field name="name">Ioba</field>
-            <field name="code">BF-IOB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-13"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-kad">
-            <field name="name">Kadiogo</field>
-            <field name="code">BF-KAD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-03"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-ken">
-            <field name="name">Kénédougou</field>
-            <field name="code">BF-KEN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-09"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-kmd">
-            <field name="name">Komondjari</field>
-            <field name="code">BF-KMD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-08"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-kmp">
-            <field name="name">Kompienga</field>
-            <field name="code">BF-KMP</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-08"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-kop">
-            <field name="name">Koulpélogo</field>
-            <field name="code">BF-KOP</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-04"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-kos">
-            <field name="name">Kossi</field>
-            <field name="code">BF-KOS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-01"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-kot">
-            <field name="name">Kouritenga</field>
-            <field name="code">BF-KOT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-04"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-kow">
-            <field name="name">Kourwéogo</field>
-            <field name="code">BF-KOW</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-11"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-ler">
-            <field name="name">Léraba</field>
-            <field name="code">BF-LER</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-02"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-lor">
-            <field name="name">Loroum</field>
-            <field name="code">BF-LOR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-10"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-mou">
-            <field name="name">Mouhoun</field>
-            <field name="code">BF-MOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-01"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-nam">
-            <field name="name">Namentenga</field>
-            <field name="code">BF-NAM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-05"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-nao">
-            <field name="name">Naouri</field>
-            <field name="code">BF-NAO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-07"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-nay">
-            <field name="name">Nayala</field>
-            <field name="code">BF-NAY</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-01"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-nou">
-            <field name="name">Noumbiel</field>
-            <field name="code">BF-NOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-13"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-oub">
-            <field name="name">Oubritenga</field>
-            <field name="code">BF-OUB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-11"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-oud">
-            <field name="name">Oudalan</field>
-            <field name="code">BF-OUD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-12"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-pas">
-            <field name="name">Passoré</field>
-            <field name="code">BF-PAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-10"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-pon">
-            <field name="name">Poni</field>
-            <field name="code">BF-PON</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-13"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-sen">
-            <field name="name">Séno</field>
-            <field name="code">BF-SEN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-12"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-sis">
-            <field name="name">Sissili</field>
-            <field name="code">BF-SIS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-06"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-smt">
-            <field name="name">Sanmatenga</field>
-            <field name="code">BF-SMT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-05"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-sng">
-            <field name="name">Sanguié</field>
-            <field name="code">BF-SNG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-06"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-som">
-            <field name="name">Soum</field>
-            <field name="code">BF-SOM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-12"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-sor">
-            <field name="name">Sourou</field>
-            <field name="code">BF-SOR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-01"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-tap">
-            <field name="name">Tapoa</field>
-            <field name="code">BF-TAP</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-08"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-tui">
-            <field name="name">Tui</field>
-            <field name="code">BF-TUI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-09"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-yag">
-            <field name="name">Yagha</field>
-            <field name="code">BF-YAG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-12"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-yat">
-            <field name="name">Yatenga</field>
-            <field name="code">BF-YAT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-10"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-zir">
-            <field name="name">Ziro</field>
-            <field name="code">BF-ZIR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-06"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-zon">
-            <field name="name">Zondoma</field>
-            <field name="code">BF-ZON</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-10"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="bf-zou">
-            <field name="name">Zoundwéogo</field>
-            <field name="code">BF-ZOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="bf-07"/>
-            <field name="country" ref="bf"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-br">
-            <field name="name">Brava</field>
-            <field name="code">CV-BR</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-bv">
-            <field name="name">Boa Vista</field>
-            <field name="code">CV-BV</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-b"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-ca">
-            <field name="name">Santa Catarina</field>
-            <field name="code">CV-CA</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-cf">
-            <field name="name">Santa Catarina de Fogo</field>
-            <field name="code">CV-CF</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-cr">
-            <field name="name">Santa Cruz</field>
-            <field name="code">CV-CR</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-ma">
-            <field name="name">Maio</field>
-            <field name="code">CV-MA</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-mo">
-            <field name="name">Mosteiros</field>
-            <field name="code">CV-MO</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-pa">
-            <field name="name">Paul</field>
-            <field name="code">CV-PA</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-b"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-pn">
-            <field name="name">Porto Novo</field>
-            <field name="code">CV-PN</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-b"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-pr">
-            <field name="name">Praia</field>
-            <field name="code">CV-PR</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-rb">
-            <field name="name">Ribeira Brava</field>
-            <field name="code">CV-RB</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-b"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-rg">
-            <field name="name">Ribeira Grande</field>
-            <field name="code">CV-RG</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-b"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-rs">
-            <field name="name">Ribeira Grande de Santiago</field>
-            <field name="code">CV-RS</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-sd">
-            <field name="name">São Domingos</field>
-            <field name="code">CV-SD</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-sf">
-            <field name="name">São Filipe</field>
-            <field name="code">CV-SF</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-sl">
-            <field name="name">Sal</field>
-            <field name="code">CV-SL</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-b"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-sm">
-            <field name="name">São Miguel</field>
-            <field name="code">CV-SM</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-so">
-            <field name="name">São Lourenço dos Órgãos</field>
-            <field name="code">CV-SO</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-ss">
-            <field name="name">São Salvador do Mundo</field>
-            <field name="code">CV-SS</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-sv">
-            <field name="name">São Vicente</field>
-            <field name="code">CV-SV</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-b"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-ta">
-            <field name="name">Tarrafal</field>
-            <field name="code">CV-TA</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cv-ts">
-            <field name="name">Tarrafal de São Nicolau</field>
-            <field name="code">CV-TS</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="cv-s"/>
-            <field name="country" ref="cv"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-101">
-            <field name="name">Praha 1</field>
-            <field name="code">CZ-101</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-102">
-            <field name="name">Praha 2</field>
-            <field name="code">CZ-102</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-103">
-            <field name="name">Praha 3</field>
-            <field name="code">CZ-103</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-104">
-            <field name="name">Praha 4</field>
-            <field name="code">CZ-104</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-105">
-            <field name="name">Praha 5</field>
-            <field name="code">CZ-105</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-106">
-            <field name="name">Praha 6</field>
-            <field name="code">CZ-106</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-107">
-            <field name="name">Praha 7</field>
-            <field name="code">CZ-107</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-108">
-            <field name="name">Praha 8</field>
-            <field name="code">CZ-108</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-109">
-            <field name="name">Praha 9</field>
-            <field name="code">CZ-109</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-110">
-            <field name="name">Praha 10</field>
-            <field name="code">CZ-110</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-111">
-            <field name="name">Praha 11</field>
-            <field name="code">CZ-111</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-112">
-            <field name="name">Praha 12</field>
-            <field name="code">CZ-112</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-113">
-            <field name="name">Praha 13</field>
-            <field name="code">CZ-113</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-114">
-            <field name="name">Praha 14</field>
-            <field name="code">CZ-114</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-115">
-            <field name="name">Praha 15</field>
-            <field name="code">CZ-115</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-116">
-            <field name="name">Praha 16</field>
-            <field name="code">CZ-116</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-117">
-            <field name="name">Praha 17</field>
-            <field name="code">CZ-117</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-118">
-            <field name="name">Praha 18</field>
-            <field name="code">CZ-118</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-119">
-            <field name="name">Praha 19</field>
-            <field name="code">CZ-119</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-120">
-            <field name="name">Praha 20</field>
-            <field name="code">CZ-120</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-121">
-            <field name="name">Praha 21</field>
-            <field name="code">CZ-121</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-122">
-            <field name="name">Praha 22</field>
-            <field name="code">CZ-122</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-10"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-201">
-            <field name="name">Benešov</field>
-            <field name="code">CZ-201</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-202">
-            <field name="name">Beroun</field>
-            <field name="code">CZ-202</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-203">
-            <field name="name">Kladno</field>
-            <field name="code">CZ-203</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-204">
-            <field name="name">Kolín</field>
-            <field name="code">CZ-204</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-205">
-            <field name="name">Kutná Hora</field>
-            <field name="code">CZ-205</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-206">
-            <field name="name">Mělník</field>
-            <field name="code">CZ-206</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-207">
-            <field name="name">Mladá Boleslav</field>
-            <field name="code">CZ-207</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-208">
-            <field name="name">Nymburk</field>
-            <field name="code">CZ-208</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-209">
-            <field name="name">Praha-východ</field>
-            <field name="code">CZ-209</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-20a">
-            <field name="name">Praha-západ</field>
-            <field name="code">CZ-20A</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-20b">
-            <field name="name">Příbram</field>
-            <field name="code">CZ-20B</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-20c">
-            <field name="name">Rakovník</field>
-            <field name="code">CZ-20C</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-20"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-311">
-            <field name="name">České Budějovice</field>
-            <field name="code">CZ-311</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-31"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-312">
-            <field name="name">Český Krumlov</field>
-            <field name="code">CZ-312</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-31"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-313">
-            <field name="name">Jindřichův Hradec</field>
-            <field name="code">CZ-313</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-31"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-314">
-            <field name="name">Písek</field>
-            <field name="code">CZ-314</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-31"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-315">
-            <field name="name">Prachatice</field>
-            <field name="code">CZ-315</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-31"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-316">
-            <field name="name">Strakonice</field>
-            <field name="code">CZ-316</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-31"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-317">
-            <field name="name">Tábor</field>
-            <field name="code">CZ-317</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-31"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-321">
-            <field name="name">Domažlice</field>
-            <field name="code">CZ-321</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-32"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-322">
-            <field name="name">Klatovy</field>
-            <field name="code">CZ-322</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-32"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-323">
-            <field name="name">Plzeň-město</field>
-            <field name="code">CZ-323</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-32"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-324">
-            <field name="name">Plzeň-jih</field>
-            <field name="code">CZ-324</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-32"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-325">
-            <field name="name">Plzeň-sever</field>
-            <field name="code">CZ-325</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-32"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-326">
-            <field name="name">Rokycany</field>
-            <field name="code">CZ-326</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-32"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-327">
-            <field name="name">Tachov</field>
-            <field name="code">CZ-327</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-32"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-411">
-            <field name="name">Cheb</field>
-            <field name="code">CZ-411</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-41"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-412">
-            <field name="name">Karlovy Vary</field>
-            <field name="code">CZ-412</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-41"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-413">
-            <field name="name">Sokolov</field>
-            <field name="code">CZ-413</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-41"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-421">
-            <field name="name">Děčín</field>
-            <field name="code">CZ-421</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-42"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-422">
-            <field name="name">Chomutov</field>
-            <field name="code">CZ-422</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-42"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-423">
-            <field name="name">Litoměřice</field>
-            <field name="code">CZ-423</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-42"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-424">
-            <field name="name">Louny</field>
-            <field name="code">CZ-424</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-42"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-425">
-            <field name="name">Most</field>
-            <field name="code">CZ-425</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-42"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-426">
-            <field name="name">Teplice</field>
-            <field name="code">CZ-426</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-42"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-427">
-            <field name="name">Ústí nad Labem</field>
-            <field name="code">CZ-427</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-42"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-511">
-            <field name="name">Česká Lípa</field>
-            <field name="code">CZ-511</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-51"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-512">
-            <field name="name">Jablonec nad Nisou</field>
-            <field name="code">CZ-512</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-51"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-513">
-            <field name="name">Liberec</field>
-            <field name="code">CZ-513</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-51"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-514">
-            <field name="name">Semily</field>
-            <field name="code">CZ-514</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-51"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-521">
-            <field name="name">Hradec Králové</field>
-            <field name="code">CZ-521</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-52"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-522">
-            <field name="name">Jičín</field>
-            <field name="code">CZ-522</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-52"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-523">
-            <field name="name">Náchod</field>
-            <field name="code">CZ-523</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-52"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-524">
-            <field name="name">Rychnov nad Kněžnou</field>
-            <field name="code">CZ-524</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-52"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-525">
-            <field name="name">Trutnov</field>
-            <field name="code">CZ-525</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-52"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-531">
-            <field name="name">Chrudim</field>
-            <field name="code">CZ-531</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-53"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-532">
-            <field name="name">Pardubice</field>
-            <field name="code">CZ-532</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-53"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-533">
-            <field name="name">Svitavy</field>
-            <field name="code">CZ-533</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-53"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-534">
-            <field name="name">Ústí nad Orlicí</field>
-            <field name="code">CZ-534</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-53"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-631">
-            <field name="name">Havlíčkův Brod</field>
-            <field name="code">CZ-631</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-63"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-632">
-            <field name="name">Jihlava</field>
-            <field name="code">CZ-632</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-63"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-633">
-            <field name="name">Pelhřimov</field>
-            <field name="code">CZ-633</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-63"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-634">
-            <field name="name">Třebíč</field>
-            <field name="code">CZ-634</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-63"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-635">
-            <field name="name">Žďár nad Sázavou</field>
-            <field name="code">CZ-635</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-63"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-641">
-            <field name="name">Blansko</field>
-            <field name="code">CZ-641</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-64"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-642">
-            <field name="name">Brno-město</field>
-            <field name="code">CZ-642</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-64"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-643">
-            <field name="name">Brno-venkov</field>
-            <field name="code">CZ-643</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-64"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-644">
-            <field name="name">Břeclav</field>
-            <field name="code">CZ-644</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-64"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-645">
-            <field name="name">Hodonín</field>
-            <field name="code">CZ-645</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-64"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-646">
-            <field name="name">Vyškov</field>
-            <field name="code">CZ-646</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-64"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-647">
-            <field name="name">Znojmo</field>
-            <field name="code">CZ-647</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-64"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-711">
-            <field name="name">Jeseník</field>
-            <field name="code">CZ-711</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-71"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-712">
-            <field name="name">Olomouc</field>
-            <field name="code">CZ-712</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-71"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-713">
-            <field name="name">Prostějov</field>
-            <field name="code">CZ-713</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-71"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-714">
-            <field name="name">Přerov</field>
-            <field name="code">CZ-714</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-71"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-715">
-            <field name="name">Šumperk</field>
-            <field name="code">CZ-715</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-71"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-721">
-            <field name="name">Kroměříž</field>
-            <field name="code">CZ-721</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-72"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-722">
-            <field name="name">Uherské Hradiště</field>
-            <field name="code">CZ-722</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-72"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-723">
-            <field name="name">Vsetín</field>
-            <field name="code">CZ-723</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-72"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-724">
-            <field name="name">Zlín</field>
-            <field name="code">CZ-724</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-72"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-801">
-            <field name="name">Bruntál</field>
-            <field name="code">CZ-801</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-80"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-802">
-            <field name="name">Frýdek Místek</field>
-            <field name="code">CZ-802</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-80"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-803">
-            <field name="name">Karviná</field>
-            <field name="code">CZ-803</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-80"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-804">
-            <field name="name">Nový Jičín</field>
-            <field name="code">CZ-804</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-80"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-805">
-            <field name="name">Opava</field>
-            <field name="code">CZ-805</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-80"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="cz-806">
-            <field name="name">Ostrava-město</field>
-            <field name="code">CZ-806</field>
-            <field name="type">district</field>
-            <field name="parent" ref="cz-80"/>
-            <field name="country" ref="cz"/>
-        </record>
-
-        <record model="country.subdivision" id="es-a">
-            <field name="name">Alicante</field>
-            <field name="code">ES-A</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-vc"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ab">
-            <field name="name">Albacete</field>
-            <field name="code">ES-AB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cm"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-al">
-            <field name="name">Almería</field>
-            <field name="code">ES-AL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-av">
-            <field name="name">Ávila</field>
-            <field name="code">ES-AV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-b">
-            <field name="name">Barcelona</field>
-            <field name="code">ES-B</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ct"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ba">
-            <field name="name">Badajoz</field>
-            <field name="code">ES-BA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ex"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-bi">
-            <field name="name">Bizkaia</field>
-            <field name="code">ES-BI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-pv"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-bu">
-            <field name="name">Burgos</field>
-            <field name="code">ES-BU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-c">
-            <field name="name">A Coruña</field>
-            <field name="code">ES-C</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ga"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ca">
-            <field name="name">Cádiz</field>
-            <field name="code">ES-CA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cc">
-            <field name="name">Cáceres</field>
-            <field name="code">ES-CC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ex"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-co">
-            <field name="name">Córdoba</field>
-            <field name="code">ES-CO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cr">
-            <field name="name">Ciudad Real</field>
-            <field name="code">ES-CR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cm"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cs">
-            <field name="name">Castellón</field>
-            <field name="code">ES-CS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-vc"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-cu">
-            <field name="name">Cuenca</field>
-            <field name="code">ES-CU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cm"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-gc">
-            <field name="name">Las Palmas</field>
-            <field name="code">ES-GC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cn"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-gi">
-            <field name="name">Girona</field>
-            <field name="code">ES-GI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ct"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-gr">
-            <field name="name">Granada</field>
-            <field name="code">ES-GR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-gu">
-            <field name="name">Guadalajara</field>
-            <field name="code">ES-GU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cm"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-h">
-            <field name="name">Huelva</field>
-            <field name="code">ES-H</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-hu">
-            <field name="name">Huesca</field>
-            <field name="code">ES-HU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ar"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-j">
-            <field name="name">Jaén</field>
-            <field name="code">ES-J</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-l">
-            <field name="name">Lleida</field>
-            <field name="code">ES-L</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ct"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-le">
-            <field name="name">León</field>
-            <field name="code">ES-LE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-lo">
-            <field name="name">La Rioja</field>
-            <field name="code">ES-LO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ri"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-lu">
-            <field name="name">Lugo</field>
-            <field name="code">ES-LU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ga"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-m">
-            <field name="name">Madrid</field>
-            <field name="code">ES-M</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-md"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ma">
-            <field name="name">Málaga</field>
-            <field name="code">ES-MA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-mu">
-            <field name="name">Murcia</field>
-            <field name="code">ES-MU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-mc"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-na">
-            <field name="name">Navarra / Nafarroa</field>
-            <field name="code">ES-NA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-nc"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-o">
-            <field name="name">Asturias</field>
-            <field name="code">ES-O</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-as"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-or">
-            <field name="name">Ourense</field>
-            <field name="code">ES-OR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ga"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-p">
-            <field name="name">Palencia</field>
-            <field name="code">ES-P</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-pm">
-            <field name="name">Balears</field>
-            <field name="code">ES-PM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ib"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-po">
-            <field name="name">Pontevedra</field>
-            <field name="code">ES-PO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ga"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-s">
-            <field name="name">Cantabria</field>
-            <field name="code">ES-S</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cb"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-sa">
-            <field name="name">Salamanca</field>
-            <field name="code">ES-SA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-se">
-            <field name="name">Sevilla</field>
-            <field name="code">ES-SE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-an"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-sg">
-            <field name="name">Segovia</field>
-            <field name="code">ES-SG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-so">
-            <field name="name">Soria</field>
-            <field name="code">ES-SO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-ss">
-            <field name="name">Gipuzkoa</field>
-            <field name="code">ES-SS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-pv"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-t">
-            <field name="name">Tarragona</field>
-            <field name="code">ES-T</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ct"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-te">
-            <field name="name">Teruel</field>
-            <field name="code">ES-TE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ar"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-tf">
-            <field name="name">Santa Cruz de Tenerife</field>
-            <field name="code">ES-TF</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cn"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-to">
-            <field name="name">Toledo</field>
-            <field name="code">ES-TO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cm"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-v">
-            <field name="name">Valencia / València</field>
-            <field name="code">ES-V</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-vc"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-va">
-            <field name="name">Valladolid</field>
-            <field name="code">ES-VA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-vi">
-            <field name="name">Álava</field>
-            <field name="code">ES-VI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-pv"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-z">
-            <field name="name">Zaragoza</field>
-            <field name="code">ES-Z</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-ar"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="es-za">
-            <field name="name">Zamora</field>
-            <field name="code">ES-ZA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="es-cl"/>
-            <field name="country" ref="es"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-01">
-            <field name="name">Ain</field>
-            <field name="code">FR-01</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-02">
-            <field name="name">Aisne</field>
-            <field name="code">FR-02</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-hdf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-03">
-            <field name="name">Allier</field>
-            <field name="code">FR-03</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-04">
-            <field name="name">Alpes-de-Haute-Provence</field>
-            <field name="code">FR-04</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pac"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-05">
-            <field name="name">Hautes-Alpes</field>
-            <field name="code">FR-05</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pac"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-06">
-            <field name="name">Alpes-Maritimes</field>
-            <field name="code">FR-06</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pac"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-07">
-            <field name="name">Ardèche</field>
-            <field name="code">FR-07</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-08">
-            <field name="name">Ardennes</field>
-            <field name="code">FR-08</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-09">
-            <field name="name">Ariège</field>
-            <field name="code">FR-09</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-10">
-            <field name="name">Aube</field>
-            <field name="code">FR-10</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-11">
-            <field name="name">Aude</field>
-            <field name="code">FR-11</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-12">
-            <field name="name">Aveyron</field>
-            <field name="code">FR-12</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-13">
-            <field name="name">Bouches-du-Rhône</field>
-            <field name="code">FR-13</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pac"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-14">
-            <field name="name">Calvados</field>
-            <field name="code">FR-14</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-nor"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-15">
-            <field name="name">Cantal</field>
-            <field name="code">FR-15</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-16">
-            <field name="name">Charente</field>
-            <field name="code">FR-16</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-17">
-            <field name="name">Charente-Maritime</field>
-            <field name="code">FR-17</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-18">
-            <field name="name">Cher</field>
-            <field name="code">FR-18</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cvl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-19">
-            <field name="name">Corrèze</field>
-            <field name="code">FR-19</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-21">
-            <field name="name">Côte-d'Or</field>
-            <field name="code">FR-21</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-22">
-            <field name="name">Côtes-d'Armor</field>
-            <field name="code">FR-22</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bre"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-23">
-            <field name="name">Creuse</field>
-            <field name="code">FR-23</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-24">
-            <field name="name">Dordogne</field>
-            <field name="code">FR-24</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-25">
-            <field name="name">Doubs</field>
-            <field name="code">FR-25</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-26">
-            <field name="name">Drôme</field>
-            <field name="code">FR-26</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-27">
-            <field name="name">Eure</field>
-            <field name="code">FR-27</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-nor"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-28">
-            <field name="name">Eure-et-Loir</field>
-            <field name="code">FR-28</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cvl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-29">
-            <field name="name">Finistère</field>
-            <field name="code">FR-29</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bre"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-2a">
-            <field name="name">Corse-du-Sud</field>
-            <field name="code">FR-2A</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cor"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-2b">
-            <field name="name">Haute-Corse</field>
-            <field name="code">FR-2B</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cor"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-30">
-            <field name="name">Gard</field>
-            <field name="code">FR-30</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-31">
-            <field name="name">Haute-Garonne</field>
-            <field name="code">FR-31</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-32">
-            <field name="name">Gers</field>
-            <field name="code">FR-32</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-33">
-            <field name="name">Gironde</field>
-            <field name="code">FR-33</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-34">
-            <field name="name">Hérault</field>
-            <field name="code">FR-34</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-35">
-            <field name="name">Ille-et-Vilaine</field>
-            <field name="code">FR-35</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bre"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-36">
-            <field name="name">Indre</field>
-            <field name="code">FR-36</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cvl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-37">
-            <field name="name">Indre-et-Loire</field>
-            <field name="code">FR-37</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cvl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-38">
-            <field name="name">Isère</field>
-            <field name="code">FR-38</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-39">
-            <field name="name">Jura</field>
-            <field name="code">FR-39</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-40">
-            <field name="name">Landes</field>
-            <field name="code">FR-40</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-41">
-            <field name="name">Loir-et-Cher</field>
-            <field name="code">FR-41</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cvl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-42">
-            <field name="name">Loire</field>
-            <field name="code">FR-42</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-43">
-            <field name="name">Haute-Loire</field>
-            <field name="code">FR-43</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-44">
-            <field name="name">Loire-Atlantique</field>
-            <field name="code">FR-44</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pdl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-45">
-            <field name="name">Loiret</field>
-            <field name="code">FR-45</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-cvl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-46">
-            <field name="name">Lot</field>
-            <field name="code">FR-46</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-47">
-            <field name="name">Lot-et-Garonne</field>
-            <field name="code">FR-47</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-48">
-            <field name="name">Lozère</field>
-            <field name="code">FR-48</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-49">
-            <field name="name">Maine-et-Loire</field>
-            <field name="code">FR-49</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pdl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-50">
-            <field name="name">Manche</field>
-            <field name="code">FR-50</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-nor"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-51">
-            <field name="name">Marne</field>
-            <field name="code">FR-51</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-52">
-            <field name="name">Haute-Marne</field>
-            <field name="code">FR-52</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-53">
-            <field name="name">Mayenne</field>
-            <field name="code">FR-53</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pdl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-54">
-            <field name="name">Meurthe-et-Moselle</field>
-            <field name="code">FR-54</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-55">
-            <field name="name">Meuse</field>
-            <field name="code">FR-55</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-56">
-            <field name="name">Morbihan</field>
-            <field name="code">FR-56</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bre"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-57">
-            <field name="name">Moselle</field>
-            <field name="code">FR-57</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-58">
-            <field name="name">Nièvre</field>
-            <field name="code">FR-58</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-59">
-            <field name="name">Nord</field>
-            <field name="code">FR-59</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-hdf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-60">
-            <field name="name">Oise</field>
-            <field name="code">FR-60</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-hdf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-61">
-            <field name="name">Orne</field>
-            <field name="code">FR-61</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-nor"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-62">
-            <field name="name">Pas-de-Calais</field>
-            <field name="code">FR-62</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-hdf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-63">
-            <field name="name">Puy-de-Dôme</field>
-            <field name="code">FR-63</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-64">
-            <field name="name">Pyrénées-Atlantiques</field>
-            <field name="code">FR-64</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-65">
-            <field name="name">Hautes-Pyrénées</field>
-            <field name="code">FR-65</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-66">
-            <field name="name">Pyrénées-Orientales</field>
-            <field name="code">FR-66</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-67">
-            <field name="name">Bas-Rhin</field>
-            <field name="code">FR-67</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-68">
-            <field name="name">Haut-Rhin</field>
-            <field name="code">FR-68</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-69">
-            <field name="name">Rhône</field>
-            <field name="code">FR-69</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-70">
-            <field name="name">Haute-Saône</field>
-            <field name="code">FR-70</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-71">
-            <field name="name">Saône-et-Loire</field>
-            <field name="code">FR-71</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-72">
-            <field name="name">Sarthe</field>
-            <field name="code">FR-72</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pdl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-73">
-            <field name="name">Savoie</field>
-            <field name="code">FR-73</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-74">
-            <field name="name">Haute-Savoie</field>
-            <field name="code">FR-74</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ara"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-75">
-            <field name="name">Paris</field>
-            <field name="code">FR-75</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-76">
-            <field name="name">Seine-Maritime</field>
-            <field name="code">FR-76</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-nor"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-77">
-            <field name="name">Seine-et-Marne</field>
-            <field name="code">FR-77</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-78">
-            <field name="name">Yvelines</field>
-            <field name="code">FR-78</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-79">
-            <field name="name">Deux-Sèvres</field>
-            <field name="code">FR-79</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-80">
-            <field name="name">Somme</field>
-            <field name="code">FR-80</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-hdf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-81">
-            <field name="name">Tarn</field>
-            <field name="code">FR-81</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-82">
-            <field name="name">Tarn-et-Garonne</field>
-            <field name="code">FR-82</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-occ"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-83">
-            <field name="name">Var</field>
-            <field name="code">FR-83</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pac"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-84">
-            <field name="name">Vaucluse</field>
-            <field name="code">FR-84</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pac"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-85">
-            <field name="name">Vendée</field>
-            <field name="code">FR-85</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-pdl"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-86">
-            <field name="name">Vienne</field>
-            <field name="code">FR-86</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-87">
-            <field name="name">Haute-Vienne</field>
-            <field name="code">FR-87</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-naq"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-88">
-            <field name="name">Vosges</field>
-            <field name="code">FR-88</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-ges"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-89">
-            <field name="name">Yonne</field>
-            <field name="code">FR-89</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-90">
-            <field name="name">Territoire de Belfort</field>
-            <field name="code">FR-90</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-bfc"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-91">
-            <field name="name">Essonne</field>
-            <field name="code">FR-91</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-92">
-            <field name="name">Hauts-de-Seine</field>
-            <field name="code">FR-92</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-93">
-            <field name="name">Seine-Saint-Denis</field>
-            <field name="code">FR-93</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-94">
-            <field name="name">Val-de-Marne</field>
-            <field name="code">FR-94</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-95">
-            <field name="name">Val-d'Oise</field>
-            <field name="code">FR-95</field>
-            <field name="type">metropolitan department</field>
-            <field name="parent" ref="fr-idf"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-gp">
-            <field name="name">Guadeloupe</field>
-            <field name="code">FR-GP</field>
-            <field name="type">overseas department</field>
-            <field name="parent" ref="fr-gua"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-re">
-            <field name="name">La Réunion</field>
-            <field name="code">FR-RE</field>
-            <field name="type">overseas department</field>
-            <field name="parent" ref="fr-lre"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="fr-yt">
-            <field name="name">Mayotte</field>
-            <field name="code">FR-YT</field>
-            <field name="type">overseas department</field>
-            <field name="parent" ref="fr-may"/>
-            <field name="country" ref="fr"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-abc">
-            <field name="name">Armagh, Banbridge and Craigavon</field>
-            <field name="code">GB-ABC</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-abd">
-            <field name="name">Aberdeenshire</field>
-            <field name="code">GB-ABD</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-abe">
-            <field name="name">Aberdeen City</field>
-            <field name="code">GB-ABE</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-agb">
-            <field name="name">Argyll and Bute</field>
-            <field name="code">GB-AGB</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-agy">
-            <field name="name">Isle of Anglesey; Sir Ynys Môn</field>
-            <field name="code">GB-AGY</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-and">
-            <field name="name">Ards and North Down</field>
-            <field name="code">GB-AND</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ann">
-            <field name="name">Antrim and Newtownabbey</field>
-            <field name="code">GB-ANN</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ans">
-            <field name="name">Angus</field>
-            <field name="code">GB-ANS</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bas">
-            <field name="name">Bath and North East Somerset</field>
-            <field name="code">GB-BAS</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bbd">
-            <field name="name">Blackburn with Darwen</field>
-            <field name="code">GB-BBD</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bdf">
-            <field name="name">Bedford</field>
-            <field name="code">GB-BDF</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bdg">
-            <field name="name">Barking and Dagenham</field>
-            <field name="code">GB-BDG</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ben">
-            <field name="name">Brent</field>
-            <field name="code">GB-BEN</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bex">
-            <field name="name">Bexley</field>
-            <field name="code">GB-BEX</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bfs">
-            <field name="name">Belfast</field>
-            <field name="code">GB-BFS</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bge">
-            <field name="name">Bridgend; Pen-y-bont ar Ogwr</field>
-            <field name="code">GB-BGE</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bgw">
-            <field name="name">Blaenau Gwent</field>
-            <field name="code">GB-BGW</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bir">
-            <field name="name">Birmingham</field>
-            <field name="code">GB-BIR</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bkm">
-            <field name="name">Buckinghamshire</field>
-            <field name="code">GB-BKM</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bmh">
-            <field name="name">Bournemouth</field>
-            <field name="code">GB-BMH</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bne">
-            <field name="name">Barnet</field>
-            <field name="code">GB-BNE</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bnh">
-            <field name="name">Brighton and Hove</field>
-            <field name="code">GB-BNH</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bns">
-            <field name="name">Barnsley</field>
-            <field name="code">GB-BNS</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bol">
-            <field name="name">Bolton</field>
-            <field name="code">GB-BOL</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bpl">
-            <field name="name">Blackpool</field>
-            <field name="code">GB-BPL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-brc">
-            <field name="name">Bracknell Forest</field>
-            <field name="code">GB-BRC</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-brd">
-            <field name="name">Bradford</field>
-            <field name="code">GB-BRD</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bry">
-            <field name="name">Bromley</field>
-            <field name="code">GB-BRY</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bst">
-            <field name="name">Bristol, City of</field>
-            <field name="code">GB-BST</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-bur">
-            <field name="name">Bury</field>
-            <field name="code">GB-BUR</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cam">
-            <field name="name">Cambridgeshire</field>
-            <field name="code">GB-CAM</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cay">
-            <field name="name">Caerphilly; Caerffili</field>
-            <field name="code">GB-CAY</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cbf">
-            <field name="name">Central Bedfordshire</field>
-            <field name="code">GB-CBF</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ccg">
-            <field name="name">Causeway Coast and Glens</field>
-            <field name="code">GB-CCG</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cgn">
-            <field name="name">Ceredigion; Sir Ceredigion</field>
-            <field name="code">GB-CGN</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-che">
-            <field name="name">Cheshire East</field>
-            <field name="code">GB-CHE</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-chw">
-            <field name="name">Cheshire West and Chester</field>
-            <field name="code">GB-CHW</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cld">
-            <field name="name">Calderdale</field>
-            <field name="code">GB-CLD</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-clk">
-            <field name="name">Clackmannanshire</field>
-            <field name="code">GB-CLK</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cma">
-            <field name="name">Cumbria</field>
-            <field name="code">GB-CMA</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cmd">
-            <field name="name">Camden</field>
-            <field name="code">GB-CMD</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cmn">
-            <field name="name">Carmarthenshire; Sir Gaerfyrddin</field>
-            <field name="code">GB-CMN</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-con">
-            <field name="name">Cornwall</field>
-            <field name="code">GB-CON</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cov">
-            <field name="name">Coventry</field>
-            <field name="code">GB-COV</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-crf">
-            <field name="name">Cardiff; Caerdydd</field>
-            <field name="code">GB-CRF</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cry">
-            <field name="name">Croydon</field>
-            <field name="code">GB-CRY</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-cwy">
-            <field name="name">Conwy</field>
-            <field name="code">GB-CWY</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dal">
-            <field name="name">Darlington</field>
-            <field name="code">GB-DAL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dby">
-            <field name="name">Derbyshire</field>
-            <field name="code">GB-DBY</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-den">
-            <field name="name">Denbighshire; Sir Ddinbych</field>
-            <field name="code">GB-DEN</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-der">
-            <field name="name">Derby</field>
-            <field name="code">GB-DER</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dev">
-            <field name="name">Devon</field>
-            <field name="code">GB-DEV</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dgy">
-            <field name="name">Dumfries and Galloway</field>
-            <field name="code">GB-DGY</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dnc">
-            <field name="name">Doncaster</field>
-            <field name="code">GB-DNC</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dnd">
-            <field name="name">Dundee City</field>
-            <field name="code">GB-DND</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dor">
-            <field name="name">Dorset</field>
-            <field name="code">GB-DOR</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-drs">
-            <field name="name">Derry and Strabane</field>
-            <field name="code">GB-DRS</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dud">
-            <field name="name">Dudley</field>
-            <field name="code">GB-DUD</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-dur">
-            <field name="name">Durham County</field>
-            <field name="code">GB-DUR</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-eal">
-            <field name="name">Ealing</field>
-            <field name="code">GB-EAL</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-eay">
-            <field name="name">East Ayrshire</field>
-            <field name="code">GB-EAY</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-edh">
-            <field name="name">Edinburgh, City of</field>
-            <field name="code">GB-EDH</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-edu">
-            <field name="name">East Dunbartonshire</field>
-            <field name="code">GB-EDU</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-eln">
-            <field name="name">East Lothian</field>
-            <field name="code">GB-ELN</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-els">
-            <field name="name">Eilean Siar</field>
-            <field name="code">GB-ELS</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-enf">
-            <field name="name">Enfield</field>
-            <field name="code">GB-ENF</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-erw">
-            <field name="name">East Renfrewshire</field>
-            <field name="code">GB-ERW</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ery">
-            <field name="name">East Riding of Yorkshire</field>
-            <field name="code">GB-ERY</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ess">
-            <field name="name">Essex</field>
-            <field name="code">GB-ESS</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-esx">
-            <field name="name">East Sussex</field>
-            <field name="code">GB-ESX</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-fal">
-            <field name="name">Falkirk</field>
-            <field name="code">GB-FAL</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-fif">
-            <field name="name">Fife</field>
-            <field name="code">GB-FIF</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-fln">
-            <field name="name">Flintshire; Sir y Fflint</field>
-            <field name="code">GB-FLN</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-fmo">
-            <field name="name">Fermanagh and Omagh</field>
-            <field name="code">GB-FMO</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-gat">
-            <field name="name">Gateshead</field>
-            <field name="code">GB-GAT</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-glg">
-            <field name="name">Glasgow City</field>
-            <field name="code">GB-GLG</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-gls">
-            <field name="name">Gloucestershire</field>
-            <field name="code">GB-GLS</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-gre">
-            <field name="name">Greenwich</field>
-            <field name="code">GB-GRE</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-gwn">
-            <field name="name">Gwynedd</field>
-            <field name="code">GB-GWN</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hal">
-            <field name="name">Halton</field>
-            <field name="code">GB-HAL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ham">
-            <field name="name">Hampshire</field>
-            <field name="code">GB-HAM</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hav">
-            <field name="name">Havering</field>
-            <field name="code">GB-HAV</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hck">
-            <field name="name">Hackney</field>
-            <field name="code">GB-HCK</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hef">
-            <field name="name">Herefordshire</field>
-            <field name="code">GB-HEF</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hil">
-            <field name="name">Hillingdon</field>
-            <field name="code">GB-HIL</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hld">
-            <field name="name">Highland</field>
-            <field name="code">GB-HLD</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hmf">
-            <field name="name">Hammersmith and Fulham</field>
-            <field name="code">GB-HMF</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hns">
-            <field name="name">Hounslow</field>
-            <field name="code">GB-HNS</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hpl">
-            <field name="name">Hartlepool</field>
-            <field name="code">GB-HPL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hrt">
-            <field name="name">Hertfordshire</field>
-            <field name="code">GB-HRT</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hrw">
-            <field name="name">Harrow</field>
-            <field name="code">GB-HRW</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-hry">
-            <field name="name">Haringey</field>
-            <field name="code">GB-HRY</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ios">
-            <field name="name">Isles of Scilly</field>
-            <field name="code">GB-IOS</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-iow">
-            <field name="name">Isle of Wight</field>
-            <field name="code">GB-IOW</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-isl">
-            <field name="name">Islington</field>
-            <field name="code">GB-ISL</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ivc">
-            <field name="name">Inverclyde</field>
-            <field name="code">GB-IVC</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-kec">
-            <field name="name">Kensington and Chelsea</field>
-            <field name="code">GB-KEC</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ken">
-            <field name="name">Kent</field>
-            <field name="code">GB-KEN</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-khl">
-            <field name="name">Kingston upon Hull</field>
-            <field name="code">GB-KHL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-kir">
-            <field name="name">Kirklees</field>
-            <field name="code">GB-KIR</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ktt">
-            <field name="name">Kingston upon Thames</field>
-            <field name="code">GB-KTT</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-kwl">
-            <field name="name">Knowsley</field>
-            <field name="code">GB-KWL</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lan">
-            <field name="name">Lancashire</field>
-            <field name="code">GB-LAN</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lbc">
-            <field name="name">Lisburn and Castlereagh</field>
-            <field name="code">GB-LBC</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lbh">
-            <field name="name">Lambeth</field>
-            <field name="code">GB-LBH</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lce">
-            <field name="name">Leicester</field>
-            <field name="code">GB-LCE</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lds">
-            <field name="name">Leeds</field>
-            <field name="code">GB-LDS</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lec">
-            <field name="name">Leicestershire</field>
-            <field name="code">GB-LEC</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lew">
-            <field name="name">Lewisham</field>
-            <field name="code">GB-LEW</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lin">
-            <field name="name">Lincolnshire</field>
-            <field name="code">GB-LIN</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-liv">
-            <field name="name">Liverpool</field>
-            <field name="code">GB-LIV</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lnd">
-            <field name="name">London, City of</field>
-            <field name="code">GB-LND</field>
-            <field name="type">city corporation</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-lut">
-            <field name="name">Luton</field>
-            <field name="code">GB-LUT</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-man">
-            <field name="name">Manchester</field>
-            <field name="code">GB-MAN</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mdb">
-            <field name="name">Middlesbrough</field>
-            <field name="code">GB-MDB</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mdw">
-            <field name="name">Medway</field>
-            <field name="code">GB-MDW</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mea">
-            <field name="name">Mid and East Antrim</field>
-            <field name="code">GB-MEA</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mik">
-            <field name="name">Milton Keynes</field>
-            <field name="code">GB-MIK</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mln">
-            <field name="name">Midlothian</field>
-            <field name="code">GB-MLN</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mon">
-            <field name="name">Monmouthshire; Sir Fynwy</field>
-            <field name="code">GB-MON</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mrt">
-            <field name="name">Merton</field>
-            <field name="code">GB-MRT</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mry">
-            <field name="name">Moray</field>
-            <field name="code">GB-MRY</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mty">
-            <field name="name">Merthyr Tydfil; Merthyr Tudful</field>
-            <field name="code">GB-MTY</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-mul">
-            <field name="name">Mid Ulster</field>
-            <field name="code">GB-MUL</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nay">
-            <field name="name">North Ayrshire</field>
-            <field name="code">GB-NAY</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nbl">
-            <field name="name">Northumberland</field>
-            <field name="code">GB-NBL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nel">
-            <field name="name">North East Lincolnshire</field>
-            <field name="code">GB-NEL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-net">
-            <field name="name">Newcastle upon Tyne</field>
-            <field name="code">GB-NET</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nfk">
-            <field name="name">Norfolk</field>
-            <field name="code">GB-NFK</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ngm">
-            <field name="name">Nottingham</field>
-            <field name="code">GB-NGM</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nlk">
-            <field name="name">North Lanarkshire</field>
-            <field name="code">GB-NLK</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nln">
-            <field name="name">North Lincolnshire</field>
-            <field name="code">GB-NLN</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nmd">
-            <field name="name">Newry, Mourne and Down</field>
-            <field name="code">GB-NMD</field>
-            <field name="type">district</field>
-            <field name="parent" ref="gb-nir"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nsm">
-            <field name="name">North Somerset</field>
-            <field name="code">GB-NSM</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nth">
-            <field name="name">Northamptonshire</field>
-            <field name="code">GB-NTH</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ntl">
-            <field name="name">Neath Port Talbot; Castell-nedd Port Talbot</field>
-            <field name="code">GB-NTL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ntt">
-            <field name="name">Nottinghamshire</field>
-            <field name="code">GB-NTT</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nty">
-            <field name="name">North Tyneside</field>
-            <field name="code">GB-NTY</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nwm">
-            <field name="name">Newham</field>
-            <field name="code">GB-NWM</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nwp">
-            <field name="name">Newport; Casnewydd</field>
-            <field name="code">GB-NWP</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-nyk">
-            <field name="name">North Yorkshire</field>
-            <field name="code">GB-NYK</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-old">
-            <field name="name">Oldham</field>
-            <field name="code">GB-OLD</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ork">
-            <field name="name">Orkney Islands</field>
-            <field name="code">GB-ORK</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-oxf">
-            <field name="name">Oxfordshire</field>
-            <field name="code">GB-OXF</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-pem">
-            <field name="name">Pembrokeshire; Sir Benfro</field>
-            <field name="code">GB-PEM</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-pkn">
-            <field name="name">Perth and Kinross</field>
-            <field name="code">GB-PKN</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ply">
-            <field name="name">Plymouth</field>
-            <field name="code">GB-PLY</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-pol">
-            <field name="name">Poole</field>
-            <field name="code">GB-POL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-por">
-            <field name="name">Portsmouth</field>
-            <field name="code">GB-POR</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-pow">
-            <field name="name">Powys</field>
-            <field name="code">GB-POW</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-pte">
-            <field name="name">Peterborough</field>
-            <field name="code">GB-PTE</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rcc">
-            <field name="name">Redcar and Cleveland</field>
-            <field name="code">GB-RCC</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rch">
-            <field name="name">Rochdale</field>
-            <field name="code">GB-RCH</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rct">
-            <field name="name">Rhondda, Cynon, Taff; Rhondda, Cynon, Taf</field>
-            <field name="code">GB-RCT</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rdb">
-            <field name="name">Redbridge</field>
-            <field name="code">GB-RDB</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rdg">
-            <field name="name">Reading</field>
-            <field name="code">GB-RDG</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rfw">
-            <field name="name">Renfrewshire</field>
-            <field name="code">GB-RFW</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ric">
-            <field name="name">Richmond upon Thames</field>
-            <field name="code">GB-RIC</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rot">
-            <field name="name">Rotherham</field>
-            <field name="code">GB-ROT</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-rut">
-            <field name="name">Rutland</field>
-            <field name="code">GB-RUT</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-saw">
-            <field name="name">Sandwell</field>
-            <field name="code">GB-SAW</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-say">
-            <field name="name">South Ayrshire</field>
-            <field name="code">GB-SAY</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-scb">
-            <field name="name">Scottish Borders, The</field>
-            <field name="code">GB-SCB</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sfk">
-            <field name="name">Suffolk</field>
-            <field name="code">GB-SFK</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sft">
-            <field name="name">Sefton</field>
-            <field name="code">GB-SFT</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sgc">
-            <field name="name">South Gloucestershire</field>
-            <field name="code">GB-SGC</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-shf">
-            <field name="name">Sheffield</field>
-            <field name="code">GB-SHF</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-shn">
-            <field name="name">St. Helens</field>
-            <field name="code">GB-SHN</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-shr">
-            <field name="name">Shropshire</field>
-            <field name="code">GB-SHR</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-skp">
-            <field name="name">Stockport</field>
-            <field name="code">GB-SKP</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-slf">
-            <field name="name">Salford</field>
-            <field name="code">GB-SLF</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-slg">
-            <field name="name">Slough</field>
-            <field name="code">GB-SLG</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-slk">
-            <field name="name">South Lanarkshire</field>
-            <field name="code">GB-SLK</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-snd">
-            <field name="name">Sunderland</field>
-            <field name="code">GB-SND</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sol">
-            <field name="name">Solihull</field>
-            <field name="code">GB-SOL</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-som">
-            <field name="name">Somerset</field>
-            <field name="code">GB-SOM</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sos">
-            <field name="name">Southend-on-Sea</field>
-            <field name="code">GB-SOS</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sry">
-            <field name="name">Surrey</field>
-            <field name="code">GB-SRY</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-ste">
-            <field name="name">Stoke-on-Trent</field>
-            <field name="code">GB-STE</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-stg">
-            <field name="name">Stirling</field>
-            <field name="code">GB-STG</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sth">
-            <field name="name">Southampton</field>
-            <field name="code">GB-STH</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-stn">
-            <field name="name">Sutton</field>
-            <field name="code">GB-STN</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sts">
-            <field name="name">Staffordshire</field>
-            <field name="code">GB-STS</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-stt">
-            <field name="name">Stockton-on-Tees</field>
-            <field name="code">GB-STT</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-sty">
-            <field name="name">South Tyneside</field>
-            <field name="code">GB-STY</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-swa">
-            <field name="name">Swansea; Abertawe</field>
-            <field name="code">GB-SWA</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-swd">
-            <field name="name">Swindon</field>
-            <field name="code">GB-SWD</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-swk">
-            <field name="name">Southwark</field>
-            <field name="code">GB-SWK</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-tam">
-            <field name="name">Tameside</field>
-            <field name="code">GB-TAM</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-tfw">
-            <field name="name">Telford and Wrekin</field>
-            <field name="code">GB-TFW</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-thr">
-            <field name="name">Thurrock</field>
-            <field name="code">GB-THR</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-tob">
-            <field name="name">Torbay</field>
-            <field name="code">GB-TOB</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-tof">
-            <field name="name">Torfaen; Tor-faen</field>
-            <field name="code">GB-TOF</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-trf">
-            <field name="name">Trafford</field>
-            <field name="code">GB-TRF</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-twh">
-            <field name="name">Tower Hamlets</field>
-            <field name="code">GB-TWH</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-vgl">
-            <field name="name">Vale of Glamorgan, The; Bro Morgannwg</field>
-            <field name="code">GB-VGL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-war">
-            <field name="name">Warwickshire</field>
-            <field name="code">GB-WAR</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wbk">
-            <field name="name">West Berkshire</field>
-            <field name="code">GB-WBK</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wdu">
-            <field name="name">West Dunbartonshire</field>
-            <field name="code">GB-WDU</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wft">
-            <field name="name">Waltham Forest</field>
-            <field name="code">GB-WFT</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wgn">
-            <field name="name">Wigan</field>
-            <field name="code">GB-WGN</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wil">
-            <field name="name">Wiltshire</field>
-            <field name="code">GB-WIL</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wkf">
-            <field name="name">Wakefield</field>
-            <field name="code">GB-WKF</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wll">
-            <field name="name">Walsall</field>
-            <field name="code">GB-WLL</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wln">
-            <field name="name">West Lothian</field>
-            <field name="code">GB-WLN</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wlv">
-            <field name="name">Wolverhampton</field>
-            <field name="code">GB-WLV</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wnd">
-            <field name="name">Wandsworth</field>
-            <field name="code">GB-WND</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wnm">
-            <field name="name">Windsor and Maidenhead</field>
-            <field name="code">GB-WNM</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wok">
-            <field name="name">Wokingham</field>
-            <field name="code">GB-WOK</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wor">
-            <field name="name">Worcestershire</field>
-            <field name="code">GB-WOR</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wrl">
-            <field name="name">Wirral</field>
-            <field name="code">GB-WRL</field>
-            <field name="type">metropolitan district</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wrt">
-            <field name="name">Warrington</field>
-            <field name="code">GB-WRT</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wrx">
-            <field name="name">Wrexham; Wrecsam</field>
-            <field name="code">GB-WRX</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-wls"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wsm">
-            <field name="name">Westminster</field>
-            <field name="code">GB-WSM</field>
-            <field name="type">london borough</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-wsx">
-            <field name="name">West Sussex</field>
-            <field name="code">GB-WSX</field>
-            <field name="type">two-tier county</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-yor">
-            <field name="name">York</field>
-            <field name="code">GB-YOR</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="gb-eng"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gb-zet">
-            <field name="name">Shetland Islands</field>
-            <field name="code">GB-ZET</field>
-            <field name="type">council area</field>
-            <field name="parent" ref="gb-sct"/>
-            <field name="country" ref="gb"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-be">
-            <field name="name">Beyla</field>
-            <field name="code">GN-BE</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-n"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-bf">
-            <field name="name">Boffa</field>
-            <field name="code">GN-BF</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-b"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-bk">
-            <field name="name">Boké</field>
-            <field name="code">GN-BK</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-b"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-co">
-            <field name="name">Coyah</field>
-            <field name="code">GN-CO</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-d"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-db">
-            <field name="name">Dabola</field>
-            <field name="code">GN-DB</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-f"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-di">
-            <field name="name">Dinguiraye</field>
-            <field name="code">GN-DI</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-f"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-dl">
-            <field name="name">Dalaba</field>
-            <field name="code">GN-DL</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-m"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-du">
-            <field name="name">Dubréka</field>
-            <field name="code">GN-DU</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-d"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-fa">
-            <field name="name">Faranah</field>
-            <field name="code">GN-FA</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-f"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-fo">
-            <field name="name">Forécariah</field>
-            <field name="code">GN-FO</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-d"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-fr">
-            <field name="name">Fria</field>
-            <field name="code">GN-FR</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-b"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-ga">
-            <field name="name">Gaoual</field>
-            <field name="code">GN-GA</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-b"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-gu">
-            <field name="name">Guékédou</field>
-            <field name="code">GN-GU</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-n"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-ka">
-            <field name="name">Kankan</field>
-            <field name="code">GN-KA</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-k"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-kb">
-            <field name="name">Koubia</field>
-            <field name="code">GN-KB</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-l"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-kd">
-            <field name="name">Kindia</field>
-            <field name="code">GN-KD</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-d"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-ke">
-            <field name="name">Kérouané</field>
-            <field name="code">GN-KE</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-k"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-kn">
-            <field name="name">Koundara</field>
-            <field name="code">GN-KN</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-b"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-ko">
-            <field name="name">Kouroussa</field>
-            <field name="code">GN-KO</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-k"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-ks">
-            <field name="name">Kissidougou</field>
-            <field name="code">GN-KS</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-f"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-la">
-            <field name="name">Labé</field>
-            <field name="code">GN-LA</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-l"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-le">
-            <field name="name">Lélouma</field>
-            <field name="code">GN-LE</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-l"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-lo">
-            <field name="name">Lola</field>
-            <field name="code">GN-LO</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-n"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-mc">
-            <field name="name">Macenta</field>
-            <field name="code">GN-MC</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-n"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-md">
-            <field name="name">Mandiana</field>
-            <field name="code">GN-MD</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-k"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-ml">
-            <field name="name">Mali</field>
-            <field name="code">GN-ML</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-l"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-mm">
-            <field name="name">Mamou</field>
-            <field name="code">GN-MM</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-m"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-nz">
-            <field name="name">Nzérékoré</field>
-            <field name="code">GN-NZ</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-n"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-pi">
-            <field name="name">Pita</field>
-            <field name="code">GN-PI</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-m"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-si">
-            <field name="name">Siguiri</field>
-            <field name="code">GN-SI</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-k"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-te">
-            <field name="name">Télimélé</field>
-            <field name="code">GN-TE</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-d"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-to">
-            <field name="name">Tougué</field>
-            <field name="code">GN-TO</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-l"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gn-yo">
-            <field name="name">Yomou</field>
-            <field name="code">GN-YO</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="gn-n"/>
-            <field name="country" ref="gn"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-an">
-            <field name="name">Annobón</field>
-            <field name="code">GQ-AN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="gq-i"/>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-bn">
-            <field name="name">Bioko Norte</field>
-            <field name="code">GQ-BN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="gq-i"/>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-bs">
-            <field name="name">Bioko Sur</field>
-            <field name="code">GQ-BS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="gq-i"/>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-cs">
-            <field name="name">Centro Sur</field>
-            <field name="code">GQ-CS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="gq-c"/>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-kn">
-            <field name="name">Kié-Ntem</field>
-            <field name="code">GQ-KN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="gq-c"/>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-li">
-            <field name="name">Litoral</field>
-            <field name="code">GQ-LI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="gq-c"/>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gq-wn">
-            <field name="name">Wele-Nzas</field>
-            <field name="code">GQ-WN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="gq-c"/>
-            <field name="country" ref="gq"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-01">
-            <field name="name">Aitolia kai Akarnania</field>
-            <field name="code">GR-01</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-g"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-03">
-            <field name="name">Voiotia</field>
-            <field name="code">GR-03</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-h"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-04">
-            <field name="name">Evvoias</field>
-            <field name="code">GR-04</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-h"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-05">
-            <field name="name">Evrytania</field>
-            <field name="code">GR-05</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-h"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-06">
-            <field name="name">Fthiotida</field>
-            <field name="code">GR-06</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-h"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-07">
-            <field name="name">Fokida</field>
-            <field name="code">GR-07</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-h"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-11">
-            <field name="name">Argolida</field>
-            <field name="code">GR-11</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-j"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-12">
-            <field name="name">Arkadia</field>
-            <field name="code">GR-12</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-j"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-13">
-            <field name="name">Achaïa</field>
-            <field name="code">GR-13</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-g"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-14">
-            <field name="name">Ileia</field>
-            <field name="code">GR-14</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-g"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-15">
-            <field name="name">Korinthia</field>
-            <field name="code">GR-15</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-j"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-16">
-            <field name="name">Lakonia</field>
-            <field name="code">GR-16</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-j"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-17">
-            <field name="name">Messinia</field>
-            <field name="code">GR-17</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-j"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-21">
-            <field name="name">Zakynthos</field>
-            <field name="code">GR-21</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-f"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-22">
-            <field name="name">Kerkyra</field>
-            <field name="code">GR-22</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-f"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-23">
-            <field name="name">Kefallonia</field>
-            <field name="code">GR-23</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-f"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-24">
-            <field name="name">Lefkada</field>
-            <field name="code">GR-24</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-f"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-31">
-            <field name="name">Arta</field>
-            <field name="code">GR-31</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-f"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-32">
-            <field name="name">Thesprotia</field>
-            <field name="code">GR-32</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-d"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-33">
-            <field name="name">Ioannina</field>
-            <field name="code">GR-33</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-d"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-34">
-            <field name="name">Preveza</field>
-            <field name="code">GR-34</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-d"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-41">
-            <field name="name">Karditsa</field>
-            <field name="code">GR-41</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-e"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-42">
-            <field name="name">Larisa</field>
-            <field name="code">GR-42</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-e"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-43">
-            <field name="name">Magnisia</field>
-            <field name="code">GR-43</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-e"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-44">
-            <field name="name">Trikala</field>
-            <field name="code">GR-44</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-e"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-51">
-            <field name="name">Grevena</field>
-            <field name="code">GR-51</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-c"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-52">
-            <field name="name">Drama</field>
-            <field name="code">GR-52</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-a"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-53">
-            <field name="name">Imathia</field>
-            <field name="code">GR-53</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-b"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-54">
-            <field name="name">Thessaloniki</field>
-            <field name="code">GR-54</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-b"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-55">
-            <field name="name">Kavala</field>
-            <field name="code">GR-55</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-a"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-56">
-            <field name="name">Kastoria</field>
-            <field name="code">GR-56</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-c"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-57">
-            <field name="name">Kilkis</field>
-            <field name="code">GR-57</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-b"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-58">
-            <field name="name">Kozani</field>
-            <field name="code">GR-58</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-c"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-59">
-            <field name="name">Pella</field>
-            <field name="code">GR-59</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-b"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-61">
-            <field name="name">Pieria</field>
-            <field name="code">GR-61</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-b"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-62">
-            <field name="name">Serres</field>
-            <field name="code">GR-62</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-b"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-63">
-            <field name="name">Florina</field>
-            <field name="code">GR-63</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-c"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-64">
-            <field name="name">Chalkidiki</field>
-            <field name="code">GR-64</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-b"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-71">
-            <field name="name">Evros</field>
-            <field name="code">GR-71</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-a"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-72">
-            <field name="name">Xanthi</field>
-            <field name="code">GR-72</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-a"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-73">
-            <field name="name">Rodopi</field>
-            <field name="code">GR-73</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-a"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-81">
-            <field name="name">Dodekanisos</field>
-            <field name="code">GR-81</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-l"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-82">
-            <field name="name">Kyklades</field>
-            <field name="code">GR-82</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-l"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-83">
-            <field name="name">Lesvos</field>
-            <field name="code">GR-83</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-k"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-84">
-            <field name="name">Samos</field>
-            <field name="code">GR-84</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-k"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-85">
-            <field name="name">Chios</field>
-            <field name="code">GR-85</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-k"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-91">
-            <field name="name">Irakleio</field>
-            <field name="code">GR-91</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-m"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-92">
-            <field name="name">Lasithi</field>
-            <field name="code">GR-92</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-m"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-93">
-            <field name="name">Rethymno</field>
-            <field name="code">GR-93</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-m"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-94">
-            <field name="name">Chania</field>
-            <field name="code">GR-94</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-m"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gr-a1">
-            <field name="name">Attiki</field>
-            <field name="code">GR-A1</field>
-            <field name="type">department</field>
-            <field name="parent" ref="gr-i"/>
-            <field name="country" ref="gr"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-ba">
-            <field name="name">Bafatá</field>
-            <field name="code">GW-BA</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-l"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-bl">
-            <field name="name">Bolama</field>
-            <field name="code">GW-BL</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-s"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-bm">
-            <field name="name">Biombo</field>
-            <field name="code">GW-BM</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-n"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-ca">
-            <field name="name">Cacheu</field>
-            <field name="code">GW-CA</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-n"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-ga">
-            <field name="name">Gabú</field>
-            <field name="code">GW-GA</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-l"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-oi">
-            <field name="name">Oio</field>
-            <field name="code">GW-OI</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-n"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-qu">
-            <field name="name">Quinara</field>
-            <field name="code">GW-QU</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-s"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="gw-to">
-            <field name="name">Tombali</field>
-            <field name="code">GW-TO</field>
-            <field name="type">region</field>
-            <field name="parent" ref="gw-s"/>
-            <field name="country" ref="gw"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ac">
-            <field name="name">Aceh</field>
-            <field name="code">ID-AC</field>
-            <field name="type">autonomous province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ba">
-            <field name="name">Bali</field>
-            <field name="code">ID-BA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-nu"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-bb">
-            <field name="name">Bangka Belitung</field>
-            <field name="code">ID-BB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-be">
-            <field name="name">Bengkulu</field>
-            <field name="code">ID-BE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-bt">
-            <field name="name">Banten</field>
-            <field name="code">ID-BT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-jw"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-go">
-            <field name="name">Gorontalo</field>
-            <field name="code">ID-GO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sl"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ja">
-            <field name="name">Jambi</field>
-            <field name="code">ID-JA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-jb">
-            <field name="name">Jawa Barat</field>
-            <field name="code">ID-JB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-jw"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ji">
-            <field name="name">Jawa Timur</field>
-            <field name="code">ID-JI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-jw"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-jk">
-            <field name="name">Jakarta Raya</field>
-            <field name="code">ID-JK</field>
-            <field name="type">special district</field>
-            <field name="parent" ref="id-jw"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-jt">
-            <field name="name">Jawa Tengah</field>
-            <field name="code">ID-JT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-jw"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-kb">
-            <field name="name">Kalimantan Barat</field>
-            <field name="code">ID-KB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ka"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ki">
-            <field name="name">Kalimantan Timur</field>
-            <field name="code">ID-KI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ka"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-kr">
-            <field name="name">Kepulauan Riau</field>
-            <field name="code">ID-KR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ks">
-            <field name="name">Kalimantan Selatan</field>
-            <field name="code">ID-KS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ka"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-kt">
-            <field name="name">Kalimantan Tengah</field>
-            <field name="code">ID-KT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ka"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-la">
-            <field name="name">Lampung</field>
-            <field name="code">ID-LA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ma">
-            <field name="name">Maluku</field>
-            <field name="code">ID-MA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ml"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-mu">
-            <field name="name">Maluku Utara</field>
-            <field name="code">ID-MU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ml"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-nb">
-            <field name="name">Nusa Tenggara Barat</field>
-            <field name="code">ID-NB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-nu"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-nt">
-            <field name="name">Nusa Tenggara Timur</field>
-            <field name="code">ID-NT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-nu"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-pa">
-            <field name="name">Papua</field>
-            <field name="code">ID-PA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ij"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-pb">
-            <field name="name">Papua Barat</field>
-            <field name="code">ID-PB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-ij"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ri">
-            <field name="name">Riau</field>
-            <field name="code">ID-RI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-sa">
-            <field name="name">Sulawesi Utara</field>
-            <field name="code">ID-SA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sl"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-sb">
-            <field name="name">Sumatra Barat</field>
-            <field name="code">ID-SB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-sg">
-            <field name="name">Sulawesi Tenggara</field>
-            <field name="code">ID-SG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sl"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-sn">
-            <field name="name">Sulawesi Selatan</field>
-            <field name="code">ID-SN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sl"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-sr">
-            <field name="name">Sulawesi Barat</field>
-            <field name="code">ID-SR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sl"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-ss">
-            <field name="name">Sumatra Selatan</field>
-            <field name="code">ID-SS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-st">
-            <field name="name">Sulawesi Tengah</field>
-            <field name="code">ID-ST</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sl"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-su">
-            <field name="name">Sumatera Utara</field>
-            <field name="code">ID-SU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="id-sm"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="id-yo">
-            <field name="name">Yogyakarta</field>
-            <field name="code">ID-YO</field>
-            <field name="type">special region</field>
-            <field name="parent" ref="id-jw"/>
-            <field name="country" ref="id"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-ce">
-            <field name="name">Clare</field>
-            <field name="code">IE-CE</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-m"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-cn">
-            <field name="name">Cavan</field>
-            <field name="code">IE-CN</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-u"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-co">
-            <field name="name">Cork</field>
-            <field name="code">IE-CO</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-m"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-cw">
-            <field name="name">Carlow</field>
-            <field name="code">IE-CW</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-d">
-            <field name="name">Dublin</field>
-            <field name="code">IE-D</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-dl">
-            <field name="name">Donegal</field>
-            <field name="code">IE-DL</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-u"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-g">
-            <field name="name">Galway</field>
-            <field name="code">IE-G</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-c"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-ke">
-            <field name="name">Kildare</field>
-            <field name="code">IE-KE</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-kk">
-            <field name="name">Kilkenny</field>
-            <field name="code">IE-KK</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-ky">
-            <field name="name">Kerry</field>
-            <field name="code">IE-KY</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-m"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-ld">
-            <field name="name">Longford</field>
-            <field name="code">IE-LD</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-lh">
-            <field name="name">Louth</field>
-            <field name="code">IE-LH</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-lk">
-            <field name="name">Limerick</field>
-            <field name="code">IE-LK</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-m"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-lm">
-            <field name="name">Leitrim</field>
-            <field name="code">IE-LM</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-c"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-ls">
-            <field name="name">Laois</field>
-            <field name="code">IE-LS</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-mh">
-            <field name="name">Meath</field>
-            <field name="code">IE-MH</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-mn">
-            <field name="name">Monaghan</field>
-            <field name="code">IE-MN</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-u"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-mo">
-            <field name="name">Mayo</field>
-            <field name="code">IE-MO</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-c"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-oy">
-            <field name="name">Offaly</field>
-            <field name="code">IE-OY</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-rn">
-            <field name="name">Roscommon</field>
-            <field name="code">IE-RN</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-c"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-so">
-            <field name="name">Sligo</field>
-            <field name="code">IE-SO</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-c"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-ta">
-            <field name="name">Tipperary</field>
-            <field name="code">IE-TA</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-m"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-wd">
-            <field name="name">Waterford</field>
-            <field name="code">IE-WD</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-m"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-wh">
-            <field name="name">Westmeath</field>
-            <field name="code">IE-WH</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-ww">
-            <field name="name">Wicklow</field>
-            <field name="code">IE-WW</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="ie-wx">
-            <field name="name">Wexford</field>
-            <field name="code">IE-WX</field>
-            <field name="type">county</field>
-            <field name="parent" ref="ie-l"/>
-            <field name="country" ref="ie"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ag">
-            <field name="name">Agrigento</field>
-            <field name="code">IT-AG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-al">
-            <field name="name">Alessandria</field>
-            <field name="code">IT-AL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-an">
-            <field name="name">Ancona</field>
-            <field name="code">IT-AN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-57"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ao">
-            <field name="name">Aosta</field>
-            <field name="code">IT-AO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-23"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ap">
-            <field name="name">Ascoli Piceno</field>
-            <field name="code">IT-AP</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-57"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-aq">
-            <field name="name">L'Aquila</field>
-            <field name="code">IT-AQ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-65"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ar">
-            <field name="name">Arezzo</field>
-            <field name="code">IT-AR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-at">
-            <field name="name">Asti</field>
-            <field name="code">IT-AT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-av">
-            <field name="name">Avellino</field>
-            <field name="code">IT-AV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-72"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ba">
-            <field name="name">Bari</field>
-            <field name="code">IT-BA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-75"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bg">
-            <field name="name">Bergamo</field>
-            <field name="code">IT-BG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bi">
-            <field name="name">Biella</field>
-            <field name="code">IT-BI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bl">
-            <field name="name">Belluno</field>
-            <field name="code">IT-BL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-34"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bn">
-            <field name="name">Benevento</field>
-            <field name="code">IT-BN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-72"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bo">
-            <field name="name">Bologna</field>
-            <field name="code">IT-BO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-br">
-            <field name="name">Brindisi</field>
-            <field name="code">IT-BR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-75"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bs">
-            <field name="name">Brescia</field>
-            <field name="code">IT-BS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bt">
-            <field name="name">Barletta-Andria-Trani</field>
-            <field name="code">IT-BT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-75"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-bz">
-            <field name="name">Bolzano</field>
-            <field name="code">IT-BZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-32"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ca">
-            <field name="name">Cagliari</field>
-            <field name="code">IT-CA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-cb">
-            <field name="name">Campobasso</field>
-            <field name="code">IT-CB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-67"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ce">
-            <field name="name">Caserta</field>
-            <field name="code">IT-CE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-72"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ch">
-            <field name="name">Chieti</field>
-            <field name="code">IT-CH</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-65"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ci">
-            <field name="name">Carbonia-Iglesias</field>
-            <field name="code">IT-CI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-cl">
-            <field name="name">Caltanissetta</field>
-            <field name="code">IT-CL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-cn">
-            <field name="name">Cuneo</field>
-            <field name="code">IT-CN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-co">
-            <field name="name">Como</field>
-            <field name="code">IT-CO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-cr">
-            <field name="name">Cremona</field>
-            <field name="code">IT-CR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-cs">
-            <field name="name">Cosenza</field>
-            <field name="code">IT-CS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-78"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ct">
-            <field name="name">Catania</field>
-            <field name="code">IT-CT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-cz">
-            <field name="name">Catanzaro</field>
-            <field name="code">IT-CZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-78"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-en">
-            <field name="name">Enna</field>
-            <field name="code">IT-EN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-fc">
-            <field name="name">Forlì-Cesena</field>
-            <field name="code">IT-FC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-fe">
-            <field name="name">Ferrara</field>
-            <field name="code">IT-FE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-fg">
-            <field name="name">Foggia</field>
-            <field name="code">IT-FG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-75"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-fi">
-            <field name="name">Firenze</field>
-            <field name="code">IT-FI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-fm">
-            <field name="name">Fermo</field>
-            <field name="code">IT-FM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-57"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-fr">
-            <field name="name">Frosinone</field>
-            <field name="code">IT-FR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-62"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ge">
-            <field name="name">Genova</field>
-            <field name="code">IT-GE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-42"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-go">
-            <field name="name">Gorizia</field>
-            <field name="code">IT-GO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-36"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-gr">
-            <field name="name">Grosseto</field>
-            <field name="code">IT-GR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-im">
-            <field name="name">Imperia</field>
-            <field name="code">IT-IM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-42"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-is">
-            <field name="name">Isernia</field>
-            <field name="code">IT-IS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-67"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-kr">
-            <field name="name">Crotone</field>
-            <field name="code">IT-KR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-78"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-lc">
-            <field name="name">Lecco</field>
-            <field name="code">IT-LC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-le">
-            <field name="name">Lecce</field>
-            <field name="code">IT-LE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-75"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-li">
-            <field name="name">Livorno</field>
-            <field name="code">IT-LI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-lo">
-            <field name="name">Lodi</field>
-            <field name="code">IT-LO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-lt">
-            <field name="name">Latina</field>
-            <field name="code">IT-LT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-62"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-lu">
-            <field name="name">Lucca</field>
-            <field name="code">IT-LU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-mb">
-            <field name="name">Monza e Brianza</field>
-            <field name="code">IT-MB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-mc">
-            <field name="name">Macerata</field>
-            <field name="code">IT-MC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-57"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-me">
-            <field name="name">Messina</field>
-            <field name="code">IT-ME</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-mi">
-            <field name="name">Milano</field>
-            <field name="code">IT-MI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-mn">
-            <field name="name">Mantova</field>
-            <field name="code">IT-MN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-mo">
-            <field name="name">Modena</field>
-            <field name="code">IT-MO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ms">
-            <field name="name">Massa-Carrara</field>
-            <field name="code">IT-MS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-mt">
-            <field name="name">Matera</field>
-            <field name="code">IT-MT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-77"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-na">
-            <field name="name">Napoli</field>
-            <field name="code">IT-NA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-72"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-no">
-            <field name="name">Novara</field>
-            <field name="code">IT-NO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-nu">
-            <field name="name">Nuoro</field>
-            <field name="code">IT-NU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-og">
-            <field name="name">Ogliastra</field>
-            <field name="code">IT-OG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-or">
-            <field name="name">Oristano</field>
-            <field name="code">IT-OR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ot">
-            <field name="name">Olbia-Tempio</field>
-            <field name="code">IT-OT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pa">
-            <field name="name">Palermo</field>
-            <field name="code">IT-PA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pc">
-            <field name="name">Piacenza</field>
-            <field name="code">IT-PC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pd">
-            <field name="name">Padova</field>
-            <field name="code">IT-PD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-34"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pe">
-            <field name="name">Pescara</field>
-            <field name="code">IT-PE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-65"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pg">
-            <field name="name">Perugia</field>
-            <field name="code">IT-PG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-55"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pi">
-            <field name="name">Pisa</field>
-            <field name="code">IT-PI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pn">
-            <field name="name">Pordenone</field>
-            <field name="code">IT-PN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-36"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-po">
-            <field name="name">Prato</field>
-            <field name="code">IT-PO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pr">
-            <field name="name">Parma</field>
-            <field name="code">IT-PR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pt">
-            <field name="name">Pistoia</field>
-            <field name="code">IT-PT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pu">
-            <field name="name">Pesaro e Urbino</field>
-            <field name="code">IT-PU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-57"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pv">
-            <field name="name">Pavia</field>
-            <field name="code">IT-PV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-pz">
-            <field name="name">Potenza</field>
-            <field name="code">IT-PZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-77"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ra">
-            <field name="name">Ravenna</field>
-            <field name="code">IT-RA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-rc">
-            <field name="name">Reggio Calabria</field>
-            <field name="code">IT-RC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-78"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-re">
-            <field name="name">Reggio Emilia</field>
-            <field name="code">IT-RE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-rg">
-            <field name="name">Ragusa</field>
-            <field name="code">IT-RG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ri">
-            <field name="name">Rieti</field>
-            <field name="code">IT-RI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-62"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-rm">
-            <field name="name">Roma</field>
-            <field name="code">IT-RM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-62"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-rn">
-            <field name="name">Rimini</field>
-            <field name="code">IT-RN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-45"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ro">
-            <field name="name">Rovigo</field>
-            <field name="code">IT-RO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-34"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-sa">
-            <field name="name">Salerno</field>
-            <field name="code">IT-SA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-72"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-si">
-            <field name="name">Siena</field>
-            <field name="code">IT-SI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-52"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-so">
-            <field name="name">Sondrio</field>
-            <field name="code">IT-SO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-sp">
-            <field name="name">La Spezia</field>
-            <field name="code">IT-SP</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-42"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-sr">
-            <field name="name">Siracusa</field>
-            <field name="code">IT-SR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ss">
-            <field name="name">Sassari</field>
-            <field name="code">IT-SS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-sv">
-            <field name="name">Savona</field>
-            <field name="code">IT-SV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-42"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ta">
-            <field name="name">Taranto</field>
-            <field name="code">IT-TA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-75"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-te">
-            <field name="name">Teramo</field>
-            <field name="code">IT-TE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-65"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-tn">
-            <field name="name">Trento</field>
-            <field name="code">IT-TN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-32"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-to">
-            <field name="name">Torino</field>
-            <field name="code">IT-TO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-tp">
-            <field name="name">Trapani</field>
-            <field name="code">IT-TP</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-82"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-tr">
-            <field name="name">Terni</field>
-            <field name="code">IT-TR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-55"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ts">
-            <field name="name">Trieste</field>
-            <field name="code">IT-TS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-36"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-tv">
-            <field name="name">Treviso</field>
-            <field name="code">IT-TV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-34"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ud">
-            <field name="name">Udine</field>
-            <field name="code">IT-UD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-36"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-va">
-            <field name="name">Varese</field>
-            <field name="code">IT-VA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-25"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-vb">
-            <field name="name">Verbano-Cusio-Ossola</field>
-            <field name="code">IT-VB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-vc">
-            <field name="name">Vercelli</field>
-            <field name="code">IT-VC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-21"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-ve">
-            <field name="name">Venezia</field>
-            <field name="code">IT-VE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-34"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-vi">
-            <field name="name">Vicenza</field>
-            <field name="code">IT-VI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-34"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-vr">
-            <field name="name">Verona</field>
-            <field name="code">IT-VR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-34"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-vs">
-            <field name="name">Medio Campidano</field>
-            <field name="code">IT-VS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-88"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-vt">
-            <field name="name">Viterbo</field>
-            <field name="code">IT-VT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-62"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="it-vv">
-            <field name="name">Vibo Valentia</field>
-            <field name="code">IT-VV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="it-78"/>
-            <field name="country" ref="it"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-01">
-            <field name="name">Christ Church Nichola Town</field>
-            <field name="code">KN-01</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-02">
-            <field name="name">Saint Anne Sandy Point</field>
-            <field name="code">KN-02</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-03">
-            <field name="name">Saint George Basseterre</field>
-            <field name="code">KN-03</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-04">
-            <field name="name">Saint George Gingerland</field>
-            <field name="code">KN-04</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-n"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-05">
-            <field name="name">Saint James Windward</field>
-            <field name="code">KN-05</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-n"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-06">
-            <field name="name">Saint John Capisterre</field>
-            <field name="code">KN-06</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-07">
-            <field name="name">Saint John Figtree</field>
-            <field name="code">KN-07</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-n"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-08">
-            <field name="name">Saint Mary Cayon</field>
-            <field name="code">KN-08</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-09">
-            <field name="name">Saint Paul Capisterre</field>
-            <field name="code">KN-09</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-10">
-            <field name="name">Saint Paul Charlestown</field>
-            <field name="code">KN-10</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-n"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-11">
-            <field name="name">Saint Peter Basseterre</field>
-            <field name="code">KN-11</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-12">
-            <field name="name">Saint Thomas Lowland</field>
-            <field name="code">KN-12</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-n"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-13">
-            <field name="name">Saint Thomas Middle Island</field>
-            <field name="code">KN-13</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="kn-15">
-            <field name="name">Trinity Palmetto Point</field>
-            <field name="code">KN-15</field>
-            <field name="type">parish</field>
-            <field name="parent" ref="kn-k"/>
-            <field name="country" ref="kn"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-11">
-            <field name="name">Kŏḷamba</field>
-            <field name="code">LK-11</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-1"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-12">
-            <field name="name">Gampaha</field>
-            <field name="code">LK-12</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-1"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-13">
-            <field name="name">Kaḷutara</field>
-            <field name="code">LK-13</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-1"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-21">
-            <field name="name">Mahanuvara</field>
-            <field name="code">LK-21</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-2"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-22">
-            <field name="name">Mātale</field>
-            <field name="code">LK-22</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-2"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-23">
-            <field name="name">Nuvara Ĕliya</field>
-            <field name="code">LK-23</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-2"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-31">
-            <field name="name">Gālla</field>
-            <field name="code">LK-31</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-3"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-32">
-            <field name="name">Mātara</field>
-            <field name="code">LK-32</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-3"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-33">
-            <field name="name">Hambantŏṭa</field>
-            <field name="code">LK-33</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-3"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-41">
-            <field name="name">Yāpanaya</field>
-            <field name="code">LK-41</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-4"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-42">
-            <field name="name">Kilinŏchchi</field>
-            <field name="code">LK-42</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-4"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-43">
-            <field name="name">Mannārama</field>
-            <field name="code">LK-43</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-4"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-44">
-            <field name="name">Vavuniyāva</field>
-            <field name="code">LK-44</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-4"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-45">
-            <field name="name">Mulativ</field>
-            <field name="code">LK-45</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-4"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-51">
-            <field name="name">Maḍakalapuva</field>
-            <field name="code">LK-51</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-5"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-52">
-            <field name="name">Ampāara</field>
-            <field name="code">LK-52</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-5"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-53">
-            <field name="name">Trikuṇāmalaya</field>
-            <field name="code">LK-53</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-5"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-61">
-            <field name="name">Kuruṇægala</field>
-            <field name="code">LK-61</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-6"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-62">
-            <field name="name">Puttalama</field>
-            <field name="code">LK-62</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-6"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-71">
-            <field name="name">Anurādhapura</field>
-            <field name="code">LK-71</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-7"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-72">
-            <field name="name">Pŏḷŏnnaruva</field>
-            <field name="code">LK-72</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-7"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-81">
-            <field name="name">Badulla</field>
-            <field name="code">LK-81</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-8"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-82">
-            <field name="name">Mŏṇarāgala</field>
-            <field name="code">LK-82</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-8"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-91">
-            <field name="name">Ratnapura</field>
-            <field name="code">LK-91</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-9"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="lk-92">
-            <field name="name">Kægalla</field>
-            <field name="code">LK-92</field>
-            <field name="type">district</field>
-            <field name="parent" ref="lk-9"/>
-            <field name="country" ref="lk"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-agd">
-            <field name="name">Agadir-Ida-Outanane</field>
-            <field name="code">MA-AGD</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-13"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-aou">
-            <field name="name">Aousserd</field>
-            <field name="code">MA-AOU</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-16"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-asz">
-            <field name="name">Assa-Zag</field>
-            <field name="code">MA-ASZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-14"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-azi">
-            <field name="name">Azilal</field>
-            <field name="code">MA-AZI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-12"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-bem">
-            <field name="name">Beni Mellal</field>
-            <field name="code">MA-BEM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-12"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-ber">
-            <field name="name">Berkane</field>
-            <field name="code">MA-BER</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-04"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-bes">
-            <field name="name">Ben Slimane</field>
-            <field name="code">MA-BES</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-09"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-bod">
-            <field name="name">Boujdour (EH)</field>
-            <field name="code">MA-BOD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-15"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-bom">
-            <field name="name">Boulemane</field>
-            <field name="code">MA-BOM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-05"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-cas">
-            <field name="name">Casablanca [Dar el Beïda]</field>
-            <field name="code">MA-CAS</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-08"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-che">
-            <field name="name">Chefchaouen</field>
-            <field name="code">MA-CHE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-01"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-chi">
-            <field name="name">Chichaoua</field>
-            <field name="code">MA-CHI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-11"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-cht">
-            <field name="name">Chtouka-Ait Baha</field>
-            <field name="code">MA-CHT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-13"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-err">
-            <field name="name">Errachidia</field>
-            <field name="code">MA-ERR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-06"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-esi">
-            <field name="name">Essaouira</field>
-            <field name="code">MA-ESI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-11"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-esm">
-            <field name="name">Es Smara (EH)</field>
-            <field name="code">MA-ESM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-14"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-fah">
-            <field name="name">Fahs-Beni Makada</field>
-            <field name="code">MA-FAH</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-01"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-fes">
-            <field name="name">Fès-Dar-Dbibegh</field>
-            <field name="code">MA-FES</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-05"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-fig">
-            <field name="name">Figuig</field>
-            <field name="code">MA-FIG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-04"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-gue">
-            <field name="name">Guelmim</field>
-            <field name="code">MA-GUE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-14"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-haj">
-            <field name="name">El Hajeb</field>
-            <field name="code">MA-HAJ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-06"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-hao">
-            <field name="name">Al Haouz</field>
-            <field name="code">MA-HAO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-11"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-hoc">
-            <field name="name">Al Hoceïma</field>
-            <field name="code">MA-HOC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-03"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-ifr">
-            <field name="name">Ifrane</field>
-            <field name="code">MA-IFR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-06"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-ine">
-            <field name="name">Inezgane-Ait Melloul</field>
-            <field name="code">MA-INE</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-13"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-jdi">
-            <field name="name">El Jadida</field>
-            <field name="code">MA-JDI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-10"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-jra">
-            <field name="name">Jrada</field>
-            <field name="code">MA-JRA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-04"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-ken">
-            <field name="name">Kénitra</field>
-            <field name="code">MA-KEN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-02"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-kes">
-            <field name="name">Kelaat es Sraghna</field>
-            <field name="code">MA-KES</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-11"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-khe">
-            <field name="name">Khemisaet</field>
-            <field name="code">MA-KHE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-07"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-khn">
-            <field name="name">Khenifra</field>
-            <field name="code">MA-KHN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-06"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-kho">
-            <field name="name">Khouribga</field>
-            <field name="code">MA-KHO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-09"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-laa">
-            <field name="name">Laâyoune (EH)</field>
-            <field name="code">MA-LAA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-15"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-lar">
-            <field name="name">Larache</field>
-            <field name="code">MA-LAR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-01"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-med">
-            <field name="name">Médiouna</field>
-            <field name="code">MA-MED</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-08"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-mek">
-            <field name="name">Meknès</field>
-            <field name="code">MA-MEK</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-06"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-mmd">
-            <field name="name">Marrakech-Medina</field>
-            <field name="code">MA-MMD</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-11"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-mmn">
-            <field name="name">Marrakech-Menara</field>
-            <field name="code">MA-MMN</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-11"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-moh">
-            <field name="name">Mohammadia</field>
-            <field name="code">MA-MOH</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-08"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-mou">
-            <field name="name">Moulay Yacoub</field>
-            <field name="code">MA-MOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-05"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-nad">
-            <field name="name">Nador</field>
-            <field name="code">MA-NAD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-04"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-nou">
-            <field name="name">Nouaceur</field>
-            <field name="code">MA-NOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-08"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-oua">
-            <field name="name">Ouarzazate</field>
-            <field name="code">MA-OUA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-13"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-oud">
-            <field name="name">Oued ed Dahab (EH)</field>
-            <field name="code">MA-OUD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-16"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-ouj">
-            <field name="name">Oujda-Angad</field>
-            <field name="code">MA-OUJ</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-04"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-rab">
-            <field name="name">Rabat</field>
-            <field name="code">MA-RAB</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-07"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-saf">
-            <field name="name">Safi</field>
-            <field name="code">MA-SAF</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-10"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-sal">
-            <field name="name">Salé</field>
-            <field name="code">MA-SAL</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-07"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-sef">
-            <field name="name">Sefrou</field>
-            <field name="code">MA-SEF</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-05"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-set">
-            <field name="name">Settat</field>
-            <field name="code">MA-SET</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-09"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-sik">
-            <field name="name">Sidl Kacem</field>
-            <field name="code">MA-SIK</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-02"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-skh">
-            <field name="name">Skhirate-Témara</field>
-            <field name="code">MA-SKH</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-07"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-syb">
-            <field name="name">Sidi Youssef Ben Ali</field>
-            <field name="code">MA-SYB</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-11"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tai">
-            <field name="name">Taourirt</field>
-            <field name="code">MA-TAI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-04"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tao">
-            <field name="name">Taounate</field>
-            <field name="code">MA-TAO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-03"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tar">
-            <field name="name">Taroudant</field>
-            <field name="code">MA-TAR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-13"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tat">
-            <field name="name">Tata</field>
-            <field name="code">MA-TAT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-14"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-taz">
-            <field name="name">Taza</field>
-            <field name="code">MA-TAZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-03"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tet">
-            <field name="name">Tétouan</field>
-            <field name="code">MA-TET</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-01"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tiz">
-            <field name="name">Tiznit</field>
-            <field name="code">MA-TIZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-13"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tng">
-            <field name="name">Tanger-Assilah</field>
-            <field name="code">MA-TNG</field>
-            <field name="type">prefecture</field>
-            <field name="parent" ref="ma-01"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-tnt">
-            <field name="name">Tan-Tan</field>
-            <field name="code">MA-TNT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-14"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="ma-zag">
-            <field name="name">Zagora</field>
-            <field name="code">MA-ZAG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ma-13"/>
-            <field name="country" ref="ma"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-alk">
-            <field name="name">Ailuk</field>
-            <field name="code">MH-ALK</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-all">
-            <field name="name">Ailinglaplap</field>
-            <field name="code">MH-ALL</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-arn">
-            <field name="name">Arno</field>
-            <field name="code">MH-ARN</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-aur">
-            <field name="name">Aur</field>
-            <field name="code">MH-AUR</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-ebo">
-            <field name="name">Ebon</field>
-            <field name="code">MH-EBO</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-eni">
-            <field name="name">Enewetak</field>
-            <field name="code">MH-ENI</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-jab">
-            <field name="name">Jabat</field>
-            <field name="code">MH-JAB</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-jal">
-            <field name="name">Jaluit</field>
-            <field name="code">MH-JAL</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-kil">
-            <field name="name">Kili</field>
-            <field name="code">MH-KIL</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-kwa">
-            <field name="name">Kwajalein</field>
-            <field name="code">MH-KWA</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-lae">
-            <field name="name">Lae</field>
-            <field name="code">MH-LAE</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-lib">
-            <field name="name">Lib</field>
-            <field name="code">MH-LIB</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-lik">
-            <field name="name">Likiep</field>
-            <field name="code">MH-LIK</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-maj">
-            <field name="name">Majuro</field>
-            <field name="code">MH-MAJ</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-mal">
-            <field name="name">Maloelap</field>
-            <field name="code">MH-MAL</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-mej">
-            <field name="name">Mejit</field>
-            <field name="code">MH-MEJ</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-mil">
-            <field name="name">Mili</field>
-            <field name="code">MH-MIL</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-nmk">
-            <field name="name">Namdrik</field>
-            <field name="code">MH-NMK</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-nmu">
-            <field name="name">Namu</field>
-            <field name="code">MH-NMU</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-ron">
-            <field name="name">Rongelap</field>
-            <field name="code">MH-RON</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-uja">
-            <field name="name">Ujae</field>
-            <field name="code">MH-UJA</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-uti">
-            <field name="name">Utirik</field>
-            <field name="code">MH-UTI</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-wtj">
-            <field name="name">Wotje</field>
-            <field name="code">MH-WTJ</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-t"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mh-wtn">
-            <field name="name">Wotho</field>
-            <field name="code">MH-WTN</field>
-            <field name="type">municipality</field>
-            <field name="parent" ref="mh-l"/>
-            <field name="country" ref="mh"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-00">
-            <field name="name">Alifu Dhaalu</field>
-            <field name="code">MV-00</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-nc"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-01">
-            <field name="name">Seenu</field>
-            <field name="code">MV-01</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-su"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-02">
-            <field name="name">Alifu Alifu</field>
-            <field name="code">MV-02</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-nc"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-03">
-            <field name="name">Lhaviyani</field>
-            <field name="code">MV-03</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-no"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-04">
-            <field name="name">Vaavu</field>
-            <field name="code">MV-04</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-nc"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-05">
-            <field name="name">Laamu</field>
-            <field name="code">MV-05</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-us"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-07">
-            <field name="name">Haa Alifu</field>
-            <field name="code">MV-07</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-un"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-08">
-            <field name="name">Thaa</field>
-            <field name="code">MV-08</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-us"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-12">
-            <field name="name">Meemu</field>
-            <field name="code">MV-12</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-ce"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-13">
-            <field name="name">Raa</field>
-            <field name="code">MV-13</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-no"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-14">
-            <field name="name">Faafu</field>
-            <field name="code">MV-14</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-ce"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-17">
-            <field name="name">Dhaalu</field>
-            <field name="code">MV-17</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-ce"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-20">
-            <field name="name">Baa</field>
-            <field name="code">MV-20</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-no"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-23">
-            <field name="name">Haa Dhaalu</field>
-            <field name="code">MV-23</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-un"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-24">
-            <field name="name">Shaviyani</field>
-            <field name="code">MV-24</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-un"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-25">
-            <field name="name">Noonu</field>
-            <field name="code">MV-25</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-no"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-26">
-            <field name="name">Kaafu</field>
-            <field name="code">MV-26</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-nc"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-27">
-            <field name="name">Gaafu Alifu</field>
-            <field name="code">MV-27</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-sc"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-28">
-            <field name="name">Gaafu Dhaalu</field>
-            <field name="code">MV-28</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-sc"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mv-29">
-            <field name="name">Gnaviyani</field>
-            <field name="code">MV-29</field>
-            <field name="type">administrative atoll</field>
-            <field name="parent" ref="mv-su"/>
-            <field name="country" ref="mv"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ba">
-            <field name="name">Balaka</field>
-            <field name="code">MW-BA</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-bl">
-            <field name="name">Blantyre</field>
-            <field name="code">MW-BL</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ck">
-            <field name="name">Chikwawa</field>
-            <field name="code">MW-CK</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-cr">
-            <field name="name">Chiradzulu</field>
-            <field name="code">MW-CR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ct">
-            <field name="name">Chitipa</field>
-            <field name="code">MW-CT</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-n"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-de">
-            <field name="name">Dedza</field>
-            <field name="code">MW-DE</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-do">
-            <field name="name">Dowa</field>
-            <field name="code">MW-DO</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-kr">
-            <field name="name">Karonga</field>
-            <field name="code">MW-KR</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-n"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ks">
-            <field name="name">Kasungu</field>
-            <field name="code">MW-KS</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-li">
-            <field name="name">Lilongwe</field>
-            <field name="code">MW-LI</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-lk">
-            <field name="name">Likoma</field>
-            <field name="code">MW-LK</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-n"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-mc">
-            <field name="name">Mchinji</field>
-            <field name="code">MW-MC</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-mg">
-            <field name="name">Mangochi</field>
-            <field name="code">MW-MG</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-mh">
-            <field name="name">Machinga</field>
-            <field name="code">MW-MH</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-mu">
-            <field name="name">Mulanje</field>
-            <field name="code">MW-MU</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-mw">
-            <field name="name">Mwanza</field>
-            <field name="code">MW-MW</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-mz">
-            <field name="name">Mzimba</field>
-            <field name="code">MW-MZ</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-n"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-nb">
-            <field name="name">Nkhata Bay</field>
-            <field name="code">MW-NB</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-n"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ne">
-            <field name="name">Neno</field>
-            <field name="code">MW-NE</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-n"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ni">
-            <field name="name">Ntchisi</field>
-            <field name="code">MW-NI</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-nk">
-            <field name="name">Nkhotakota</field>
-            <field name="code">MW-NK</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ns">
-            <field name="name">Nsanje</field>
-            <field name="code">MW-NS</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-nu">
-            <field name="name">Ntcheu</field>
-            <field name="code">MW-NU</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ph">
-            <field name="name">Phalombe</field>
-            <field name="code">MW-PH</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-ru">
-            <field name="name">Rumphi</field>
-            <field name="code">MW-RU</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-n"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-sa">
-            <field name="name">Salima</field>
-            <field name="code">MW-SA</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-c"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-th">
-            <field name="name">Thyolo</field>
-            <field name="code">MW-TH</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="mw-zo">
-            <field name="name">Zomba</field>
-            <field name="code">MW-ZO</field>
-            <field name="type">district</field>
-            <field name="parent" ref="mw-s"/>
-            <field name="country" ref="mw"/>
-        </record>
-
-        <record model="country.subdivision" id="np-ba">
-            <field name="name">Bagmati</field>
-            <field name="code">NP-BA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-1"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-bh">
-            <field name="name">Bheri</field>
-            <field name="code">NP-BH</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-2"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-dh">
-            <field name="name">Dhawalagiri</field>
-            <field name="code">NP-DH</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-3"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-ga">
-            <field name="name">Gandaki</field>
-            <field name="code">NP-GA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-3"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-ja">
-            <field name="name">Janakpur</field>
-            <field name="code">NP-JA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-1"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-ka">
-            <field name="name">Karnali</field>
-            <field name="code">NP-KA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-2"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-ko">
-            <field name="name">Kosi</field>
-            <field name="code">NP-KO</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-4"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-lu">
-            <field name="name">Lumbini</field>
-            <field name="code">NP-LU</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-3"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-ma">
-            <field name="name">Mahakali</field>
-            <field name="code">NP-MA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-5"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-me">
-            <field name="name">Mechi</field>
-            <field name="code">NP-ME</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-4"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-na">
-            <field name="name">Narayani</field>
-            <field name="code">NP-NA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-1"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-ra">
-            <field name="name">Rapti</field>
-            <field name="code">NP-RA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-2"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-sa">
-            <field name="name">Sagarmatha</field>
-            <field name="code">NP-SA</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-4"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="np-se">
-            <field name="name">Seti</field>
-            <field name="code">NP-SE</field>
-            <field name="type">zone</field>
-            <field name="parent" ref="np-5"/>
-            <field name="country" ref="np"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-auk">
-            <field name="name">Auckland</field>
-            <field name="code">NZ-AUK</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-bop">
-            <field name="name">Bay of Plenty</field>
-            <field name="code">NZ-BOP</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-can">
-            <field name="name">Canterbury</field>
-            <field name="code">NZ-CAN</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-s"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-gis">
-            <field name="name">Gisborne District</field>
-            <field name="code">NZ-GIS</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-hkb">
-            <field name="name">Hawke's Bay</field>
-            <field name="code">NZ-HKB</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-mbh">
-            <field name="name">Marlborough District</field>
-            <field name="code">NZ-MBH</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="nz-s"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-mwt">
-            <field name="name">Manawatu-Wanganui</field>
-            <field name="code">NZ-MWT</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-nsn">
-            <field name="name">Nelson City</field>
-            <field name="code">NZ-NSN</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="nz-s"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-ntl">
-            <field name="name">Northland</field>
-            <field name="code">NZ-NTL</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-ota">
-            <field name="name">Otago</field>
-            <field name="code">NZ-OTA</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-s"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-stl">
-            <field name="name">Southland</field>
-            <field name="code">NZ-STL</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-s"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-tas">
-            <field name="name">Tasman District</field>
-            <field name="code">NZ-TAS</field>
-            <field name="type">unitary authority</field>
-            <field name="parent" ref="nz-s"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-tki">
-            <field name="name">Taranaki</field>
-            <field name="code">NZ-TKI</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-wgn">
-            <field name="name">Wellington</field>
-            <field name="code">NZ-WGN</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-wko">
-            <field name="name">Waikato</field>
-            <field name="code">NZ-WKO</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-n"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="nz-wtc">
-            <field name="name">West Coast</field>
-            <field name="code">NZ-WTC</field>
-            <field name="type">regional council</field>
-            <field name="parent" ref="nz-s"/>
-            <field name="country" ref="nz"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-abr">
-            <field name="name">Abra</field>
-            <field name="code">PH-ABR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-15"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-agn">
-            <field name="name">Agusan del Norte</field>
-            <field name="code">PH-AGN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-13"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ags">
-            <field name="name">Agusan del Sur</field>
-            <field name="code">PH-AGS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-13"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-akl">
-            <field name="name">Aklan</field>
-            <field name="code">PH-AKL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-06"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-alb">
-            <field name="name">Albay</field>
-            <field name="code">PH-ALB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-05"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ant">
-            <field name="name">Antique</field>
-            <field name="code">PH-ANT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-06"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-apa">
-            <field name="name">Apayao</field>
-            <field name="code">PH-APA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-15"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-aur">
-            <field name="name">Aurora</field>
-            <field name="code">PH-AUR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-03"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ban">
-            <field name="name">Batasn</field>
-            <field name="code">PH-BAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-03"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-bas">
-            <field name="name">Basilan</field>
-            <field name="code">PH-BAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-09"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ben">
-            <field name="name">Benguet</field>
-            <field name="code">PH-BEN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-15"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-bil">
-            <field name="name">Biliran</field>
-            <field name="code">PH-BIL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-08"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-boh">
-            <field name="name">Bohol</field>
-            <field name="code">PH-BOH</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-07"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-btg">
-            <field name="name">Batangas</field>
-            <field name="code">PH-BTG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-40"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-btn">
-            <field name="name">Batanes</field>
-            <field name="code">PH-BTN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-02"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-buk">
-            <field name="name">Bukidnon</field>
-            <field name="code">PH-BUK</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-10"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-bul">
-            <field name="name">Bulacan</field>
-            <field name="code">PH-BUL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-03"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-cag">
-            <field name="name">Cagayan</field>
-            <field name="code">PH-CAG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-02"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-cam">
-            <field name="name">Camiguin</field>
-            <field name="code">PH-CAM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-10"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-can">
-            <field name="name">Camarines Norte</field>
-            <field name="code">PH-CAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-05"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-cap">
-            <field name="name">Capiz</field>
-            <field name="code">PH-CAP</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-06"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-cas">
-            <field name="name">Camarines Sur</field>
-            <field name="code">PH-CAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-05"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-cat">
-            <field name="name">Catanduanes</field>
-            <field name="code">PH-CAT</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-05"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-cav">
-            <field name="name">Cavite</field>
-            <field name="code">PH-CAV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-40"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ceb">
-            <field name="name">Cebu</field>
-            <field name="code">PH-CEB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-07"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-com">
-            <field name="name">Compostela Valley</field>
-            <field name="code">PH-COM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-11"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-dao">
-            <field name="name">Davao Oriental</field>
-            <field name="code">PH-DAO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-11"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-das">
-            <field name="name">Davao del Sur</field>
-            <field name="code">PH-DAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-11"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-dav">
-            <field name="name">Davao del Norte</field>
-            <field name="code">PH-DAV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-11"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-din">
-            <field name="name">Dinagat Islands</field>
-            <field name="code">PH-DIN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-13"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-eas">
-            <field name="name">Eastern Samar</field>
-            <field name="code">PH-EAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-08"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-gui">
-            <field name="name">Guimaras</field>
-            <field name="code">PH-GUI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-06"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ifu">
-            <field name="name">Ifugao</field>
-            <field name="code">PH-IFU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-15"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ili">
-            <field name="name">Iloilo</field>
-            <field name="code">PH-ILI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-06"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-iln">
-            <field name="name">Ilocos Norte</field>
-            <field name="code">PH-ILN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-01"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ils">
-            <field name="name">Ilocos Sur</field>
-            <field name="code">PH-ILS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-01"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-isa">
-            <field name="name">Isabela</field>
-            <field name="code">PH-ISA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-02"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-kal">
-            <field name="name">Kalinga-Apayso</field>
-            <field name="code">PH-KAL</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-15"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-lag">
-            <field name="name">Laguna</field>
-            <field name="code">PH-LAG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-40"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-lan">
-            <field name="name">Lanao del Norte</field>
-            <field name="code">PH-LAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-12"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-las">
-            <field name="name">Lanao del Sur</field>
-            <field name="code">PH-LAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-14"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ley">
-            <field name="name">Leyte</field>
-            <field name="code">PH-LEY</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-08"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-lun">
-            <field name="name">La Union</field>
-            <field name="code">PH-LUN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-01"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-mad">
-            <field name="name">Marinduque</field>
-            <field name="code">PH-MAD</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-41"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-mag">
-            <field name="name">Maguindanao</field>
-            <field name="code">PH-MAG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-14"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-mas">
-            <field name="name">Masbate</field>
-            <field name="code">PH-MAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-05"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-mdc">
-            <field name="name">Mindoro Occidental</field>
-            <field name="code">PH-MDC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-41"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-mdr">
-            <field name="name">Mindoro Oriental</field>
-            <field name="code">PH-MDR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-41"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-mou">
-            <field name="name">Mountain Province</field>
-            <field name="code">PH-MOU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-15"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-msc">
-            <field name="name">Misamis Occidental</field>
-            <field name="code">PH-MSC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-10"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-msr">
-            <field name="name">Misamis Oriental</field>
-            <field name="code">PH-MSR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-10"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-nco">
-            <field name="name">North Cotabato</field>
-            <field name="code">PH-NCO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-12"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-nec">
-            <field name="name">Negros Occidental</field>
-            <field name="code">PH-NEC</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-06"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-ner">
-            <field name="name">Negros Oriental</field>
-            <field name="code">PH-NER</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-07"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-nsa">
-            <field name="name">Northern Samar</field>
-            <field name="code">PH-NSA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-08"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-nue">
-            <field name="name">Nueva Ecija</field>
-            <field name="code">PH-NUE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-03"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-nuv">
-            <field name="name">Nueva Vizcaya</field>
-            <field name="code">PH-NUV</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-02"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-pam">
-            <field name="name">Pampanga</field>
-            <field name="code">PH-PAM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-03"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-pan">
-            <field name="name">Pangasinan</field>
-            <field name="code">PH-PAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-01"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-plw">
-            <field name="name">Palawan</field>
-            <field name="code">PH-PLW</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-41"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-que">
-            <field name="name">Quezon</field>
-            <field name="code">PH-QUE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-40"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-qui">
-            <field name="name">Quirino</field>
-            <field name="code">PH-QUI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-02"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-riz">
-            <field name="name">Rizal</field>
-            <field name="code">PH-RIZ</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-40"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-rom">
-            <field name="name">Romblon</field>
-            <field name="code">PH-ROM</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-41"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-sar">
-            <field name="name">Sarangani</field>
-            <field name="code">PH-SAR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-11"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-sco">
-            <field name="name">South Cotabato</field>
-            <field name="code">PH-SCO</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-11"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-sig">
-            <field name="name">Siquijor</field>
-            <field name="code">PH-SIG</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-07"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-sle">
-            <field name="name">Southern Leyte</field>
-            <field name="code">PH-SLE</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-08"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-slu">
-            <field name="name">Sulu</field>
-            <field name="code">PH-SLU</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-14"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-sor">
-            <field name="name">Sorsogon</field>
-            <field name="code">PH-SOR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-05"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-suk">
-            <field name="name">Sultan Kudarat</field>
-            <field name="code">PH-SUK</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-12"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-sun">
-            <field name="name">Surigao del Norte</field>
-            <field name="code">PH-SUN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-13"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-sur">
-            <field name="name">Surigao del Sur</field>
-            <field name="code">PH-SUR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-13"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-tar">
-            <field name="name">Tarlac</field>
-            <field name="code">PH-TAR</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-03"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-taw">
-            <field name="name">Tawi-Tawi</field>
-            <field name="code">PH-TAW</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-14"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-wsa">
-            <field name="name">Western Samar</field>
-            <field name="code">PH-WSA</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-08"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-zan">
-            <field name="name">Zamboanga del Norte</field>
-            <field name="code">PH-ZAN</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-09"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-zas">
-            <field name="name">Zamboanga del Sur</field>
-            <field name="code">PH-ZAS</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-09"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-zmb">
-            <field name="name">Zambales</field>
-            <field name="code">PH-ZMB</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-03"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="ph-zsi">
-            <field name="name">Zamboanga Sibugay</field>
-            <field name="code">PH-ZSI</field>
-            <field name="type">province</field>
-            <field name="parent" ref="ph-09"/>
-            <field name="country" ref="ph"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-01">
-            <field name="name">Severnobački okrug</field>
-            <field name="code">RS-01</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-vo"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-02">
-            <field name="name">Srednjebanatski okrug</field>
-            <field name="code">RS-02</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-vo"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-03">
-            <field name="name">Severnobanatski okrug</field>
-            <field name="code">RS-03</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-vo"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-04">
-            <field name="name">Južnobanatski okrug</field>
-            <field name="code">RS-04</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-vo"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-05">
-            <field name="name">Zapadnobački okrug</field>
-            <field name="code">RS-05</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-vo"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-06">
-            <field name="name">Južnobački okrug</field>
-            <field name="code">RS-06</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-vo"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-07">
-            <field name="name">Sremski okrug</field>
-            <field name="code">RS-07</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-vo"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-25">
-            <field name="name">Kosovski okrug</field>
-            <field name="code">RS-25</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-km"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-26">
-            <field name="name">Pećki okrug</field>
-            <field name="code">RS-26</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-km"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-27">
-            <field name="name">Prizrenski okrug</field>
-            <field name="code">RS-27</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-km"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-28">
-            <field name="name">Kosovsko-Mitrovački okrug</field>
-            <field name="code">RS-28</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-km"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="rs-29">
-            <field name="name">Kosovsko-Pomoravski okrug</field>
-            <field name="code">RS-29</field>
-            <field name="type">district</field>
-            <field name="parent" ref="rs-km"/>
-            <field name="country" ref="rs"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-101">
-            <field name="name">Kalangala</field>
-            <field name="code">UG-101</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-102">
-            <field name="name">Kampala</field>
-            <field name="code">UG-102</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-103">
-            <field name="name">Kiboga</field>
-            <field name="code">UG-103</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-104">
-            <field name="name">Luwero</field>
-            <field name="code">UG-104</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-105">
-            <field name="name">Masaka</field>
-            <field name="code">UG-105</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-106">
-            <field name="name">Mpigi</field>
-            <field name="code">UG-106</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-107">
-            <field name="name">Mubende</field>
-            <field name="code">UG-107</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-108">
-            <field name="name">Mukono</field>
-            <field name="code">UG-108</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-109">
-            <field name="name">Nakasongola</field>
-            <field name="code">UG-109</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-110">
-            <field name="name">Rakai</field>
-            <field name="code">UG-110</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-111">
-            <field name="name">Sembabule</field>
-            <field name="code">UG-111</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-112">
-            <field name="name">Kayunga</field>
-            <field name="code">UG-112</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-113">
-            <field name="name">Wakiso</field>
-            <field name="code">UG-113</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-114">
-            <field name="name">Mityana</field>
-            <field name="code">UG-114</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-115">
-            <field name="name">Nakaseke</field>
-            <field name="code">UG-115</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-116">
-            <field name="name">Lyantonde</field>
-            <field name="code">UG-116</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-c"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-201">
-            <field name="name">Bugiri</field>
-            <field name="code">UG-201</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-202">
-            <field name="name">Busia</field>
-            <field name="code">UG-202</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-203">
-            <field name="name">Iganga</field>
-            <field name="code">UG-203</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-204">
-            <field name="name">Jinja</field>
-            <field name="code">UG-204</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-205">
-            <field name="name">Kamuli</field>
-            <field name="code">UG-205</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-206">
-            <field name="name">Kapchorwa</field>
-            <field name="code">UG-206</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-207">
-            <field name="name">Katakwi</field>
-            <field name="code">UG-207</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-208">
-            <field name="name">Kumi</field>
-            <field name="code">UG-208</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-209">
-            <field name="name">Mbale</field>
-            <field name="code">UG-209</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-210">
-            <field name="name">Pallisa</field>
-            <field name="code">UG-210</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-211">
-            <field name="name">Soroti</field>
-            <field name="code">UG-211</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-212">
-            <field name="name">Tororo</field>
-            <field name="code">UG-212</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-213">
-            <field name="name">Kaberamaido</field>
-            <field name="code">UG-213</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-214">
-            <field name="name">Mayuge</field>
-            <field name="code">UG-214</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-215">
-            <field name="name">Sironko</field>
-            <field name="code">UG-215</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-216">
-            <field name="name">Amuria</field>
-            <field name="code">UG-216</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-217">
-            <field name="name">Budaka</field>
-            <field name="code">UG-217</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-218">
-            <field name="name">Bukwa</field>
-            <field name="code">UG-218</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-219">
-            <field name="name">Butaleja</field>
-            <field name="code">UG-219</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-220">
-            <field name="name">Kaliro</field>
-            <field name="code">UG-220</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-221">
-            <field name="name">Manafwa</field>
-            <field name="code">UG-221</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-222">
-            <field name="name">Namutumba</field>
-            <field name="code">UG-222</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-223">
-            <field name="name">Bududa</field>
-            <field name="code">UG-223</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-224">
-            <field name="name">Bukedea</field>
-            <field name="code">UG-224</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-e"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-301">
-            <field name="name">Adjumani</field>
-            <field name="code">UG-301</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-302">
-            <field name="name">Apac</field>
-            <field name="code">UG-302</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-303">
-            <field name="name">Arua</field>
-            <field name="code">UG-303</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-304">
-            <field name="name">Gulu</field>
-            <field name="code">UG-304</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-305">
-            <field name="name">Kitgum</field>
-            <field name="code">UG-305</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-306">
-            <field name="name">Kotido</field>
-            <field name="code">UG-306</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-307">
-            <field name="name">Lira</field>
-            <field name="code">UG-307</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-308">
-            <field name="name">Moroto</field>
-            <field name="code">UG-308</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-309">
-            <field name="name">Moyo</field>
-            <field name="code">UG-309</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-310">
-            <field name="name">Nebbi</field>
-            <field name="code">UG-310</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-311">
-            <field name="name">Nakapiripirit</field>
-            <field name="code">UG-311</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-312">
-            <field name="name">Pader</field>
-            <field name="code">UG-312</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-313">
-            <field name="name">Yumbe</field>
-            <field name="code">UG-313</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-314">
-            <field name="name">Amolatar</field>
-            <field name="code">UG-314</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-315">
-            <field name="name">Kaabong</field>
-            <field name="code">UG-315</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-316">
-            <field name="name">Koboko</field>
-            <field name="code">UG-316</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-317">
-            <field name="name">Abim</field>
-            <field name="code">UG-317</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-318">
-            <field name="name">Dokolo</field>
-            <field name="code">UG-318</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-319">
-            <field name="name">Amuru</field>
-            <field name="code">UG-319</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-320">
-            <field name="name">Maracha</field>
-            <field name="code">UG-320</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-321">
-            <field name="name">Oyam</field>
-            <field name="code">UG-321</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-n"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-401">
-            <field name="name">Bundibugyo</field>
-            <field name="code">UG-401</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-402">
-            <field name="name">Bushenyi</field>
-            <field name="code">UG-402</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-403">
-            <field name="name">Hoima</field>
-            <field name="code">UG-403</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-404">
-            <field name="name">Kabale</field>
-            <field name="code">UG-404</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-405">
-            <field name="name">Kabarole</field>
-            <field name="code">UG-405</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-406">
-            <field name="name">Kasese</field>
-            <field name="code">UG-406</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-407">
-            <field name="name">Kibaale</field>
-            <field name="code">UG-407</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-408">
-            <field name="name">Kisoro</field>
-            <field name="code">UG-408</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-409">
-            <field name="name">Masindi</field>
-            <field name="code">UG-409</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-410">
-            <field name="name">Mbarara</field>
-            <field name="code">UG-410</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-411">
-            <field name="name">Ntungamo</field>
-            <field name="code">UG-411</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-412">
-            <field name="name">Rukungiri</field>
-            <field name="code">UG-412</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-413">
-            <field name="name">Kamwenge</field>
-            <field name="code">UG-413</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-414">
-            <field name="name">Kanungu</field>
-            <field name="code">UG-414</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-415">
-            <field name="name">Kyenjojo</field>
-            <field name="code">UG-415</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-416">
-            <field name="name">Ibanda</field>
-            <field name="code">UG-416</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-417">
-            <field name="name">Isingiro</field>
-            <field name="code">UG-417</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-418">
-            <field name="name">Kiruhura</field>
-            <field name="code">UG-418</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-
-        <record model="country.subdivision" id="ug-419">
-            <field name="name">Buliisa</field>
-            <field name="code">UG-419</field>
-            <field name="type">district</field>
-            <field name="parent" ref="ug-w"/>
-            <field name="country" ref="ug"/>
-        </record>
-    </data>
-</tryton>
diff -r 60363ba041e2 modules/country/doc/index.rst
--- a/modules/country/doc/index.rst	Wed Jun 26 22:06:39 2019 +0200
+++ b/modules/country/doc/index.rst	Wed Jul 24 18:28:49 2019 +0200
@@ -24,3 +24,13 @@
 ***
 
 A zip links a zip code of a country to a city.
+
+Scripts
+*******
+
+There are two scripts:
+
+* `trytond_import_countries` to create and update countries and
+  subdivisions from the ISO database.
+
+* `trytond_import_zip` to create zips by country from the geonames database.
diff -r 60363ba041e2 modules/country/scripts/countries.py
--- a/modules/country/scripts/countries.py	Wed Jun 26 22:06:39 2019 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,55 +0,0 @@
-#!/usr/bin/env python
-# This file is part of Tryton.  The COPYRIGHT file at the top level of
-# this repository contains the full copyright notices and license terms.
-
-import sys
-import pycountry
-
-sys.stdout.write('<?xml version="1.0"?>\n')
-sys.stdout.write('<tryton>\n')
-sys.stdout.write('    <data skiptest="1" grouped="1">\n')
-
-for country in pycountry.countries:
-    record = '''
-        <record model="country.country" id="%s">
-            <field name="name">%s</field>
-            <field name="code">%s</field>
-            <field name="code3">%s</field>
-            <field name="code_numeric">%s</field>
-        </record>\n''' % (country.alpha_2.lower(), country.name,
-                country.alpha_2, country.alpha_3, country.numeric)
-    sys.stdout.write(record)
-sys.stdout.write('    </data>\n')
-
-subdivision_codes = {s.code.lower() for s in pycountry.subdivisions}
-existing_parents = set()
-while existing_parents < subdivision_codes:
-    sys.stdout.write('    <data skiptest="1" grouped="1">\n')
-    new_parents = set()
-    for subdivision in pycountry.subdivisions:
-        if (subdivision.code.lower() in existing_parents
-                or (subdivision.parent_code
-                    and subdivision.parent_code.lower() not in
-                    existing_parents)):
-            continue
-        new_parents.add(subdivision.code.lower())
-        record = '''
-        <record model="country.subdivision" id="%s">
-            <field name="name">%s</field>
-            <field name="code">%s</field>
-            <field name="type">%s</field>\n''' % (subdivision.code.lower(),
-                    subdivision.name, subdivision.code,
-                    subdivision.type.lower())
-        if subdivision.parent_code:
-            record += '''\
-            <field name="parent" ref="%s"/>\n''' % \
-                subdivision.parent.code.lower()
-        record += '''\
-            <field name="country" ref="%s"/>
-        </record>\n''' % subdivision.country.alpha_2.lower()
-
-        sys.stdout.write(record)
-    sys.stdout.write('    </data>\n')
-    existing_parents |= new_parents
-
-sys.stdout.write('</tryton>\n')
diff -r 60363ba041e2 modules/country/scripts/trytond_import_countries
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/modules/country/scripts/trytond_import_countries	Wed Jul 24 18:28:49 2019 +0200
@@ -0,0 +1,173 @@
+#!/usr/bin/env python3
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
+import gettext
+import os
+import sys
+from argparse import ArgumentParser
+
+import pycountry
+
+try:
+    from progressbar import ProgressBar, Bar, ETA, SimpleProgress
+except ImportError:
+    ProgressBar = None
+
+try:
+    from proteus import Model, config
+except ImportError:
+    prog = os.path.basename(sys.argv[0])
+    sys.exit("proteus must be installed to use %s" % prog)
+
+
+def _progress(iterable):
+    if ProgressBar:
+        pbar = ProgressBar(
+            widgets=[SimpleProgress(), Bar(), ETA()])
+    else:
+        pbar = iter
+    return pbar(iterable)
+
+
+def _get_language_codes():
+    Language = Model.get('ir.lang')
+    languages = Language.find([('translatable', '=', True)])
+    for l in languages:
+        yield l.code
+
+
+def get_countries():
+    Country = Model.get('country.country')
+
+    with config.get_config().set_context(active_test=False):
+        return {c.code: c for c in Country.find([])}
+
+
+def update_countries(countries):
+    print("Update countries")
+    Country = Model.get('country.country')
+
+    records = []
+    for country in _progress(pycountry.countries):
+        code = country.alpha_2
+        if code in countries:
+            record = countries[code]
+        else:
+            record = Country(code=code)
+        record.name = country.name
+        record.code3 = country.alpha_3
+        record.code_numeric = country.numeric
+        records.append(record)
+
+    Country.save(records)
+    return {c.code: c for c in records}
+
+
+def translate_countries(countries):
+    Country = Model.get('country.country')
+
+    current_config = config.get_config()
+    for code in _get_language_codes():
+        try:
+            gnutranslation = gettext.translation(
+                'iso3166', pycountry.LOCALES_DIR, languages=[code])
+        except IOError:
+            continue
+        print("Update countries %s" % code)
+        with current_config.set_context(language=code):
+            records = []
+            for country in _progress(pycountry.countries):
+                record = Country(countries[country.alpha_2].id)
+                record.name = gnutranslation.gettext(country.name)
+                records.append(record)
+            Country.save(records)
+
+
+def get_subdivisions():
+    Subdivision = Model.get('country.subdivision')
+
+    with config.get_config().set_context(active_test=False):
+        return {(s.country.code, s.code): s for s in Subdivision.find([])}
+
+
+def update_subdivisions(countries, subdivisions):
+    print("Update subdivisions")
+    Subdivision = Model.get('country.subdivision')
+
+    records = []
+    for subdivision in _progress(pycountry.subdivisions):
+        code = subdivision.code
+        country_code = subdivision.country_code
+        if (country_code, code) in subdivisions:
+            record = subdivisions[(country_code, code)]
+        else:
+            record = Subdivision(code=code, country=countries[country_code])
+        record.name = subdivision.name
+        record.type = subdivision.type.lower()
+        records.append(record)
+
+    Subdivision.save(records)
+    return {(s.country.code, s.code): s for s in records}
+
+
+def update_subdivisions_parent(subdivisions):
+    print("Update subdivisions parent")
+    Subdivision = Model.get('country.subdivision')
+
+    records = []
+    for subdivision in _progress(pycountry.subdivisions):
+        code = subdivision.code
+        country_code = subdivision.country_code
+        record = subdivisions[(country_code, code)]
+        if subdivision.parent_code:
+            record.parent = subdivisions[
+                (country_code, subdivision.parent_code)]
+        else:
+            record.parent = None
+        records.append(record)
+    Subdivision.save(records)
+
+
+def translate_subdivisions(subdivisions):
+    Subdivision = Model.get('country.subdivision')
+
+    current_config = config.get_config()
+    for code in _get_language_codes():
+        try:
+            gnutranslation = gettext.translation(
+                'iso3166-2', pycountry.LOCALES_DIR, languages=[code])
+        except IOError:
+            continue
+        print("Update subdivisions %s" % code)
+        with current_config.set_context(language=code):
+            records = []
+            for subdivision in _progress(pycountry.subdivisions):
+                record = Subdivision(subdivisions[
+                        (subdivision.country_code, subdivision.code)].id)
+                record.name = gnutranslation.gettext(subdivision.name)
+                records.append(record)
+            Subdivision.save(records)
+
+
+def main(database, config_file=None):
+    config.set_trytond(database, config_file=config_file)
+
+    countries = get_countries()
+    countries = update_countries(countries)
+    translate_countries(countries)
+    subdivisions = get_subdivisions()
+    subdivisions = update_subdivisions(countries, subdivisions)
+    update_subdivisions_parent(subdivisions)
+    translate_subdivisions(subdivisions)
+
+
+if __name__ == '__main__':
+    parser = ArgumentParser()
+    parser.add_argument('-d', '--database', dest='database')
+    parser.add_argument('-c', '--config', dest='config_file',
+        help='the trytond config file')
+
+    args = parser.parse_args()
+    if not args.database:
+        parser.error('Missing database')
+    main(args.database, args.config_file)
diff -r 60363ba041e2 modules/country/setup.py
--- a/modules/country/setup.py	Wed Jun 26 22:06:39 2019 +0200
+++ b/modules/country/setup.py	Wed Jul 24 18:28:49 2019 +0200
@@ -79,7 +79,10 @@
         'trytond.modules.country': (info.get('xml', [])
             + ['tryton.cfg', 'view/*.xml', 'locale/*.po', 'icons/*.svg']),
         },
-    scripts=['scripts/trytond_import_zip'],
+    scripts=[
+        'scripts/trytond_import_countries',
+        'scripts/trytond_import_zip',
+        ],
     classifiers=[
         'Development Status :: 5 - Production/Stable',
         'Environment :: Plugins',
@@ -120,6 +123,7 @@
     python_requires='>=3.5',
     install_requires=requires,
     extras_require={
+        'data': ['pycountry', get_require_version('proteus')],
         'GeoNames': [get_require_version('proteus')],
         },
     dependency_links=dependency_links,
diff -r 60363ba041e2 modules/country/tryton.cfg
--- a/modules/country/tryton.cfg	Wed Jun 26 22:06:39 2019 +0200
+++ b/modules/country/tryton.cfg	Wed Jul 24 18:28:49 2019 +0200
@@ -5,4 +5,3 @@
     res
 xml:
     country.xml
-    data.xml
diff -r 02664e9b5ec6 modules/currency/CHANGELOG
--- a/modules/currency/CHANGELOG	Mon May 06 15:03:00 2019 +0200
+++ b/modules/currency/CHANGELOG	Wed Jul 24 18:28:49 2019 +0200
@@ -1,3 +1,5 @@
+* Replace XML data by import script
+
 Version 5.2.0 - 2019-05-06
 * Bug fixes (see mercurial logs for details)
 
diff -r 02664e9b5ec6 modules/currency/currency.py
--- a/modules/currency/currency.py	Mon May 06 15:03:00 2019 +0200
+++ b/modules/currency/currency.py	Wed Jul 24 18:28:49 2019 +0200
@@ -51,6 +51,11 @@
 
     @classmethod
     def __register__(cls, module_name):
+        pool = Pool()
+        Data = pool.get('ir.model.data')
+        data = Data.__table__()
+        cursor = Transaction().connection.cursor()
+
         super(Currency, cls).__register__(module_name)
 
         table_h = cls.__table_handler__(module_name)
@@ -61,6 +66,10 @@
                 'p_sign_posn', 'n_sign_posn']:
             table_h.not_null_action(col, 'remove')
 
+        # Migration from 5.2: remove country data
+        cursor.execute(*data.delete(where=(data.module == 'currency')
+                & (data.model == cls.__name__)))
+
     @staticmethod
     def default_rounding():
         return Decimal('0.01')
diff -r 02664e9b5ec6 modules/currency/currency.xml
--- a/modules/currency/currency.xml	Mon May 06 15:03:00 2019 +0200
+++ b/modules/currency/currency.xml	Wed Jul 24 18:28:49 2019 +0200
@@ -99,14 +99,4 @@
         </record>
 
     </data>
-
-    <data noupdate="1" skiptest="1">
-        <!--- Default rate -->
-        <record model="currency.currency.rate" id="eur_rate">
-            <field name="date" eval="time.strftime('%Y-01-01')"/>
-            <field name="rate" eval="Decimal('1.0')"/>
-            <field name="currency" ref="eur"/>
-        </record>
-
-    </data>
 </tryton>
diff -r 02664e9b5ec6 modules/currency/data.xml
--- a/modules/currency/data.xml	Mon May 06 15:03:00 2019 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1205 +0,0 @@
-<?xml version="1.0"?>
-<tryton>
-    <data skiptest="1" grouped="1">
-
-        <record model="currency.currency" id="aed">
-            <field name="name">UAE Dirham</field>
-            <field name="code">AED</field>
-            <field name="numeric_code">784</field>
-            <field name="symbol">AED</field>
-        </record>
-
-        <record model="currency.currency" id="afn">
-            <field name="name">Afghani</field>
-            <field name="code">AFN</field>
-            <field name="numeric_code">971</field>
-            <field name="symbol">؋</field>
-        </record>
-
-        <record model="currency.currency" id="all">
-            <field name="name">Lek</field>
-            <field name="code">ALL</field>
-            <field name="numeric_code">008</field>
-            <field name="symbol">Lek</field>
-        </record>
-
-        <record model="currency.currency" id="amd">
-            <field name="name">Armenian Dram</field>
-            <field name="code">AMD</field>
-            <field name="numeric_code">051</field>
-            <field name="symbol">AMD</field>
-        </record>
-
-        <record model="currency.currency" id="ang">
-            <field name="name">Netherlands Antillean Guilder</field>
-            <field name="code">ANG</field>
-            <field name="numeric_code">532</field>
-            <field name="symbol">ƒ</field>
-        </record>
-
-        <record model="currency.currency" id="aoa">
-            <field name="name">Kwanza</field>
-            <field name="code">AOA</field>
-            <field name="numeric_code">973</field>
-            <field name="symbol">AOA</field>
-        </record>
-
-        <record model="currency.currency" id="ars">
-            <field name="name">Argentine Peso</field>
-            <field name="code">ARS</field>
-            <field name="numeric_code">032</field>
-            <field name="symbol">$</field>
-            <field name="rounding" eval="Decimal('0.01')"/>
-            <field name="digits" eval="2"/>
-        </record>
-
-        <record model="currency.currency" id="aud">
-            <field name="name">Australian Dollar</field>
-            <field name="code">AUD</field>
-            <field name="numeric_code">036</field>
-            <field name="symbol">AUD</field>
-        </record>
-
-        <record model="currency.currency" id="awg">
-            <field name="name">Aruban Florin</field>
-            <field name="code">AWG</field>
-            <field name="numeric_code">533</field>
-            <field name="symbol">ƒ</field>
-        </record>
-
-        <record model="currency.currency" id="azn">
-            <field name="name">Azerbaijanian Manat</field>
-            <field name="code">AZN</field>
-            <field name="numeric_code">944</field>
-            <field name="symbol">ман</field>
-        </record>
-
-        <record model="currency.currency" id="bam">
-            <field name="name">Convertible Mark</field>
-            <field name="code">BAM</field>
-            <field name="numeric_code">977</field>
-            <field name="symbol">KM</field>
-        </record>
-
-        <record model="currency.currency" id="bbd">
-            <field name="name">Barbados Dollar</field>
-            <field name="code">BBD</field>
-            <field name="numeric_code">052</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="bdt">
-            <field name="name">Taka</field>
-            <field name="code">BDT</field>
-            <field name="numeric_code">050</field>
-            <field name="symbol">BDT</field>
-        </record>
-
-        <record model="currency.currency" id="bgn">
-            <field name="name">Bulgarian Lev</field>
-            <field name="code">BGN</field>
-            <field name="numeric_code">975</field>
-            <field name="symbol">лв</field>
-        </record>
-
-        <record model="currency.currency" id="bhd">
-            <field name="name">Bahraini Dinar</field>
-            <field name="code">BHD</field>
-            <field name="numeric_code">048</field>
-            <field name="symbol">BHD</field>
-        </record>
-
-        <record model="currency.currency" id="bif">
-            <field name="name">Burundi Franc</field>
-            <field name="code">BIF</field>
-            <field name="numeric_code">108</field>
-            <field name="symbol">BIF</field>
-        </record>
-
-        <record model="currency.currency" id="bmd">
-            <field name="name">Bermudian Dollar</field>
-            <field name="code">BMD</field>
-            <field name="numeric_code">060</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="bnd">
-            <field name="name">Brunei Dollar</field>
-            <field name="code">BND</field>
-            <field name="numeric_code">096</field>
-            <field name="symbol">BND</field>
-        </record>
-
-        <record model="currency.currency" id="bob">
-            <field name="name">Boliviano</field>
-            <field name="code">BOB</field>
-            <field name="numeric_code">068</field>
-            <field name="symbol">$b</field>
-        </record>
-
-        <record model="currency.currency" id="brl">
-            <field name="name">Brazilian Real</field>
-            <field name="code">BRL</field>
-            <field name="numeric_code">986</field>
-            <field name="symbol">R$</field>
-        </record>
-
-        <record model="currency.currency" id="bsd">
-            <field name="name">Bahamian Dollar</field>
-            <field name="code">BSD</field>
-            <field name="numeric_code">044</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="btn">
-            <field name="name">Ngultrum</field>
-            <field name="code">BTN</field>
-            <field name="numeric_code">064</field>
-            <field name="symbol">BTN</field>
-        </record>
-
-        <record model="currency.currency" id="bwp">
-            <field name="name">Pula</field>
-            <field name="code">BWP</field>
-            <field name="numeric_code">072</field>
-            <field name="symbol">P</field>
-        </record>
-
-        <record model="currency.currency" id="byn">
-            <field name="name">Belarusian Ruble</field>
-            <field name="code">BYN</field>
-            <field name="numeric_code">933</field>
-            <field name="symbol">BYN</field>
-        </record>
-
-        <record model="currency.currency" id="bzd">
-            <field name="name">Belize Dollar</field>
-            <field name="code">BZD</field>
-            <field name="numeric_code">084</field>
-            <field name="symbol">BZ$</field>
-        </record>
-
-        <record model="currency.currency" id="cad">
-            <field name="name">Canadian Dollar</field>
-            <field name="code">CAD</field>
-            <field name="numeric_code">124</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="cdf">
-            <field name="name">Congolese Franc</field>
-            <field name="code">CDF</field>
-            <field name="numeric_code">976</field>
-            <field name="symbol">CDF</field>
-        </record>
-
-        <record model="currency.currency" id="chf">
-            <field name="name">Swiss Franc</field>
-            <field name="code">CHF</field>
-            <field name="numeric_code">756</field>
-            <field name="symbol">CHF</field>
-            <field name="rounding" eval="Decimal('0.01')"/>
-            <field name="digits" eval="2"/>
-        </record>
-
-        <record model="currency.currency" id="clp">
-            <field name="name">Chilean Peso</field>
-            <field name="code">CLP</field>
-            <field name="numeric_code">152</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="cny">
-            <field name="name">Yuan Renminbi</field>
-            <field name="code">CNY</field>
-            <field name="numeric_code">156</field>
-            <field name="symbol">元</field>
-        </record>
-
-        <record model="currency.currency" id="cop">
-            <field name="name">Colombian Peso</field>
-            <field name="code">COP</field>
-            <field name="numeric_code">170</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="crc">
-            <field name="name">Costa Rican Colon</field>
-            <field name="code">CRC</field>
-            <field name="numeric_code">188</field>
-            <field name="symbol">₡</field>
-        </record>
-
-        <record model="currency.currency" id="cuc">
-            <field name="name">Peso Convertible</field>
-            <field name="code">CUC</field>
-            <field name="numeric_code">931</field>
-            <field name="symbol">CUC</field>
-        </record>
-
-        <record model="currency.currency" id="cup">
-            <field name="name">Cuban Peso</field>
-            <field name="code">CUP</field>
-            <field name="numeric_code">192</field>
-            <field name="symbol">₱</field>
-        </record>
-
-        <record model="currency.currency" id="cve">
-            <field name="name">Cabo Verde Escudo</field>
-            <field name="code">CVE</field>
-            <field name="numeric_code">132</field>
-            <field name="symbol">CVE</field>
-        </record>
-
-        <record model="currency.currency" id="czk">
-            <field name="name">Czech Koruna</field>
-            <field name="code">CZK</field>
-            <field name="numeric_code">203</field>
-            <field name="symbol">Kč</field>
-        </record>
-
-        <record model="currency.currency" id="djf">
-            <field name="name">Djibouti Franc</field>
-            <field name="code">DJF</field>
-            <field name="numeric_code">262</field>
-            <field name="symbol">DJF</field>
-        </record>
-
-        <record model="currency.currency" id="dkk">
-            <field name="name">Danish Krone</field>
-            <field name="code">DKK</field>
-            <field name="numeric_code">208</field>
-            <field name="symbol">kr</field>
-        </record>
-
-        <record model="currency.currency" id="dop">
-            <field name="name">Dominican Peso</field>
-            <field name="code">DOP</field>
-            <field name="numeric_code">214</field>
-            <field name="symbol">RD$</field>
-        </record>
-
-        <record model="currency.currency" id="dzd">
-            <field name="name">Algerian Dinar</field>
-            <field name="code">DZD</field>
-            <field name="numeric_code">012</field>
-            <field name="symbol">DZD</field>
-        </record>
-
-        <record model="currency.currency" id="egp">
-            <field name="name">Egyptian Pound</field>
-            <field name="code">EGP</field>
-            <field name="numeric_code">818</field>
-            <field name="symbol">£</field>
-        </record>
-
-        <record model="currency.currency" id="ern">
-            <field name="name">Nakfa</field>
-            <field name="code">ERN</field>
-            <field name="numeric_code">232</field>
-            <field name="symbol">ERN</field>
-        </record>
-
-        <record model="currency.currency" id="etb">
-            <field name="name">Ethiopian Birr</field>
-            <field name="code">ETB</field>
-            <field name="numeric_code">230</field>
-            <field name="symbol">ETB</field>
-        </record>
-
-        <record model="currency.currency" id="eur">
-            <field name="name">Euro</field>
-            <field name="code">EUR</field>
-            <field name="numeric_code">978</field>
-            <field name="symbol">€</field>
-            <field name="rounding" eval="Decimal('0.01')"/>
-            <field name="digits" eval="2"/>
-        </record>
-
-        <record model="currency.currency" id="fjd">
-            <field name="name">Fiji Dollar</field>
-            <field name="code">FJD</field>
-            <field name="numeric_code">242</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="fkp">
-            <field name="name">Falkland Islands Pound</field>
-            <field name="code">FKP</field>
-            <field name="numeric_code">238</field>
-            <field name="symbol">FKP</field>
-        </record>
-
-        <record model="currency.currency" id="gbp">
-            <field name="name">Pound Sterling</field>
-            <field name="code">GBP</field>
-            <field name="numeric_code">826</field>
-            <field name="symbol">£</field>
-            <field name="rounding" eval="Decimal('0.01')"/>
-            <field name="digits" eval="2"/>
-        </record>
-
-        <record model="currency.currency" id="gel">
-            <field name="name">Lari</field>
-            <field name="code">GEL</field>
-            <field name="numeric_code">981</field>
-            <field name="symbol">GEL</field>
-        </record>
-
-        <record model="currency.currency" id="ghs">
-            <field name="name">Ghana Cedi</field>
-            <field name="code">GHS</field>
-            <field name="numeric_code">936</field>
-            <field name="symbol">GHS</field>
-        </record>
-
-        <record model="currency.currency" id="gip">
-            <field name="name">Gibraltar Pound</field>
-            <field name="code">GIP</field>
-            <field name="numeric_code">292</field>
-            <field name="symbol">£</field>
-        </record>
-
-        <record model="currency.currency" id="gmd">
-            <field name="name">Dalasi</field>
-            <field name="code">GMD</field>
-            <field name="numeric_code">270</field>
-            <field name="symbol">GMD</field>
-        </record>
-
-        <record model="currency.currency" id="gnf">
-            <field name="name">Guinea Franc</field>
-            <field name="code">GNF</field>
-            <field name="numeric_code">324</field>
-            <field name="symbol">GNF</field>
-        </record>
-
-        <record model="currency.currency" id="gtq">
-            <field name="name">Quetzal</field>
-            <field name="code">GTQ</field>
-            <field name="numeric_code">320</field>
-            <field name="symbol">Q</field>
-        </record>
-
-        <record model="currency.currency" id="gyd">
-            <field name="name">Guyana Dollar</field>
-            <field name="code">GYD</field>
-            <field name="numeric_code">328</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="hkd">
-            <field name="name">Hong Kong Dollar</field>
-            <field name="code">HKD</field>
-            <field name="numeric_code">344</field>
-            <field name="symbol">HK$</field>
-        </record>
-
-        <record model="currency.currency" id="hnl">
-            <field name="name">Lempira</field>
-            <field name="code">HNL</field>
-            <field name="numeric_code">340</field>
-            <field name="symbol">L</field>
-        </record>
-
-        <record model="currency.currency" id="hrk">
-            <field name="name">Kuna</field>
-            <field name="code">HRK</field>
-            <field name="numeric_code">191</field>
-            <field name="symbol">kn</field>
-        </record>
-
-        <record model="currency.currency" id="htg">
-            <field name="name">Gourde</field>
-            <field name="code">HTG</field>
-            <field name="numeric_code">332</field>
-            <field name="symbol">HTG</field>
-        </record>
-
-        <record model="currency.currency" id="huf">
-            <field name="name">Forint</field>
-            <field name="code">HUF</field>
-            <field name="numeric_code">348</field>
-            <field name="symbol">Ft</field>
-        </record>
-
-        <record model="currency.currency" id="idr">
-            <field name="name">Rupiah</field>
-            <field name="code">IDR</field>
-            <field name="numeric_code">360</field>
-            <field name="symbol">Rp</field>
-        </record>
-
-        <record model="currency.currency" id="ils">
-            <field name="name">New Israeli Sheqel</field>
-            <field name="code">ILS</field>
-            <field name="numeric_code">376</field>
-            <field name="symbol">₪</field>
-        </record>
-
-        <record model="currency.currency" id="inr">
-            <field name="name">Indian Rupee</field>
-            <field name="code">INR</field>
-            <field name="numeric_code">356</field>
-            <field name="symbol">₨</field>
-        </record>
-
-        <record model="currency.currency" id="iqd">
-            <field name="name">Iraqi Dinar</field>
-            <field name="code">IQD</field>
-            <field name="numeric_code">368</field>
-            <field name="symbol">IQD</field>
-        </record>
-
-        <record model="currency.currency" id="irr">
-            <field name="name">Iranian Rial</field>
-            <field name="code">IRR</field>
-            <field name="numeric_code">364</field>
-            <field name="symbol">﷼</field>
-        </record>
-
-        <record model="currency.currency" id="isk">
-            <field name="name">Iceland Krona</field>
-            <field name="code">ISK</field>
-            <field name="numeric_code">352</field>
-            <field name="symbol">kr</field>
-        </record>
-
-        <record model="currency.currency" id="jmd">
-            <field name="name">Jamaican Dollar</field>
-            <field name="code">JMD</field>
-            <field name="numeric_code">388</field>
-            <field name="symbol">J$</field>
-        </record>
-
-        <record model="currency.currency" id="jod">
-            <field name="name">Jordanian Dinar</field>
-            <field name="code">JOD</field>
-            <field name="numeric_code">400</field>
-            <field name="symbol">JOD</field>
-        </record>
-
-        <record model="currency.currency" id="jpy">
-            <field name="name">Yen</field>
-            <field name="code">JPY</field>
-            <field name="numeric_code">392</field>
-            <field name="symbol">¥</field>
-        </record>
-
-        <record model="currency.currency" id="kes">
-            <field name="name">Kenyan Shilling</field>
-            <field name="code">KES</field>
-            <field name="numeric_code">404</field>
-            <field name="symbol">KES</field>
-        </record>
-
-        <record model="currency.currency" id="kgs">
-            <field name="name">Som</field>
-            <field name="code">KGS</field>
-            <field name="numeric_code">417</field>
-            <field name="symbol">лв</field>
-        </record>
-
-        <record model="currency.currency" id="khr">
-            <field name="name">Riel</field>
-            <field name="code">KHR</field>
-            <field name="numeric_code">116</field>
-            <field name="symbol">៛</field>
-        </record>
-
-        <record model="currency.currency" id="kmf">
-            <field name="name">Comoro Franc</field>
-            <field name="code">KMF</field>
-            <field name="numeric_code">174</field>
-            <field name="symbol">KMF</field>
-        </record>
-
-        <record model="currency.currency" id="kpw">
-            <field name="name">North Korean Won</field>
-            <field name="code">KPW</field>
-            <field name="numeric_code">408</field>
-            <field name="symbol">₩</field>
-        </record>
-
-        <record model="currency.currency" id="krw">
-            <field name="name">Won</field>
-            <field name="code">KRW</field>
-            <field name="numeric_code">410</field>
-            <field name="symbol">KRW</field>
-        </record>
-
-        <record model="currency.currency" id="kwd">
-            <field name="name">Kuwaiti Dinar</field>
-            <field name="code">KWD</field>
-            <field name="numeric_code">414</field>
-            <field name="symbol">KWD</field>
-        </record>
-
-        <record model="currency.currency" id="kyd">
-            <field name="name">Cayman Islands Dollar</field>
-            <field name="code">KYD</field>
-            <field name="numeric_code">136</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="kzt">
-            <field name="name">Tenge</field>
-            <field name="code">KZT</field>
-            <field name="numeric_code">398</field>
-            <field name="symbol">лв</field>
-        </record>
-
-        <record model="currency.currency" id="lak">
-            <field name="name">Kip</field>
-            <field name="code">LAK</field>
-            <field name="numeric_code">418</field>
-            <field name="symbol">₭</field>
-        </record>
-
-        <record model="currency.currency" id="lbp">
-            <field name="name">Lebanese Pound</field>
-            <field name="code">LBP</field>
-            <field name="numeric_code">422</field>
-            <field name="symbol">£</field>
-        </record>
-
-        <record model="currency.currency" id="lkr">
-            <field name="name">Sri Lanka Rupee</field>
-            <field name="code">LKR</field>
-            <field name="numeric_code">144</field>
-            <field name="symbol">₨</field>
-        </record>
-
-        <record model="currency.currency" id="lrd">
-            <field name="name">Liberian Dollar</field>
-            <field name="code">LRD</field>
-            <field name="numeric_code">430</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="lsl">
-            <field name="name">Loti</field>
-            <field name="code">LSL</field>
-            <field name="numeric_code">426</field>
-            <field name="symbol">LSL</field>
-        </record>
-
-        <record model="currency.currency" id="lyd">
-            <field name="name">Libyan Dinar</field>
-            <field name="code">LYD</field>
-            <field name="numeric_code">434</field>
-            <field name="symbol">LYD</field>
-        </record>
-
-        <record model="currency.currency" id="mad">
-            <field name="name">Moroccan Dirham</field>
-            <field name="code">MAD</field>
-            <field name="numeric_code">504</field>
-            <field name="symbol">MAD</field>
-        </record>
-
-        <record model="currency.currency" id="mdl">
-            <field name="name">Moldovan Leu</field>
-            <field name="code">MDL</field>
-            <field name="numeric_code">498</field>
-            <field name="symbol">MDL</field>
-        </record>
-
-        <record model="currency.currency" id="mga">
-            <field name="name">Malagasy Ariary</field>
-            <field name="code">MGA</field>
-            <field name="numeric_code">969</field>
-            <field name="symbol">MGA</field>
-        </record>
-
-        <record model="currency.currency" id="mkd">
-            <field name="name">Denar</field>
-            <field name="code">MKD</field>
-            <field name="numeric_code">807</field>
-            <field name="symbol">ден</field>
-        </record>
-
-        <record model="currency.currency" id="mmk">
-            <field name="name">Kyat</field>
-            <field name="code">MMK</field>
-            <field name="numeric_code">104</field>
-            <field name="symbol">MMK</field>
-        </record>
-
-        <record model="currency.currency" id="mnt">
-            <field name="name">Tugrik</field>
-            <field name="code">MNT</field>
-            <field name="numeric_code">496</field>
-            <field name="symbol">₮</field>
-        </record>
-
-        <record model="currency.currency" id="mop">
-            <field name="name">Pataca</field>
-            <field name="code">MOP</field>
-            <field name="numeric_code">446</field>
-            <field name="symbol">MOP</field>
-        </record>
-
-        <record model="currency.currency" id="mro">
-            <field name="name">Ouguiya</field>
-            <field name="code">MRO</field>
-            <field name="numeric_code">478</field>
-            <field name="symbol">MRO</field>
-        </record>
-
-        <record model="currency.currency" id="mur">
-            <field name="name">Mauritius Rupee</field>
-            <field name="code">MUR</field>
-            <field name="numeric_code">480</field>
-            <field name="symbol">₨</field>
-        </record>
-
-        <record model="currency.currency" id="mvr">
-            <field name="name">Rufiyaa</field>
-            <field name="code">MVR</field>
-            <field name="numeric_code">462</field>
-            <field name="symbol">MVR</field>
-        </record>
-
-        <record model="currency.currency" id="mwk">
-            <field name="name">Malawi Kwacha</field>
-            <field name="code">MWK</field>
-            <field name="numeric_code">454</field>
-            <field name="symbol">MWK</field>
-        </record>
-
-        <record model="currency.currency" id="mxn">
-            <field name="name">Mexican Peso</field>
-            <field name="code">MXN</field>
-            <field name="numeric_code">484</field>
-            <field name="symbol">MXN</field>
-        </record>
-
-        <record model="currency.currency" id="myr">
-            <field name="name">Malaysian Ringgit</field>
-            <field name="code">MYR</field>
-            <field name="numeric_code">458</field>
-            <field name="symbol">RM</field>
-        </record>
-
-        <record model="currency.currency" id="mzn">
-            <field name="name">Mozambique Metical</field>
-            <field name="code">MZN</field>
-            <field name="numeric_code">943</field>
-            <field name="symbol">MT</field>
-        </record>
-
-        <record model="currency.currency" id="nad">
-            <field name="name">Namibia Dollar</field>
-            <field name="code">NAD</field>
-            <field name="numeric_code">516</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="ngn">
-            <field name="name">Naira</field>
-            <field name="code">NGN</field>
-            <field name="numeric_code">566</field>
-            <field name="symbol">₦</field>
-        </record>
-
-        <record model="currency.currency" id="nio">
-            <field name="name">Cordoba Oro</field>
-            <field name="code">NIO</field>
-            <field name="numeric_code">558</field>
-            <field name="symbol">C$</field>
-        </record>
-
-        <record model="currency.currency" id="nok">
-            <field name="name">Norwegian Krone</field>
-            <field name="code">NOK</field>
-            <field name="numeric_code">578</field>
-            <field name="symbol">kr</field>
-        </record>
-
-        <record model="currency.currency" id="npr">
-            <field name="name">Nepalese Rupee</field>
-            <field name="code">NPR</field>
-            <field name="numeric_code">524</field>
-            <field name="symbol">₨</field>
-        </record>
-
-        <record model="currency.currency" id="nzd">
-            <field name="name">New Zealand Dollar</field>
-            <field name="code">NZD</field>
-            <field name="numeric_code">554</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="omr">
-            <field name="name">Rial Omani</field>
-            <field name="code">OMR</field>
-            <field name="numeric_code">512</field>
-            <field name="symbol">﷼</field>
-        </record>
-
-        <record model="currency.currency" id="pab">
-            <field name="name">Balboa</field>
-            <field name="code">PAB</field>
-            <field name="numeric_code">590</field>
-            <field name="symbol">B/.</field>
-        </record>
-
-        <record model="currency.currency" id="pen">
-            <field name="name">Sol</field>
-            <field name="code">PEN</field>
-            <field name="numeric_code">604</field>
-            <field name="symbol">S/.</field>
-        </record>
-
-        <record model="currency.currency" id="pgk">
-            <field name="name">Kina</field>
-            <field name="code">PGK</field>
-            <field name="numeric_code">598</field>
-            <field name="symbol">PGK</field>
-        </record>
-
-        <record model="currency.currency" id="php">
-            <field name="name">Philippine Peso</field>
-            <field name="code">PHP</field>
-            <field name="numeric_code">608</field>
-            <field name="symbol">Php</field>
-        </record>
-
-        <record model="currency.currency" id="pkr">
-            <field name="name">Pakistan Rupee</field>
-            <field name="code">PKR</field>
-            <field name="numeric_code">586</field>
-            <field name="symbol">₨</field>
-        </record>
-
-        <record model="currency.currency" id="pln">
-            <field name="name">Zloty</field>
-            <field name="code">PLN</field>
-            <field name="numeric_code">985</field>
-            <field name="symbol">zł</field>
-        </record>
-
-        <record model="currency.currency" id="pyg">
-            <field name="name">Guarani</field>
-            <field name="code">PYG</field>
-            <field name="numeric_code">600</field>
-            <field name="symbol">Gs</field>
-        </record>
-
-        <record model="currency.currency" id="qar">
-            <field name="name">Qatari Rial</field>
-            <field name="code">QAR</field>
-            <field name="numeric_code">634</field>
-            <field name="symbol">﷼</field>
-        </record>
-
-        <record model="currency.currency" id="ron">
-            <field name="name">Romanian Leu</field>
-            <field name="code">RON</field>
-            <field name="numeric_code">946</field>
-            <field name="symbol">lei</field>
-        </record>
-
-        <record model="currency.currency" id="rsd">
-            <field name="name">Serbian Dinar</field>
-            <field name="code">RSD</field>
-            <field name="numeric_code">941</field>
-            <field name="symbol">Дин.</field>
-        </record>
-
-        <record model="currency.currency" id="rub">
-            <field name="name">Russian Ruble</field>
-            <field name="code">RUB</field>
-            <field name="numeric_code">643</field>
-            <field name="symbol">руб</field>
-        </record>
-
-        <record model="currency.currency" id="rwf">
-            <field name="name">Rwanda Franc</field>
-            <field name="code">RWF</field>
-            <field name="numeric_code">646</field>
-            <field name="symbol">RWF</field>
-        </record>
-
-        <record model="currency.currency" id="sar">
-            <field name="name">Saudi Riyal</field>
-            <field name="code">SAR</field>
-            <field name="numeric_code">682</field>
-            <field name="symbol">﷼</field>
-        </record>
-
-        <record model="currency.currency" id="sbd">
-            <field name="name">Solomon Islands Dollar</field>
-            <field name="code">SBD</field>
-            <field name="numeric_code">090</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="scr">
-            <field name="name">Seychelles Rupee</field>
-            <field name="code">SCR</field>
-            <field name="numeric_code">690</field>
-            <field name="symbol">₨</field>
-        </record>
-
-        <record model="currency.currency" id="sdg">
-            <field name="name">Sudanese Pound</field>
-            <field name="code">SDG</field>
-            <field name="numeric_code">938</field>
-            <field name="symbol">SDG</field>
-        </record>
-
-        <record model="currency.currency" id="sek">
-            <field name="name">Swedish Krona</field>
-            <field name="code">SEK</field>
-            <field name="numeric_code">752</field>
-            <field name="symbol">kr</field>
-        </record>
-
-        <record model="currency.currency" id="sgd">
-            <field name="name">Singapore Dollar</field>
-            <field name="code">SGD</field>
-            <field name="numeric_code">702</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="shp">
-            <field name="name">Saint Helena Pound</field>
-            <field name="code">SHP</field>
-            <field name="numeric_code">654</field>
-            <field name="symbol">£</field>
-        </record>
-
-        <record model="currency.currency" id="sll">
-            <field name="name">Leone</field>
-            <field name="code">SLL</field>
-            <field name="numeric_code">694</field>
-            <field name="symbol">SLL</field>
-        </record>
-
-        <record model="currency.currency" id="sos">
-            <field name="name">Somali Shilling</field>
-            <field name="code">SOS</field>
-            <field name="numeric_code">706</field>
-            <field name="symbol">S</field>
-        </record>
-
-        <record model="currency.currency" id="srd">
-            <field name="name">Surinam Dollar</field>
-            <field name="code">SRD</field>
-            <field name="numeric_code">968</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="ssp">
-            <field name="name">South Sudanese Pound</field>
-            <field name="code">SSP</field>
-            <field name="numeric_code">728</field>
-            <field name="symbol">SSP</field>
-        </record>
-
-        <record model="currency.currency" id="std">
-            <field name="name">Dobra</field>
-            <field name="code">STD</field>
-            <field name="numeric_code">678</field>
-            <field name="symbol">STD</field>
-        </record>
-
-        <record model="currency.currency" id="svc">
-            <field name="name">El Salvador Colon</field>
-            <field name="code">SVC</field>
-            <field name="numeric_code">222</field>
-            <field name="symbol">SVC</field>
-        </record>
-
-        <record model="currency.currency" id="syp">
-            <field name="name">Syrian Pound</field>
-            <field name="code">SYP</field>
-            <field name="numeric_code">760</field>
-            <field name="symbol">SYP</field>
-        </record>
-
-        <record model="currency.currency" id="szl">
-            <field name="name">Lilangeni</field>
-            <field name="code">SZL</field>
-            <field name="numeric_code">748</field>
-            <field name="symbol">SZL</field>
-        </record>
-
-        <record model="currency.currency" id="thb">
-            <field name="name">Baht</field>
-            <field name="code">THB</field>
-            <field name="numeric_code">764</field>
-            <field name="symbol">฿</field>
-        </record>
-
-        <record model="currency.currency" id="tjs">
-            <field name="name">Somoni</field>
-            <field name="code">TJS</field>
-            <field name="numeric_code">972</field>
-            <field name="symbol">TJS</field>
-        </record>
-
-        <record model="currency.currency" id="tmt">
-            <field name="name">Turkmenistan New Manat</field>
-            <field name="code">TMT</field>
-            <field name="numeric_code">934</field>
-            <field name="symbol">TMT</field>
-        </record>
-
-        <record model="currency.currency" id="tnd">
-            <field name="name">Tunisian Dinar</field>
-            <field name="code">TND</field>
-            <field name="numeric_code">788</field>
-            <field name="symbol">TND</field>
-        </record>
-
-        <record model="currency.currency" id="top">
-            <field name="name">Pa’anga</field>
-            <field name="code">TOP</field>
-            <field name="numeric_code">776</field>
-            <field name="symbol">TOP</field>
-        </record>
-
-        <record model="currency.currency" id="try">
-            <field name="name">Turkish Lira</field>
-            <field name="code">TRY</field>
-            <field name="numeric_code">949</field>
-            <field name="symbol">YTL</field>
-        </record>
-
-        <record model="currency.currency" id="ttd">
-            <field name="name">Trinidad and Tobago Dollar</field>
-            <field name="code">TTD</field>
-            <field name="numeric_code">780</field>
-            <field name="symbol">TT$</field>
-        </record>
-
-        <record model="currency.currency" id="twd">
-            <field name="name">New Taiwan Dollar</field>
-            <field name="code">TWD</field>
-            <field name="numeric_code">901</field>
-            <field name="symbol">NT$</field>
-        </record>
-
-        <record model="currency.currency" id="tzs">
-            <field name="name">Tanzanian Shilling</field>
-            <field name="code">TZS</field>
-            <field name="numeric_code">834</field>
-            <field name="symbol">TZS</field>
-        </record>
-
-        <record model="currency.currency" id="uah">
-            <field name="name">Hryvnia</field>
-            <field name="code">UAH</field>
-            <field name="numeric_code">980</field>
-            <field name="symbol">₴</field>
-        </record>
-
-        <record model="currency.currency" id="ugx">
-            <field name="name">Uganda Shilling</field>
-            <field name="code">UGX</field>
-            <field name="numeric_code">800</field>
-            <field name="symbol">UGX</field>
-        </record>
-
-        <record model="currency.currency" id="usd">
-            <field name="name">US Dollar</field>
-            <field name="code">USD</field>
-            <field name="numeric_code">840</field>
-            <field name="symbol">$</field>
-            <field name="rounding" eval="Decimal('0.01')"/>
-            <field name="digits" eval="2"/>
-        </record>
-
-        <record model="currency.currency" id="uyu">
-            <field name="name">Peso Uruguayo</field>
-            <field name="code">UYU</field>
-            <field name="numeric_code">858</field>
-            <field name="symbol">$U</field>
-        </record>
-
-        <record model="currency.currency" id="uzs">
-            <field name="name">Uzbekistan Sum</field>
-            <field name="code">UZS</field>
-            <field name="numeric_code">860</field>
-            <field name="symbol">лв</field>
-        </record>
-
-        <record model="currency.currency" id="vef">
-            <field name="name">Bolívar</field>
-            <field name="code">VEF</field>
-            <field name="numeric_code">937</field>
-            <field name="symbol">Bs</field>
-        </record>
-
-        <record model="currency.currency" id="vnd">
-            <field name="name">Dong</field>
-            <field name="code">VND</field>
-            <field name="numeric_code">704</field>
-            <field name="symbol">₫</field>
-        </record>
-
-        <record model="currency.currency" id="vuv">
-            <field name="name">Vatu</field>
-            <field name="code">VUV</field>
-            <field name="numeric_code">548</field>
-            <field name="symbol">VUV</field>
-        </record>
-
-        <record model="currency.currency" id="wst">
-            <field name="name">Tala</field>
-            <field name="code">WST</field>
-            <field name="numeric_code">882</field>
-            <field name="symbol">WST</field>
-        </record>
-
-        <record model="currency.currency" id="xaf">
-            <field name="name">CFA Franc BEAC</field>
-            <field name="code">XAF</field>
-            <field name="numeric_code">950</field>
-            <field name="symbol">XAF</field>
-        </record>
-
-        <record model="currency.currency" id="xag">
-            <field name="name">Silver</field>
-            <field name="code">XAG</field>
-            <field name="numeric_code">961</field>
-            <field name="symbol">XAG</field>
-        </record>
-
-        <record model="currency.currency" id="xau">
-            <field name="name">Gold</field>
-            <field name="code">XAU</field>
-            <field name="numeric_code">959</field>
-            <field name="symbol">XAU</field>
-        </record>
-
-        <record model="currency.currency" id="xba">
-            <field name="name">Bond Markets Unit European Composite Unit (EURCO)</field>
-            <field name="code">XBA</field>
-            <field name="numeric_code">955</field>
-            <field name="symbol">XBA</field>
-        </record>
-
-        <record model="currency.currency" id="xbb">
-            <field name="name">Bond Markets Unit European Monetary Unit (E.M.U.-6)</field>
-            <field name="code">XBB</field>
-            <field name="numeric_code">956</field>
-            <field name="symbol">XBB</field>
-        </record>
-
-        <record model="currency.currency" id="xbc">
-            <field name="name">Bond Markets Unit European Unit of Account 9 (E.U.A.-9)</field>
-            <field name="code">XBC</field>
-            <field name="numeric_code">957</field>
-            <field name="symbol">XBC</field>
-        </record>
-
-        <record model="currency.currency" id="xbd">
-            <field name="name">Bond Markets Unit European Unit of Account 17 (E.U.A.-17)</field>
-            <field name="code">XBD</field>
-            <field name="numeric_code">958</field>
-            <field name="symbol">XBD</field>
-        </record>
-
-        <record model="currency.currency" id="xcd">
-            <field name="name">East Caribbean Dollar</field>
-            <field name="code">XCD</field>
-            <field name="numeric_code">951</field>
-            <field name="symbol">$</field>
-        </record>
-
-        <record model="currency.currency" id="xdr">
-            <field name="name">SDR (Special Drawing Right)</field>
-            <field name="code">XDR</field>
-            <field name="numeric_code">960</field>
-            <field name="symbol">XDR</field>
-        </record>
-
-        <record model="currency.currency" id="xof">
-            <field name="name">CFA Franc BCEAO</field>
-            <field name="code">XOF</field>
-            <field name="numeric_code">952</field>
-            <field name="symbol">XOF</field>
-        </record>
-
-        <record model="currency.currency" id="xpd">
-            <field name="name">Palladium</field>
-            <field name="code">XPD</field>
-            <field name="numeric_code">964</field>
-            <field name="symbol">XPD</field>
-        </record>
-
-        <record model="currency.currency" id="xpf">
-            <field name="name">CFP Franc</field>
-            <field name="code">XPF</field>
-            <field name="numeric_code">953</field>
-            <field name="symbol">XPF</field>
-        </record>
-
-        <record model="currency.currency" id="xpt">
-            <field name="name">Platinum</field>
-            <field name="code">XPT</field>
-            <field name="numeric_code">962</field>
-            <field name="symbol">XPT</field>
-        </record>
-
-        <record model="currency.currency" id="xsu">
-            <field name="name">Sucre</field>
-            <field name="code">XSU</field>
-            <field name="numeric_code">994</field>
-            <field name="symbol">XSU</field>
-        </record>
-
-        <record model="currency.currency" id="xts">
-            <field name="name">Codes specifically reserved for testing purposes</field>
-            <field name="code">XTS</field>
-            <field name="numeric_code">963</field>
-            <field name="symbol">XTS</field>
-        </record>
-
-        <record model="currency.currency" id="xua">
-            <field name="name">ADB Unit of Account</field>
-            <field name="code">XUA</field>
-            <field name="numeric_code">965</field>
-            <field name="symbol">XUA</field>
-        </record>
-
-        <record model="currency.currency" id="xxx">
-            <field name="name">The codes assigned for transactions where no currency is involved</field>
-            <field name="code">XXX</field>
-            <field name="numeric_code">999</field>
-            <field name="symbol">XXX</field>
-        </record>
-
-        <record model="currency.currency" id="yer">
-            <field name="name">Yemeni Rial</field>
-            <field name="code">YER</field>
-            <field name="numeric_code">886</field>
-            <field name="symbol">﷼</field>
-        </record>
-
-        <record model="currency.currency" id="zar">
-            <field name="name">Rand</field>
-            <field name="code">ZAR</field>
-            <field name="numeric_code">710</field>
-            <field name="symbol">R</field>
-        </record>
-
-        <record model="currency.currency" id="zmw">
-            <field name="name">Zambian Kwacha</field>
-            <field name="code">ZMW</field>
-            <field name="numeric_code">967</field>
-            <field name="symbol">ZMW</field>
-        </record>
-
-        <record model="currency.currency" id="zwl">
-            <field name="name">Zimbabwe Dollar</field>
-            <field name="code">ZWL</field>
-            <field name="numeric_code">932</field>
-            <field name="symbol">ZWL</field>
-        </record>
-    </data>
-</tryton>
diff -r 02664e9b5ec6 modules/currency/doc/index.rst
--- a/modules/currency/doc/index.rst	Mon May 06 15:03:00 2019 +0200
+++ b/modules/currency/doc/index.rst	Wed Jul 24 18:28:49 2019 +0200
@@ -21,3 +21,11 @@
 A rate is defined by a date and a numeric value. The date gives the
 time from which this rate is correct. All rates are defined implicitly
 with respect to the same currency (the one whose rate is 1).
+
+Scripts
+*******
+
+There is a scripts:
+
+    * `trytond_import_currencies` to create and update currencies from the ISO
+      database.
diff -r 02664e9b5ec6 modules/currency/scripts/currencies.py
--- a/modules/currency/scripts/currencies.py	Mon May 06 15:03:00 2019 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,157 +0,0 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# This file is part of Tryton.  The COPYRIGHT file at the top level of
-# this repository contains the full copyright notices and license terms.
-
-import sys
-import pycountry
-
-symbols = {
-    'AFN': '؋',
-    'ARS': '$',
-    'AWG': 'ƒ',
-    'AZN': 'ман',
-    'BSD': '$',
-    'THB': '฿',
-    'PAB': 'B/.',
-    'BBD': '$',
-    'BYR': 'p.',
-    'BZD': 'BZ$',
-    'BMD': '$',
-    'VEF': 'Bs',
-    'BOB': '$b',
-    'BRL': 'R$',
-    'BGN': 'лв',
-    'CAD': '$',
-    'KYD': '$',
-    'CLP': '$',
-    'COP': '$',
-    'BAM': 'KM',
-    'NIO': 'C$',
-    'CRC': '₡',
-    'HRK': 'kn',
-    'CUP': '₱',
-    'CZK': 'Kč',
-    'DKK': 'kr',
-    'MKD': 'ден',
-    'DOP': 'RD$',
-    'VND': '₫',
-    'XCD': '$',
-    'EGP': '£',
-    'EUR': '€',
-    'FJD': '$',
-    'HUF': 'Ft',
-    'GBP': '£',
-    'GIP': '£',
-    'PYG': 'Gs',
-    'GYD': '$',
-    'HKD': 'HK$',
-    'UAH': '₴',
-    'ISK': 'kr',
-    'INR': '₨',
-    'IRR': '﷼',
-    'JMD': 'J$',
-    'LAK': '₭',
-    'EEK': 'kr',
-    'LBP': '£',
-    'ALL': 'Lek',
-    'HNL': 'L',
-    'LRD': '$',
-    'LTL': 'Lt',
-    'MYR': 'RM',
-    'MUR': '₨',
-    'MZN': 'MT',
-    'NGN': '₦',
-    'NAD': '$',
-    'NPR': '₨',
-    'ANG': 'ƒ',
-    'ILS': '₪',
-    'RON': 'lei',
-    'TWD': 'NT$',
-    'TRY': 'YTL',
-    'NZD': '$',
-    'KPW': '₩',
-    'NOK': 'kr',
-    'PEN': 'S/.',
-    'PKR': '₨',
-    'UYU': '$U',
-    'PHP': 'Php',
-    'BWP': 'P',
-    'QAR': '﷼',
-    'GTQ': 'Q',
-    'ZAR': 'R',
-    'OMR': '﷼',
-    'KHR': '៛',
-    'IDR': 'Rp',
-    'RUB': 'руб',
-    'SHP': '£',
-    'SAR': '﷼',
-    'RSD': 'Дин.',
-    'SCR': '₨',
-    'SGD': '$',
-    'SBD': '$',
-    'KGS': 'лв',
-    'SOS': 'S',
-    'LKR': '₨',
-    'SRD': '$',
-    'SEK': 'kr',
-    'CHF': 'CHF',
-    'KZT': 'лв',
-    'TTD': 'TT$',
-    'MNT': '₮',
-    'USD': '$',
-    'UZS': 'лв',
-    'YER': '﷼',
-    'JPY': '¥',
-    'CNY': '元',
-    'ZWD': 'Z$',
-    'PLN': 'zł',
-}
-
-currencies = {
-    'EUR': {
-        'rounding': "Decimal('0.01')",
-        'digits': '2',
-        },
-    'GBP': {
-        'rounding': "Decimal('0.01')",
-        'digits': '2',
-        },
-    'CHF': {
-        'rounding': "Decimal('0.01')",
-        'digits': '2',
-        },
-    'USD': {
-        'rounding': "Decimal('0.01')",
-        'digits': '2',
-        },
-    'ARS': {
-        'rounding': "Decimal('0.01')",
-        'digits': '2',
-        },
-}
-
-sys.stdout.write('<?xml version="1.0"?>\n')
-sys.stdout.write('<tryton>\n')
-sys.stdout.write('    <data skiptest="1" grouped="1">\n')
-
-for currency in pycountry.currencies:
-    extend = ''
-    if currency.alpha_3 in currencies:
-        extend = '''
-            <field name="rounding" eval="%(rounding)s"/>
-            <field name="digits" eval="%(digits)s"/>''' % (
-                currencies[currency.alpha_3])
-    record = '''
-        <record model="currency.currency" id="%s">
-            <field name="name">%s</field>
-            <field name="code">%s</field>
-            <field name="numeric_code">%s</field>
-            <field name="symbol">%s</field>%s
-        </record>\n''' % (currency.alpha_3.lower(), currency.name,
-                currency.alpha_3, currency.numeric,
-                symbols.get(currency.alpha_3, currency.alpha_3), extend)
-    sys.stdout.write(record)
-
-sys.stdout.write('    </data>\n')
-sys.stdout.write('</tryton>\n')
diff -r 02664e9b5ec6 modules/currency/scripts/trytond_import_currencies
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/modules/currency/scripts/trytond_import_currencies	Wed Jul 24 18:28:49 2019 +0200
@@ -0,0 +1,105 @@
+#!/usr/bin/env python3
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
+import gettext
+import os
+import sys
+from argparse import ArgumentParser
+
+import pycountry
+from forex_python.converter import CurrencyCodes
+
+try:
+    from progressbar import ProgressBar, Bar, ETA, SimpleProgress
+except ImportError:
+    ProgressBar = None
+
+try:
+    from proteus import Model, config
+except ImportError:
+    prog = os.path.basename(sys.argv[0])
+    sys.exit("proteus must be installed to use %s" % prog)
+
+
+def _progress(iterable):
+    if ProgressBar:
+        pbar = ProgressBar(
+            widgets=[SimpleProgress(), Bar(), ETA()])
+    else:
+        pbar = iter
+    return pbar(iterable)
+
+
+def _get_language_codes():
+    Language = Model.get('ir.lang')
+    languages = Language.find([('translatable', '=', True)])
+    for l in languages:
+        yield l.code
+
+
+def get_currencies():
+    Currency = Model.get('currency.currency')
+
+    with config.get_config().set_context(active_test=False):
+        return {c.code: c for c in Currency.find([])}
+
+
+def update_currencies(currencies):
+    print("Update currencies")
+    Currency = Model.get('currency.currency')
+    codes = CurrencyCodes()
+
+    records = []
+    for currency in _progress(pycountry.currencies):
+        code = currency.alpha_3
+        if code in currencies:
+            record = currencies[code]
+        else:
+            record = Currency(code=code)
+        record.name = currency.name
+        record.numeric_code = currency.numeric
+        record.symbol = codes.get_symbol(currency.alpha_3) or currency.alpha_3
+        records.append(record)
+
+    Currency.save(records)
+    return {c.code: c for c in records}
+
+
+def translate_currencies(currencies):
+    Currency = Model.get('currency.currency')
+
+    current_config = config.get_config()
+    for code in _get_language_codes():
+        try:
+            gnutranslation = gettext.translation(
+                'iso4217', pycountry.LOCALES_DIR, languages=[code])
+        except IOError:
+            continue
+        print("Update currencies %s" % code)
+        with current_config.set_context(language=code):
+            records = []
+            for currency in _progress(pycountry.currencies):
+                record = Currency(currencies[currency.alpha_3].id)
+                record.name = gnutranslation.gettext(currency.name)
+                records.append(record)
+            Currency.save(records)
+
+
+def main(database, config_file=None):
+    config.set_trytond(database, config_file=config_file)
+
+    currencies = get_currencies()
+    currencies = update_currencies(currencies)
+    translate_currencies(currencies)
+
+
+if __name__ == '__main__':
+    parser = ArgumentParser()
+    parser.add_argument('-d', '--database', dest='database')
+    parser.add_argument('-c', '--config', dest='config_file',
+        help='the trytond config file')
+
+    args = parser.parse_args()
+    if not args.database:
+        parser.error('Missing database')
+    main(args.database, args.config_file)
diff -r 02664e9b5ec6 modules/currency/setup.py
--- a/modules/currency/setup.py	Mon May 06 15:03:00 2019 +0200
+++ b/modules/currency/setup.py	Wed Jul 24 18:28:49 2019 +0200
@@ -81,6 +81,9 @@
             + ['tryton.cfg', 'view/*.xml', 'locale/*.po', 'icons/*.svg',
             'tests/*.rst']),
         },
+    scripts=[
+        'scripts/trytond_import_currencies',
+        ],
     classifiers=[
         'Development Status :: 5 - Production/Stable',
         'Environment :: Plugins',
@@ -121,6 +124,10 @@
     license='GPL-3',
     python_requires='>=3.5',
     install_requires=requires,
+    extras_require={
+        'data': [
+            'pycountry', 'forex-python', get_require_version('proteus')],
+        },
     dependency_links=dependency_links,
     zip_safe=False,
     entry_points="""
diff -r 02664e9b5ec6 modules/currency/tryton.cfg
--- a/modules/currency/tryton.cfg	Mon May 06 15:03:00 2019 +0200
+++ b/modules/currency/tryton.cfg	Wed Jul 24 18:28:49 2019 +0200
@@ -4,6 +4,5 @@
     ir
     res
 xml:
-    data.xml
     currency.xml
     message.xml
diff -r f9adae254aac modules/party/CHANGELOG
--- a/modules/party/CHANGELOG	Thu Jun 06 10:10:38 2019 +0200
+++ b/modules/party/CHANGELOG	Wed Jul 24 18:28:49 2019 +0200
@@ -1,3 +1,4 @@
+* Replace country and language in address format by codes
 * Add sequence field to contact mechanism form view
 
 Version 5.2.0 - 2019-05-06
diff -r f9adae254aac modules/party/address.py
--- a/modules/party/address.py	Thu Jun 06 10:10:38 2019 +0200
+++ b/modules/party/address.py	Wed Jul 24 18:28:49 2019 +0200
@@ -3,8 +3,8 @@
 'Address'
 from string import Template
 
-from sql import Null
-from sql.conditionals import Case, Coalesce
+from sql.conditionals import Coalesce
+from sql.functions import Substring
 from sql.operators import Concat
 
 from trytond.i18n import gettext
@@ -225,8 +225,8 @@
 class AddressFormat(DeactivableMixin, MatchMixin, ModelSQL, ModelView):
     "Address Format"
     __name__ = 'party.address.format'
-    country = fields.Many2One('country.country', "Country")
-    language = fields.Many2One('ir.lang', "Language")
+    country_code = fields.Char("Country Code", size=2)
+    language_code = fields.Char("Language Code", size=2)
     format_ = fields.Text("Format", required=True,
         help="Available variables (also in upper case):\n"
         "- ${party_name}\n"
@@ -245,8 +245,42 @@
     @classmethod
     def __setup__(cls):
         super(AddressFormat, cls).__setup__()
-        cls._order.insert(0, ('country', 'ASC'))
-        cls._order.insert(1, ('language', 'ASC'))
+        cls._order.insert(0, ('country_code', 'ASC NULLS LAST'))
+        cls._order.insert(1, ('language_code', 'ASC NULLS LAST'))
+
+    @classmethod
+    def __register__(cls, module_name):
+        pool = Pool()
+        Country = pool.get('country.country')
+        Language = pool.get('ir.lang')
+        country = Country.__table__()
+        language = Language.__table__()
+        table = cls.__table__()
+        cursor = Transaction().connection.cursor()
+
+        super().__register__(module_name)
+
+        table_h = cls.__table_handler__()
+
+        # Migration from 5.2: replace country by country_code
+        if table_h.column_exist('country'):
+            query = table.update(
+                [table.country_code],
+                country.select(
+                    country.code,
+                    where=country.id == table.country))
+            cursor.execute(*query)
+            table_h.drop_column('country')
+
+        # Migration from 5.2: replace language by language_code
+        if table_h.column_exist('language'):
+            query = table.update(
+                [table.language_code],
+                language.select(
+                    Substring(language.code, 0, 2),
+                    where=language.id == table.language))
+            cursor.execute(*query)
+            table_h.drop_column('language')
 
     @classmethod
     def default_format_(cls):
@@ -257,11 +291,6 @@
 ${subdivision}
 ${COUNTRY}"""
 
-    @staticmethod
-    def order_language(tables):
-        table, _ = tables[None]
-        return [Case((table.language == Null, 1), else_=0), table.language]
-
     @classmethod
     def create(cls, *args, **kwargs):
         records = super(AddressFormat, cls).create(*args, **kwargs)
@@ -298,24 +327,13 @@
 
     @classmethod
     def get_format(cls, address, pattern=None):
-        pool = Pool()
-        Language = pool.get('ir.lang')
-
         if pattern is None:
             pattern = {}
         else:
             pattern = pattern.copy()
         pattern.setdefault(
-            'country', address.country.id if address.country else None)
-
-        languages = Language.search([
-                ('code', '=', Transaction().language),
-                ], limit=1)
-        if languages:
-            language, = languages
-        else:
-            language = None
-        pattern.setdefault('language', language.id if language else None)
+            'country_code', address.country.code if address.country else None)
+        pattern.setdefault('language', Transaction().language[:2])
 
         key = tuple(sorted(pattern.items()))
         format_ = cls._get_format_cache.get(key)
diff -r f9adae254aac modules/party/address.xml
--- a/modules/party/address.xml	Thu Jun 06 10:10:38 2019 +0200
+++ b/modules/party/address.xml	Wed Jul 24 18:28:49 2019 +0200
@@ -86,10 +86,10 @@
         </record>
 
     </data>
-    <data noupdate="1" grouped="1" skiptest="1">
+    <data noupdate="1" grouped="1">
         <!-- From https://en.wikipedia.org/wiki/Address_(geography) -->
         <record model="party.address.format" id="address_format_ar">
-            <field name="country" ref="country.ar"/>
+            <field name="country_code">AR</field>
             <field name="format_">${party_name}
 ${name}
 ${street}
@@ -99,7 +99,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_au">
-            <field name="country" ref="country.au"/>
+            <field name="country_code">AU</field>
             <field name="format_">${party_name}
 ${attn}
 ${name}
@@ -110,7 +110,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_at">
-            <field name="country" ref="country.at"/>
+            <field name="country_code">AT</field>
             <field name="format_">${party_name}
 ${attn}
 ${name}
@@ -120,7 +120,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_bd">
-            <field name="country" ref="country.bd"/>
+            <field name="country_code">BD</field>
             <field name="format_">${party_name}
 ${attn}
 ${name}
@@ -130,7 +130,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_by">
-            <field name="country" ref="country.by"/>
+            <field name="country_code">BY</field>
             <field name="format_">${party_name}
 ${name}
 ${street}
@@ -140,7 +140,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_be">
-            <field name="country" ref="country.be"/>
+            <field name="country_code">BE</field>
             <field name="format_">${attn}
 ${party_name}
 ${name}
@@ -150,7 +150,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_br">
-            <field name="country" ref="country.br"/>
+            <field name="country_code">BR</field>
             <field name="format_">${party_name}
 ${street}
 ${name}
@@ -160,8 +160,8 @@
         </record>
 
         <record model="party.address.format" id="address_format_ca_fr">
-            <field name="country" ref="country.ca"/>
-            <field name="language" ref="ir.lang_fr"/>
+            <field name="country_code">CA</field>
+            <field name="language_code">fr</field>
             <field name="format_">${attn}
 ${party_name}
 ${name}
@@ -171,7 +171,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ca">
-            <field name="country" ref="country.ca"/>
+            <field name="country_code">CA</field>
             <field name="format_">${ATTN}
 ${PARTY_NAME}
 ${NAME}
@@ -181,7 +181,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_cl">
-            <field name="country" ref="country.cl"/>
+            <field name="country_code">CL</field>
             <field name="format_">${party_name}
 ${street}
 ${name}
@@ -191,22 +191,22 @@
         </record>
 
         <record model="party.address.format" id="address_format_cn_zh_CN">
-            <field name="country" ref="country.cn"/>
-            <field name="language" ref="ir.lang_zh_CN"/>
+            <field name="country_code">CN</field>
+            <field name="language_code">zh</field>
             <field name="format_">${COUNTRY} ${ZIP}
 ${subdivision}${city}${street}${name}
 ${party_name}</field>
         </record>
 
         <record model="party.address.format" id="address_format_cn">
-            <field name="country" ref="country.cn"/>
+            <field name="country_code">CN</field>
             <field name="format_">${COUNTRY} ${ZIP}
 ${subdivision}, ${city}, ${street}, ${name}
 ${party_name}</field>
         </record>
 
         <record model="party.address.format" id="address_format_hr">
-            <field name="country" ref="country.hr"/>
+            <field name="country_code">HR</field>
             <field name="format_">${party_name}
 ${street}
 ${COUNTRY_CODE}-${ZIP} ${city}
@@ -214,7 +214,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_cz">
-            <field name="country" ref="country.cz"/>
+            <field name="country_code">CZ</field>
             <field name="format_">${party_name}
 ${attn}
 ${street}
@@ -223,7 +223,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_dk">
-            <field name="country" ref="country.dk"/>
+            <field name="country_code">DK</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${city}
@@ -231,7 +231,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ee">
-            <field name="country" ref="country.ee"/>
+            <field name="country_code">EE</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${city}
@@ -239,7 +239,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_fi">
-            <field name="country" ref="country.fi"/>
+            <field name="country_code">FI</field>
             <field name="format_">${attn}
 ${party_name}
 ${street}
@@ -248,7 +248,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_fr">
-            <field name="country" ref="country.fr"/>
+            <field name="country_code">FR</field>
             <field name="format_">${party_name}
 ${attn}
 ${name}
@@ -258,7 +258,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_de">
-            <field name="country" ref="country.de"/>
+            <field name="country_code">DE</field>
             <field name="format_">${party_name}
 ${attn}
 ${name}
@@ -268,7 +268,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_gr">
-            <field name="country" ref="country.gr"/>
+            <field name="country_code">GR</field>
             <field name="format_">${party_name}
 ${street}
 ${COUNTRY_CODE}-${ZIP} ${CITY}
@@ -276,7 +276,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_hk">
-            <field name="country" ref="country.hk"/>
+            <field name="country_code">HK</field>
             <field name="format_">${party_name}
 ${name}
 ${street}
@@ -285,7 +285,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_hu">
-            <field name="country" ref="country.hu"/>
+            <field name="country_code">HU</field>
             <field name="format_">${party_name}
 ${city}
 ${street}
@@ -294,7 +294,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_is">
-            <field name="country" ref="country.is"/>
+            <field name="country_code">IS</field>
             <field name="format_">${party_name}
 ${street}
 ${name}
@@ -303,7 +303,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_in">
-            <field name="country" ref="country.in"/>
+            <field name="country_code">IN</field>
             <field name="format_">${party_name}
 ${name}
 ${street}
@@ -313,7 +313,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_id">
-            <field name="country" ref="country.id"/>
+            <field name="country_code">ID</field>
             <field name="format_">${party_name}
 ${name}
 ${street}
@@ -323,7 +323,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ir">
-            <field name="country" ref="country.ir"/>
+            <field name="country_code">IR</field>
             <field name="format_">${party_name}
 ${name}
 ${city}
@@ -334,7 +334,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_iq">
-            <field name="country" ref="country.iq"/>
+            <field name="country_code">IQ</field>
             <field name="format_">${party_name}
 ${street}
 ${name}
@@ -344,7 +344,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ie">
-            <field name="country" ref="country.ie"/>
+            <field name="country_code">IE</field>
             <field name="format_">${party_name}
 ${street}
 ${city} ${zip}
@@ -352,7 +352,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_il">
-            <field name="country" ref="country.il"/>
+            <field name="country_code">IL</field>
             <field name="format_">${party_name}
 ${street}
 ${city} ${zip}
@@ -360,7 +360,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_it">
-            <field name="country" ref="country.it"/>
+            <field name="country_code">IT</field>
             <field name="format_">${party_name}
 ${attn}
 ${name}
@@ -369,38 +369,34 @@
 ${COUNTRY}</field>
         </record>
 
-        <!-- for Japan language
         <record model="party.address.format" id="address_format_jp_jp">
-            <field name="country" ref="country.jp"/>
-            <field name="language" ref="ir.lang_jp"/>
+            <field name="country_code">JP</field>
+            <field name="language_code">jp</field>
             <field name="format_">${COUNTRY}
 ${zip}
 ${subdivision}${city}${street}
 ${party_name}</field>
         </record>
-        -->
 
         <record model="party.address.format" id="address_format_jp">
-            <field name="country" ref="country.jp"/>
+            <field name="country_code">JP</field>
             <field name="format_">${party_name}
 ${street}
 ${city}, ${SUBDIVISION} ${zip}
 ${COUNTRY}</field>
         </record>
 
-        <!-- for Korean language
         <record model="party.address.format" id="address_format_kr_ko">
-            <field name="country" ref="country.kr"/>
-            <field name="language" ref="ir.lang_ko"/>
+            <field name="country_code">KR</field>
+            <field name="language_code">ko</field>
             <field name="format_">${COUNTRY}
 ${street}
 ${party_name}
 ${zip}</field>
         </record>
-        -->
 
         <record model="party.address.format" id="address_format_kr">
-            <field name="country" ref="country.kr"/>
+            <field name="country_code">KR</field>
             <field name="format_">${party_name}
 ${street}
 ${city}, ${subdivision} ${zip}
@@ -408,7 +404,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_lv">
-            <field name="country" ref="country.lv"/>
+            <field name="country_code">LV</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
@@ -418,8 +414,8 @@
         </record>
 
         <record model="party.address.format" id="address_format_mo_zh_CN">
-            <field name="country" ref="country.mo"/>
-            <field name="language" ref="ir.lang_zh_CN"/>
+            <field name="country_code">MO</field>
+            <field name="language_code">zh</field>
             <field name="format_">${COUNTRY}
 ${city}
 ${street}
@@ -427,7 +423,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_mo">
-            <field name="country" ref="country.mo"/>
+            <field name="country_code">MO</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
@@ -435,7 +431,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_my">
-            <field name="country" ref="country.my"/>
+            <field name="country_code">MY</field>
             <field name="format_">${attn}
 ${party_name}
 ${name}
@@ -446,7 +442,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_mx">
-            <field name="country" ref="country.mx"/>
+            <field name="country_code">MX</field>
             <field name="format_">${attn}
 ${party_name}
 ${street}
@@ -456,7 +452,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_nl">
-            <field name="country" ref="country.nl"/>
+            <field name="country_code">NL</field>
             <field name="format_">${party_name}
 ${attn}
 ${name}
@@ -466,7 +462,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_nz">
-            <field name="country" ref="country.nz"/>
+            <field name="country_code">NZ</field>
             <field name="format_">${party_name}
 ${street}
 ${city} ${zip}
@@ -474,7 +470,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_no">
-            <field name="country" ref="country.no"/>
+            <field name="country_code">NO</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${CITY}
@@ -482,7 +478,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_om">
-            <field name="country" ref="country.om"/>
+            <field name="country_code">OM</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
@@ -490,7 +486,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_pk">
-            <field name="country" ref="country.pk"/>
+            <field name="country_code">PK</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
@@ -500,7 +496,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_pe">
-            <field name="country" ref="country.pe"/>
+            <field name="country_code">PE</field>
             <field name="format_">${party_name}
 ${street}
 ${name}
@@ -510,7 +506,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ph">
-            <field name="country" ref="country.ph"/>
+            <field name="country_code">PH</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${CITY}
@@ -518,7 +514,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_pl">
-            <field name="country" ref="country.pl"/>
+            <field name="country_code">PL</field>
             <field name="format_">${attn} ${party_name}
 ${street}
 ${zip} ${city}
@@ -526,7 +522,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_pt">
-            <field name="country" ref="country.pt"/>
+            <field name="country_code">PT</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${city}
@@ -534,7 +530,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_qa">
-            <field name="country" ref="country.qa"/>
+            <field name="country_code">QA</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
@@ -542,7 +538,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ro">
-            <field name="country" ref="country.ro"/>
+            <field name="country_code">RO</field>
             <field name="format_">${attn} ${party_name}
 ${street}
 ${city}
@@ -551,7 +547,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ru">
-            <field name="country" ref="country.ru"/>
+            <field name="country_code">RU</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
@@ -561,7 +557,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_sa">
-            <field name="country" ref="country.sa"/>
+            <field name="country_code">SA</field>
             <field name="format_">${party_name}
 ${street}
 ${city} ${zip}
@@ -569,7 +565,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_rs">
-            <field name="country" ref="country.rs"/>
+            <field name="country_code">RS</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${city}
@@ -577,7 +573,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_sg">
-            <field name="country" ref="country.sg"/>
+            <field name="country_code">SG</field>
             <field name="format_">${party_name}
 ${street}
 ${name}
@@ -586,7 +582,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_sk">
-            <field name="country" ref="country.sk"/>
+            <field name="country_code">SK</field>
             <field name="format_">${attn}
 ${party_name}
 ${street}
@@ -595,7 +591,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_sl">
-            <field name="country" ref="country.sl"/>
+            <field name="country_code">SL</field>
             <field name="format_">${party_name}
 ${attn}
 ${street}
@@ -604,7 +600,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_es">
-            <field name="country" ref="country.es"/>
+            <field name="country_code">ES</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${city}
@@ -613,7 +609,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_lk">
-            <field name="country" ref="country.lk"/>
+            <field name="country_code">LK</field>
             <field name="format_">${party_name}
 ${street}
 ${CITY}
@@ -622,7 +618,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_se">
-            <field name="country" ref="country.se"/>
+            <field name="country_code">SE</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${city}
@@ -630,7 +626,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ch">
-            <field name="country" ref="country.ch"/>
+            <field name="country_code">CH</field>
             <field name="format_">${party_name}
 ${street}
 ${zip} ${city}
@@ -638,8 +634,8 @@
         </record>
 
         <record model="party.address.format" id="address_format_tw_zh_CN">
-            <field name="country" ref="country.tw"/>
-            <field name="language" ref="ir.lang_zh_CN"/>
+            <field name="country_code">TW</field>
+            <field name="language_code">zh</field>
             <field name="format_">${COUNTRY}
 ${zip}
 ${street}
@@ -647,7 +643,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_tw">
-            <field name="country" ref="country.tw"/>
+            <field name="country_code">TW</field>
             <field name="format_">${party_name}
 ${street}
 ${city}, ${subdivision} ${zip}
@@ -655,7 +651,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_th">
-            <field name="country" ref="country.th"/>
+            <field name="country_code">TH</field>
             <field name="format_">${party_name}
 ${street}
 ${name}
@@ -665,7 +661,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_tr">
-            <field name="country" ref="country.tr"/>
+            <field name="country_code">TR</field>
             <field name="format_">${party_name}
 ${attn}
 ${street}
@@ -675,7 +671,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_ua">
-            <field name="country" ref="country.ua"/>
+            <field name="country_code">UA</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
@@ -685,7 +681,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_gb">
-            <field name="country" ref="country.gb"/>
+            <field name="country_code">GB</field>
             <field name="format_">${party_name}
 ${street}
 ${CITY}
@@ -694,7 +690,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_us">
-            <field name="country" ref="country.us"/>
+            <field name="country_code">US</field>
             <field name="format_">${attn}
 ${party_name}
 ${street}
@@ -703,7 +699,7 @@
         </record>
 
         <record model="party.address.format" id="address_format_vn">
-            <field name="country" ref="country.vn"/>
+            <field name="country_code">VN</field>
             <field name="format_">${party_name}
 ${street}
 ${city}
diff -r f9adae254aac modules/party/view/address_format_form.xml
--- a/modules/party/view/address_format_form.xml	Thu Jun 06 10:10:38 2019 +0200
+++ b/modules/party/view/address_format_form.xml	Wed Jul 24 18:28:49 2019 +0200
@@ -1,11 +1,11 @@
 <?xml version="1.0"?>
 <form>
-    <label name="country"/>
-    <field name="country"/>
+    <label name="country_code"/>
+    <field name="country_code"/>
     <label name="active"/>
     <field name="active"/>
-    <label name="language"/>
-    <field name="language"/>
+    <label name="language_code"/>
+    <field name="language_code"/>
     <separator name="format_" colspan="4"/>
     <field name="format_" colspan="4"/>
 </form>
diff -r f9adae254aac modules/party/view/address_format_list.xml
--- a/modules/party/view/address_format_list.xml	Thu Jun 06 10:10:38 2019 +0200
+++ b/modules/party/view/address_format_list.xml	Wed Jul 24 18:28:49 2019 +0200
@@ -1,5 +1,5 @@
 <?xml version="1.0"?>
 <tree>
-    <field name="country"/>
-    <field name="language"/>
+    <field name="country_code"/>
+    <field name="language_code"/>
 </tree>
